/*
 *
 * Wijmo Library 2.0.3
 * http://wijmo.com/
 *
 * Copyright(c) ComponentOne, LLC.  All rights reserved.
 * 
 * Dual licensed under the Wijmo Commercial or GNU GPL Version 3 licenses.
 * licensing@wijmo.com
 * http://wijmo.com/license
 *
 *
 **/
/**
 * Cookie plugin
 *
 * Copyright (c) 2006 Klaus Hartl (stilbuero.de)
 * Dual licensed under the MIT and GPL licenses:
 * http://www.opensource.org/licenses/mit-license.php
 * http://www.gnu.org/licenses/gpl.html
 *
 */

/**
 * Create a cookie with the given name and value and other optional parameters.
 *
 * @example $.cookie('the_cookie', 'the_value');
 * @desc Set the value of a cookie.
 * @example $.cookie('the_cookie', 'the_value', { expires: 7, path: '/', domain: 'jquery.com', secure: true });
 * @desc Create a cookie with all available options.
 * @example $.cookie('the_cookie', 'the_value');
 * @desc Create a session cookie.
 * @example $.cookie('the_cookie', null);
 * @desc Delete a cookie by passing null as value. Keep in mind that you have to use the same path and domain
 *       used when the cookie was set.
 *
 * @param String name The name of the cookie.
 * @param String value The value of the cookie.
 * @param Object options An object literal containing key/value pairs to provide optional cookie attributes.
 * @option Number|Date expires Either an integer specifying the expiration date from now on in days or a Date object.
 *                             If a negative value is specified (e.g. a date in the past), the cookie will be deleted.
 *                             If set to null or omitted, the cookie will be a session cookie and will not be retained
 *                             when the the browser exits.
 * @option String path The value of the path atribute of the cookie (default: path of page that created the cookie).
 * @option String domain The value of the domain attribute of the cookie (default: domain of page that created the cookie).
 * @option Boolean secure If true, the secure attribute of the cookie will be set and the cookie transmission will
 *                        require a secure protocol (like HTTPS).
 * @type undefined
 *
 * @name $.cookie
 * @cat Plugins/Cookie
 * @author Klaus Hartl/klaus.hartl@stilbuero.de
 */

/**
 * Get the value of a cookie with the given name.
 *
 * @example $.cookie('the_cookie');
 * @desc Get the value of a cookie.
 *
 * @param String name The name of the cookie.
 * @return The value of the cookie.
 * @type String
 *
 * @name $.cookie
 * @cat Plugins/Cookie
 * @author Klaus Hartl/klaus.hartl@stilbuero.de
 */
jQuery.cookie = function(name, value, options) {
    if (typeof value != 'undefined') { // name and value given, set cookie
        options = options || {};
        if (value === null) {
            value = '';
            options.expires = -1;
        }
        var expires = '';
        if (options.expires && (typeof options.expires == 'number' || options.expires.toUTCString)) {
            var date;
            if (typeof options.expires == 'number') {
                date = new Date();
                date.setTime(date.getTime() + (options.expires * 24 * 60 * 60 * 1000));
            } else {
                date = options.expires;
            }
            expires = '; expires=' + date.toUTCString(); // use expires attribute, max-age is not supported by IE
        }
        // CAUTION: Needed to parenthesize options.path and options.domain
        // in the following expressions, otherwise they evaluate to undefined
        // in the packed version for some reason...
        var path = options.path ? '; path=' + (options.path) : '';
        var domain = options.domain ? '; domain=' + (options.domain) : '';
        var secure = options.secure ? '; secure' : '';
        document.cookie = [name, '=', encodeURIComponent(value), expires, path, domain, secure].join('');
    } else { // only name given, get cookie
        var cookieValue = null;
        if (document.cookie && document.cookie != '') {
            var cookies = document.cookie.split(';');
            for (var i = 0; i < cookies.length; i++) {
                var cookie = jQuery.trim(cookies[i]);
                // Does this cookie string begin with the name we want?
                if (cookie.substring(0, name.length + 1) == (name + '=')) {
                    cookieValue = decodeURIComponent(cookie.substring(name.length + 1));
                    break;
                }
            }
        }
        return cookieValue;
    }
};
// ┌─────────────────────────────────────────────────────────────────────┐ \\
// │ Raphaël 2.0.1 - JavaScript Vector Library                           │ \\
// ├─────────────────────────────────────────────────────────────────────┤ \\
// │ Copyright (c) 2008-2011 Dmitry Baranovskiy (http://raphaeljs.com)   │ \\
// │ Copyright (c) 2008-2011 Sencha Labs (http://sencha.com)             │ \\
// │ Licensed under the MIT (http://raphaeljs.com/license.html) license. │ \\
// └─────────────────────────────────────────────────────────────────────┘ \\
(function(a){var b="0.4.0",c="hasOwnProperty",d=/[\.\/]/,e="*",f=function(){},g=function(a,b){return a-b},h,i,j={n:{}},k=function(a,b){var c=j,d=i,e=Array.prototype.slice.call(arguments,2),f=k.listeners(a),l=0,m=!1,n,o=[],p={},q=[],r=[];h=a,i=0;for(var s=0,t=f.length;s<t;s++)"zIndex"in f[s]&&(o.push(f[s].zIndex),f[s].zIndex<0&&(p[f[s].zIndex]=f[s]));o.sort(g);while(o[l]<0){n=p[o[l++]],q.push(n.apply(b,e));if(i){i=d;return q}}for(s=0;s<t;s++){n=f[s];if("zIndex"in n)if(n.zIndex==o[l]){q.push(n.apply(b,e));if(i){i=d;return q}do{l++,n=p[o[l]],n&&q.push(n.apply(b,e));if(i){i=d;return q}}while(n)}else p[n.zIndex]=n;else{q.push(n.apply(b,e));if(i){i=d;return q}}}i=d;return q.length?q:null};k.listeners=function(a){var b=a.split(d),c=j,f,g,h,i,k,l,m,n,o=[c],p=[];for(i=0,k=b.length;i<k;i++){n=[];for(l=0,m=o.length;l<m;l++){c=o[l].n,g=[c[b[i]],c[e]],h=2;while(h--)f=g[h],f&&(n.push(f),p=p.concat(f.f||[]))}o=n}return p},k.on=function(a,b){var c=a.split(d),e=j;for(var g=0,h=c.length;g<h;g++)e=e.n,!e[c[g]]&&(e[c[g]]={n:{}}),e=e[c[g]];e.f=e.f||[];for(g=0,h=e.f.length;g<h;g++)if(e.f[g]==b)return f;e.f.push(b);return function(a){+a==+a&&(b.zIndex=+a)}},k.stop=function(){i=1},k.nt=function(a){if(a)return(new RegExp("(?:\\.|\\/|^)"+a+"(?:\\.|\\/|$)")).test(h);return h},k.unbind=function(a,b){var f=a.split(d),g,h,i,k,l,m,n,o=[j];for(k=0,l=f.length;k<l;k++)for(m=0;m<o.length;m+=i.length-2){i=[m,1],g=o[m].n;if(f[k]!=e)g[f[k]]&&i.push(g[f[k]]);else for(h in g)g[c](h)&&i.push(g[h]);o.splice.apply(o,i)}for(k=0,l=o.length;k<l;k++){g=o[k];while(g.n){if(b){if(g.f){for(m=0,n=g.f.length;m<n;m++)if(g.f[m]==b){g.f.splice(m,1);break}!g.f.length&&delete g.f}for(h in g.n)if(g.n[c](h)&&g.n[h].f){var p=g.n[h].f;for(m=0,n=p.length;m<n;m++)if(p[m]==b){p.splice(m,1);break}!p.length&&delete g.n[h].f}}else{delete g.f;for(h in g.n)g.n[c](h)&&g.n[h].f&&delete g.n[h].f}g=g.n}}},k.once=function(a,b){var c=function(){b.apply(this,arguments),k.unbind(a,c)};return k.on(a,c)},k.version=b,k.toString=function(){return"You are running Eve "+b},typeof module!="undefined"&&module.exports?module.exports=k:a.eve=k})(this),function(){function cr(b,d,e,f,h,i){e=Q(e);var j,k,l,m=[],o,p,q,t=b.ms,u={},v={},w={};if(f)for(y=0,z=cl.length;y<z;y++){var x=cl[y];if(x.el.id==d.id&&x.anim==b){x.percent!=e?(cl.splice(y,1),l=1):k=x,d.attr(x.totalOrigin);break}}else f=+v;for(var y=0,z=b.percents.length;y<z;y++){if(b.percents[y]==e||b.percents[y]>f*b.top){e=b.percents[y],p=b.percents[y-1]||0,t=t/b.top*(e-p),o=b.percents[y+1],j=b.anim[e];break}f&&d.attr(b.anim[b.percents[y]])}if(!!j){if(!k){for(var A in j)if(j[g](A))if(U[g](A)||d.paper.customAttributes[g](A)){u[A]=d.attr(A),u[A]==null&&(u[A]=T[A]),v[A]=j[A];switch(U[A]){case C:w[A]=(v[A]-u[A])/t;break;case"colour":u[A]=a.getRGB(u[A]);var B=a.getRGB(v[A]);w[A]={r:(B.r-u[A].r)/t,g:(B.g-u[A].g)/t,b:(B.b-u[A].b)/t};break;case"path":var D=bG(u[A],v[A]),E=D[1];u[A]=D[0],w[A]=[];for(y=0,z=u[A].length;y<z;y++){w[A][y]=[0];for(var F=1,G=u[A][y].length;F<G;F++)w[A][y][F]=(E[y][F]-u[A][y][F])/t}break;case"transform":var H=d._,I=bP(H[A],v[A]);if(I){u[A]=I.from,v[A]=I.to,w[A]=[],w[A].real=!0;for(y=0,z=u[A].length;y<z;y++){w[A][y]=[u[A][y][0]];for(F=1,G=u[A][y].length;F<G;F++)w[A][y][F]=(v[A][y][F]-u[A][y][F])/t}}else{var J=d.matrix||new bQ,K={_:{transform:H.transform},getBBox:function(){return d.getBBox(1)}};u[A]=[J.a,J.b,J.c,J.d,J.e,J.f],bN(K,v[A]),v[A]=K._.transform,w[A]=[(K.matrix.a-J.a)/t,(K.matrix.b-J.b)/t,(K.matrix.c-J.c)/t,(K.matrix.d-J.d)/t,(K.matrix.e-J.e)/t,(K.matrix.e-J.f)/t]}break;case"csv":var L=r(j[A])[s](c),M=r(u[A])[s](c);if(A=="clip-rect"){u[A]=M,w[A]=[],y=M.length;while(y--)w[A][y]=(L[y]-u[A][y])/t}v[A]=L;break;default:L=[][n](j[A]),M=[][n](u[A]),w[A]=[],y=d.paper.customAttributes[A].length;while(y--)w[A][y]=((L[y]||0)-(M[y]||0))/t}}var O=j.easing,P=a.easing_formulas[O];if(!P){P=r(O).match(N);if(P&&P.length==5){var R=P;P=function(a){return cp(a,+R[1],+R[2],+R[3],+R[4],t)}}else P=be}q=j.start||b.start||+(new Date),x={anim:b,percent:e,timestamp:q,start:q+(b.del||0),status:0,initstatus:f||0,stop:!1,ms:t,easing:P,from:u,diff:w,to:v,el:d,callback:j.callback,prev:p,next:o,repeat:i||b.times,origin:d.attr(),totalOrigin:h},cl.push(x);if(f&&!k&&!l){x.stop=!0,x.start=new Date-t*f;if(cl.length==1)return cn()}l&&(x.start=new Date-x.ms*f),cl.length==1&&cm(cn)}else k.initstatus=f,k.start=new Date-k.ms*f;eve("anim.start."+d.id,d,b)}}function cq(a,b){var c=[],d={};this.ms=b,this.times=1;if(a){for(var e in a)a[g](e)&&(d[Q(e)]=a[e],c.push(Q(e)));c.sort(bc)}this.anim=d,this.top=c[c.length-1],this.percents=c}function cp(a,b,c,d,e,f){function o(a,b){var c,d,e,f,j,k;for(e=a,k=0;k<8;k++){f=m(e)-a;if(z(f)<b)return e;j=(3*i*e+2*h)*e+g;if(z(j)<1e-6)break;e=e-f/j}c=0,d=1,e=a;if(e<c)return c;if(e>d)return d;while(c<d){f=m(e);if(z(f-a)<b)return e;a>f?c=e:d=e,e=(d-c)/2+c}return e}function n(a,b){var c=o(a,b);return((l*c+k)*c+j)*c}function m(a){return((i*a+h)*a+g)*a}var g=3*b,h=3*(d-b)-g,i=1-g-h,j=3*c,k=3*(e-c)-j,l=1-j-k;return n(a,1/(200*f))}function cd(){return this.x+q+this.y+q+this.width+" × "+this.height}function cc(){return this.x+q+this.y}function bQ(a,b,c,d,e,f){a!=null?(this.a=+a,this.b=+b,this.c=+c,this.d=+d,this.e=+e,this.f=+f):(this.a=1,this.b=0,this.c=0,this.d=1,this.e=0,this.f=0)}function bw(a){var b=[];for(var c=0,d=a.length;d-2>c;c+=2){var e=[{x:+a[c],y:+a[c+1]},{x:+a[c],y:+a[c+1]},{x:+a[c+2],y:+a[c+3]},{x:+a[c+4],y:+a[c+5]}];d-4==c?(e[0]={x:+a[c-2],y:+a[c-1]},e[3]=e[2]):c&&(e[0]={x:+a[c-2],y:+a[c-1]}),b.push(["C",(-e[0].x+6*e[1].x+e[2].x)/6,(-e[0].y+6*e[1].y+e[2].y)/6,(e[1].x+6*e[2].x-e[3].x)/6,(e[1].y+6*e[2].y-e[3].y)/6,e[2].x,e[2].y])}return b}function bv(){return this.hex}function bt(a,b,c){function d(){var e=Array.prototype.slice.call(arguments,0),f=e.join("␀"),h=d.cache=d.cache||{},i=d.count=d.count||[];if(h[g](f)){bs(i,f);return c?c(h[f]):h[f]}i.length>=1e3&&delete h[i.shift()],i.push(f),h[f]=a[m](b,e);return c?c(h[f]):h[f]}return d}function bs(a,b){for(var c=0,d=a.length;c<d;c++)if(a[c]===b)return a.push(a.splice(c,1)[0])}function a(c){if(a.is(c,"function"))return b?c():eve.on("DOMload",c);if(a.is(c,E))return a._engine.create[m](a,c.splice(0,3+a.is(c[0],C))).add(c);var d=Array.prototype.slice.call(arguments,0);if(a.is(d[d.length-1],"function")){var e=d.pop();return b?e.call(a._engine.create[m](a,d)):eve.on("DOMload",function(){e.call(a._engine.create[m](a,d))})}return a._engine.create[m](a,arguments)}a.version="2.0.1",a.eve=eve;var b,c=/[, ]+/,d={circle:1,rect:1,path:1,ellipse:1,text:1,image:1},e=/\{(\d+)\}/g,f="prototype",g="hasOwnProperty",h={doc:document,win:window},i={was:Object.prototype[g].call(h.win,"Raphael"),is:h.win.Raphael},j=function(){this.ca=this.customAttributes={}},k,l="appendChild",m="apply",n="concat",o="createTouch"in h.doc,p="",q=" ",r=String,s="split",t="click dblclick mousedown mousemove mouseout mouseover mouseup touchstart touchmove touchend touchcancel"[s](q),u={mousedown:"touchstart",mousemove:"touchmove",mouseup:"touchend"},v=r.prototype.toLowerCase,w=Math,x=w.max,y=w.min,z=w.abs,A=w.pow,B=w.PI,C="number",D="string",E="array",F="toString",G="fill",H=Object.prototype.toString,I={},J="push",K=a._ISURL=/^url\(['"]?([^\)]+?)['"]?\)$/i,L=/^\s*((#[a-f\d]{6})|(#[a-f\d]{3})|rgba?\(\s*([\d\.]+%?\s*,\s*[\d\.]+%?\s*,\s*[\d\.]+%?(?:\s*,\s*[\d\.]+%?)?)\s*\)|hsba?\(\s*([\d\.]+(?:deg|\xb0|%)?\s*,\s*[\d\.]+%?\s*,\s*[\d\.]+(?:%?\s*,\s*[\d\.]+)?)%?\s*\)|hsla?\(\s*([\d\.]+(?:deg|\xb0|%)?\s*,\s*[\d\.]+%?\s*,\s*[\d\.]+(?:%?\s*,\s*[\d\.]+)?)%?\s*\))\s*$/i,M={NaN:1,Infinity:1,"-Infinity":1},N=/^(?:cubic-)?bezier\(([^,]+),([^,]+),([^,]+),([^\)]+)\)/,O=w.round,P="setAttribute",Q=parseFloat,R=parseInt,S=r.prototype.toUpperCase,T=a._availableAttrs={"arrow-end":"none","arrow-start":"none",blur:0,"clip-rect":"0 0 1e9 1e9",cursor:"default",cx:0,cy:0,fill:"#fff","fill-opacity":1,font:'10px "Arial"',"font-family":'"Arial"',"font-size":"10","font-style":"normal","font-weight":400,gradient:0,height:0,href:"http://raphaeljs.com/","letter-spacing":0,opacity:1,path:"M0,0",r:0,rx:0,ry:0,src:"",stroke:"#000","stroke-dasharray":"","stroke-linecap":"butt","stroke-linejoin":"butt","stroke-miterlimit":0,"stroke-opacity":1,"stroke-width":1,target:"_blank","text-anchor":"middle",title:"Raphael",transform:"",width:0,x:0,y:0},U=a._availableAnimAttrs={blur:C,"clip-rect":"csv",cx:C,cy:C,fill:"colour","fill-opacity":C,"font-size":C,height:C,opacity:C,path:"path",r:C,rx:C,ry:C,stroke:"colour","stroke-opacity":C,"stroke-width":C,transform:"transform",width:C,x:C,y:C},V=/\s*,\s*/,W={hs:1,rg:1},X=/,?([achlmqrstvxz]),?/gi,Y=/([achlmrqstvz])[\s,]*((-?\d*\.?\d*(?:e[\-+]?\d+)?\s*,?\s*)+)/ig,Z=/([rstm])[\s,]*((-?\d*\.?\d*(?:e[\-+]?\d+)?\s*,?\s*)+)/ig,$=/(-?\d*\.?\d*(?:e[\-+]?\d+)?)\s*,?\s*/ig,_=a._radial_gradient=/^r(?:\(([^,]+?)\s*,\s*([^\)]+?)\))?/,ba={},bb=function(a,b){return a.key-b.key},bc=function(a,b){return Q(a)-Q(b)},bd=function(){},be=function(a){return a},bf=a._rectPath=function(a,b,c,d,e){if(e)return[["M",a+e,b],["l",c-e*2,0],["a",e,e,0,0,1,e,e],["l",0,d-e*2],["a",e,e,0,0,1,-e,e],["l",e*2-c,0],["a",e,e,0,0,1,-e,-e],["l",0,e*2-d],["a",e,e,0,0,1,e,-e],["z"]];return[["M",a,b],["l",c,0],["l",0,d],["l",-c,0],["z"]]},bg=function(a,b,c,d){d==null&&(d=c);return[["M",a,b],["m",0,-d],["a",c,d,0,1,1,0,2*d],["a",c,d,0,1,1,0,-2*d],["z"]]},bh=a._getPath={path:function(a){return a.attr("path")},circle:function(a){var b=a.attrs;return bg(b.cx,b.cy,b.r)},ellipse:function(a){var b=a.attrs;return bg(b.cx,b.cy,b.rx,b.ry)},rect:function(a){var b=a.attrs;return bf(b.x,b.y,b.width,b.height,b.r)},image:function(a){var b=a.attrs;return bf(b.x,b.y,b.width,b.height)},text:function(a){var b=a._getBBox();return bf(b.x,b.y,b.width,b.height)}},bi=a.mapPath=function(a,b){if(!b)return a;var c,d,e,f,g,h,i;a=bG(a);for(e=0,g=a.length;e<g;e++){i=a[e];for(f=1,h=i.length;f<h;f+=2)c=b.x(i[f],i[f+1]),d=b.y(i[f],i[f+1]),i[f]=c,i[f+1]=d}return a};a._g=h,a.type=h.win.SVGAngle||h.doc.implementation.hasFeature("http://www.w3.org/TR/SVG11/feature#BasicStructure","1.1")?"SVG":"VML";if(a.type=="VML"){var bj=h.doc.createElement("div"),bk;bj.innerHTML='<v:shape adj="1"/>',bk=bj.firstChild,bk.style.behavior="url(#default#VML)";if(!bk||typeof bk.adj!="object")return a.type=p;bj=null}a.svg=!(a.vml=a.type=="VML"),a._Paper=j,a.fn=k=j.prototype=a.prototype,a._id=0,a._oid=0,a.is=function(a,b){b=v.call(b);if(b=="finite")return!M[g](+a);if(b=="array")return a instanceof Array;return b=="null"&&a===null||b==typeof a&&a!==null||b=="object"&&a===Object(a)||b=="array"&&Array.isArray&&Array.isArray(a)||H.call(a).slice(8,-1).toLowerCase()==b},a.angle=function(b,c,d,e,f,g){if(f==null){var h=b-d,i=c-e;if(!h&&!i)return 0;return(180+w.atan2(-i,-h)*180/B+360)%360}return a.angle(b,c,f,g)-a.angle(d,e,f,g)},a.rad=function(a){return a%360*B/180},a.deg=function(a){return a*180/B%360},a.snapTo=function(b,c,d){d=a.is(d,"finite")?d:10;if(a.is(b,E)){var e=b.length;while(e--)if(z(b[e]-c)<=d)return b[e]}else{b=+b;var f=c%b;if(f<d)return c-f;if(f>b-d)return c-f+b}return c};var bl=a.createUUID=function(a,b){return function(){return"xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx".replace(a,b).toUpperCase()}}(/[xy]/g,function(a){var b=w.random()*16|0,c=a=="x"?b:b&3|8;return c.toString(16)});a.setWindow=function(b){eve("setWindow",a,h.win,b),h.win=b,h.doc=h.win.document,a._engine.initWin&&a._engine.initWin(h.win)};var bm=function(b){if(a.vml){var c=/^\s+|\s+$/g,d;try{var e=new ActiveXObject("htmlfile");e.write("<body>"),e.close(),d=e.body}catch(f){d=createPopup().document.body}var g=d.createTextRange();bm=bt(function(a){try{d.style.color=r(a).replace(c,p);var b=g.queryCommandValue("ForeColor");b=(b&255)<<16|b&65280|(b&16711680)>>>16;return"#"+("000000"+b.toString(16)).slice(-6)}catch(e){return"none"}})}else{var i=h.doc.createElement("i");i.title="Raphaël Colour Picker",i.style.display="none",h.doc.body.appendChild(i),bm=bt(function(a){i.style.color=a;return h.doc.defaultView.getComputedStyle(i,p).getPropertyValue("color")})}return bm(b)},bn=function(){return"hsb("+[this.h,this.s,this.b]+")"},bo=function(){return"hsl("+[this.h,this.s,this.l]+")"},bp=function(){return this.hex},bq=function(b,c,d){c==null&&a.is(b,"object")&&"r"in b&&"g"in b&&"b"in b&&(d=b.b,c=b.g,b=b.r);if(c==null&&a.is(b,D)){var e=a.getRGB(b);b=e.r,c=e.g,d=e.b}if(b>1||c>1||d>1)b/=255,c/=255,d/=255;return[b,c,d]},br=function(b,c,d,e){b*=255,c*=255,d*=255;var f={r:b,g:c,b:d,hex:a.rgb(b,c,d),toString:bp};a.is(e,"finite")&&(f.opacity=e);return f};a.color=function(b){var c;a.is(b,"object")&&"h"in b&&"s"in b&&"b"in b?(c=a.hsb2rgb(b),b.r=c.r,b.g=c.g,b.b=c.b,b.hex=c.hex):a.is(b,"object")&&"h"in b&&"s"in b&&"l"in b?(c=a.hsl2rgb(b),b.r=c.r,b.g=c.g,b.b=c.b,b.hex=c.hex):(a.is(b,"string")&&(b=a.getRGB(b)),a.is(b,"object")&&"r"in b&&"g"in b&&"b"in b?(c=a.rgb2hsl(b),b.h=c.h,b.s=c.s,b.l=c.l,c=a.rgb2hsb(b),b.v=c.b):(b={hex:"none"},b.r=b.g=b.b=b.h=b.s=b.v=b.l=-1)),b.toString=bp;return b},a.hsb2rgb=function(a,b,c,d){this.is(a,"object")&&"h"in a&&"s"in a&&"b"in a&&(c=a.b,b=a.s,a=a.h,d=a.o),a*=360;var e,f,g,h,i;a=a%360/60,i=c*b,h=i*(1-z(a%2-1)),e=f=g=c-i,a=~~a,e+=[i,h,0,0,h,i][a],f+=[h,i,i,h,0,0][a],g+=[0,0,h,i,i,h][a];return br(e,f,g,d)},a.hsl2rgb=function(a,b,c,d){this.is(a,"object")&&"h"in a&&"s"in a&&"l"in a&&(c=a.l,b=a.s,a=a.h);if(a>1||b>1||c>1)a/=360,b/=100,c/=100;a*=360;var e,f,g,h,i;a=a%360/60,i=2*b*(c<.5?c:1-c),h=i*(1-z(a%2-1)),e=f=g=c-i/2,a=~~a,e+=[i,h,0,0,h,i][a],f+=[h,i,i,h,0,0][a],g+=[0,0,h,i,i,h][a];return br(e,f,g,d)},a.rgb2hsb=function(a,b,c){c=bq(a,b,c),a=c[0],b=c[1],c=c[2];var d,e,f,g;f=x(a,b,c),g=f-y(a,b,c),d=g==0?null:f==a?(b-c)/g:f==b?(c-a)/g+2:(a-b)/g+4,d=(d+360)%6*60/360,e=g==0?0:g/f;return{h:d,s:e,b:f,toString:bn}},a.rgb2hsl=function(a,b,c){c=bq(a,b,c),a=c[0],b=c[1],c=c[2];var d,e,f,g,h,i;g=x(a,b,c),h=y(a,b,c),i=g-h,d=i==0?null:g==a?(b-c)/i:g==b?(c-a)/i+2:(a-b)/i+4,d=(d+360)%6*60/360,f=(g+h)/2,e=i==0?0:f<.5?i/(2*f):i/(2-2*f);return{h:d,s:e,l:f,toString:bo}},a._path2string=function(){return this.join(",").replace(X,"$1")};var bu=a._preload=function(a,b){var c=h.doc.createElement("img");c.style.cssText="position:absolute;left:-9999em;top:-9999em",c.onload=function(){b.call(this),this.onload=null,h.doc.body.removeChild(this)},c.onerror=function(){h.doc.body.removeChild(this)},h.doc.body.appendChild(c),c.src=a};a.getRGB=bt(function(b){if(!b||!!((b=r(b)).indexOf("-")+1))return{r:-1,g:-1,b:-1,hex:"none",error:1,toString:bv};if(b=="none")return{r:-1,g:-1,b:-1,hex:"none",toString:bv};!W[g](b.toLowerCase().substring(0,2))&&b.charAt()!="#"&&(b=bm(b));var c,d,e,f,h,i,j,k=b.match(L);if(k){k[2]&&(f=R(k[2].substring(5),16),e=R(k[2].substring(3,5),16),d=R(k[2].substring(1,3),16)),k[3]&&(f=R((i=k[3].charAt(3))+i,16),e=R((i=k[3].charAt(2))+i,16),d=R((i=k[3].charAt(1))+i,16)),k[4]&&(j=k[4][s](V),d=Q(j[0]),j[0].slice(-1)=="%"&&(d*=2.55),e=Q(j[1]),j[1].slice(-1)=="%"&&(e*=2.55),f=Q(j[2]),j[2].slice(-1)=="%"&&(f*=2.55),k[1].toLowerCase().slice(0,4)=="rgba"&&(h=Q(j[3])),j[3]&&j[3].slice(-1)=="%"&&(h/=100));if(k[5]){j=k[5][s](V),d=Q(j[0]),j[0].slice(-1)=="%"&&(d*=2.55),e=Q(j[1]),j[1].slice(-1)=="%"&&(e*=2.55),f=Q(j[2]),j[2].slice(-1)=="%"&&(f*=2.55),(j[0].slice(-3)=="deg"||j[0].slice(-1)=="°")&&(d/=360),k[1].toLowerCase().slice(0,4)=="hsba"&&(h=Q(j[3])),j[3]&&j[3].slice(-1)=="%"&&(h/=100);return a.hsb2rgb(d,e,f,h)}if(k[6]){j=k[6][s](V),d=Q(j[0]),j[0].slice(-1)=="%"&&(d*=2.55),e=Q(j[1]),j[1].slice(-1)=="%"&&(e*=2.55),f=Q(j[2]),j[2].slice(-1)=="%"&&(f*=2.55),(j[0].slice(-3)=="deg"||j[0].slice(-1)=="°")&&(d/=360),k[1].toLowerCase().slice(0,4)=="hsla"&&(h=Q(j[3])),j[3]&&j[3].slice(-1)=="%"&&(h/=100);return a.hsl2rgb(d,e,f,h)}k={r:d,g:e,b:f,toString:bv},k.hex="#"+(16777216|f|e<<8|d<<16).toString(16).slice(1),a.is(h,"finite")&&(k.opacity=h);return k}return{r:-1,g:-1,b:-1,hex:"none",error:1,toString:bv}},a),a.hsb=bt(function(b,c,d){return a.hsb2rgb(b,c,d).hex}),a.hsl=bt(function(b,c,d){return a.hsl2rgb(b,c,d).hex}),a.rgb=bt(function(a,b,c){return"#"+(16777216|c|b<<8|a<<16).toString(16).slice(1)}),a.getColor=function(a){var b=this.getColor.start=this.getColor.start||{h:0,s:1,b:a||.75},c=this.hsb2rgb(b.h,b.s,b.b);b.h+=.075,b.h>1&&(b.h=0,b.s-=.2,b.s<=0&&(this.getColor.start={h:0,s:1,b:b.b}));return c.hex},a.getColor.reset=function(){delete this.start},a.parsePathString=bt(function(b){if(!b)return null;var c={a:7,c:6,h:1,l:2,m:2,r:4,q:4,s:4,t:2,v:1,z:0},d=[];a.is(b,E)&&a.is(b[0],E)&&(d=by(b)),d.length||r(b).replace(Y,function(a,b,e){var f=[],g=b.toLowerCase();e.replace($,function(a,b){b&&f.push(+b)}),g=="m"&&f.length>2&&(d.push([b][n](f.splice(0,2))),g="l",b=b=="m"?"l":"L");if(g=="r")d.push([b][n](f));else while(f.length>=c[g]){d.push([b][n](f.splice(0,c[g])));if(!c[g])break}}),d.toString=a._path2string;return d}),a.parseTransformString=bt(function(b){if(!b)return null;var c={r:3,s:4,t:2,m:6},d=[];a.is(b,E)&&a.is(b[0],E)&&(d=by(b)),d.length||r(b).replace(Z,function(a,b,c){var e=[],f=v.call(b);c.replace($,function(a,b){b&&e.push(+b)}),d.push([b][n](e))}),d.toString=a._path2string;return d}),a.findDotsAtSegment=function(a,b,c,d,e,f,g,h,i){var j=1-i,k=A(j,3),l=A(j,2),m=i*i,n=m*i,o=k*a+l*3*i*c+j*3*i*i*e+n*g,p=k*b+l*3*i*d+j*3*i*i*f+n*h,q=a+2*i*(c-a)+m*(e-2*c+a),r=b+2*i*(d-b)+m*(f-2*d+b),s=c+2*i*(e-c)+m*(g-2*e+c),t=d+2*i*(f-d)+m*(h-2*f+d),u=j*a+i*c,v=j*b+i*d,x=j*e+i*g,y=j*f+i*h,z=90-w.atan2(q-s,r-t)*180/B;(q>s||r<t)&&(z+=180);return{x:o,y:p,m:{x:q,y:r},n:{x:s,y:t},start:{x:u,y:v},end:{x:x,y:y},alpha:z}},a._removedFactory=function(a){return function(){throw new Error("Raphaël: you are calling to method “"+a+"” of removed object")}};var bx=bt(function(a){if(!a)return{x:0,y:0,width:0,height:0};a=bG(a);var b=0,c=0,d=[],e=[],f;for(var g=0,h=a.length;g<h;g++){f=a[g];if(f[0]=="M")b=f[1],c=f[2],d.push(b),e.push(c);else{var i=bF(b,c,f[1],f[2],f[3],f[4],f[5],f[6]);d=d[n](i.min.x,i.max.x),e=e[n](i.min.y,i.max.y),b=f[5],c=f[6]}}var j=y[m](0,d),k=y[m](0,e);return{x:j,y:k,width:x[m](0,d)-j,height:x[m](0,e)-k}},null,function(a){return{x:a.x,y:a.y,width:a.width,height:a.height}}),by=function(b){var c=[];if(!a.is(b,E)||!a.is(b&&b[0],E))b=a.parsePathString(b);for(var d=0,e=b.length;d<e;d++){c[d]=[];for(var f=0,g=b[d].length;f<g;f++)c[d][f]=b[d][f]}c.toString=a._path2string;return c},bz=a._pathToRelative=bt(function(b){if(!a.is(b,E)||!a.is(b&&b[0],E))b=a.parsePathString(b);var c=[],d=0,e=0,f=0,g=0,h=0;b[0][0]=="M"&&(d=b[0][1],e=b[0][2],f=d,g=e,h++,c.push(["M",d,e]));for(var i=h,j=b.length;i<j;i++){var k=c[i]=[],l=b[i];if(l[0]!=v.call(l[0])){k[0]=v.call(l[0]);switch(k[0]){case"a":k[1]=l[1],k[2]=l[2],k[3]=l[3],k[4]=l[4],k[5]=l[5],k[6]=+(l[6]-d).toFixed(3),k[7]=+(l[7]-e).toFixed(3);break;case"v":k[1]=+(l[1]-e).toFixed(3);break;case"m":f=l[1],g=l[2];default:for(var m=1,n=l.length;m<n;m++)k[m]=+(l[m]-(m%2?d:e)).toFixed(3)}}else{k=c[i]=[],l[0]=="m"&&(f=l[1]+d,g=l[2]+e);for(var o=0,p=l.length;o<p;o++)c[i][o]=l[o]}var q=c[i].length;switch(c[i][0]){case"z":d=f,e=g;break;case"h":d+=+c[i][q-1];break;case"v":e+=+c[i][q-1];break;default:d+=+c[i][q-2],e+=+c[i][q-1]}}c.toString=a._path2string;return c},0,by),bA=a._pathToAbsolute=bt(function(b){if(!a.is(b,E)||!a.is(b&&b[0],E))b=a.parsePathString(b);if(!b||!b.length)return[["M",0,0]];var c=[],d=0,e=0,f=0,g=0,h=0;b[0][0]=="M"&&(d=+b[0][1],e=+b[0][2],f=d,g=e,h++,c[0]=["M",d,e]);for(var i,j,k=h,l=b.length;k<l;k++){c.push(i=[]),j=b[k];if(j[0]!=S.call(j[0])){i[0]=S.call(j[0]);switch(i[0]){case"A":i[1]=j[1],i[2]=j[2],i[3]=j[3],i[4]=j[4],i[5]=j[5],i[6]=+(j[6]+d),i[7]=+(j[7]+e);break;case"V":i[1]=+j[1]+e;break;case"H":i[1]=+j[1]+d;break;case"R":var m=[d,e][n](j.slice(1));for(var o=2,p=m.length;o<p;o++)m[o]=+m[o]+d,m[++o]=+m[o]+e;c.pop(),c=c[n](bw(m));break;case"M":f=+j[1]+d,g=+j[2]+e;default:for(o=1,p=j.length;o<p;o++)i[o]=+j[o]+(o%2?d:e)}}else if(j[0]=="R")m=[d,e][n](j.slice(1)),c.pop(),c=c[n](bw(m)),i=["R"][n](j.slice(-2));else for(var q=0,r=j.length;q<r;q++)i[q]=j[q];switch(i[0]){case"Z":d=f,e=g;break;case"H":d=i[1];break;case"V":e=i[1];break;case"M":f=i[i.length-2],g=i[i.length-1];default:d=i[i.length-2],e=i[i.length-1]}}c.toString=a._path2string;return c},null,by),bB=function(a,b,c,d){return[a,b,c,d,c,d]},bC=function(a,b,c,d,e,f){var g=1/3,h=2/3;return[g*a+h*c,g*b+h*d,g*e+h*c,g*f+h*d,e,f]},bD=function(a,b,c,d,e,f,g,h,i,j){var k=B*120/180,l=B/180*(+e||0),m=[],o,p=bt(function(a,b,c){var d=a*w.cos(c)-b*w.sin(c),e=a*w.sin(c)+b*w.cos(c);return{x:d,y:e}});if(!j){o=p(a,b,-l),a=o.x,b=o.y,o=p(h,i,-l),h=o.x,i=o.y;var q=w.cos(B/180*e),r=w.sin(B/180*e),t=(a-h)/2,u=(b-i)/2,v=t*t/(c*c)+u*u/(d*d);v>1&&(v=w.sqrt(v),c=v*c,d=v*d);var x=c*c,y=d*d,A=(f==g?-1:1)*w.sqrt(z((x*y-x*u*u-y*t*t)/(x*u*u+y*t*t))),C=A*c*u/d+(a+h)/2,D=A*-d*t/c+(b+i)/2,E=w.asin(((b-D)/d).toFixed(9)),F=w.asin(((i-D)/d).toFixed(9));E=a<C?B-E:E,F=h<C?B-F:F,E<0&&(E=B*2+E),F<0&&(F=B*2+F),g&&E>F&&(E=E-B*2),!g&&F>E&&(F=F-B*2)}else E=j[0],F=j[1],C=j[2],D=j[3];var G=F-E;if(z(G)>k){var H=F,I=h,J=i;F=E+k*(g&&F>E?1:-1),h=C+c*w.cos(F),i=D+d*w.sin(F),m=bD(h,i,c,d,e,0,g,I,J,[F,H,C,D])}G=F-E;var K=w.cos(E),L=w.sin(E),M=w.cos(F),N=w.sin(F),O=w.tan(G/4),P=4/3*c*O,Q=4/3*d*O,R=[a,b],S=[a+P*L,b-Q*K],T=[h+P*N,i-Q*M],U=[h,i];S[0]=2*R[0]-S[0],S[1]=2*R[1]-S[1];if(j)return[S,T,U][n](m);m=[S,T,U][n](m).join()[s](",");var V=[];for(var W=0,X=m.length;W<X;W++)V[W]=W%2?p(m[W-1],m[W],l).y:p(m[W],m[W+1],l).x;return V},bE=function(a,b,c,d,e,f,g,h,i){var j=1-i;return{x:A(j,3)*a+A(j,2)*3*i*c+j*3*i*i*e+A(i,3)*g,y:A(j,3)*b+A(j,2)*3*i*d+j*3*i*i*f+A(i,3)*h}},bF=bt(function(a,b,c,d,e,f,g,h){var i=e-2*c+a-(g-2*e+c),j=2*(c-a)-2*(e-c),k=a-c,l=(-j+w.sqrt(j*j-4*i*k))/2/i,n=(-j-w.sqrt(j*j-4*i*k))/2/i,o=[b,h],p=[a,g],q;z(l)>"1e12"&&(l=.5),z(n)>"1e12"&&(n=.5),l>0&&l<1&&(q=bE(a,b,c,d,e,f,g,h,l),p.push(q.x),o.push(q.y)),n>0&&n<1&&(q=bE(a,b,c,d,e,f,g,h,n),p.push(q.x),o.push(q.y)),i=f-2*d+b-(h-2*f+d),j=2*(d-b)-2*(f-d),k=b-d,l=(-j+w.sqrt(j*j-4*i*k))/2/i,n=(-j-w.sqrt(j*j-4*i*k))/2/i,z(l)>"1e12"&&(l=.5),z(n)>"1e12"&&(n=.5),l>0&&l<1&&(q=bE(a,b,c,d,e,f,g,h,l),p.push(q.x),o.push(q.y)),n>0&&n<1&&(q=bE(a,b,c,d,e,f,g,h,n),p.push(q.x),o.push(q.y));return{min:{x:y[m](0,p),y:y[m](0,o)},max:{x:x[m](0,p),y:x[m](0,o)}}}),bG=a._path2curve=bt(function(a,b){var c=bA(a),d=b&&bA(b),e={x:0,y:0,bx:0,by:0,X:0,Y:0,qx:null,qy:null},f={x:0,y:0,bx:0,by:0,X:0,Y:0,qx:null,qy:null},g=function(a,b){var c,d;if(!a)return["C",b.x,b.y,b.x,b.y,b.x,b.y];!(a[0]in{T:1,Q:1})&&(b.qx=b.qy=null);switch(a[0]){case"M":b.X=a[1],b.Y=a[2];break;case"A":a=["C"][n](bD[m](0,[b.x,b.y][n](a.slice(1))));break;case"S":c=b.x+(b.x-(b.bx||b.x)),d=b.y+(b.y-(b.by||b.y)),a=["C",c,d][n](a.slice(1));break;case"T":b.qx=b.x+(b.x-(b.qx||b.x)),b.qy=b.y+(b.y-(b.qy||b.y)),a=["C"][n](bC(b.x,b.y,b.qx,b.qy,a[1],a[2]));break;case"Q":b.qx=a[1],b.qy=a[2],a=["C"][n](bC(b.x,b.y,a[1],a[2],a[3],a[4]));break;case"L":a=["C"][n](bB(b.x,b.y,a[1],a[2]));break;case"H":a=["C"][n](bB(b.x,b.y,a[1],b.y));break;case"V":a=["C"][n](bB(b.x,b.y,b.x,a[1]));break;case"Z":a=["C"][n](bB(b.x,b.y,b.X,b.Y))}return a},h=function(a,b){if(a[b].length>7){a[b].shift();var e=a[b];while(e.length)a.splice(b++,0,["C"][n](e.splice(0,6)));a.splice(b,1),k=x(c.length,d&&d.length||0)}},i=function(a,b,e,f,g){a&&b&&a[g][0]=="M"&&b[g][0]!="M"&&(b.splice(g,0,["M",f.x,f.y]),e.bx=0,e.by=0,e.x=a[g][1],e.y=a[g][2],k=x(c.length,d&&d.length||0))};for(var j=0,k=x(c.length,d&&d.length||0);j<k;j++){c[j]=g(c[j],e),h(c,j),d&&(d[j]=g(d[j],f)),d&&h(d,j),i(c,d,e,f,j),i(d,c,f,e,j);var l=c[j],o=d&&d[j],p=l.length,q=d&&o.length;e.x=l[p-2],e.y=l[p-1],e.bx=Q(l[p-4])||e.x,e.by=Q(l[p-3])||e.y,f.bx=d&&(Q(o[q-4])||f.x),f.by=d&&(Q(o[q-3])||f.y),f.x=d&&o[q-2],f.y=d&&o[q-1]}return d?[c,d]:c},null,by),bH=a._parseDots=bt(function(b){var c=[];for(var d=0,e=b.length;d<e;d++){var f={},g=b[d].match(/^([^:]*):?([\d\.]*)/);f.color=a.getRGB(g[1]);if(f.color.error)return null;f.color=f.color.hex,g[2]&&(f.offset=g[2]+"%"),c.push(f)}for(d=1,e=c.length-1;d<e;d++)if(!c[d].offset){var h=Q(c[d-1].offset||0),i=0;for(var j=d+1;j<e;j++)if(c[j].offset){i=c[j].offset;break}i||(i=100,j=e),i=Q(i);var k=(i-h)/(j-d+1);for(;d<j;d++)h+=k,c[d].offset=h+"%"}return c}),bI=a._tear=function(a,b){a==b.top&&(b.top=a.prev),a==b.bottom&&(b.bottom=a.next),a.next&&(a.next.prev=a.prev),a.prev&&(a.prev.next=a.next)},bJ=a._tofront=function(a,b){b.top!==a&&(bI(a,b),a.next=null,a.prev=b.top,b.top.next=a,b.top=a)},bK=a._toback=function(a,b){b.bottom!==a&&(bI(a,b),a.next=b.bottom,a.prev=null,b.bottom.prev=a,b.bottom=a)},bL=a._insertafter=function(a,b,c){bI(a,c),b==c.top&&(c.top=a),b.next&&(b.next.prev=a),a.next=b.next,a.prev=b,b.next=a},bM=a._insertbefore=function(a,b,c){bI(a,c),b==c.bottom&&(c.bottom=a),b.prev&&(b.prev.next=a),a.prev=b.prev,b.prev=a,a.next=b},bN=a._extractTransform=function(b,c){if(c==null)return b._.transform;c=r(c).replace(/\.{3}|\u2026/g,b._.transform||p);var d=a.parseTransformString(c),e=0,f=0,g=0,h=1,i=1,j=b._,k=new bQ;j.transform=d||[];if(d)for(var l=0,m=d.length;l<m;l++){var n=d[l],o=n.length,q=r(n[0]).toLowerCase(),s=n[0]!=q,t=s?k.invert():0,u,v,w,x,y;q=="t"&&o==3?s?(u=t.x(0,0),v=t.y(0,0),w=t.x(n[1],n[2]),x=t.y(n[1],n[2]),k.translate(w-u,x-v)):k.translate(n[1],n[2]):q=="r"?o==2?(y=y||b.getBBox(1),k.rotate(n[1],y.x+y.width/2,y.y+y.height/2),e+=n[1]):o==4&&(s?(w=t.x(n[2],n[3]),x=t.y(n[2],n[3]),k.rotate(n[1],w,x)):k.rotate(n[1],n[2],n[3]),e+=n[1]):q=="s"?o==2||o==3?(y=y||b.getBBox(1),k.scale(n[1],n[o-1],y.x+y.width/2,y.y+y.height/2),h*=n[1],i*=n[o-1]):o==5&&(s?(w=t.x(n[3],n[4]),x=t.y(n[3],n[4]),k.scale(n[1],n[2],w,x)):k.scale(n[1],n[2],n[3],n[4]),h*=n[1],i*=n[2]):q=="m"&&o==7&&k.add(n[1],n[2],n[3],n[4],n[5],n[6]),j.dirtyT=1,b.matrix=k}b.matrix=k,j.sx=h,j.sy=i,j.deg=e,j.dx=f=k.e,j.dy=g=k.f,h==1&&i==1&&!e&&j.bbox?(j.bbox.x+=+f,j.bbox.y+=+g):j.dirtyT=1},bO=function(a){var b=a[0];switch(b.toLowerCase()){case"t":return[b,0,0];case"m":return[b,1,0,0,1,0,0];case"r":return a.length==4?[b,0,a[2],a[3]]:[b,0];case"s":return a.length==5?[b,1,1,a[3],a[4]]:a.length==3?[b,1,1]:[b,1]}},bP=a._equaliseTransform=function(b,c){c=r(c).replace(/\.{3}|\u2026/g,b),b=a.parseTransformString(b)||[],c=a.parseTransformString(c)||[];var d=x(b.length,c.length),e=[],f=[],g=0,h,i,j,k;for(;g<d;g++){j=b[g]||bO(c[g]),k=c[g]||bO(j);if(j[0]!=k[0]||j[0].toLowerCase()=="r"&&(j[2]!=k[2]||j[3]!=k[3])||j[0].toLowerCase()=="s"&&(j[3]!=k[3]||j[4]!=k[4]))return;e[g]=[],f[g]=[];for(h=0,i=x(j.length,k.length);h<i;h++)h in j&&(e[g][h]=j[h]),h in k&&(f[g][h]=k[h])}return{from:e,to:f}};a._getContainer=function(b,c,d,e){var f;f=e==null&&!a.is(b,"object")?h.doc.getElementById(b):b;if(f!=null){if(f.tagName)return c==null?{container:f,width:f.style.pixelWidth||f.offsetWidth,height:f.style.pixelHeight||f.offsetHeight}:{container:f,width:c,height:d};return{container:1,x:b,y:c,width:d,height:e}}},a.pathToRelative=bz,a._engine={},a.path2curve=bG,a.matrix=function(a,b,c,d,e,f){return new bQ(a,b,c,d,e,f)},function(b){function d(a){var b=w.sqrt(c(a));a[0]&&(a[0]/=b),a[1]&&(a[1]/=b)}function c(a){return a[0]*a[0]+a[1]*a[1]}b.add=function(a,b,c,d,e,f){var g=[[],[],[]],h=[[this.a,this.c,this.e],[this.b,this.d,this.f],[0,0,1]],i=[[a,c,e],[b,d,f],[0,0,1]],j,k,l,m;a&&a instanceof bQ&&(i=[[a.a,a.c,a.e],[a.b,a.d,a.f],[0,0,1]]);for(j=0;j<3;j++)for(k=0;k<3;k++){m=0;for(l=0;l<3;l++)m+=h[j][l]*i[l][k];g[j][k]=m}this.a=g[0][0],this.b=g[1][0],this.c=g[0][1],this.d=g[1][1],this.e=g[0][2],this.f=g[1][2]},b.invert=function(){var a=this,b=a.a*a.d-a.b*a.c;return new bQ(a.d/b,-a.b/b,-a.c/b,a.a/b,(a.c*a.f-a.d*a.e)/b,(a.b*a.e-a.a*a.f)/b)},b.clone=function(){return new bQ(this.a,this.b,this.c,this.d,this.e,this.f)},b.translate=function(a,b){this.add(1,0,0,1,a,b)},b.scale=function(a,b,c,d){b==null&&(b=a),(c||d)&&this.add(1,0,0,1,c,d),this.add(a,0,0,b,0,0),(c||d)&&this.add(1,0,0,1,-c,-d)},b.rotate=function(b,c,d){b=a.rad(b),c=c||0,d=d||0;var e=+w.cos(b).toFixed(9),f=+w.sin(b).toFixed(9);this.add(e,f,-f,e,c,d),this.add(1,0,0,1,-c,-d)},b.x=function(a,b){return a*this.a+b*this.c+this.e},b.y=function(a,b){return a*this.b+b*this.d+this.f},b.get=function(a){return+this[r.fromCharCode(97+a)].toFixed(4)},b.toString=function(){return a.svg?"matrix("+[this.get(0),this.get(1),this.get(2),this.get(3),this.get(4),this.get(5)].join()+")":[this.get(0),this.get(2),this.get(1),this.get(3),0,0].join()},b.toFilter=function(){return"progid:DXImageTransform.Microsoft.Matrix(M11="+this.get(0)+", M12="+this.get(2)+", M21="+this.get(1)+", M22="+this.get(3)+", Dx="+this.get(4)+", Dy="+this.get(5)+", sizingmethod='auto expand')"},b.offset=function(){return[this.e.toFixed(4),this.f.toFixed(4)]},b.split=function(){var b={};b.dx=this.e,b.dy=this.f;var e=[[this.a,this.c],[this.b,this.d]];b.scalex=w.sqrt(c(e[0])),d(e[0]),b.shear=e[0][0]*e[1][0]+e[0][1]*e[1][1],e[1]=[e[1][0]-e[0][0]*b.shear,e[1][1]-e[0][1]*b.shear],b.scaley=w.sqrt(c(e[1])),d(e[1]),b.shear/=b.scaley;var f=-e[0][1],g=e[1][1];g<0?(b.rotate=a.deg(w.acos(g)),f<0&&(b.rotate=360-b.rotate)):b.rotate=a.deg(w.asin(f)),b.isSimple=!+b.shear.toFixed(9)&&(b.scalex.toFixed(9)==b.scaley.toFixed(9)||!b.rotate),b.isSuperSimple=!+b.shear.toFixed(9)&&b.scalex.toFixed(9)==b.scaley.toFixed(9)&&!b.rotate,b.noRotation=!+b.shear.toFixed(9)&&!b.rotate;return b},b.toTransformString=function(a){var b=a||this[s]();if(b.isSimple){b.scalex=+b.scalex.toFixed(4),b.scaley=+b.scaley.toFixed(4),b.rotate=+b.rotate.toFixed(4);return(b.dx&&b.dy?"t"+[b.dx,b.dy]:p)+(b.scalex!=1||b.scaley!=1?"s"+[b.scalex,b.scaley,0,0]:p)+(b.rotate?"r"+[b.rotate,0,0]:p)}return"m"+[this.get(0),this.get(1),this.get(2),this.get(3),this.get(4),this.get(5)]}}(bQ.prototype);var bR=navigator.userAgent.match(/Version\/(.*?)\s/)||navigator.userAgent.match(/Chrome\/(\d+)/);navigator.vendor=="Apple Computer, Inc."&&(bR&&bR[1]<4||navigator.platform.slice(0,2)=="iP")||navigator.vendor=="Google Inc."&&bR&&bR[1]<8?k.safari=function(){var a=this.rect(-99,-99,this.width+99,this.height+99).attr({stroke:"none"});setTimeout(function(){a.remove()})}:k.safari=bd;var bS=function(){this.returnValue=!1},bT=function(){return this.originalEvent.preventDefault()},bU=function(){this.cancelBubble=!0},bV=function(){return this.originalEvent.stopPropagation()},bW=function(){if(h.doc.addEventListener)return function(a,b,c,d){var e=o&&u[b]?u[b]:b,f=function(e){var f=h.doc.documentElement.scrollTop||h.doc.body.scrollTop,i=h.doc.documentElement.scrollLeft||h.doc.body.scrollLeft,j=e.clientX+i,k=e.clientY+f;if(o&&u[g](b))for(var l=0,m=e.targetTouches&&e.targetTouches.length;l<m;l++)if(e.targetTouches[l].target==a){var n=e;e=e.targetTouches[l],e.originalEvent=n,e.preventDefault=bT,e.stopPropagation=bV;break}return c.call(d,e,j,k)};a.addEventListener(e,f,!1);return function(){a.removeEventListener(e,f,!1);return!0}};if(h.doc.attachEvent)return function(a,b,c,d){var e=function(a){a=a||h.win.event;var b=h.doc.documentElement.scrollTop||h.doc.body.scrollTop,e=h.doc.documentElement.scrollLeft||h.doc.body.scrollLeft,f=a.clientX+e,g=a.clientY+b;a.preventDefault=a.preventDefault||bS,a.stopPropagation=a.stopPropagation||bU;return c.call(d,a,f,g)};a.attachEvent("on"+b,e);var f=function(){a.detachEvent("on"+b,e);return!0};return f}}(),bX=[],bY=function(a){var b=a.clientX,c=a.clientY,d=h.doc.documentElement.scrollTop||h.doc.body.scrollTop,e=h.doc.documentElement.scrollLeft||h.doc.body.scrollLeft,f,g=bX.length;while(g--){f=bX[g];if(o){var i=a.touches.length,j;while(i--){j=a.touches[i];if(j.identifier==f.el._drag.id){b=j.clientX,c=j.clientY,(a.originalEvent?a.originalEvent:a).preventDefault();break}}}else a.preventDefault();var k=f.el.node,l,m=k.nextSibling,n=k.parentNode,p=k.style.display;h.win.opera&&n.removeChild(k),k.style.display="none",l=f.el.paper.getElementByPoint(b,c),k.style.display=p,h.win.opera&&(m?n.insertBefore(k,m):n.appendChild(k)),l&&eve("drag.over."+f.el.id,f.el,l),b+=e,c+=d,eve("drag.move."+f.el.id,f.move_scope||f.el,b-f.el._drag.x,c-f.el._drag.y,b,c,a)}},bZ=function(b){a.unmousemove(bY).unmouseup(bZ);var c=bX.length,d;while(c--)d=bX[c],d.el._drag={},eve("drag.end."+d.el.id,d.end_scope||d.start_scope||d.move_scope||d.el,b);bX=[]},b$=a.el={};for(var b_=t.length;b_--;)(function(b){a[b]=b$[b]=function(c,d){a.is(c,"function")&&(this.events=this.events||[],this.events.push({name:b,f:c,unbind:bW(this.shape||this.node||h.doc,b,c,d||this)}));return this},a["un"+b]=b$["un"+b]=function(a){var c=this.events,d=c.length;while(d--)if(c[d].name==b&&c[d].f==a){c[d].unbind(),c.splice(d,1),!c.length&&delete this.events;return this}return this}})(t[b_]);b$.data=function(b,c){var d=ba[this.id]=ba[this.id]||{};if(arguments.length==1){if(a.is(b,"object")){for(var e in b)b[g](e)&&this.data(e,b[e]);return this}eve("data.get."+this.id,this,d[b],b);return d[b]}d[b]=c,eve("data.set."+this.id,this,c,b);return this},b$.removeData=function(a){a==null?ba[this.id]={}:ba[this.id]&&delete ba[this.id][a];return this},b$.hover=function(a,b,c,d){return this.mouseover(a,c).mouseout(b,d||c)},b$.unhover=function(a,b){return this.unmouseover(a).unmouseout(b)};var ca=[];b$.drag=function(b,c,d,e,f,g){function i(i){(i.originalEvent||i).preventDefault();var j=h.doc.documentElement.scrollTop||h.doc.body.scrollTop,k=h.doc.documentElement.scrollLeft||h.doc.body.scrollLeft;this._drag.x=i.clientX+k,this._drag.y=i.clientY+j,this._drag.id=i.identifier,!bX.length&&a.mousemove(bY).mouseup(bZ),bX.push({el:this,move_scope:e,start_scope:f,end_scope:g}),c&&eve.on("drag.start."+this.id,c),b&&eve.on("drag.move."+this.id,b),d&&eve.on("drag.end."+this.id,d),eve("drag.start."+this.id,f||e||this,i.clientX+k,i.clientY+j,i)}this._drag={},ca.push({el:this,start:i}),this.mousedown(i);return this},b$.onDragOver=function(a){a?eve.on("drag.over."+this.id,a):eve.unbind("drag.over."+this.id)},b$.undrag=function(){var b=ca.length;while(b--)ca[b].el==this&&(this.unmousedown(ca[b].start),ca.splice(b,1),eve.unbind("drag.*."+this.id));!ca.length&&a.unmousemove(bY).unmouseup(bZ)},k.circle=function(b,c,d){var e=a._engine.circle(this,b||0,c||0,d||0);this.__set__&&this.__set__.push(e);return e},k.rect=function(b,c,d,e,f){var g=a._engine.rect(this,b||0,c||0,d||0,e||0,f||0);this.__set__&&this.__set__.push(g);return g},k.ellipse=function(b,c,d,e){var f=a._engine.ellipse(this,b||0,c||0,d||0,e||0);this.__set__&&this.__set__.push(f);return f},k.path=function(b){b&&!a.is(b,D)&&!a.is(b[0],E)&&(b+=p);var c=a._engine.path(a.format[m](a,arguments),this);this.__set__&&this.__set__.push(c);return c},k.image=function(b,c,d,e,f){var g=a._engine.image(this,b||"about:blank",c||0,d||0,e||0,f||0);this.__set__&&this.__set__.push(g);return g},k.text=function(b,c,d){var e=a._engine.text(this,b||0,c||0,r(d));this.__set__&&this.__set__.push(e);return e},k.set=function(b){!a.is(b,"array")&&(b=Array.prototype.splice.call(arguments,0,arguments.length));var c=new cs(b);this.__set__&&this.__set__.push(c);return c},k.setStart=function(a){this.__set__=a||this.set()},k.setFinish=function(a){var b=this.__set__;delete this.__set__;return b},k.setSize=function(b,c){return a._engine.setSize.call(this,b,c)},k.setViewBox=function(b,c,d,e,f){return a._engine.setViewBox.call(this,b,c,d,e,f)},k.top=k.bottom=null,k.raphael=a;var cb=function(a){var b=a.getBoundingClientRect(),c=a.ownerDocument,d=c.body,e=c.documentElement,f=e.clientTop||d.clientTop||0,g=e.clientLeft||d.clientLeft||0,i=b.top+(h.win.pageYOffset||e.scrollTop||d.scrollTop)-f,j=b.left+(h.win.pageXOffset||e.scrollLeft||d.scrollLeft)-g;return{y:i,x:j}};k.getElementByPoint=function(a,b){var c=this,d=c.canvas,e=h.doc.elementFromPoint(a,b);if(h.win.opera&&e.tagName=="svg"){var f=cb(d),g=d.createSVGRect();g.x=a-f.x,g.y=b-f.y,g.width=g.height=1;var i=d.getIntersectionList(g,null);i.length&&(e=i[i.length-1])}if(!e)return null;while(e.parentNode&&e!=d.parentNode&&!e.raphael)e=e.parentNode;e==c.canvas.parentNode&&(e=d),e=e&&e.raphael?c.getById(e.raphaelid):null;return e},k.getById=function(a){var b=this.bottom;while(b){if(b.id==a)return b;b=b.next}return null},k.forEach=function(a,b){var c=this.bottom;while(c){if(a.call(b,c)===!1)return this;c=c.next}return this},b$.getBBox=function(a){if(this.removed)return{};var b=this._;if(a){if(b.dirty||!b.bboxwt)this.realPath=bh[this.type](this),b.bboxwt=bx(this.realPath),b.bboxwt.toString=cd,b.dirty=0;return b.bboxwt}if(b.dirty||b.dirtyT||!b.bbox){if(b.dirty||!this.realPath)b.bboxwt=0,this.realPath=bh[this.type](this);b.bbox=bx(bi(this.realPath,this.matrix)),b.bbox.toString=cd,b.dirty=b.dirtyT=0}return b.bbox},b$.clone=function(){if(this.removed)return null;var a=this.paper[this.type]().attr(this.attr());this.__set__&&this.__set__.push(a);return a},b$.glow=function(a){if(this.type=="text")return null;a=a||{};var b={width:(a.width||10)+(+this.attr("stroke-width")||1),fill:a.fill||!1,opacity:a.opacity||.5,offsetx:a.offsetx||0,offsety:a.offsety||0,color:a.color||"#000"},c=b.width/2,d=this.paper,e=d.set(),f=this.realPath||bh[this.type](this);f=this.matrix?bi(f,this.matrix):f;for(var g=1;g<c+1;g++)e.push(d.path(f).attr({stroke:b.color,fill:b.fill?b.color:"none","stroke-linejoin":"round","stroke-linecap":"round","stroke-width":+(b.width/c*g).toFixed(3),opacity:+(b.opacity/c).toFixed(3)}));return e.insertBefore(this).translate(b.offsetx,b.offsety)};var ce={},cf=function(b,c,d,e,f,g,h,i,j){var k=0,l=100,m=[b,c,d,e,f,g,h,i].join(),n=ce[m],o,p;!n&&(ce[m]=n={data:[]}),n.timer&&clearTimeout(n.timer),n.timer=setTimeout(function(){delete ce[m]},2e3);if(j!=null&&!n.precision){var q=cf(b,c,d,e,f,g,h,i);n.precision=~~q*10,n.data=[]}l=n.precision||l;for(var r=0;r<l+1;r++){n.data[r*l]?p=n.data[r*l]:(p=a.findDotsAtSegment(b,c,d,e,f,g,h,i,r/l),n.data[r*l]=p),r&&(k+=A(A(o.x-p.x,2)+A(o.y-p.y,2),.5));if(j!=null&&k>=j)return p;o=p}if(j==null)return k},cg=function(b,c){return function(d,e,f){d=bG(d);var g,h,i,j,k="",l={},m,n=0;for(var o=0,p=d.length;o<p;o++){i=d[o];if(i[0]=="M")g=+i[1],h=+i[2];else{j=cf(g,h,i[1],i[2],i[3],i[4],i[5],i[6]);if(n+j>e){if(c&&!l.start){m=cf(g,h,i[1],i[2],i[3],i[4],i[5],i[6],e-n),k+=["C"+m.start.x,m.start.y,m.m.x,m.m.y,m.x,m.y];if(f)return k;l.start=k,k=["M"+m.x,m.y+"C"+m.n.x,m.n.y,m.end.x,m.end.y,i[5],i[6]].join(),n+=j,g=+i[5],h=+i[6];continue}if(!b&&!c){m=cf(g,h,i[1],i[2],i[3],i[4],i[5],i[6],e-n);return{x:m.x,y:m.y,alpha:m.alpha}}}n+=j,g=+i[5],h=+i[6]}k+=i.shift()+i}l.end=k,m=b?n:c?l:a.findDotsAtSegment(g,h,i[0],i[1],i[2],i[3],i[4],i[5],1),m.alpha&&(m={x:m.x,y:m.y,alpha:m.alpha});return m}},ch=cg(1),ci=cg(),cj=cg(0,1);a.getTotalLength=ch,a.getPointAtLength=ci,a.getSubpath=function(a,b,c){if(this.getTotalLength(a)-c<1e-6)return cj(a,b).end;var d=cj(a,c,1);return b?cj(d,b).end:d},b$.getTotalLength=function(){if(this.type=="path"){if(this.node.getTotalLength)return this.node.getTotalLength();return ch(this.attrs.path)}},b$.getPointAtLength=function(a){if(this.type=="path")return ci(this.attrs.path,a)},b$.getSubpath=function(b,c){if(this.type=="path")return a.getSubpath(this.attrs.path,b,c)};var ck=a.easing_formulas={linear:function(a){return a},"<":function(a){return A(a,1.7)},">":function(a){return A(a,.48)},"<>":function(a){var b=.48-a/1.04,c=w.sqrt(.1734+b*b),d=c-b,e=A(z(d),1/3)*(d<0?-1:1),f=-c-b,g=A(z(f),1/3)*(f<0?-1:1),h=e+g+.5;return(1-h)*3*h*h+h*h*h},backIn:function(a){var b=1.70158;return a*a*((b+1)*a-b)},backOut:function(a){a=a-1;var b=1.70158;return a*a*((b+1)*a+b)+1},elastic:function(a){if(a==!!a)return a;return A(2,-10*a)*w.sin((a-.075)*2*B/.3)+1},bounce:function(a){var b=7.5625,c=2.75,d;a<1/c?d=b*a*a:a<2/c?(a-=1.5/c,d=b*a*a+.75):a<2.5/c?(a-=2.25/c,d=b*a*a+.9375):(a-=2.625/c,d=b*a*a+.984375);return d}};ck.easeIn=ck["ease-in"]=ck["<"],ck.easeOut=ck["ease-out"]=ck[">"],ck.easeInOut=ck["ease-in-out"]=ck["<>"],ck["back-in"]=ck.backIn,ck["back-out"]=ck.backOut;var cl=[],cm=window.requestAnimationFrame||window.webkitRequestAnimationFrame||window.mozRequestAnimationFrame||window.oRequestAnimationFrame||window.msRequestAnimationFrame||function(a){setTimeout(a,16)},cn=function(){var b=+(new Date),c=0;for(;c<cl.length;c++){var d=cl[c];if(d.el.removed||d.paused)continue;var e=b-d.start,f=d.ms,h=d.easing,i=d.from,j=d.diff,k=d.to,l=d.t,m=d.el,o={},p,r={},s;d.initstatus?(e=(d.initstatus*d.anim.top-d.prev)/(d.percent-d.prev)*f,d.status=d.initstatus,delete d.initstatus,d.stop&&cl.splice(c--,1)):d.status=(d.prev+(d.percent-d.prev)*(e/f))/d.anim.top;if(e<0)continue;if(e<f){var t=h(e/f);for(var u in i)if(i[g](u)){switch(U[u]){case C:p=+i[u]+t*f*j[u];break;case"colour":p="rgb("+[co(O(i[u].r+t*f*j[u].r)),co(O(i[u].g+t*f*j[u].g)),co(O(i[u].b+t*f*j[u].b))].join(",")+")";break;case"path":p=[];for(var v=0,w=i[u].length;v<w;v++){p[v]=[i[u][v][0]];for(var x=1,y=i[u][v].length;x<y;x++)p[v][x]=+i[u][v][x]+t*f*j[u][v][x];p[v]=p[v].join(q)}p=p.join(q);break;case"transform":if(j[u].real){p=[];for(v=0,w=i[u].length;v<w;v++){p[v]=[i[u][v][0]];for(x=1,y=i[u][v].length;x<y;x++)p[v][x]=i[u][v][x]+t*f*j[u][v][x]}}else{var z=function(a){return+i[u][a]+t*f*j[u][a]};p=[["m",z(0),z(1),z(2),z(3),z(4),z(5)]]}break;case"csv":if(u=="clip-rect"){p=[],v=4;while(v--)p[v]=+i[u][v]+t*f*j[u][v]}break;default:var A=[][n](i[u]);p=[],v=m.paper.customAttributes[u].length;while(v--)p[v]=+A[v]+t*f*j[u][v]}o[u]=p}m.attr(o),function(a,b,c){setTimeout(function(){eve("anim.frame."+a,b,c)})}(m.id,m,d.anim)}else{(function(b,c,d){setTimeout(function(){eve("anim.frame."+c.id,c,d),eve("anim.finish."+c.id,c,d),a.is(b,"function")&&b.call(c)})})(d.callback,m,d.anim),m.attr(k),cl.splice(c--,1);if(d.repeat>1&&!d.next){for(s in k)k[g](s)&&(r[s]=d.totalOrigin[s]);d.el.attr(r),cr(d.anim,d.el,d.anim.percents[0],null,d.totalOrigin,d.repeat-1)}d.next&&!d.stop&&cr(d.anim,d.el,d.next,null,d.totalOrigin,d.repeat)}}a.svg&&m&&m.paper&&m.paper.safari(),cl.length&&cm(cn)},co=function(a){return a>255?255:a<0?0:a};b$.animateWith=function(b,c,d,e,f,g){var h=d?a.animation(d,e,f,g):c,i=b.status(c);return this.animate(h).status(h,i*c.ms/h.ms)},b$.onAnimation=function(a){a?eve.on("anim.frame."+this.id,a):eve.unbind("anim.frame."+this.id);return this},cq.prototype.delay=function(a){var b=new cq(this.anim,this.ms);b.times=this.times,b.del=+a||0;return b},cq.prototype.repeat=function(a){var b=new cq(this.anim,this.ms);b.del=this.del,b.times=w.floor(x(a,0))||1;return b},a.animation=function(b,c,d,e){if(b instanceof cq)return b;if(a.is(d,"function")||!d)e=e||d||null,d=null;b=Object(b),c=+c||0;var f={},h,i;for(i in b)b[g](i)&&Q(i)!=i&&Q(i)+"%"!=i&&(h=!0,f[i]=b[i]);if(!h)return new cq(b,c);d&&(f.easing=d),e&&(f.callback=e);return new cq({100:f},c)},b$.animate=function(b,c,d,e){var f=this;if(f.removed){e&&e.call(f);return f}var g=b instanceof cq?b:a.animation(b,c,d,e);cr(g,f,g.percents[0],null,f.attr());return f},b$.setTime=function(a,b){a&&b!=null&&this.status(a,y(b,a.ms)/a.ms);return this},b$.status=function(a,b){var c=[],d=0,e,f;if(b!=null){cr(a,this,-1,y(b,1));return this}e=cl.length;for(;d<e;d++){f=cl[d];if(f.el.id==this.id&&(!a||f.anim==a)){if(a)return f.status;c.push({anim:f.anim,status:f.status})}}if(a)return 0;return c},b$.pause=function(a){for(var b=0;b<cl.length;b++)cl[b].el.id==this.id&&(!a||cl[b].anim==a)&&eve("anim.pause."+this.id,this,cl[b].anim)!==!1&&(cl[b].paused=!0);return this},b$.resume=function(a){for(var b=0;b<cl.length;b++)if(cl[b].el.id==this.id&&(!a||cl[b].anim==a)){var c=cl[b];eve("anim.resume."+this.id,this,c.anim)!==!1&&(delete c.paused,this.status(c.anim,c.status))}return this},b$.stop=function(a){for(var b=0;b<cl.length;b++)cl[b].el.id==this.id&&(!a||cl[b].anim==a)&&eve("anim.stop."+this.id,this,cl[b].anim)!==!1&&cl.splice(b--,1);return this},b$.toString=function(){return"Raphaël’s object"};var cs=function(a){this.items=[],this.length=0,this.type="set";if(a)for(var b=0,c=a.length;b<c;b++)a[b]&&(a[b].constructor==b$.constructor||a[b].constructor==cs)&&(this[this.items.length]=this.items[this.items.length]=a[b],this.length++)},ct=cs.prototype;ct.push=function(){var a,b;for(var c=0,d=arguments.length;c<d;c++)a=arguments[c],a&&(a.constructor==b$.constructor||a.constructor==cs)&&(b=this.items.length,this[b]=this.items[b]=a,this.length++);return this},ct.pop=function(){this.length&&delete this[this.length--];return this.items.pop()},ct.forEach=function(a,b){for(var c=0,d=this.items.length;c<d;c++)if(a.call(b,this.items[c],c)===!1)return this;return this};for(var cu in b$)b$[g](cu)&&(ct[cu]=function(a){return function(){var b=arguments;return this.forEach(function(c){c[a][m](c,b)})}}(cu));ct.attr=function(b,c){if(b&&a.is(b,E)&&a.is(b[0],"object"))for(var d=0,e=b.length;d<e;d++)this.items[d].attr(b[d]);else for(var f=0,g=this.items.length;f<g;f++)this.items[f].attr(b,c);return this},ct.clear=function(){while(this.length)this.pop()},ct.splice=function(a,b,c){a=a<0?x(this.length+a,0):a,b=x(0,y(this.length-a,b));var d=[],e=[],f=[],g;for(g=2;g<arguments.length;g++)f.push(arguments[g]);for(g=0;g<b;g++)e.push(this[a+g]);for(;g<this.length-a;g++)d.push(this[a+g]);var h=f.length;for(g=0;g<h+d.length;g++)this.items[a+g]=this[a+g]=g<h?f[g]:d[g-h];g=this.items.length=this.length-=b-h;while(this[g])delete this[g++];return new cs(e)},ct.exclude=function(a){for(var b=0,c=this.length;b<c;b++)if(this[b]==a){this.splice(b,1);return!0}},ct.animate=function(b,c,d,e){(a.is(d,"function")||!d)&&(e=d||null);var f=this.items.length,g=f,h,i=this,j;if(!f)return this;e&&(j=function(){!--f&&e.call(i)}),d=a.is(d,D)?d:j;var k=a.animation(b,c,d,j);h=this.items[--g].animate(k);while(g--)this.items[g]&&!this.items[g].removed&&this.items[g].animateWith(h,k);return this},ct.insertAfter=function(a){var b=this.items.length;while(b--)this.items[b].insertAfter(a);return this},ct.getBBox=function(){var a=[],b=[],c=[],d=[];for(var e=this.items.length;e--;)if(!this.items[e].removed){var f=this.items[e].getBBox();a.push(f.x),b.push(f.y),c.push(f.x+f.width),d.push(f.y+f.height)}a=y[m](0,a),b=y[m](0,b);return{x:a,y:b,width:x[m](0,c)-a,height:x[m](0,d)-b}},ct.clone=function(a){a=new cs;for(var b=0,c=this.items.length;b<c;b++)a.push(this.items[b].clone());return a},ct.toString=function(){return"Raphaël‘s set"},a.registerFont=function(a){if(!a.face)return a;this.fonts=this.fonts||{};var b={w:a.w,face:{},glyphs:{}},c=a.face["font-family"];for(var d in a.face)a.face[g](d)&&(b.face[d]=a.face[d]);this.fonts[c]?this.fonts[c].push(b):this.fonts[c]=[b];if(!a.svg){b.face["units-per-em"]=R(a.face["units-per-em"],10);for(var e in a.glyphs)if(a.glyphs[g](e)){var f=a.glyphs[e];b.glyphs[e]={w:f.w,k:{},d:f.d&&"M"+f.d.replace(/[mlcxtrv]/g,function(a){return{l:"L",c:"C",x:"z",t:"m",r:"l",v:"c"}[a]||"M"})+"z"};if(f.k)for(var h in f.k)f[g](h)&&(b.glyphs[e].k[h]=f.k[h])}}return a},k.getFont=function(b,c,d,e){e=e||"normal",d=d||"normal",c=+c||{normal:400,bold:700,lighter:300,bolder:800}[c]||400;if(!!a.fonts){var f=a.fonts[b];if(!f){var h=new RegExp("(^|\\s)"+b.replace(/[^\w\d\s+!~.:_-]/g,p)+"(\\s|$)","i");for(var i in a.fonts)if(a.fonts[g](i)&&h.test(i)){f=a.fonts[i];break}}var j;if(f)for(var k=0,l=f.length;k<l;k++){j=f[k];if(j.face["font-weight"]==c&&(j.face["font-style"]==d||!j.face["font-style"])&&j.face["font-stretch"]==e)break}return j}},k.print=function(b,d,e,f,g,h,i){h=h||"middle",i=x(y(i||0,1),-1);var j=this.set(),k=r(e)[s](p),l=0,m=p,n;a.is(f,e)&&(f=this.getFont(f));if(f){n=(g||16)/f.face["units-per-em"];var o=f.face.bbox[s](c),q=+o[0],t=+o[1]+(h=="baseline"?o[3]-o[1]+ +f.face.descent:(o[3]-o[1])/2);for(var u=0,v=k.length;u<v;u++){var w=u&&f.glyphs[k[u-1]]||{},z=f.glyphs[k[u]];l+=u?(w.w||f.w)+(w.k&&w.k[k[u]]||0)+f.w*i:0,z&&z.d&&j.push(this.path(z.d).attr({fill:"#000",stroke:"none",transform:[["t",l*n,0]]}))}j.transform(["...s",n,n,q,t,"t",(b-q)/n,(d-t)/n])}return j},k.add=function(b){if(a.is(b,"array")){var c=this.set(),e=0,f=b.length,h;for(;e<f;e++)h=b[e]||{},d[g](h.type)&&c.push(this[h.type]().attr(h))}return c},a.format=function(b,c){var d=a.is(c,E)?[0][n](c):arguments;b&&a.is(b,D)&&d.length-1&&(b=b.replace(e,function(a,b){return d[++b]==null?p:d[b]}));return b||p},a.fullfill=function(){var a=/\{([^\}]+)\}/g,b=/(?:(?:^|\.)(.+?)(?=\[|\.|$|\()|\[('|")(.+?)\2\])(\(\))?/g,c=function(a,c,d){var e=d;c.replace(b,function(a,b,c,d,f){b=b||d,e&&(b in e&&(e=e[b]),typeof e=="function"&&f&&(e=e()))}),e=(e==null||e==d?a:e)+"";return e};return function(b,d){return String(b).replace(a,function(a,b){return c(a,b,d)})}}(),a.ninja=function(){i.was?h.win.Raphael=i.is:delete Raphael;return a},a.st=ct,function(b,c,d){function e(){/in/.test(b.readyState)?setTimeout(e,9):a.eve("DOMload")}b.readyState==null&&b.addEventListener&&(b.addEventListener(c,d=function(){b.removeEventListener(c,d,!1),b.readyState="complete"},!1),b.readyState="loading"),e()}(document,"DOMContentLoaded"),i.was?h.win.Raphael=a:Raphael=a,eve.on("DOMload",function(){b=!0})}(),window.Raphael.svg&&function(a){var b="hasOwnProperty",c=String,d=parseFloat,e=parseInt,f=Math,g=f.max,h=f.abs,i=f.pow,j=/[, ]+/,k=a.eve,l="",m=" ",n="http://www.w3.org/1999/xlink",o={block:"M5,0 0,2.5 5,5z",classic:"M5,0 0,2.5 5,5 3.5,3 3.5,2z",diamond:"M2.5,0 5,2.5 2.5,5 0,2.5z",open:"M6,1 1,3.5 6,6",oval:"M2.5,0A2.5,2.5,0,0,1,2.5,5 2.5,2.5,0,0,1,2.5,0z"},p={};a.toString=function(){return"Your browser supports SVG.\nYou are running Raphaël "+this.version};var q=function(d,e){if(e){typeof d=="string"&&(d=q(d));for(var f in e)e[b](f)&&(f.substring(0,6)=="xlink:"?d.setAttributeNS(n,f.substring(6),c(e[f])):d.setAttribute(f,c(e[f])))}else d=a._g.doc.createElementNS("http://www.w3.org/2000/svg",d),d.style&&(d.style.webkitTapHighlightColor="rgba(0,0,0,0)");return d},r=function(b,e){var j="linear",k=b.id+e,m=.5,n=.5,o=b.node,p=b.paper,r=o.style,s=a._g.doc.getElementById(k);if(!s){e=c(e).replace(a._radial_gradient,function(a,b,c){j="radial";if(b&&c){m=d(b),n=d(c);var e=(n>.5)*2-1;i(m-.5,2)+i(n-.5,2)>.25&&(n=f.sqrt(.25-i(m-.5,2))*e+.5)&&n!=.5&&(n=n.toFixed(5)-1e-5*e)}return l}),e=e.split(/\s*\-\s*/);if(j=="linear"){var t=e.shift();t=-d(t);if(isNaN(t))return null;var u=[0,0,f.cos(a.rad(t)),f.sin(a.rad(t))],v=1/(g(h(u[2]),h(u[3]))||1);u[2]*=v,u[3]*=v,u[2]<0&&(u[0]=-u[2],u[2]=0),u[3]<0&&(u[1]=-u[3],u[3]=0)}var w=a._parseDots(e);if(!w)return null;k=k.replace(/[\(\)\s,\xb0#]/g,"_"),b.gradient&&k!=b.gradient.id&&(p.defs.removeChild(b.gradient),delete b.gradient);if(!b.gradient){s=q(j+"Gradient",{id:k}),b.gradient=s,q(s,j=="radial"?{fx:m,fy:n}:{x1:u[0],y1:u[1],x2:u[2],y2:u[3],gradientTransform:b.matrix.invert()}),p.defs.appendChild(s);for(var x=0,y=w.length;x<y;x++)s.appendChild(q("stop",{offset:w[x].offset?w[x].offset:x?"100%":"0%","stop-color":w[x].color||"#fff"}))}}q(o,{fill:"url(#"+k+")",opacity:1,"fill-opacity":1}),r.fill=l,r.opacity=1,r.fillOpacity=1;return 1},s=function(a){var b=a.getBBox(1);q(a.pattern,{patternTransform:a.matrix.invert()+" translate("+b.x+","+b.y+")"})},t=function(d,e,f){if(d.type=="path"){var g=c(e).toLowerCase().split("-"),h=d.paper,i=f?"end":"start",j=d.node,k=d.attrs,l=k["stroke-width"],n=g.length,r="classic",s,t,u,v,w,x=3,y=3,z=5;while(n--)switch(g[n]){case"block":case"classic":case"oval":case"diamond":case"open":case"none":r=g[n];break;case"wide":y=5;break;case"narrow":y=2;break;case"long":x=5;break;case"short":x=2}r=="open"?(x+=2,y+=2,z+=2,u=1,v=f?4:1,w={fill:"none",stroke:k.stroke}):(v=u=x/2,w={fill:k.stroke,stroke:"none"}),d._.arrows?f?(d._.arrows.endPath&&p[d._.arrows.endPath]--,d._.arrows.endMarker&&p[d._.arrows.endMarker]--):(d._.arrows.startPath&&p[d._.arrows.startPath]--,d._.arrows.startMarker&&p[d._.arrows.startMarker]--):d._.arrows={};if(r!="none"){var A="raphael-marker-"+r,B="raphael-marker-"+i+r+x+y;a._g.doc.getElementById(A)?p[A]++:(h.defs.appendChild(q(q("path"),{"stroke-linecap":"round",d:o[r],id:A})),p[A]=1);var C=a._g.doc.getElementById(B),D;C?(p[B]++,D=C.getElementsByTagName("use")[0]):(C=q(q("marker"),{id:B,markerHeight:y,markerWidth:x,orient:"auto",refX:v,refY:y/2}),D=q(q("use"),{"xlink:href":"#"+A,transform:(f?" rotate(180 "+x/2+" "+y/2+") ":m)+"scale("+x/z+","+y/z+")","stroke-width":1/((x/z+y/z)/2)}),C.appendChild(D),h.defs.appendChild(C),p[B]=1),q(D,w);var E=u*(r!="diamond"&&r!="oval");f?(s=d._.arrows.startdx*l||0,t=a.getTotalLength(k.path)-E*l):(s=E*l,t=a.getTotalLength(k.path)-(d._.arrows.enddx*l||0)),w={},w["marker-"+i]="url(#"+B+")";if(t||s)w.d=Raphael.getSubpath(k.path,s,t);q(j,w),d._.arrows[i+"Path"]=A,d._.arrows[i+"Marker"]=B,d._.arrows[i+"dx"]=E,d._.arrows[i+"Type"]=r,d._.arrows[i+"String"]=e}else f?(s=d._.arrows.startdx*l||0,t=a.getTotalLength(k.path)-s):(s=0,t=a.getTotalLength(k.path)-(d._.arrows.enddx*l||0)),d._.arrows[i+"Path"]&&q(j,{d:Raphael.getSubpath(k.path,s,t)}),delete d._.arrows[i+"Path"],delete d._.arrows[i+"Marker"],delete d._.arrows[i+"dx"],delete d._.arrows[i+"Type"],delete d._.arrows[i+"String"];for(w in p)if(p[b](w)&&!p[w]){var F=a._g.doc.getElementById(w);F&&F.parentNode.removeChild(F)}}},u={"":[0],none:[0],"-":[3,1],".":[1,1],"-.":[3,1,1,1],"-..":[3,1,1,1,1,1],". ":[1,3],"- ":[4,3],"--":[8,3],"- .":[4,3,1,3],"--.":[8,3,1,3],"--..":[8,3,1,3,1,3]},v=function(a,b,d){b=u[c(b).toLowerCase()];if(b){var e=a.attrs["stroke-width"]||"1",f={round:e,square:e,butt:0}[a.attrs["stroke-linecap"]||d["stroke-linecap"]]||0,g=[],h=b.length;while(h--)g[h]=b[h]*e+(h%2?1:-1)*f;q(a.node,{"stroke-dasharray":g.join(",")})}},w=function(d,f){var i=d.node,k=d.attrs,m=i.style.visibility;i.style.visibility="hidden";for(var o in f)if(f[b](o)){if(!a._availableAttrs[b](o))continue;var p=f[o];k[o]=p;switch(o){case"blur":d.blur(p);break;case"href":case"title":case"target":var u=i.parentNode;if(u.tagName.toLowerCase()!="a"){var w=q("a");u.insertBefore(w,i),w.appendChild(i),u=w}o=="target"&&p=="blank"?u.setAttributeNS(n,"show","new"):u.setAttributeNS(n,o,p);break;case"cursor":i.style.cursor=p;break;case"transform":d.transform(p);break;case"arrow-start":t(d,p);break;case"arrow-end":t(d,p,1);break;case"clip-rect":var x=c(p).split(j);if(x.length==4){d.clip&&d.clip.parentNode.parentNode.removeChild(d.clip.parentNode);var z=q("clipPath"),A=q("rect");z.id=a.createUUID(),q(A,{x:x[0],y:x[1],width:x[2],height:x[3]}),z.appendChild(A),d.paper.defs.appendChild(z),q(i,{"clip-path":"url(#"+z.id+")"}),d.clip=A}if(!p){var B=i.getAttribute("clip-path");if(B){var C=a._g.doc.getElementById(B.replace(/(^url\(#|\)$)/g,l));C&&C.parentNode.removeChild(C),q(i,{"clip-path":l}),delete d.clip}}break;case"path":d.type=="path"&&(q(i,{d:p?k.path=a._pathToAbsolute(p):"M0,0"}),d._.dirty=1,d._.arrows&&("startString"in d._.arrows&&t(d,d._.arrows.startString),"endString"in d._.arrows&&t(d,d._.arrows.endString,1)));break;case"width":i.setAttribute(o,p),d._.dirty=1;if(k.fx)o="x",p=k.x;else break;case"x":k.fx&&(p=-k.x-(k.width||0));case"rx":if(o=="rx"&&d.type=="rect")break;case"cx":i.setAttribute(o,p),d.pattern&&s(d),d._.dirty=1;break;case"height":i.setAttribute(o,p),d._.dirty=1;if(k.fy)o="y",p=k.y;else break;case"y":k.fy&&(p=-k.y-(k.height||0));case"ry":if(o=="ry"&&d.type=="rect")break;case"cy":i.setAttribute(o,p),d.pattern&&s(d),d._.dirty=1;break;case"r":d.type=="rect"?q(i,{rx:p,ry:p}):i.setAttribute(o,p),d._.dirty=1;break;case"src":d.type=="image"&&i.setAttributeNS(n,"href",p);break;case"stroke-width":if(d._.sx!=1||d._.sy!=1)p/=g(h(d._.sx),h(d._.sy))||1;d.paper._vbSize&&(p*=d.paper._vbSize),i.setAttribute(o,p),k["stroke-dasharray"]&&v(d,k["stroke-dasharray"],f),d._.arrows&&("startString"in d._.arrows&&t(d,d._.arrows.startString),"endString"in d._.arrows&&t(d,d._.arrows.endString,1));break;case"stroke-dasharray":v(d,p,f);break;case"fill":var D=c(p).match(a._ISURL);if(D){z=q("pattern");var F=q("image");z.id=a.createUUID(),q(z,{x:0,y:0,patternUnits:"userSpaceOnUse",height:1,width:1}),q(F,{x:0,y:0,"xlink:href":D[1]}),z.appendChild(F),function(b){a._preload(D[1],function(){var a=this.offsetWidth,c=this.offsetHeight;q(b,{width:a,height:c}),q(F,{width:a,height:c}),d.paper.safari()})}(z),d.paper.defs.appendChild(z),i.style.fill="url(#"+z.id+")",q(i,{fill:"url(#"+z.id+")"}),d.pattern=z,d.pattern&&s(d);break}var G=a.getRGB(p);if(!G.error)delete f.gradient,delete k.gradient,!a.is(k.opacity,"undefined")&&a.is(f.opacity,"undefined")&&q(i,{opacity:k.opacity}),!a.is(k["fill-opacity"],"undefined")&&a.is(f["fill-opacity"],"undefined")&&q(i,{"fill-opacity":k["fill-opacity"]});else if((d.type=="circle"||d.type=="ellipse"||c(p).charAt()!="r")&&r(d,p)){if("opacity"in k||"fill-opacity"in k){var H=a._g.doc.getElementById(i.getAttribute("fill").replace(/^url\(#|\)$/g,l));if(H){var I=H.getElementsByTagName("stop");q(I[I.length-1],{"stop-opacity":("opacity"in k?k.opacity:1)*("fill-opacity"in k?k["fill-opacity"]:1)})}}k.gradient=p,k.fill="none";break}G[b]("opacity")&&q(i,{"fill-opacity":G.opacity>1?G.opacity/100:G.opacity});case"stroke":G=a.getRGB(p),i.setAttribute(o,G.hex),o=="stroke"&&G[b]("opacity")&&q(i,{"stroke-opacity":G.opacity>1?G.opacity/100:G.opacity}),o=="stroke"&&d._.arrows&&("startString"in d._.arrows&&t(d,d._.arrows.startString),"endString"in d._.arrows&&t(d,d._.arrows.endString,1));break;case"gradient":(d.type=="circle"||d.type=="ellipse"||c(p).charAt()!="r")&&r(d,p);break;case"opacity":k.gradient&&!k[b]("stroke-opacity")&&q(i,{"stroke-opacity":p>1?p/100:p});case"fill-opacity":if(k.gradient){H=a._g.doc.getElementById(i.getAttribute("fill").replace(/^url\(#|\)$/g,l)),H&&(I=H.getElementsByTagName("stop"),q(I[I.length-1],{"stop-opacity":p}));break};default:o=="font-size"&&(p=e(p,10)+"px");var J=o.replace(/(\-.)/g,function(a){return a.substring(1).toUpperCase()});i.style[J]=p,d._.dirty=1,i.setAttribute(o,p)}}y(d,f),i.style.visibility=m},x=1.2,y=function(d,f){if(d.type=="text"&&!!(f[b]("text")||f[b]("font")||f[b]("font-size")||f[b]("x")||f[b]("y"))){var g=d.attrs,h=d.node,i=h.firstChild?e(a._g.doc.defaultView.getComputedStyle(h.firstChild,l).getPropertyValue("font-size"),10):10;if(f[b]("text")){g.text=f.text;while(h.firstChild)h.removeChild(h.firstChild);var j=c(f.text).split("\n"),k=[],m;for(var n=0,o=j.length;n<o;n++)m=q("tspan"),n&&q(m,{dy:i*x,x:g.x}),m.appendChild(a._g.doc.createTextNode(j[n])),h.appendChild(m),k[n]=m}else{k=h.getElementsByTagName("tspan");for(n=0,o=k.length;n<o;n++)n?q(k[n],{dy:i*x,x:g.x}):q(k[0],{dy:0})}q(h,{x:g.x,y:g.y}),d._.dirty=1;var p=d._getBBox(),r=g.y-(p.y+p.height/2);r&&a.is(r,"finite")&&q(k[0],{dy:r})}},z=function(b,c){var d=0,e=0;this[0]=this.node=b,b.raphael=!0,this.id=a._oid++,b.raphaelid=this.id,this.matrix=a.matrix(),this.realPath=null,this.paper=c,this.attrs=this.attrs||{},this._={transform:[],sx:1,sy:1,deg:0,dx:0,dy:0,dirty:1},!c.bottom&&(c.bottom=this),this.prev=c.top,c.top&&(c.top.next=this),c.top=this,this.next=null},A=a.el;z.prototype=A,A.constructor=z,a._engine.path=function(a,b){var c=q("path");b.canvas&&b.canvas.appendChild(c);var d=new z(c,b);d.type="path",w(d,{fill:"none",stroke:"#000",path:a});return d},A.rotate=function(a,b,e){if(this.removed)return this;a=c(a).split(j),a.length-1&&(b=d(a[1]),e=d(a[2])),a=d(a[0]),e==null&&(b=e);if(b==null||e==null){var f=this.getBBox(1);b=f.x+f.width/2,e=f.y+f.height/2}this.transform(this._.transform.concat([["r",a,b,e]]));return this},A.scale=function(a,b,e,f){if(this.removed)return this;a=c(a).split(j),a.length-1&&(b=d(a[1]),e=d(a[2]),f=d(a[3])),a=d(a[0]),b==null&&(b=a),f==null&&(e=f);if(e==null||f==null)var g=this.getBBox(1);e=e==null?g.x+g.width/2:e,f=f==null?g.y+g.height/2:f,this.transform(this._.transform.concat([["s",a,b,e,f]]));return this},A.translate=function(a,b){if(this.removed)return this;a=c(a).split(j),a.length-1&&(b=d(a[1])),a=d(a[0])||0,b=+b||0,this.transform(this._.transform.concat([["t",a,b]]));return this},A.transform=function(c){var d=this._;if(c==null)return d.transform;a._extractTransform(this,c),this.clip&&q(this.clip,{transform:this.matrix.invert()}),this.pattern&&s(this),this.node&&q(this.node,{transform:this.matrix});if(d.sx!=1||d.sy!=1){var e=this.attrs[b]("stroke-width")?this.attrs["stroke-width"]:1;this.attr({"stroke-width":e})}return this},A.hide=function(){!this.removed&&this.paper.safari(this.node.style.display="none");return this},A.show=function(){!this.removed&&this.paper.safari(this.node.style.display="");return this},A.remove=function(){if(!this.removed){var b=this.paper;b.__set__&&b.__set__.exclude(this),k.unbind("*.*."+this.id),this.gradient&&b.defs.removeChild(this.gradient),a._tear(this,b),this.node.parentNode.removeChild(this.node);for(var c in this)this[c]=typeof this[c]=="function"?a._removedFactory(c):null;this.removed=!0}},A._getBBox=function(){if(this.node.style.display=="none"){this.show();var a=!0}var b={};try{b=this.node.getBBox()}catch(c){}finally{b=b||{}}a&&this.hide();return b},A.attr=function(c,d){if(this.removed)return this;if(c==null){var e={};for(var f in this.attrs)this.attrs[b](f)&&(e[f]=this.attrs[f]);e.gradient&&e.fill=="none"&&(e.fill=e.gradient)&&delete e.gradient,e.transform=this._.transform;return e}if(d==null&&a.is(c,"string")){if(c=="fill"&&this.attrs.fill=="none"&&this.attrs.gradient)return this.attrs.gradient;if(c=="transform")return this._.transform;var g=c.split(j),h={};for(var i=0,l=g.length;i<l;i++)c=g[i],c in this.attrs?h[c]=this.attrs[c]:a.is(this.paper.customAttributes[c],"function")?h[c]=this.paper.customAttributes[c].def:h[c]=a._availableAttrs[c];return l-1?h:h[g[0]]}if(d==null&&a.is(c,"array")){h={};for(i=0,l=c.length;i<l;i++)h[c[i]]=this.attr(c[i]);return h}if(d!=null){var m={};m[c]=d}else c!=null&&a.is(c,"object")&&(m=c);for(var n in m)k("attr."+n+"."+this.id,this,m[n]);for(n in this.paper.customAttributes)if(this.paper.customAttributes[b](n)&&m[b](n)&&a.is(this.paper.customAttributes[n],"function")){var o=this.paper.customAttributes[n].apply(this,[].concat(m[n]));this.attrs[n]=m[n];for(var p in o)o[b](p)&&(m[p]=o[p])}w(this,m);return this},A.toFront=function(){if(this.removed)return this;this.node.parentNode.tagName.toLowerCase()=="a"?this.node.parentNode.parentNode.appendChild(this.node.parentNode):this.node.parentNode.appendChild(this.node);var b=this.paper;b.top!=this&&a._tofront(this,b);return this},A.toBack=function(){if(this.removed)return this;var b=this.node.parentNode;b.tagName.toLowerCase()=="a"?b.parentNode.insertBefore(this.node.parentNode,this.node.parentNode.parentNode.firstChild):b.firstChild!=this.node&&b.insertBefore(this.node,this.node.parentNode.firstChild),a._toback(this,this.paper);var c=this.paper;return this},A.insertAfter=function(b){if(this.removed)return this;var c=b.node||b[b.length-1].node;c.nextSibling?c.parentNode.insertBefore(this.node,c.nextSibling):c.parentNode.appendChild(this.node),a._insertafter(this,b,this.paper);return this},A.insertBefore=function(b){if(this.removed)return this;var c=b.node||b[0].node;c.parentNode.insertBefore(this.node,c),a._insertbefore(this,b,this.paper);return this},A.blur=function(b){var c=this;if(+b!==0){var d=q("filter"),e=q("feGaussianBlur");c.attrs.blur=b,d.id=a.createUUID(),q(e,{stdDeviation:+b||1.5}),d.appendChild(e),c.paper.defs.appendChild(d),c._blur=d,q(c.node,{filter:"url(#"+d.id+")"})}else c._blur&&(c._blur.parentNode.removeChild(c._blur),delete c._blur,delete c.attrs.blur),c.node.removeAttribute("filter")},a._engine.circle=function(a,b,c,d){var e=q("circle");a.canvas&&a.canvas.appendChild(e);var f=new z(e,a);f.attrs={cx:b,cy:c,r:d,fill:"none",stroke:"#000"},f.type="circle",q(e,f.attrs);return f},a._engine.rect=function(a,b,c,d,e,f){var g=q("rect");a.canvas&&a.canvas.appendChild(g);var h=new z(g,a);h.attrs={x:b,y:c,width:d,height:e,r:f||0,rx:f||0,ry:f||0,fill:"none",stroke:"#000"},h.type="rect",q(g,h.attrs);return h},a._engine.ellipse=function(a,b,c,d,e){var f=q("ellipse");a.canvas&&a.canvas.appendChild(f);var g=new z(f,a);g.attrs={cx:b,cy:c,rx:d,ry:e,fill:"none",stroke:"#000"},g.type="ellipse",q(f,g.attrs);return g},a._engine.image=function(a,b,c,d,e,f){var g=q("image");q(g,{x:c,y:d,width:e,height:f,preserveAspectRatio:"none"}),g.setAttributeNS(n,"href",b),a.canvas&&a.canvas.appendChild(g);var h=new z(g,a);h.attrs={x:c,y:d,width:e,height:f,src:b},h.type="image";return h},a._engine.text=function(b,c,d,e){var f=q("text");b.canvas&&b.canvas.appendChild(f);var g=new z(f,b);g.attrs={x:c,y:d,"text-anchor":"middle",text:e,font:a._availableAttrs.font,stroke:"none",fill:"#000"},g.type="text",w(g,g.attrs);return g},a._engine.setSize=function(a,b){this.width=a||this.width,this.height=b||this.height,this.canvas.setAttribute("width",this.width),this.canvas.setAttribute("height",this.height),this._viewBox&&this.setViewBox.apply(this,this._viewBox);return this},a._engine.create=function(){var b=a._getContainer.apply(0,arguments),c=b&&b.container,d=b.x,e=b.y,f=b.width,g=b.height;if(!c)throw new Error("SVG container not found.");var h=q("svg"),i="overflow:hidden;",j;d=d||0,e=e||0,f=f||512,g=g||342,q(h,{height:g,version:1.1,width:f,xmlns:"http://www.w3.org/2000/svg"}),c==1?(h.style.cssText=i+"position:absolute;left:"+d+"px;top:"+e+"px",a._g.doc.body.appendChild(h),j=1):(h.style.cssText=i+"position:relative",c.firstChild?c.insertBefore(h,c.firstChild):c.appendChild(h)),c=new a._Paper,c.width=f,c.height=g,c.canvas=h,c.clear(),c._left=c._top=0,j&&(c.renderfix=function(){}),c.renderfix();return c},a._engine.setViewBox=function(a,b,c,d,e){k("setViewBox",this,this._viewBox,[a,b,c,d,e]);var f=g(c/this.width,d/this.height),h=this.top,i=e?"meet":"xMinYMin",j,l;a==null?(this._vbSize&&(f=1),delete this._vbSize,j="0 0 "+this.width+m+this.height):(this._vbSize=f,j=a+m+b+m+c+m+d),q(this.canvas,{viewBox:j,preserveAspectRatio:i});while(f&&h)l="stroke-width"in h.attrs?h.attrs["stroke-width"]:1,h.attr({"stroke-width":l}),h._.dirty=1,h._.dirtyT=1,h=h.prev;this._viewBox=[a,b,c,d,!!e];return this},a.prototype.renderfix=function(){var a=this.canvas,b=a.style,c=a.getScreenCTM()||a.createSVGMatrix(),d=-c.e%1,e=-c.f%1;if(d||e)d&&(this._left=(this._left+d)%1,b.left=this._left+"px"),e&&(this._top=(this._top+e)%1,b.top=this._top+"px")},a.prototype.clear=function(){a.eve("clear",this);var b=this.canvas;while(b.firstChild)b.removeChild(b.firstChild);this.bottom=this.top=null,(this.desc=q("desc")).appendChild(a._g.doc.createTextNode("Created with Raphaël "+a.version)),b.appendChild(this.desc),b.appendChild(this.defs=q("defs"))},a.prototype.remove=function(){k("remove",this),this.canvas.parentNode&&this.canvas.parentNode.removeChild(this.canvas);for(var b in this)this[b]=typeof this[b]=="function"?a._removedFactory(b):null};var B=a.st;for(var C in A)A[b](C)&&!B[b](C)&&(B[C]=function(a){return function(){var b=arguments;return this.forEach(function(c){c[a].apply(c,b)})}}(C))}(window.Raphael),window.Raphael.vml&&function(a){var b="hasOwnProperty",c=String,d=parseFloat,e=Math,f=e.round,g=e.max,h=e.min,i=e.abs,j="fill",k=/[, ]+/,l=a.eve,m=" progid:DXImageTransform.Microsoft",n=" ",o="",p={M:"m",L:"l",C:"c",Z:"x",m:"t",l:"r",c:"v",z:"x"},q=/([clmz]),?([^clmz]*)/gi,r=/ progid:\S+Blur\([^\)]+\)/g,s=/-?[^,\s-]+/g,t="position:absolute;left:0;top:0;width:1px;height:1px",u=21600,v={path:1,rect:1,image:1},w={circle:1,ellipse:1},x=function(b){var d=/[ahqstv]/ig,e=a._pathToAbsolute;c(b).match(d)&&(e=a._path2curve),d=/[clmz]/g;if(e==a._pathToAbsolute&&!c(b).match(d)){var g=c(b).replace(q,function(a,b,c){var d=[],e=b.toLowerCase()=="m",g=p[b];c.replace(s,function(a){e&&d.length==2&&(g+=d+p[b=="m"?"l":"L"],d=[]),d.push(f(a*u))});return g+d});return g}var h=e(b),i,j;g=[];for(var k=0,l=h.length;k<l;k++){i=h[k],j=h[k][0].toLowerCase(),j=="z"&&(j="x");for(var m=1,r=i.length;m<r;m++)j+=f(i[m]*u)+(m!=r-1?",":o);g.push(j)}return g.join(n)},y=function(b,c,d){var e=a.matrix();e.rotate(-b,.5,.5);return{dx:e.x(c,d),dy:e.y(c,d)}},z=function(a,b,c,d,e,f){var g=a._,h=a.matrix,k=g.fillpos,l=a.node,m=l.style,o=1,p="",q,r=u/b,s=u/c;m.visibility="hidden";if(!!b&&!!c){l.coordsize=i(r)+n+i(s),m.rotation=f*(b*c<0?-1:1);if(f){var t=y(f,d,e);d=t.dx,e=t.dy}b<0&&(p+="x"),c<0&&(p+=" y")&&(o=-1),m.flip=p,l.coordorigin=d*-r+n+e*-s;if(k||g.fillsize){var v=l.getElementsByTagName(j);v=v&&v[0],l.removeChild(v),k&&(t=y(f,h.x(k[0],k[1]),h.y(k[0],k[1])),v.position=t.dx*o+n+t.dy*o),g.fillsize&&(v.size=g.fillsize[0]*i(b)+n+g.fillsize[1]*i(c)),l.appendChild(v)}m.visibility="visible"}};a.toString=function(){return"Your browser doesn’t support SVG. Falling down to VML.\nYou are running Raphaël "+this.version};var A=function(a,b,d){var e=c(b).toLowerCase().split("-"),f=d?"end":"start",g=e.length,h="classic",i="medium",j="medium";while(g--)switch(e[g]){case"block":case"classic":case"oval":case"diamond":case"open":case"none":h=e[g];break;case"wide":case"narrow":j=e[g];break;case"long":case"short":i=e[g]}var k=a.node.getElementsByTagName("stroke")[0];k[f+"arrow"]=h,k[f+"arrowlength"]=i,k[f+"arrowwidth"]=j},B=function(e,i){e.attrs=e.attrs||{};var l=e.node,m=e.attrs,p=l.style,q,r=v[e.type]&&(i.x!=m.x||i.y!=m.y||i.width!=m.width||i.height!=m.height||i.cx!=m.cx||i.cy!=m.cy||i.rx!=m.rx||i.ry!=m.ry||i.r!=m.r),s=w[e.type]&&(m.cx!=i.cx||m.cy!=i.cy||m.r!=i.r||m.rx!=i.rx||m.ry!=i.ry),t=e;for(var y in i)i[b](y)&&(m[y]=i[y]);r&&(m.path=a._getPath[e.type](e),e._.dirty=1),i.href&&(l.href=i.href),i.title&&(l.title=i.title),i.target&&(l.target=i.target),i.cursor&&(p.cursor=i.cursor),"blur"in i&&e.blur(i.blur);if(i.path&&e.type=="path"||r)l.path=x(~c(m.path).toLowerCase().indexOf("r")?a._pathToAbsolute(m.path):m.path),e.type=="image"&&(e._.fillpos=[m.x,m.y],e._.fillsize=[m.width,m.height],z(e,1,1,0,0,0));"transform"in i&&e.transform(i.transform);if(s){var B=+m.cx,D=+m.cy,E=+m.rx||+m.r||0,G=+m.ry||+m.r||0;l.path=a.format("ar{0},{1},{2},{3},{4},{1},{4},{1}x",f((B-E)*u),f((D-G)*u),f((B+E)*u),f((D+G)*u),f(B*u))}if("clip-rect"in i){var H=c(i["clip-rect"]).split(k);if(H.length==4){H[2]=+H[2]+ +H[0],H[3]=+H[3]+ +H[1];var I=l.clipRect||a._g.doc.createElement("div"),J=I.style;J.clip=a.format("rect({1}px {2}px {3}px {0}px)",H),l.clipRect||(J.position="absolute",J.top=0,J.left=0,J.width=e.paper.width+"px",J.height=e.paper.height+"px",l.parentNode.insertBefore(I,l),I.appendChild(l),l.clipRect=I)}i["clip-rect"]||l.clipRect&&(l.clipRect.style.clip="auto")}if(e.textpath){var K=e.textpath.style;i.font&&(K.font=i.font),i["font-family"]&&(K.fontFamily='"'+i["font-family"].split(",")[0].replace(/^['"]+|['"]+$/g,o)+'"'),i["font-size"]&&(K.fontSize=i["font-size"]),i["font-weight"]&&(K.fontWeight=i["font-weight"]),i["font-style"]&&(K.fontStyle=i["font-style"])}"arrow-start"in i&&A(t,i["arrow-start"]),"arrow-end"in i&&A(t,i["arrow-end"],1);if(i.opacity!=null||i["stroke-width"]!=null||i.fill!=null||i.src!=null||i.stroke!=null||i["stroke-width"]!=null||i["stroke-opacity"]!=null||i["fill-opacity"]!=null||i["stroke-dasharray"]!=null||i["stroke-miterlimit"]!=null||i["stroke-linejoin"]!=null||i["stroke-linecap"]!=null){var L=l.getElementsByTagName(j),M=!1;L=L&&L[0],!L&&(M=L=F(j)),e.type=="image"&&i.src&&(L.src=i.src),i.fill&&(L.on=!0);if(L.on==null||i.fill=="none"||i.fill===null)L.on=!1;if(L.on&&i.fill){var N=c(i.fill).match(a._ISURL);if(N){L.parentNode==l&&l.removeChild(L),L.rotate=!0,L.src=N[1],L.type="tile";var O=e.getBBox(1);L.position=O.x+n+O.y,e._.fillpos=[O.x,O.y],a._preload(N[1],function(){e._.fillsize=[this.offsetWidth,this.offsetHeight]})}else L.color=a.getRGB(i.fill).hex,L.src=o,L.type="solid",a.getRGB(i.fill).error&&(t.type in{circle:1,ellipse:1}||c(i.fill).charAt()!="r")&&C(t,i.fill,L)&&(m.fill="none",m.gradient=i.fill,L.rotate=!1)}if("fill-opacity"in i||"opacity"in i){var P=((+m["fill-opacity"]+1||2)-1)*((+m.opacity+1||2)-1)*((+a.getRGB(i.fill).o+1||2)-1);P=h(g(P,0),1),L.opacity=P,L.src&&(L.color="none")}l.appendChild(L);var Q=l.getElementsByTagName("stroke")&&l.getElementsByTagName("stroke")[0],T=!1;!Q&&(T=Q=F("stroke"));if(i.stroke&&i.stroke!="none"||i["stroke-width"]||i["stroke-opacity"]!=null||i["stroke-dasharray"]||i["stroke-miterlimit"]||i["stroke-linejoin"]||i["stroke-linecap"])Q.on=!0;(i.stroke=="none"||i.stroke===null||Q.on==null||i.stroke==0||i["stroke-width"]==0)&&(Q.on=!1);var U=a.getRGB(i.stroke);Q.on&&i.stroke&&(Q.color=U.hex),P=((+m["stroke-opacity"]+1||2)-1)*((+m.opacity+1||2)-1)*((+U.o+1||2)-1);var V=(d(i["stroke-width"])||1)*.75;P=h(g(P,0),1),i["stroke-width"]==null&&(V=m["stroke-width"]),i["stroke-width"]&&(Q.weight=V),V&&V<1&&(P*=V)&&(Q.weight=1),Q.opacity=P,i["stroke-linejoin"]&&(Q.joinstyle=i["stroke-linejoin"]||"miter"),Q.miterlimit=i["stroke-miterlimit"]||8,i["stroke-linecap"]&&(Q.endcap=i["stroke-linecap"]=="butt"?"flat":i["stroke-linecap"]=="square"?"square":"round");if(i["stroke-dasharray"]){var W={"-":"shortdash",".":"shortdot","-.":"shortdashdot","-..":"shortdashdotdot",". ":"dot","- ":"dash","--":"longdash","- .":"dashdot","--.":"longdashdot","--..":"longdashdotdot"};Q.dashstyle=W[b](i["stroke-dasharray"])?W[i["stroke-dasharray"]]:o}T&&l.appendChild(Q)}if(t.type=="text"){t.paper.canvas.style.display=o;var X=t.paper.span,Y=100,Z=m.font&&m.font.match(/\d+(?:\.\d*)?(?=px)/);p=X.style,m.font&&(p.font=m.font),m["font-family"]&&(p.fontFamily=m["font-family"]),m["font-weight"]&&(p.fontWeight=m["font-weight"]),m["font-style"]&&(p.fontStyle=m["font-style"]),Z=d(m["font-size"]||Z&&Z[0])||10,p.fontSize=Z*Y+"px",t.textpath.string&&(X.innerHTML=c(t.textpath.string).replace(/</g,"&#60;").replace(/&/g,"&#38;").replace(/\n/g,"<br>"));var $=X.getBoundingClientRect();t.W=m.w=($.right-$.left)/Y,t.H=m.h=($.bottom-$.top)/Y,t.X=m.x,t.Y=m.y+t.H/2,("x"in i||"y"in i)&&(t.path.v=a.format("m{0},{1}l{2},{1}",f(m.x*u),f(m.y*u),f(m.x*u)+1));var _=["x","y","text","font","font-family","font-weight","font-style","font-size"];for(var ba=0,bb=_.length;ba<bb;ba++)if(_[ba]in i){t._.dirty=1;break}switch(m["text-anchor"]){case"start":t.textpath.style["v-text-align"]="left",t.bbx=t.W/2;break;case"end":t.textpath.style["v-text-align"]="right",t.bbx=-t.W/2;break;default:t.textpath.style["v-text-align"]="center",t.bbx=0}t.textpath.style["v-text-kern"]=!0}},C=function(b,f,g){b.attrs=b.attrs||{};var h=b.attrs,i=Math.pow,j,k,l="linear",m=".5 .5";b.attrs.gradient=f,f=c(f).replace(a._radial_gradient,function(a,b,c){l="radial",b&&c&&(b=d(b),c=d(c),i(b-.5,2)+i(c-.5,2)>.25&&(c=e.sqrt(.25-i(b-.5,2))*((c>.5)*2-1)+.5),m=b+n+c);return o}),f=f.split(/\s*\-\s*/);if(l=="linear"){var p=f.shift();p=-d(p);if(isNaN(p))return null}var q=a._parseDots(f);if(!q)return null;b=b.shape||b.node;if(q.length){b.removeChild(g),g.on=!0,g.method="none",g.color=q[0].color,g.color2=q[q.length-1].color;var r=[];for(var s=0,t=q.length;s<t;s++)q[s].offset&&r.push(q[s].offset+n+q[s].color);g.colors=r.length?r.join():"0% "+g.color,l=="radial"?(g.type="gradientTitle",g.focus="100%",g.focussize="0 0",g.focusposition=m,g.angle=0):(g.type="gradient",g.angle=(270-p)%360),b.appendChild(g)}return 1},D=function(b,c){this[0]=this.node=b,b.raphael=!0,this.id=a._oid++,b.raphaelid=this.id,this.X=0,this.Y=0,this.attrs={},this.paper=c,this.matrix=a.matrix(),this._={transform:[],sx:1,sy:1,dx:0,dy:0,deg:0,dirty:1,dirtyT:1},!c.bottom&&(c.bottom=this),this.prev=c.top,c.top&&(c.top.next=this),c.top=this,this.next=null},E=a.el;D.prototype=E,E.constructor=D,E.transform=function(b){if(b==null)return this._.transform;var d=this.paper._viewBoxShift,e=d?"s"+[d.scale,d.scale]+"-1-1t"+[d.dx,d.dy]:o,f;d&&(f=b=c(b).replace(/\.{3}|\u2026/g,this._.transform||o)),a._extractTransform(this,e+b);var g=this.matrix.clone(),h=this.skew,i=this.node,j,k=~c(this.attrs.fill).indexOf("-"),l=!c(this.attrs.fill).indexOf("url(");g.translate(-0.5,-0.5);if(l||k||this.type=="image"){h.matrix="1 0 0 1",h.offset="0 0",j=g.split();if(k&&j.noRotation||!j.isSimple){i.style.filter=g.toFilter();var m=this.getBBox(),p=this.getBBox(1),q=m.x-p.x,r=m.y-p.y;i.coordorigin=q*-u+n+r*-u,z(this,1,1,q,r,0)}else i.style.filter=o,z(this,j.scalex,j.scaley,j.dx,j.dy,j.rotate)}else i.style.filter=o,h.matrix=c(g),h.offset=g.offset();f&&(this._.transform=f);return this},E.rotate=function(a,b,e){if(this.removed)return this;if(a!=null){a=c(a).split(k),a.length-1&&(b=d(a[1]),e=d(a[2])),a=d(a[0]),e==null&&(b=e);if(b==null||e==null){var f=this.getBBox(1);b=f.x+f.width/2,e=f.y+f.height/2}this._.dirtyT=1,this.transform(this._.transform.concat([["r",a,b,e]]));return this}},E.translate=function(a,b){if(this.removed)return this;a=c(a).split(k),a.length-1&&(b=d(a[1])),a=d(a[0])||0,b=+b||0,this._.bbox&&(this._.bbox.x+=a,this._.bbox.y+=b),this.transform(this._.transform.concat([["t",a,b]]));return this},E.scale=function(a,b,e,f){if(this.removed)return this;a=c(a).split(k),a.length-1&&(b=d(a[1]),e=d(a[2]),f=d(a[3]),isNaN(e)&&(e=null),isNaN(f)&&(f=null)),a=d(a[0]),b==null&&(b=a),f==null&&(e=f);if(e==null||f==null)var g=this.getBBox(1);e=e==null?g.x+g.width/2:e,f=f==null?g.y+g.height/2:f,this.transform(this._.transform.concat([["s",a,b,e,f]])),this._.dirtyT=1;return this},E.hide=function(){!this.removed&&(this.node.style.display="none");return this},E.show=function(){!this.removed&&(this.node.style.display=o);return this},E._getBBox=function(){if(this.removed)return{};return{x:this.X+(this.bbx||0)-this.W/2,y:this.Y-this.H,width:this.W,height:this.H}},E.remove=function(){if(!this.removed){this.paper.__set__&&this.paper.__set__.exclude(this),a.eve.unbind("*.*."+this.id),a._tear(this,this.paper),this.node.parentNode.removeChild(this.node),this.shape&&this.shape.parentNode.removeChild(this.shape);for(var b in this)this[b]=typeof this[b]=="function"?a._removedFactory(b):null;this.removed=!0}},E.attr=function(c,d){if(this.removed)return this;if(c==null){var e={};for(var f in this.attrs)this.attrs[b](f)&&(e[f]=this.attrs[f]);e.gradient&&e.fill=="none"&&(e.fill=e.gradient)&&delete e.gradient,e.transform=this._.transform;return e}if(d==null&&a.is(c,"string")){if(c==j&&this.attrs.fill=="none"&&this.attrs.gradient)return this.attrs.gradient;var g=c.split(k),h={};for(var i=0,m=g.length;i<m;i++)c=g[i],c in this.attrs?h[c]=this.attrs[c]:a.is(this.paper.customAttributes[c],"function")?h[c]=this.paper.customAttributes[c].def:h[c]=a._availableAttrs[c];return m-1?h:h[g[0]]}if(this.attrs&&d==null&&a.is(c,"array")){h={};for(i=0,m=c.length;i<m;i++)h[c[i]]=this.attr(c[i]);return h}var n;d!=null&&(n={},n[c]=d),d==null&&a.is(c,"object")&&(n=c);for(var o in n)l("attr."+o+"."+this.id,this,n[o]);if(n){for(o in this.paper.customAttributes)if(this.paper.customAttributes[b](o)&&n[b](o)&&a.is(this.paper.customAttributes[o],"function")){var p=this.paper.customAttributes[o].apply(this,[].concat(n[o]));this.attrs[o]=n[o];for(var q in p)p[b](q)&&(n[q]=p[q])}n.text&&this.type=="text"&&(this.textpath.string=n.text),B(this,n)}return this},E.toFront=function(){!this.removed&&this.node.parentNode.appendChild(this.node),this.paper&&this.paper.top!=this&&a._tofront(this,this.paper);return this},E.toBack=function(){if(this.removed)return this;this.node.parentNode.firstChild!=this.node&&(this.node.parentNode.insertBefore(this.node,this.node.parentNode.firstChild),a._toback(this,this.paper));return this},E.insertAfter=function(b){if(this.removed)return this;b.constructor==a.st.constructor&&(b=b[b.length-1]),b.node.nextSibling?b.node.parentNode.insertBefore(this.node,b.node.nextSibling):b.node.parentNode.appendChild(this.node),a._insertafter(this,b,this.paper);return this},E.insertBefore=function(b){if(this.removed)return this;b.constructor==a.st.constructor&&(b=b[0]),b.node.parentNode.insertBefore(this.node,b.node),a._insertbefore(this,b,this.paper);return this},E.blur=function(b){var c=this.node.runtimeStyle,d=c.filter;d=d.replace(r,o),+b!==0?(this.attrs.blur=b,c.filter=d+n+m+".Blur(pixelradius="+(+b||1.5)+")",c.margin=a.format("-{0}px 0 0 -{0}px",f(+b||1.5))):(c.filter=d,c.margin=0,delete this.attrs.blur)},a._engine.path=function(a,b){var c=F("shape");c.style.cssText=t,c.coordsize=u+n+u,c.coordorigin=b.coordorigin;var d=new D(c,b),e={fill:"none",stroke:"#000"};a&&(e.path=a),d.type="path",d.path=[],d.Path=o,B(d,e),b.canvas.appendChild(c);var f=F("skew");f.on=!0,c.appendChild(f),d.skew=f,d.transform(o);return d},a._engine.rect=function(b,c,d,e,f,g){var h=a._rectPath(c,d,e,f,g),i=b.path(h),j=i.attrs;i.X=j.x=c,i.Y=j.y=d,i.W=j.width=e,i.H=j.height=f,j.r=g,j.path=h,i.type="rect";return i},a._engine.ellipse=function(a,b,c,d,e){var f=a.path(),g=f.attrs;f.X=b-d,f.Y=c-e,f.W=d*2,f.H=e*2,f.type="ellipse",B(f,{cx:b,cy:c,rx:d,ry:e});return f},a._engine.circle=function(a,b,c,d){var e=a.path(),f=e.attrs;e.X=b-d,e.Y=c-d,e.W=e.H=d*2,e.type="circle",B(e,{cx:b,cy:c,r:d});return e},a._engine.image=function(b,c,d,e,f,g){var h=a._rectPath(d,e,f,g),i=b.path(h).attr({stroke:"none"}),k=i.attrs,l=i.node,m=l.getElementsByTagName(j)[0];k.src=c,i.X=k.x=d,i.Y=k.y=e,i.W=k.width=f,i.H=k.height=g,k.path=h,i.type="image",m.parentNode==l&&l.removeChild(m),m.rotate=!0,m.src=c,m.type="tile",i._.fillpos=[d,e],i._.fillsize=[f,g],l.appendChild(m),z(i,1,1,0,0,0);return i},a._engine.text=function(b,d,e,g){var h=F("shape"),i=F("path"),j=F("textpath");d=d||0,e=e||0,g=g||"",i.v=a.format("m{0},{1}l{2},{1}",f(d*u),f(e*u),f(d*u)+1),i.textpathok=!0,j.string=c(g),j.on=!0,h.style.cssText=t,h.coordsize=u+n+u,h.coordorigin="0 0";var k=new D(h,b),l={fill:"#000",stroke:"none",font:a._availableAttrs.font,text:g};k.shape=h,k.path=i,k.textpath=j,k.type="text",k.attrs.text=c(g),k.attrs.x=d,k.attrs.y=e,k.attrs.w=1,k.attrs.h=1,B(k,l),h.appendChild(j),h.appendChild(i),b.canvas.appendChild(h);var m=F("skew");m.on=!0,h.appendChild(m),k.skew=m,k.transform(o);return k},a._engine.setSize=function(b,c){var d=this.canvas.style;this.width=b,this.height=c,b==+b&&(b+="px"),c==+c&&(c+="px"),d.width=b,d.height=c,d.clip="rect(0 "+b+" "+c+" 0)",this._viewBox&&a._engine.setViewBox.apply(this,this._viewBox);return this},a._engine.setViewBox=function(b,c,d,e,f){a.eve("setViewBox",this,this._viewBox,[b,c,d,e,f]);var h=this.width,i=this.height,j=1/g(d/h,e/i),k,l;f&&(k=i/e,l=h/d,d*k<h&&(b-=(h-d*k)/2/k),e*l<i&&(c-=(i-e*l)/2/l)),this._viewBox=[b,c,d,e,!!f],this._viewBoxShift={dx:-b,dy:-c,scale:j},this.forEach(function(a){a.transform("...")});return this};var F;a._engine.initWin=function(a){var b=a.document;b.createStyleSheet().addRule(".rvml","behavior:url(#default#VML)");try{!b.namespaces.rvml&&b.namespaces.add("rvml","urn:schemas-microsoft-com:vml"),F=function(a){return b.createElement("<rvml:"+a+' class="rvml">')}}catch(c){F=function(a){return b.createElement("<"+a+' xmlns="urn:schemas-microsoft.com:vml" class="rvml">')}}},a._engine.initWin(a._g.win),a._engine.create=function(){var b=a._getContainer.apply(0,arguments),c=b.container,d=b.height,e,f=b.width,g=b.x,h=b.y;if(!c)throw new Error("VML container not found.");var i=new a._Paper,j=i.canvas=a._g.doc.createElement("div"),k=j.style;g=g||0,h=h||0,f=f||512,d=d||342,i.width=f,i.height=d,f==+f&&(f+="px"),d==+d&&(d+="px"),i.coordsize=u*1e3+n+u*1e3,i.coordorigin="0 0",i.span=a._g.doc.createElement("span"),i.span.style.cssText="position:absolute;left:-9999em;top:-9999em;padding:0;margin:0;line-height:1;",j.appendChild(i.span),k.cssText=a.format("top:0;left:0;width:{0};height:{1};display:inline-block;position:relative;clip:rect(0 {0} {1} 0);overflow:hidden",f,d),c==1?(a._g.doc.body.appendChild(j),k.left=g+"px",k.top=h+"px",k.position="absolute"):c.firstChild?c.insertBefore(j,c.firstChild):c.appendChild(j),i.renderfix=function(){};return i},a.prototype.clear=function(){a.eve("clear",this),this.canvas.innerHTML=o,this.span=a._g.doc.createElement("span"),this.span.style.cssText="position:absolute;left:-9999em;top:-9999em;padding:0;margin:0;line-height:1;display:inline;",this.canvas.appendChild(this.span),this.bottom=this.top=null},a.prototype.remove=function(){a.eve("remove",this),this.canvas.parentNode.removeChild(this.canvas);for(var b in this)this[b]=typeof this[b]=="function"?a._removedFactory(b):null;return!0};var G=a.st;for(var H in E)E[b](H)&&!G[b](H)&&(G[H]=function(a){return function(){var b=arguments;return this.forEach(function(c){c[a].apply(c,b)})}}(H))}(window.Raphael);
(function(a){"use strict";a.widget("wijmo.wijpager",{options:{firstPageClass:"ui-icon-seek-first",firstPageText:"First",lastPageClass:"ui-icon-seek-end",lastPageText:"Last",mode:"numeric",nextPageClass:"ui-icon-seek-next",nextPageText:"Next",pageButtonCount:10,previousPageClass:"ui-icon-seek-prev",previousPageText:"Previous",pageCount:1,pageIndex:0,pageIndexChanging:null,pageIndexChanged:null},_create:function(){this.element.addClass("ui-widget wijmo-wijpager ui-helper-clearfix");this.options.disabled&&this.disable();this._refresh()},_init:function(){},destroy:function(){this.element.removeClass("ui-widget wijmo-wijpager ui-helper-clearfix");this.$ul.remove();a.Widget.prototype.destroy.apply(this,arguments)},_setOption:function(){a.Widget.prototype._setOption.apply(this,arguments);this._refresh()},_refresh:function(){this._validate();this.$ul&&this.$ul.remove();this.element.append(this.$ul=a('<ul class="ui-list ui-corner-all ui-widget-content ui-helper-clearfix" role="tablist"></ul>'));switch((this.options.mode||"").toLowerCase()){case"nextprevious":this._createNextPrev(false);break;case"nextpreviousfirstlast":this._createNextPrev(true);break;case"numeric":this._createNumeric(false);break;case"numericfirstlast":this._createNumeric(true)}},_validate:function(){var a=this.options;if(isNaN(a.pageCount)||a.pageCount<1)a.pageCount=1;if(isNaN(a.pageIndex)||a.pageIndex<0)a.pageIndex=0;else if(a.pageIndex>=a.pageCount)a.pageIndex=a.pageCount-1;if(isNaN(a.pageButtonCount)||a.pageButtonCount<1)a.pageButtonCount=1},_createNextPrev:function(b){var a=this.options;b&&a.pageIndex&&this.$ul.append(this._createPagerItem(false,a.firstPageText,1,a.firstPageClass));a.pageIndex&&this.$ul.append(this._createPagerItem(false,a.previousPageText,a.pageIndex,a.previousPageClass));a.pageIndex+1<a.pageCount&&this.$ul.append(this._createPagerItem(false,a.nextPageText,a.pageIndex+2,a.nextPageClass));b&&a.pageIndex+1<a.pageCount&&this.$ul.append(this._createPagerItem(false,a.lastPageText,a.pageCount,a.lastPageClass))},_createNumeric:function(e){var a=this.options,f=a.pageIndex+1,c=1,b=Math.min(a.pageCount,a.pageButtonCount),d;if(f>b){c=Math.floor(a.pageIndex/a.pageButtonCount)*a.pageButtonCount+1;b=c+a.pageButtonCount-1;b=Math.min(b,a.pageCount);if(b-c+1<a.pageButtonCount)c=Math.max(1,b-a.pageButtonCount+1)}if(c!==1){e&&this.$ul.append(this._createPagerItem(false,a.firstPageText,1,a.firstPageClass));this.$ul.append(this._createPagerItem(false,"...",c-1,""))}for(d=c;d<=b;d++)this.$ul.append(this._createPagerItem(d===f,d.toString(),d,""));if(a.pageCount>b){this.$ul.append(this._createPagerItem(false,"...",b+1,""));e&&this.$ul.append(this._createPagerItem(false,a.lastPageText,a.pageCount,a.lastPageClass))}},_createPagerItem:function(f,d,g,e){var b,c=a("<li />").addClass("ui-page ui-corner-all").attr({role:"tab","aria-label":d,title:d});if(f)c.addClass("ui-state-active").attr("aria-selected","true");else c.addClass("ui-state-default").hover(function(){a(this).removeClass("ui-state-default").addClass("ui-state-hover")},function(){a(this).removeClass("ui-state-hover").addClass("ui-state-default")}).bind("click."+this.widgetName,{newPageIndex:g-1},a.proxy(this._onClick,this));if(f)b=a("<span />");else b=e?a("<span />").addClass("ui-icon "+e):a("<a/>").attr("href","#");b.text(d);c.append(b);return c},_onClick:function(b){if(this.options.disabled)return false;var a={newPageIndex:b.data.newPageIndex,handled:false};if(this._trigger("pageIndexChanging",null,a)!==false)if(this.options.pageIndex!==a.newPageIndex){this.options.pageIndex=a.newPageIndex;!a.handled&&this._refresh();this._trigger("pageIndexChanged",null,{newPageIndex:a.newPageIndex})}return false}})})(jQuery);
(function(a){"use strict";a.fn.extend({wijtextselection:function(){var c,e,g=this[0],d=this.val();if(arguments.length===0){var b,i,f,h;if(a.browser.msie){var k=document.selection;if(g.tagName.toLowerCase()!="textarea"){b=k.createRange().duplicate();b.moveEnd("character",d.length);f=b.text==""?d.length:d.lastIndexOf(b.text);b=k.createRange().duplicate();b.moveStart("character",-d.length);h=b.text.length}else{b=k.createRange();i=b.duplicate();i.moveToElementText(g);i.setEndPoint("EndToEnd",b);f=i.text.length-b.text.length,h=f+b.text.length}}else{f=g.selectionStart;h=g.selectionEnd}var m=d.substring(f,h);return{start:f,end:h,text:m,replace:function(a){return d.substring(0,f)+a+d.substring(h,d.length)}}}else if(arguments.length===1){if(typeof arguments[0]==="object"&&typeof arguments[0].start==="number"&&typeof arguments[0].end==="number"){c=arguments[0].start;e=arguments[0].end}else if(typeof arguments[0]==="string"){if((c=d.indexOf(arguments[0]))>-1)e=c+arguments[0].length}else if(Object.prototype.toString.call(arguments[0])==="[object RegExp]"){var l=arguments[0].exec(d);if(l!=null){c=l.index;e=c+l[0].length}}}else if(arguments.length===2)if(typeof arguments[0]==="number"&&typeof arguments[1]==="number"){c=arguments[0];e=arguments[1]}if(typeof c==="undefined"){c=0;e=d.length}if(a.browser.msie){var j=g.createTextRange();j.collapse(true);j.moveStart("character",c);j.moveEnd("character",e-c);j.select()}else{g.selectionStart=c;g.selectionEnd=e}}})})(jQuery);
(function(a){"use strict";var c,b,d;c=function(b){var a=this;a.data={};a.reader=null;a.proxy=null;a.items=[];a.loading=null;a.loaded=null;a._constructor(b)};window.wijdatasource=c;a.extend(c.prototype,{_constructor:function(b){a.extend(this,b)},load:function(c,e){var b=this,d=b.proxy;a.isFunction(b.loading)&&b.loading(b,c);if(d)d.request(b,b.loaded,c);else{(b.items.length===0||e)&&this.read();a.isFunction(b.loaded)&&b.loaded(b,c)}},read:function(){var a=this,b=a.data;if(b&&a.reader)a.reader.read(a);else a.items=a.data}});b=function(b){if(a.isArray(b))this.fields=b};window.wijarrayreader=b;a.extend(b.prototype,{read:function(b){if(a.isArray(b.data))b.items=this._map(b.data);else b.items=[]},_map:function(d){var c=this,b=[];if(c.fields===undefined||c.fields.length===0){a.extend(true,b,d);return b}else a.each(d,function(f,d){var e={};a.each(c.fields,function(g,b){if(a.isFunction(b.mapping)){e[b.name]=b.mapping(d);return true}var f=b.mapping!==undefined?b.mapping:b.name,c=d[f];if(c===undefined)if(b.defaultValue!==undefined)c=b.defaultValue;else c=d;e[b.name]=c});b.push(e)});return b}});d=function(a){this.options=a};window.wijhttpproxy=d;a.extend(d.prototype,{request:function(d,e,f){var g=this,b=a.extend({},this.options),c=b.success;b.success=function(h){a.isFunction(c)&&c(h);g._complete(h,d,e,b,f)};a.ajax(b)},_complete:function(e,b,c,d,f){b.data=d.key!==undefined?e[d.key]:e;b.read();a.isFunction(c)&&c(b,f)}})})(jQuery);
(function(a){"use strict";var g="wijmo-wijcombobox-input",c="ui-state-hover",d="ui-state-active",b="ui-state-focus",f="ui-corner-left",e="ui-corner-right",h="<div class='wijmo-wijcombobox-trigger ui-state-default ui-corner-right'><span class='ui-icon ui-icon-triangle-1-s'></span></div>",i="<label class='wijmo-wijcombobox-label ui-widget-content'></label>";a.widget("wijmo.wijcombobox",{options:{data:null,labelText:null,minLength:4,delay:300,showingAnimation:null,hidingAnimation:null,showTrigger:true,triggerPosition:"right",dropdownHeight:300,dropdownWidth:"auto",selectOnItemFocus:false,autoFilter:true,autoComplete:true,highlightMatching:true,dropDownListPosition:{},columns:[],selectionMode:"single",multipleSelectionSeparator:",",forceSelectionText:false,select:null,isEditable:true,selectedIndex:-1,selectedValue:null,open:null,close:null,selectElementWidthFix:6,search:null,changed:null,listOptions:null},_create:function(){var a=this;a.selectedItem=null;a.selectedItems=[];a._createDOMElements();a._bindInputEvents();a._initDropDownList();a.repaint();a._checkSelectIndex()},_checkSelectIndex:function(){var c=this,d,b=c.options;b.selectedIndex===-1&&b.selectedValue&&a.each(b.data,function(a){if(b.data[a].value===b.selectedValue){c.options.selectedIndex=a;return false}});d=b.selectedIndex;!c._usingRemoteData()&&(d>=0||a.isArray(d))&&c.search(null,"checkindex")},repaint:function(){var a=this;if(a.element.is(":visible")||a._comboDiv||a._select!==undefined&&a._input.is(":visible")){a._showTrigger();a.options.disabled&&a.disable();return true}return false},_bindInputEvents:function(){var c=this,e,f,g,d;e=c._input;f=c.options;e.bind("keydown.wijcombobox",function(b){if(f.disabled===true)return;g=b.keyCode;d=a.ui.keyCode;switch(g){case d.UP:c._move("previous",b);b.preventDefault();break;case d.DOWN:c._move("next",b);b.preventDefault();break;case d.ENTER:if(c.menu.active){b.preventDefault();c.menu.select(b)}break;case d.TAB:e.trigger("wijcomboblur");if(!c.menu.active||f.selectionMode==="multiple"&&d.TAB===g)return;c.menu.select(b);var h=e.val().length;c._selectText(h,h,e);break;case d.ESCAPE:c.close(b);break;case d.LEFT:case d.RIGHT:case d.SHIFT:case d.CONTROL:case d.HOME:case d.END:case d.DELETE:case d.PAGE_UP:case d.PAGE_DOWN:break;case 18:e.trigger("wijcomboblur");break;default:window.clearTimeout(c.searching);if(f.isEditable===false){if(c._cacheKey===undefined)c._cacheKey="";c._cacheKey+=String.fromCharCode(g)}c.searching=window.setTimeout(function(){var a;if(f.isEditable===false){a=c._cacheKey;c._cacheKey=undefined}else a=e.val();c.search(a,b)},f.delay)}}).bind("wijcomboblur.wijcombobox",function(a){window.clearTimeout(c.searching);c._addInputFocus(false,b);c.closing=window.setTimeout(function(){c.close(a,true)},150)}).bind("focus.wijcombobox",function(){c._addInputFocus(true,b)}).bind("blur.wijcombobox",function(){!c.menu.element.is(":visible")&&e.trigger("wijcomboblur");c._change()})},_addInputFocus:function(f,e){var c=this,d,b,a;d=c._input.parent();b=f?"addClass":"removeClass";a=c._triggerArrow;d[b](e);a!==undefined&&a[b](e)},_renderColumnsHeader:function(c){var b=a("<ul class='wijmo-wijcombobox-rowheader'></ul>");a.each(this.options.columns,function(e,c){var d=a("<li class='wijmo-wijcombobox-cell ui-widget-header'></li>");d.html(c.name);c.width!==undefined&&d.width(c.width);d.appendTo(b)});c.append(b)},_hasSameValueText:function(a,b){return a.label===b.label&&a.value===b.value},_initDropDownList:function(){var b=this,g,d,c,f,e;g=b.element[0].ownerDocument;if(!b._comboDiv)d=a("<div class='wijmo-wijcombobox-list'></div>");else d=b._oriList;c=b.options;if(c.columns.length>0){d.addClass("wijmo-wijcombobox-multicolumn");f=a("<div class='wijmo-wijsuperpanel-header ui-state-default'></div>");b._renderColumnsHeader(f);d.append(f)}e={keepHightlightOnMouseLeave:true,selectionMode:c.selectionMode,addHoverItemClass:c.columns.length===0,focus:function(e,d){var a=d;c.selectOnItemFocus&&b.menu.select(null,{notCloseAfterSelected:true});if(c.columns.length>0){a.element.prev().addClass("wijmo-wijcombobox-active-prev");a.element.find(".wijmo-wijcombobox-row>.wijmo-wijcombobox-cell").addClass("ui-state-hover")}},selected:function(i,f){window.clearTimeout(b.closing);var j=c.selectionMode,d,e,h,g;d=f.item;if(b._trigger("select",i,d))if(j==="single"){if(!b._usingRemoteData()){e=a.inArray(d,b.items);if(e===undefined)e=f.selectedIndex;if(e!==c.selectedIndex){b._input.val(d.label);g=b.selectedItem;if(g!==null)g.selected=false;b.selectedItem=d;h=c.selectedIndex;c.selectedIndex=e;c.selectedValue=b.selectedItem.value;if(b._select!==undefined){b._select[0].selectedIndex=c.selectedIndex;b._select.trigger("change")}b._trigger("changed",null,{oldItem:g,selectedItem:b.selectedItem,newIndex:c.selectedIndex,oldIndex:h})}}else if(b.selectedItem===null||!b._hasSameValueText(d,b.selectedItem)){b._input.val(d.label);b.selectedItem=d;b._trigger("changed",null,{selectedItem:d})}}else if(!b._usingRemoteData()){b.selectedItems=f.selectedItems;b._selectedItemsToInputVal(b.selectedItems);b._trigger("changed",null,{selectedItem:d,selectedItems:b.selectedItems})}if((f.data===undefined||!f.data.notCloseAfterSelected)&&j==="single"){b.close(i);b._input.focus()}},blur:function(d,b){var a=b.element;if(c.columns.length>0){a.find(".wijmo-wijcombobox-row>.wijmo-wijcombobox-cell").removeClass("ui-state-hover");a.prev().removeClass("wijmo-wijcombobox-active-prev")}},itemRendering:function(g,f){var d=f,e;e="";if(d.isSeparator)e+=" wijmo-wijcombobox-separator";if(d.selected)e+=" wijmo-wijcombobox-selecteditem";e.length>0&&d.element.addClass(e);if(b._keypress&&c.isEditable&&c.columns.length===0&&c.highlightMatching&&a.trim(b._input.val()).length>0&&d.label)d.text=d.label.replace(new RegExp("(?![^&;]+;)(?!<[^<>]*)("+b._escapeRegex(b._input.val())+")(?![^<>]*>)(?![^&;]+;)","gi"),"<span class='ui-priority-primary'>$1</span>");else d.text=undefined},itemRendered:function(f,e){var b=e,c,d;if(b.cells===undefined)return;c=b.element;c.empty();d=a("<ul class='wijmo-wijcombobox-row'></ul>");a.each(b.cells,function(e,c){var b=a("<li class='wijmo-wijcombobox-cell ui-state-default'></li>");b.append(c);b.attr("title",c);d.append(b)});c.append(d)},superPanelOptions:{resized:function(){var d=b.menu,a=d.element;c.dropdownWidth=a.outerWidth();c.dropdownHeight=a.outerHeight();b._positionList();b.menu.refreshSuperPanel()}}};e=a.extend(true,e,c.listOptions);b.menu=d.appendTo("body",g).wijlist(e).zIndex(b._input.zIndex()+1).css({top:0,left:0}).hide().data("wijlist");b._menuUL=b.menu.ul},_getSelectedItemsText:function(e){var b="",c,d;c=this;d=c.options.multipleSelectionSeparator;c.selectedItems=e;a.each(e,function(c,a){b+=a.label+d});if(b.length>0)b=b.substr(0,b.lastIndexOf(d));return b},_selectedItemsToInputVal:function(b){var a=this;a._input.val(a._getSelectedItemsText(b))},_createDOMElements:function(){var b=this,e,d,f,h;h=a("<div class='wijmo-wijcombobox-wrapper ui-state-default ui-corner-all'></div>");d=b.element;if(d.is("select")){e=a("<div role='combobox' class='wijmo-wijcombobox ui-widget ui-helper-clearfix'></div>");e.append(h);b._comboElement=e;b._select=d;d.addClass("ui-widget");f=b._input=a("<input role='textbox' aria-autocomplete='list' aria-haspopup='true' />").insertAfter(d);b.options.data=b._convertSelectOptions()}else if(d.is("div")&&a(d.children()[0]).is("input[type='text']")&&a(d.children()[1]).is("div")){b._comboElement=b._comboDiv=e=d;b._oriList=a(d.children()[1]);f=b._input=a(d.children()[0]);h.prependTo(e).append(f);d.addClass("wijmo-wijcombobox ui-widget ui-helper-clearfix");d.attr("role","combobox")}else{e=a("<div role='combobox' class='wijmo-wijcombobox ui-widget ui-helper-clearfix'></div>");e.append(h);b._comboElement=e;f=b._input=d}if(!b._comboDiv){e.insertBefore(f);f.width(f.width());e.children(".wijmo-wijcombobox-wrapper").append(f)}f.attr({autocomplete:"off",role:"textbox","aria-wijcombobox":"list","aria-haspopup":"true"}).addClass(g);b._oldWidth=d.css("width");b.options.isEditable===false&&f.attr("readonly","readonly");e.bind("mouseenter",function(){b._addInputFocus(true,c)}).bind("mouseleave",function(){b._addInputFocus(false,c)})},_convertSelectOptions:function(){var d=[],b,c;b=this;c=b._select.get(0).options;a.each(c,function(b,a){d.push({label:a.text,value:a.value})});b.options.selectedIndex=b._select[0].selectedIndex;return d},getComboElement:function(){return this._comboElement},_showTrigger:function(){var g=this,l,j,q,p,r,t=0,b,k,o,m,s,n;l=g.options;j=g._input;q=j.parent();p=g._comboElement;b=g._triggerArrow;k=g._label;if(g._select!==undefined){if(!a.browser.msie)t=g._select.width();else{r=g._select.clone();g._select.after(r);t=r.width();r.remove()}j.width(t+(l.data.length>20?l.selectElementWidthFix:0));g._select.hide()}j.css("margin-left","");j.css("margin-right","");p.width(q[0].offsetWidth);if(l.labelText!==null){k=g._label=a(i);q.append(k.html(l.labelText))}else if(k!==undefined){k.remove();g._label=undefined}if(l.showTrigger){j.removeClass("ui-corner-all");if(b===undefined){b=g._triggerArrow=a(h);p.append(b);b.bind("mouseover.triggerevent",g,function(d){if(l.disabled===true)return;var b=a(d.currentTarget);b.addClass(c)}).bind("mousedown.triggerevent",g,function(c){if(l.disabled===true)return;var b=a(c.currentTarget);b.addClass(d)}).bind("mouseup.triggerevent",g,function(c){var b=a(c.currentTarget);b.removeClass(d)}).bind("click.triggerevent",g,function(){if(l.disabled===true)return;g._triggerClick()})}if(l.triggerPosition==="right"){b.css({left:"",right:"0px"});b.removeClass(f);b.addClass(e)}else{b.css({right:"",left:"0px"});b.removeClass(e);b.addClass(f)}b.setOutHeight(p.innerHeight());o=b.find("span");o.css("margin-left",(b.innerWidth()-o[0].offsetWidth)/2);o.css("margin-top",(b.innerHeight()-o[0].offsetHeight)/2)}else{if(b!==undefined){b.unbind(".triggerevent");b.remove();g._triggerArrow=undefined}j.removeClass("ui-corner-left");j.removeClass("ui-corner-right");j.addClass("ui-corner-all")}m=s=n=0;if(k!==undefined)s+=k[0].offsetWidth;if(b!==undefined)n=b[0].offsetWidth;m=s+n;j.setOutWidth(q.innerWidth()-m);m=m===0?"":m;if(l.triggerPosition==="right"){j.css("margin-left","");j.css("margin-right",m);if(k!==undefined){k.css("left","");k.css("right",n)}}else{j.css("margin-right","");j.css("margin-left",m);if(k!==undefined){k.css("right","");k.css("left",n)}}},_triggerClick:function(c){var a=this,b="";window.clearTimeout(a.closing);if(a.menu.element.is(":visible"))a.close();else{if(a._usingRemoteData())b=a._input.val();a.search(b,c)}},destroy:function(){var b=this,c=b.element;b.options.isEditable===false&&c.removeAttr("readonly");if(b._select!==undefined){b._select.removeClass("ui-widget");b._select.show();b._input.remove()}else if(b._comboDiv){b._comboDiv.removeClass("wijmo-wijcombobox ui-widget ui-helper-clearfix");b._comboDiv.removeAttr("role");b._input.insertBefore(b._comboDiv);b._comboDiv.children(".wijmo-wijcombobox-wrapper").remove()}else{c.css("width",b._oldWidth);c.removeClass(g);c.removeAttr("autocomplete").removeAttr("role").removeAttr("aria-wijcombobox").removeAttr("aria-haspopup");c.insertBefore(b._comboElement);c.css("padding","")}b._comboElement.remove();b.menu.destroy();b.menu.element.remove();a.Widget.prototype.destroy.call(b)},_setOption:function(f,d){var b=this,g,e,c;g=b._comboElement;e=b.element;a.Widget.prototype._setOption.apply(b,arguments);if(f==="disabled")if(d){g.addClass("wijmo-wijcombobox-disabled ui-state-disabled");e.attr("disabled","disabled");b._comboDiv&&b._input.addClass("wijmo-wijcombobox-disabled ui-state-disabled").attr("disabled","disabled");b.close()}else{g.removeClass("wijmo-wijcombobox-disabled ui-state-disabled");e.removeAttr("disabled");b._comboDiv&&b._input.removeClass("wijmo-wijcombobox-disabled ui-state-disabled").removeAttr("disabled")}else if(f==="isEditable")if(d)e.attr("readonly","readonly");else e.removeAttr("readonly");else if(f==="data"){b.selectedItem=null;b.options.selectedIndex=-1;b.options.selectedValue=null;b._input.val("")}else if(f==="selectedIndex"){if(d>-1){if(b.selectedItem!==null)b.selectedItem.selected=false;c=b.items;if(!c)c=b.options.data;if(c&&c[d]!==null){b.selectedItem=c[d];b.selectedItem.selected=true;b._input.val(b.selectedItem.label)}}}else if(f==="selectedValue")if(d){if(b.selectedItem!==null)b.selectedItem.selected=false;c=b.items;if(!c)c=b.options.data;a.each(c,function(a){if(c[a].value===d){b.selectedItem=c[a];b.selectedItem.selected=true;b._input.val(b.selectedItem.label);return false}})}},search:function(g,d){var b=this,f,c,e;f=b.options;c=f.data;window.clearTimeout(b.closing);e={value:g,e:d,self:b};if(c!==null||b._comboDiv){if(d!=="checkindex")if(b._trigger("search",d,{datasrc:c,term:e})===false)return;if(a.isArray(c)||b._comboDiv){b._hideShowArrow(false);b._onListLoaded(c,e)}else{if(b._usingRemoteData()&&d!==undefined&&g.length<f.minLength)return;b._hideShowArrow(false);c.loaded=b._onListLoaded;c.load(e)}}},_usingRemoteData:function(){var b=this.options.data,c=false;if(!a.isArray(b)&&b!==null&&b.proxy!==null)c=true;return c},_hideShowArrow:function(d){var c=this,b,a;b=c.element;a=c._triggerArrow;a!==undefined&&a[d?"show":"hide"]();b[d?"removeClass":"addClass"]("wijmo-wijcombobox-loading")},_onListLoaded:function(g,h){var c=h.self,k,i,j,d,f,e;k=c._input;i=c.options;j=h.value;if(g===null)d=null;else d=a.isArray(g)?g:g.items;c.items=d;if(h.e==="checkindex"){f=i.selectedIndex;if(i.selectionMode==="multiple"&&a.isArray(f)){a.each(f,function(e,b){var a=d[b];a.selected=true;c.selectedItems.push(a)});c._selectedItemsToInputVal(c.selectedItems)}else{d[f].selected=true;c.selectedItem=d[f];k.val(c.selectedItem.label)}c._hideShowArrow(true);return}if(!c._usingRemoteData()&&d){c._filter(d,j);e=a.grep(d,function(a){return!i.autoFilter||a.match})}else{c._topHit=null;e=d}if(e&&e.length>0||c._comboDiv){c._openlist(e,h);c._trigger("open");c._addInputFocus(true,b)}else c.close(null,true);c._hideShowArrow(true)},close:function(h,g){var e=this,d,c,f;d=e.menu;e._dropDownHeight=d.element.outerHeight();e._dropDownWidth=d.element.outerWidth();window.clearTimeout(e.closing);if(d.element.is(":visible")&&!d.element.is(":animated")&&!d.element.parent().is(":animated")){e._trigger("close",h);d.deactivate();c=e.options.hidingAnimation;if(c&&(c.effect==="size"||c.animated==="size"))c.options=a.extend({to:{width:0,height:0}},c.options);f=d.element.attr("style");if(g!==true&&c)d.element.hide(c.effect||c.animated,c.options,c.speed||c.duration,function(){d.element.removeAttr("style").attr("style",f).hide();c.callback&&c.callback.apply(this,arguments)});else d.element.hide();e._addInputFocus(false,b);a(document).unbind("click",e.closeOnClick)}},_change:function(){var a=this,e,f,d,b,g,c;e=a.options;f=e.forceSelectionText;d=e.selectionMode;b=a._input;g=b.val();c=a.selectedItem;if(f)if(d==="single")if(c!==null)c.label!==g&&b.val(c.label);else b.val("");d==="multiple"&&a._selectedItemsToInputVal(a.selectedItems)},_openlist:function(o,p){var b=p.self,f=p.e,i,h,c,e,n,r=2,k=0,g,j,q,d,l,m;i=b._keypress=!!f;e=b.options;c=b.menu.element;c.zIndex(b.element.zIndex()+100);if(b._comboDiv)b.menu.setTemplateItems(o);else b.menu.setItems(o);b.menu.renderList();b.menu.element.show();if(e.dropdownWidth==="auto")h=b._comboElement.outerWidth();else h=e.dropdownWidth;n=c.css("padding");c.css("padding","0px");c.setOutWidth(h);c.css("padding",n);g=e.dropdownHeight;if(b._select!==undefined)g=20*b._menuUL.children(".wijmo-wijlist-item:first").outerHeight();if(c.children(".wijmo-wijsuperpanel-header"))k=c.children(".wijmo-wijsuperpanel-header").outerHeight();q=Math.min(b._menuUL.outerHeight()+r+k,g);c.setOutHeight(q);b.menu.refreshSuperPanel();b._positionList();!i&&b.selectedItem!==undefined&&b.menu.activate(null,b.selectedItem,true);if(i&&f.keyCode!==a.ui.keyCode.BACKSPACE)if(e.isEditable)b._runAutoComplete();else b.menu.activate(null,b._topHit,true);else{d=b.options.showingAnimation;if(e.showingAnimation!==null&&!(f!==undefined&&f.keyCode===a.ui.keyCode.BACKSPACE)){b.menu.element.hide();m={from:{width:0,height:0},to:{width:b._dropDownWidth||c.outerWidth(),height:b._dropDownHeight||c.outerHeight()}};if(d&&(d.effect==="size"||d.animated==="size"))d.options=a.extend(m,d.options);l=c.attr("style");c.show(d.effect||d.animated,d.options,d.speed||d.duration,function(){c.removeAttr("style").attr("style",l).show();d.callback&&d.callback.apply(this,arguments);a.browser.msie&&c.css("filter","")})}}if(!b.hasOwnProperty("closeOnClick")){j=b.closeOnClick;b.closeOnClick=function(a){return j(a)}}a(document).bind("click",b,b.closeOnClick)},closeOnClick:function(c){var b=c.data,d=c.target;if(!a.contains(b._comboElement[0],d)&&!a.contains(b.menu.element[0],d)){b.close();a(".wijmo-wijcombobox-wrapper",b._comboElement[0]).removeClass("ui-state-hover").removeClass("ui-state-focus");a(".wijmo-wijcombobox-trigger",b._comboElement[0]).removeClass("ui-state-hover").removeClass("ui-state-focus")}},_positionList:function(){var c=this,d,b;d=c.options.dropDownListPosition;b={my:"left top",at:"left bottom",of:c._comboElement,collision:"none"};b=a.extend(b,d);c.menu.element.position(b)},_runAutoComplete:function(){var a=this,c,b,e,d,f,g;c=a._input;b=a._topHit;if(!a.options.autoComplete||b===null)return;a.menu.activate(null,b,true);e=c.val();d=b.label;c.val(d);f=e.length;g=d.length;a._selectText(f,g,c)},_selectText:function(d,e,c){var f=c.val(),a=c.get(0),b;if(f.length>0)if(a.setSelectionRange!==undefined)a.setSelectionRange(d,e);else if(a.createTextRange!==undefined){b=a.createTextRange();b.moveStart("character",d);b.moveEnd("character",e-f.length);b.select()}},_move:function(a,b){if(!this.menu.element.is(":visible")){this.search("",b);return}if(this.menu.first()&&/^previous/.test(a)||this.menu.last()&&/^next/.test(a))return;this.menu[a](b)},_escapeRegex:function(a){return a===undefined?a:a.replace(/([\^\$\(\)\[\]\{\}\*\.\+\?\|\\])/gi,"\\$1")},_filter:function(c,f){var d=this._escapeRegex(f),e,b=null;if(!c)return null;e=new RegExp(d,"i");a.each(c,function(f,a){if(d===undefined||d.length===0){a.match=true;return}var c=e.exec(a.label);if(c===null)a.match=false;else{if(b===null&&c.index===0)b=a;a.match=c.index>=0}});this._topHit=b;return c}})})(jQuery);
(function(a){"use strict";window.wijinputcore={options:{culture:"",invalidClass:"ui-state-error",nullText:"",showNullText:false,hideEnter:false,disableUserInput:false,buttonAlign:"right",showTrigger:false,showSpinner:false,comboItems:undefined,comboWidth:undefined,comboHeight:undefined,initializing:null,initialized:null,triggerMouseDown:null,triggerMouseUp:null,textChanged:null,invalidInput:null},_create:function(){if(this.element[0].tagName.toLowerCase()!=="input")throw"Target element is not a INPUT";this.element.data("widgetName",this.widgetName);a.effects.save(this.element,["width","height"]);var b=this.element.width();this.element.wrap("<div class='wijmo-wijinput ui-widget ui-helper-clearfix ui-state-default ui-corner-all'><span class='wijmo-wijinput-wrapper'></span></div>");this.element.addClass("wijmo-wijinput-input ui-corner-all").attr({role:"textbox","aria-multiline":false});this.wrapper=this.element.parent();this.outerDiv=this.wrapper.parent();this.outerDiv.width(b);if(this.options.showTrigger){this.triggerBtn=a("<div class='wijmo-wijinput-trigger ui-state-default'><span class='ui-icon ui-icon-triangle-1-s'></span></div>").addClass(this.options.buttonAlign==="left"?"ui-corner-left":"ui-corner-right").attr("role","button").appendTo(this.outerDiv);this.element.attr({role:"combobox","aria-expanded":false})}if(this.options.showSpinner){this.spinner=a("<div class='wijmo-wijinput-spinner wijmo-wijinput-button'></div>");this.spinUp=a("<div class='ui-state-default wijmo-wijinput-spinup'><span class='ui-icon ui-icon-triangle-1-n'></span></div>").attr("role","button");this.spinDown=a("<div class='ui-state-default wijmo-wijinput-spindown'><span class='ui-icon ui-icon-triangle-1-s'></span></div>").attr("role","button");if(!this.options.showTrigger){this.spinUp.addClass(this.options.buttonAlign==="left"?"ui-corner-tl":"ui-corner-tr");this.spinDown.addClass(this.options.buttonAlign==="left"?"ui-corner-bl":"ui-corner-br")}this.spinner.append(this.spinUp).append(this.spinDown).appendTo(this.outerDiv);this.element.attr("role","spinner")}if(this.options.showTrigger&&this.options.showSpinner)this.outerDiv.addClass(this.options.buttonAlign==="left"?"ui-input-spinner-trigger-left":"ui-input-spinner-trigger-right");else{this.options.showTrigger&&this.outerDiv.addClass(this.options.buttonAlign==="left"?"ui-input-trigger-left":"ui-input-trigger-right");this.options.showSpinner&&this.outerDiv.addClass(this.options.buttonAlign==="left"?"ui-input-spinner-left":"ui-input-spinner-right")}this.element.setOutWidth(this.outerDiv.width());this._initialize()},_createTextProvider:function(){return undefined},_beginUpdate:function(){},_endUpdate:function(){},_onTriggerClicked:function(){},_initialize:function(){this.element.data("initializing",true);this._trigger("initializing");this.element.data("preText",this.element.val());this.element.data("elementValue",this.element.val());this.element.data("errorstate",false);this.element.data("breakSpinner",true);this.element.data("prevCursorPos",-1);this.element.data("simulating",false);this._createTextProvider();this._beginUpdate();var c=function(a){return(!a.which?a.button:a.which)===1},d=this.options,b=this;this.triggerBtn&&!d.disabled&&this.triggerBtn.bind({mouseover:function(){b._addState("hover",a(this))},mouseout:function(){b._removeState("hover",a(this))},mousedown:function(d){if(!c(d))return;b._addState("active",a(this));b._trigger("triggerMouseDown")},click:function(d){if(!c(d))return;b._stopEvent(d);b._stopSpin();b._removeState("active",a(this));b._trigger("triggerMouseUp");b._onTriggerClicked();b._trySetFocus()}});var e=function(d){if(!c(d))return;b._trySetFocus();b.element.data("breakSpinner",false);b._addState("active",a(this));b._doSpin(a(d.currentTarget).hasClass("wijmo-wijinput-spinup"),true)},f=function(d){if(!c(d))return;b._stopSpin();b._removeState("active",a(this))};this.spinUp&&!d.disabled&&this.spinUp.bind({mouseover:function(){b._addState("hover",a(this))},mouseout:function(){b._removeState("hover",a(this))},mousedown:e,mouseup:f});this.spinDown&&!d.disabled&&this.spinDown.bind({mouseover:function(){b._addState("hover",a(this))},mouseout:function(){b._removeState("hover",a(this))},mousedown:e,mouseup:f});this.element.bind({"focus.wijinput":a.proxy(this._onFocus,this),"blur.wijinput":a.proxy(this._onBlur,this),"mouseup.wijinput":a.proxy(this._onMouseUp,this),"keypress.wijinput":a.proxy(this._onKeyPress,this),"keydown.wijinput":a.proxy(this._onKeyDown,this),"keyup.wijinput":a.proxy(this._onKeyUp,this),"change.wijinput":a.proxy(this._onChange,this),"paste.wijinput":a.proxy(this._onPaste,this),"drop.wijinput":a.proxy(this._onDrop,this)});this.element.bind("propertychange.wijinput input.wijinput",a.proxy(this._onInput,this));this.element.data("initializing",false);this._resetData();this._endUpdate();this._updateText();this.options.disabled&&this.disable();this.element.data("initialized",true);this._trigger("initialized")},_init:function(){},_setOption:function(c,b){a.Widget.prototype._setOption.apply(this,arguments);switch(c){case"buttonAlign":case"showTrigger":case"showSpinner":this._destroy();this._create();break;case"showNullText":this._updateText();break;case"disabled":this.element.attr("disabled",b);this.element[b?"addClass":"removeClass"](this.namespace+"-state-disabled");this.triggerBtn!==undefined&&this.triggerBtn[b?"addClass":"removeClass"](this.namespace+"-state-disabled");this.spinup!==undefined&&this.spinup[b?"addClass":"removeClass"](this.namespace+"-state-disabled");this.spindown!==undefined&&this.spindown[b?"addClass":"removeClass"](this.namespace+"-state-disabled")}},destroy:function(){a.Widget.prototype.destroy.apply(this,arguments);this._destroy()},_destroy:function(){this.wrapper=undefined;this.outerDiv=undefined;this.element.unbind(".wijinput");this.element.removeData("errorstate").removeData("breakSpinner").removeData("prevCursorPos").removeData("simulating").removeData("isPassword").removeClass("wijmo-wijinput-input").removeAttr("role").removeAttr("aria-valuemin").removeAttr("aria-valuemax").removeAttr("aria-valuenow").removeAttr("aria-expanded");this.element.parent().replaceWith(this.element);this.element.parent().replaceWith(this.element);a.effects.restore(this.element,["width","height"])},widget:function(){return this.outerDiv},_getCulture:function(a){return Globalize.findClosestCulture(a||this.options.culture)},_addState:function(b,a){a.is(":not(.ui-state-disabled)")&&a.addClass("ui-state-"+b)},_removeState:function(a,b){b.removeClass("ui-state-"+a)},_isInitialized:function(){return!this.element.data("initializing")},_setData:function(a){this.setText(a)},_resetData:function(){},_validateData:function(){},getText:function(){return!this._isInitialized()?this.element.val():this._textProvider.toString(true,false,false)},setText:function(a){if(!this._isInitialized())this.element.val(a);else{this._textProvider.set(a);this._updateText()}},getPostValue:function(){return!this._isInitialized()?this.element.val():this._textProvider.toString(true,false,true)},selectText:function(a,b){if(this.element.is(":disabled"))return;this.element.wijtextselection(a,b)},focus:function(){if(this.element.is(":disabled"))return;this.element.get(0).focus()},isFocused:function(){return this.outerDiv.hasClass("ui-state-focus")},_raiseTextChanged:function(){var a=this.element.val(),b=this.element.data("preText");if(!!this.element.data("initialized")&&b!==a){this._trigger("textChanged",null,{text:a});this.element.data("changed",true)}this.element.data("preText",a)},_raiseDataChanged:function(){},_allowEdit:function(){return!(this.element.attr("readOnly")&&this.element.is(":disabled"))},_updateText:function(a){if(!this._isInitialized())return;a=!!a;var b=this.element.wijtextselection();this.element.val(this._textProvider.toString());this.options.text=this._textProvider.toString(true,false,false);if(this.element.is(":disabled"))return;a&&this.selectText(b.start,b.end);this.element.data("prevCursorPos",b.start);this._raiseTextChanged();this._raiseDataChanged()},_trySetFocus:function(){if(!this.isFocused())try{!this.options.disableUserInput&&this.element.focus()}catch(a){}},_deleteSelText:function(b){if(!this._allowEdit())return;var a=this.element.wijtextselection();b=!!b;if(b)if(a.end===a.start)if(a.end>=1){a.end=a.end-1;a.start=a.start-1}else return;else a.end=a.end-1;else a.end=a.end-1;if(a.end<a.start)a.end=a.start;var c=new wijInputResult;this._textProvider.removeAt(a.start,a.end,c);this._updateText();this.selectText(c.testPosition,c.testPosition)},_fireIvalidInputEvent:function(c){if(this._trigger("invalidInput",null,{widget:this,"char":c})===true)return;if(!this.element.data("errorstate")){var b=this.options.invalidClass||"ui-state-error";this.element.data("errorstate",true);var a=this;window.setTimeout(function(){a.outerDiv.removeClass(b);a.element.data("errorstate",false)},100);this.outerDiv.addClass(b)}},_onInput:function(){if(!this._isSimulating()||!this.element.data("ime"))return;this._simulate()},_keyDownPreview:function(){return false},_beforeSimulate:function(a){if(!this.element.data("lastSelection")){this.element.data("lastSelection",this.element.wijtextselection());this.element.data("lastValue",this.element.val())}this.element.data("ime",a);this.element.data("simulating",true)},_isSimulating:function(){return this.element.data("simulating")},_simulate:function(d){var a=this,b=null;if(typeof d==="string")b=d;else{var f=this.element.wijtextselection(),c=this.element.data("lastSelection").start,e=f.end;if(e>=c)b=this.element.val().substring(c,e)}b&&window.setTimeout(function(){if(!a.element.data("lastValue"))return;a.element.val(a.element.data("lastValue"));var e=a.element.data("lastSelection");a.element.wijtextselection(e);a.element.data("batchKeyPress",true);a.element.data("simulating",false);var c=jQuery.Event("keypress");c.ctrlKey=c.altKey=false;for(var d=0;d<b.length;d++){c.which=c.charCode=c.keyCode=b.charCodeAt(d);a._onKeyPress(c)}a.element.data("batchKeyPress",false);a._endSimulate()},1)},_endSimulate:function(){this.element.removeData("ime");this.element.removeData("lastSelection");this.element.removeData("lastValue")},_onKeyDown:function(b){this.element.data("prevCursorPos",-1);if(!this._isInitialized())return;var c=this._getKeyCode(b);if(c===229){this._beforeSimulate(true);return}this._endSimulate();if(this.options.disableUserInput){this._stopEvent(b);return}if(this._keyDownPreview(b)){this._stopEvent(b);return}switch(c){case a.ui.keyCode.UP:this._doSpin(true,false);this._stopEvent(b);return;case a.ui.keyCode.DOWN:this._doSpin(false,false);this._stopEvent(b);return}if(b.ctrlKey)switch(c){case a.ui.keyCode.INSERT:case 67:return}if(b.ctrlKey||b.altKey)return;switch(c){case 112:case 113:case 114:case 115:case 116:case 117:case a.ui.keyCode.TAB:case a.ui.keyCode.CAPSLOCK:case a.ui.keyCode.END:case a.ui.keyCode.HOME:case a.ui.keyCode.CTRL:case a.ui.keyCode.SHIFT:return;case a.ui.keyCode.BACKSPACE:this._deleteSelText(true);this._stopEvent(b);return;case a.ui.keyCode.DELETE:this._deleteSelText(false);this._stopEvent(b);return;case a.ui.keyCode.ENTER:if(!this.options.hideEnter)return;break;case a.ui.keyCode.ESCAPE:this._stopEvent(b);window.setTimeout(a.proxy(this._resetData,this),1);return;case a.ui.keyCode.PAGE_UP:case a.ui.keyCode.PAGE_DOWN:case a.ui.keyCode.ALT:this._stopEvent(b);return}},_onKeyUp:function(b){if(this._isSimulating())return;var c=this._getKeyCode(b);if(!this._isInitialized())return;if(c===a.ui.keyCode.ENTER)return;if(c===a.ui.keyCode.ESCAPE)return;if(this.options.disableUserInput){this._raiseTextChanged();this._raiseDataChanged();return}this._stopEvent(b)},_getKeyCode:function(a){var b=window.navigator.userAgent;return(b.indexOf("iPod")!==-1||b.indexOf("iPhone")!==-1)&&a.which===127?8:a.keyCode||a.which},_keyPressPreview:function(){return false},_onKeyPress:function(b){if(this._isSimulating())return;this.element.data("prevCursorPos",-1);if(this.options.disableUserInput)return;if(!this._allowEdit())return;if(b.ctrlKey&&b.keyCode==119){this._onPaste(b);return}if(b.which===0)return;var d=b.keyCode||b.which;if(d===a.ui.keyCode.BACKSPACE){this._stopEvent(b);return}if(b.ctrlKey||b.altKey)if(d!==a.ui.keyCode.SPACE)return;if(this._keyPressPreview(b))return;if(d===a.ui.keyCode.ENTER&&!this.options.hideEnter)return true;var c=this.element.wijtextselection(),f=String.fromCharCode(d);c.start<c.end&&this._textProvider.removeAt(c.start,c.end-1,new wijInputResult);var e=new wijInputResult,g=this._textProvider.insertAt(f,c.start,e);if(g){this._updateText();this.selectText(e.testPosition+1,e.testPosition+1)}else this._fireIvalidInputEvent(f);!this.element.data("batchKeyPress")&&this._stopEvent(b)},_isNullText:function(a){a=a||this.element.val();return this.options.showNullText&&a===this.options.nullText},_doFocus:function(){var c=this.element.wijtextselection(),b=c.start;this._updateText();var d=this.element.val();if(d.length===b)b=0;!a.browser.safari&&this.selectText(b,b)},_afterFocused:function(){this._isNullText()&&this._doFocus()},_onFocus:function(){if(this.options.disableUserInput)return;this._addState("focus",this.outerDiv);if(!this.element.data("breakSpinner"))return;if(!this._isInitialized())return;if(!this._allowEdit())return;!this.element.data("focusNotCalledFirstTime")&&this.element.data("focusNotCalledFirstTime",+new Date);this._afterFocused()},_onBlur:function(){if(this.options.disableUserInput)return;if(this._isComboListVisible())return;var c=this.isFocused();this._removeState("focus",this.outerDiv);if(!this.element.data("breakSpinner")){this.element.get(0).focus();var b=this.element.data("prevCursorPos");b!==undefined&&b!==-1&&this.selectText(b,b);return}if(!this._isInitialized())return;if(!c)return;this.element.data("value",this.element.val());var a=this;window.setTimeout(function(){a._onChange();a._updateText();a._validateData();!a._popupVisible()&&!!a.element.data("changed")&&a._trigger("change");a.element.data("changed",false)},100)},_popupVisible:function(){return this._isComboListVisible()},_onMouseUp:function(){if(!this._isInitialized())return;if(this.element.is(":disabled"))return;var a=this.element.wijtextselection();this.element.data("prevCursorPos",a.start)},_onChange:function(){if(!this.element)return;var a=this.element.val(),b=this.getText();b!==a&&this.setText(a)},_onPaste:function(){this._beforeSimulate();var a=this;window.setTimeout(function(){a._simulate()},1)},_onDrop:function(a){this._beforeSimulate();if(a.originalEvent&&a.originalEvent.dataTransfer){var b=a.originalEvent.dataTransfer.getData("Text");b&&this._simulate(b)}},_stopEvent:function(a){a.stopPropagation();a.preventDefault()},_calcSpinInterval:function(){this._repeatingCount++;return this._repeatingCount>10?50:this._repeatingCount>4?100:this._repeatingCount>2?200:400},_doSpin:function(){},_stopSpin:function(){this.element.data("breakSpinner",true);this._repeatingCount=0},_hasComboItems:function(){return!!this.options.comboItems&&this.options.comboItems.length},_isComboListVisible:function(){return!this._comboDiv?false:this._comboDiv.wijpopup("isVisible")},_popupComboList:function(){if(!this._hasComboItems())return;if(!this._allowEdit())return;if(this._isComboListVisible()){this._comboDiv.wijpopup("hide");return}var b=this;if(this._comboDiv===undefined){this._comboDiv=a("<div></div>").appendTo(document.body).width(this.element.width()).height(this.options.comboHeight||180).css("position","absolute");var c=this._normalize(this.options.comboItems);this._comboDiv.wijlist({autoSize:true,maxItemsCount:5,selected:function(c,a){b._setData(a.item.value);b._comboDiv.wijpopup("hide");b._trySetFocus()}});this._comboDiv.wijlist("setItems",c);this._comboDiv.wijlist("renderList");this._comboDiv.wijlist("refreshSuperPanel")}this._comboDiv.wijpopup({autoHide:true});this.outerDiv.attr("aria-expanded",true);this._comboDiv.wijpopup("show",{of:this.outerDiv,offset:"0 4",hidden:function(){b.outerDiv.attr("aria-expanded",false)}})},_normalize:function(b){return b.length&&b[0].label&&b[0].value?b:a.map(b,function(b){return typeof b==="string"?{label:b,value:b}:a.extend({label:b.label||b.value,value:b.value||b.label},b)})}};window.wijInputResult=function(){this.alphanumericCharacterExpected=-2;this.asciiCharacterExpected=-1;this.digitExpected=-3;this.invalidInput=-51;this.letterExpected=-4;this.nonEditPosition=-54;this.positionOutOfRange=-55;this.promptCharNotAllowed=-52;this.signedDigitExpected=-5;this.unavailableEditPosition=-53;this.testPosition=-1};window.wijInputResult.prototype={characterEscaped:1,noEffect:2,sideEffect:3,success:4,unknown:0,hint:0,clone:function(){var a=new wijInputResult;a.hint=this.hint;a.testPosition=this.testPosition;return a}}})(jQuery);
(function(b){"use strict";var A={useDefault:-2,asIs:-1,zero:0,one:1,two:2,three:3,four:4,five:5,six:6,seven:7,eight:8};b.widget("wijmo.wijinputdate",b.extend(true,{},wijinputcore,{options:{date:null,minDate:null,maxDate:null,dateFormat:"d",startYear:1950,smartInputMode:true,activeField:0,keyDelay:800,autoNextField:true,calendar:"default",popupPosition:{offset:"0 4"},dateChanged:null},_createTextProvider:function(){this._textProvider=new z(this,this.options.dateFormat)},_strToDate:function(a){return this._textProvider.parseDate(a)},_beginUpdate:function(){var a=this.options,c,b=null;if(a.minDate)if(typeof a.minDate==="string")a.minDate=this._strToDate(a.minDate);if(a.maxDate)if(typeof a.maxDate==="string")a.maxDate=this._strToDate(a.maxDate);if(!a.date){if(!!this.element.data("elementValue"))c=this.element.data("elementValue")}else if(typeof a.date==="string")c=a.date;else b=a.date;if(c)b=this._strToDate(c);this._safeSetDate(b);this.element.data({defaultDate:b===null?b:new Date(a.date.getTime()),preDate:b===null?b:new Date(a.date.getTime())});this._resetTimeStamp();a.showTrigger&&!this._hasComboItems()&&this._initCalendar();this.element.addClass("wijmo-wijinput-date").attr({"aria-valuemin":new Date(1900,1,1),"aria-valuemax":new Date(2099,1,1),"aria-valuenow":a.date})},_endUpdate:function(){var a=this;this.element.click(function(){a._highLightCursor()});this.element.mousewheel(function(c,b){a._doSpin(b>0,false)})},_onTriggerClicked:function(){if(this._hasComboItems())this._popupComboList();else this._popupOrHideCalendar()},_isValidDate:function(a,c){var b=this.options;if(a===undefined)return false;if(isNaN(a))return false;if(a.getFullYear()<1||a.getFullYear()>9999)return false;if(c){if(b.minDate)if(a<b.minDate)return false;if(b.maxDate)if(a>b.maxDate)return false}return true},_checkRange:function(a){var b=this.options;if(!!a){if(b.minDate&&a<b.minDate)a=new Date(Math.max(b.minDate,a));if(b.maxDate&&a>b.maxDate)a=new Date(Math.min(b.maxDate,a))}return a},_safeSetDate:function(a){var c=this.options,b=a;a=this._checkRange(a);if(isNaN(a))a=b;c.date=a;return true},_safeGetDate:function(){var b=this.options,a=b.date;if(!a)a=new Date;a=this._checkRange(a);return a},_setOption:function(c,a){b.Widget.prototype._setOption.apply(this,arguments);wijinputcore._setOption.apply(this,arguments);switch(c){case"date":if(!!a){if(typeof a==="string")a=this._strToDate(a);else if(typeof a==="object")a=new Date(a.getTime());else a=new Date(a);if(isNaN(a))a=new Date}this._safeSetDate(a);this._updateText();this._highLightField();break;case"dateFormat":case"culture":this._textProvider._setFormat(this.options.dateFormat);this._updateText();break;case"activeField":a=Math.min(a,this._textProvider.getFieldCount()-1);a=Math.max(a,0);this.options.activeField=a;this._highLightField();this._resetTimeStamp()}},_setData:function(a){this.option("date",a)},_resetData:function(){var b=this.options,a=this.element.data("defaultDate");if(a===undefined||a===null){a=this.element.data("elementValue");if(a!==undefined&&a!==null&&a!=="")this.setText(val);else this._setData(null)}else this._setData(a)},_resetTimeStamp:function(){this.element.data("cursorPos",0);this.element.data("timeStamp",new Date("1900/1/1"))},getPostValue:function(){if(!this._isInitialized())return this.element.val();if(this.options.showNullText&&this.isDateNull())return"";var a=this._textProvider.toString();return a===this.options.nullText?"":a},_highLightField:function(a){if(a===undefined)a=this.options.activeField;if(this.isFocused()){var b=this._textProvider.getFieldRange(a);b&&this.element.wijtextselection(b)}},_highLightCursor:function(a){if(this._isNullText())return;if(a===undefined)a=Math.max(0,this.element.wijtextselection().start);var b=this._textProvider.getCursorField(a);if(b<0)return;this._setOption("activeField",b)},_toNextField:function(){this._setOption("activeField",this.options.activeField+1)},_toPrevField:function(){this._setOption("activeField",this.options.activeField-1)},_toFirstField:function(){this._setOption("activeField",0)},_toLastField:function(){this._setOption("activeField",this._textProvider.getFieldCount())},_clearField:function(a){if(a===undefined)a=this.options.activeField;var b=this._textProvider.getFieldRange(a);if(b){var d=new wijInputResult;this._textProvider.removeAt(b.start,b.end,d);this._updateText();var c=this;window.setTimeout(function(){c._highLightField()},1)}},_doSpin:function(c,a){c=!!c;a=!!a;if(!this._allowEdit())return;if(a&&this.element.data("breakSpinner"))return;if(this._textProvider[c?"incEnumPart":"decEnumPart"]()){this._updateText();this._highLightField()}a&&!this.element.data("breakSpinner")&&window.setTimeout(b.proxy(function(){this._doSpin(c,true)},this),this._calcSpinInterval())},_onChange:function(){},_afterFocused:function(){this._isNullText()&&this._doFocus();var a=this,b=function(){a._highLightCursor();a._resetTimeStamp()};window.setTimeout(b,10)},_keyDownPreview:function(a){var d=a.keyCode||a.which;switch(d){case b.ui.keyCode.LEFT:this._toPrevField();return true;break;case b.ui.keyCode.RIGHT:this._toNextField();return true;break;case b.ui.keyCode.TAB:case b.ui.keyCode.SPACE:case 188:case 190:case 110:case 191:if(a.shiftKey){if(this.options.activeField>0){this._toPrevField();return true}}else if(this.options.activeField<this._textProvider.getFieldCount()-1){this._toNextField();return true}break;case b.ui.keyCode.HOME:if(a.ctrlKey)this._setOption("date",new Date);else this._toFirstField();return true;break;case b.ui.keyCode.END:if(a.ctrlKey)this._setOption("date",new Date("1970/1/1"));else this._toLastField();return true;break;case b.ui.keyCode.DELETE:if(this._allowEdit()){var c=this.element.wijtextselection();if(c.end-c.start===this.element.val().length)this._setOption("date",new Date("1970/1/1"));else this._clearField();return true}}return false},_autoMoveToNextField:function(a,b){if(!this.options.autoNextField)return;this._textProvider.needToMove(this.options.activeField,a,b)&&this._toNextField()},_keyPressPreview:function(a){var d=a.keyCode||a.which;if(d===b.ui.keyCode.ENTER){if(this.isDateNull())this.options.date=new Date;return false}var g=this._textProvider.getFieldRange(this.options.activeField);if(g){if(d===b.ui.keyCode.TAB)return true;if(d===b.ui.keyCode.SPACE){this._stopEvent(a);return true}var e=String.fromCharCode(d),i=this._textProvider.isFieldSep(e,this.options.activeField);if(i){this._toNextField();this._stopEvent(a);return true}var c=this.element.data("cursorPos"),h=new Date,j=this.element.data("timeStamp");this.element.data("timeStamp",h);var f=h.getTime()-j.getTime()>this.options.keyDelay;if(f)c=0;var k=g.start+c;this.element.data("cursorPos",++c);var l=this._textProvider.addToField(e,this.options.activeField,k,!f);if(l){this._updateText();this._autoMoveToNextField(c,e);this._highLightField()}else this._fireIvalidInputEvent();this._stopEvent(a);return true}return false},_raiseDataChanged:function(){var a=this.options.date,b=this.element.data("preDate");this.element.data("preDate",!a?null:new Date(a.getTime()));if(!b&&a||b&&!a||b&&a&&b.getTime()!==a.getTime()){this._syncCalendar();this.element.attr("aria-valuenow",a);this._trigger("dateChanged",null,{date:a})}},isDateNull:function(){return this.options.date===null||this.options.date===undefined},_isMinDate:function(a){return a.getFullYear()===1&&a.getMonth()===0&&a.getDate()===1},_initCalendar:function(){var a=this.options.calendar;if(a===undefined||a===null)return;if(typeof a==="boolean"||a==="default"){a=b("<div/>");a.appendTo(document.body)}var c=b(a);if(c.length!=1)return;this.element.data("calendar",c);c.wijcalendar({popupMode:true,culture:this.options.culture});this._syncCalendar();var d=this;c.bind("wijcalendarselecteddateschanged",function(){var a=b(this).wijcalendar("getSelectedDate");b(this).wijcalendar("close");!!a&&d.option("date",a);d._trySetFocus()})},_syncCalendar:function(){var a=this.element.data("calendar");if(!a)return;var c=this.options,b=this._safeGetDate();if(this._isMinDate(b))b=new Date;a.wijcalendar("option","displayDate",b);c.minDate&&a.wijcalendar("option","minDate",c.minDate);c.maxDate&&a.wijcalendar("option","maxDate",c.maxDate);a.wijcalendar("unSelectAll");a.wijcalendar("selectDate",b);a.wijcalendar("refresh")},_popupOrHideCalendar:function(){if(!this._allowEdit())return;var a=this.element.data("calendar");if(!a)return;if(a.wijcalendar("isPopupShowing")){a.wijcalendar("hide");this._trySetFocus();return}this._syncCalendar();a.wijcalendar("popup",b.extend({},this.options.popupPosition,{of:this.outerDiv}))},_isCalendarVisible:function(){if(!this._allowEdit())return false;var a=this.element.data("calendar");return!a?false:a.wijcalendar("isPopupShowing")},_popupVisible:function(){return this._hasComboItems()?this._isComboListVisible():this._isCalendarVisible()}}));var z=function(b,a){this.inputWidget=b;this.descriptors=new Array(0);this.desPostions=new Array(0);this.fields=new Array(0);this._setFormat(a)};z.prototype={descriptors:undefined,desPostions:undefined,maskPartsCount:0,pattern:"M/d/yyyy",initialize:function(){},getFieldCount:function(){return this.fields.length},getFieldRange:function(b){var a=this.fields[b];return{start:a.startIndex,end:a.startIndex+a.getText().length}},getCursorField:function(a){a=Math.min(a,this.desPostions.length-1);a=Math.max(a,0);var c=this.desPostions[a].desc;if(c.type===-1){var d=b.inArray(c,this.descriptors);if(d>0&&this.descriptors[d-1].type!=-1)c=this.descriptors[d-1];else return-1}return b.inArray(c,this.fields)},needToMove:function(c,d,e){if(!this.inputWidget._isValidDate(this.inputWidget._safeGetDate(),true))return false;var b=this.fields[c];if(d===b.maxLen)return true;var a=e*1;if(isNaN(a))return false;switch(b.type){case 20:case 25:case 45:case 46:return a>1;break;case 47:case 48:return a>2;break;case 30:case 31:return a>3;break;case 50:case 51:case 60:case 61:return a>6}return false},_getCulture:function(){return this.inputWidget._getCulture()},_isDigitString:function(a){a=b.trim(a);if(a.length===0)return true;var c=a.charAt(0);if(c==="+"||c==="-"){a=a.substr(1);a=b.trim(a)}if(a.length===0)return true;try{var d=parseFloat(a),e=d.toString();return e===a}catch(f){return false}},_setFormat:function(h){this.descriptors=[];var a="",d="",e=false,g=false;this.pattern=this._parseFormatToPattern(h);for(var f=0;f<this.pattern.length;f++){var c=this.pattern.charAt(f);if(g){this.descriptors.push(this.createDescriptor(-1,c));a="";g=false;continue}if(c==="\\"){g=true;if(a.length>0){!this.handlePattern(a)&&this.descriptors.push(this.createDescriptor(-1,d));a=""}continue}if(c==="'"){if(e){e=false;a=""}else{e=true;if(a.length>0){!this.handlePattern(a)&&this.descriptors.push(this.createDescriptor(-1,d));a=""}}continue}if(e){this.descriptors.push(this.createDescriptor(-1,c));a="";continue}if(!f)d=c;if(d!==c&&a.length>0){!this.handlePattern(a)&&this.descriptors.push(this.createDescriptor(-1,d));a=""}a+=c;d=c}if(a.length>0)!this.handlePattern(a)&&this.descriptors.push(this.createDescriptor(-1,d));this.fields=b.grep(this.descriptors,function(a){return a.type!==-1})},_parseFormatToPattern:function(c){var a=this.inputWidget._getCulture().calendars.standard,b=a.patterns.d;if(c.length<=1)switch(c){case"":case"d":b=a.patterns.d;break;case"D":b=a.patterns.D;break;case"f":b=a.patterns.D+" "+a.patterns.t;break;case"F":b=a.patterns.D+" "+a.patterns.T;break;case"g":b=a.patterns.d+" "+a.patterns.t;break;case"G":b=a.patterns.d+" "+a.patterns.T;break;case"m":b=a.patterns.M;break;case"M":b=a.patterns.M;break;case"s":b=a.patterns.S;break;case"t":b=a.patterns.t;break;case"T":b=a.patterns.T;break;case"u":b=a.patterns.S;break;case"U":b=a.patterns.D+" "+a.patterns.T;break;case"y":b=a.patterns.Y;break;case"Y":b=a.patterns.Y}else b=c;return b},getDate:function(){return!!this.inputWidget?new Date(this.inputWidget._safeGetDate().getTime()):undefined},setDate:function(a){this.inputWidget&&this.inputWidget._setData(a)},_internalSetDate:function(e){if(this.inputWidget){var b=this,a=this.inputWidget.options,c=this.inputWidget.element,f=!!c.data("typing");if(f){a.date=e;var d=function(){var f=new Date,e=c.data("timeStamp");if(f.getTime()-e.getTime()>a.keyDelay){b.inputWidget._safeSetDate(a.date);b.inputWidget._updateText();b.inputWidget._highLightField()}else window.setTimeout(d,a.keyDelay)};window.setTimeout(d,a.keyDelay)}else this.inputWidget._safeSetDate(e)}},daysInMonth:function(a,c){a=a-1;var b=new Date(c,++a,1,-1).getDate();return b},setYear:function(a,d,i){try{if(d&&d.isfullreset){d.offset=1;a="1970"}if(typeof a==="string")if(!this._isDigitString(a))return false;a=a*1;var g=this.inputWidget.options,e=1,f=9999;if(i){if(g.minDate)e=Math.max(e,g.minDate.getFullYear());if(g.maxDate)f=Math.min(f,g.maxDate.getFullYear())}if(d&&d.isreset)a=e;if(a<e)a=e;if(a>f)a=f;var c=this.getDate(),b=new Date(c.getTime());b.setFullYear(a);if(this._isValidDate(b)){var h=this.daysInMonth(this.getMonth(),this.getYear());if(h===c.getDate()){b=new Date(c.getTime());b.setDate(1);b.setFullYear(a);h=this.daysInMonth(b.getMonth()+1,b.getFullYear());b.setDate(h);if(this._isValidDate(b)){this._internalSetDate(b);return true}else return false}c.setFullYear(a);this._internalSetDate(c);return true}else{if(d&&d.isreset){c.setFullYear(1);this._internalSetDate(c);return true}return false}}catch(j){return false}},getYear:function(){try{var a=this.getDate().getFullYear();a=""+a+"";while(a.length<4)a="0"+a;return""+a+""}catch(b){alert("getYear() failed")}return""},setMonth:function(b,e,c){try{if(c&&c.isfullreset)b="1";b=b*1;var f=this.getDate();if(typeof e!=="undefined"&&!e)if(b>12||b<1)if(c&&c.isreset)b=1;else return false;var d=this.daysInMonth(this.getMonth(),this.getYear()),a;if(d===this.getDate().getDate()){a=new Date(f.getTime());a.setDate(1);a.setMonth(b-1);d=this.daysInMonth(a.getMonth()+1,a.getFullYear());a.setDate(d);if(this._isValidDate(a)){this._internalSetDate(a);return true}else return false}else{a=new Date(f.getTime());a.setMonth(b-1);if(this._isValidDate(a)){this._internalSetDate(a);return true}else return false}}catch(g){return false}},getMonth:function(){return this.getDate().getMonth()+1},setDayOfMonth:function(b,c,a){try{if(a&&a.isfullreset)return this.setDayOfMonth(1,c);var e=this.getDate();b=b*1;if(typeof c!=="undefined"&&!c){var f=this.daysInMonth(this.getMonth(),this.getYear());if(b>f||b<1)return a&&a.isreset?this.setDayOfMonth(1,c,a):false}var d=new Date(e.getTime());d.setDate(b);if(this._isValidDate(d)){this._internalSetDate(d);return true}else return false}catch(g){return false}},getDayOfMonth:function(){return this.getDate().getDate()},setHours:function(a,c){try{a=a*1;if(typeof c!=="undefined"&&!c)if(a>24)return false;var b=new Date(this.getDate().getTime());b.setHours(a);if(this._isValidDate(b)){this._internalSetDate(b);return true}else return false}catch(d){return false}},getHours:function(){return this.getDate().getHours()},setMinutes:function(a,c){try{a=a*1;if(typeof c!=="undefined"&&!c)if(a>60)return false;var b=new Date(this.getDate().getTime());b.setMinutes(a);if(this._isValidDate(b)){this._internalSetDate(b);return true}else return false}catch(d){return false}},getMinutes:function(){return this.getDate().getMinutes()},setSeconds:function(a,c){try{a=a*1;if(typeof c!=="undefined"&&!c)if(a>60)return false;var b=new Date(this.getDate().getTime());b.setSeconds(a);if(this._isValidDate(b)){this._internalSetDate(b);return true}else return false}catch(d){return false}},getSeconds:function(){return this.getDate().getSeconds()},setDayOfWeek:function(a){try{a=a*1;var b=a-this.getDayOfWeek()*1;return this.setDayOfMonth(this.getDayOfMonth()*1+b*1,true)}catch(c){return false}},getDayOfWeek:function(){return this.getDate().getDay()+1},handlePattern:function(c){var a=new RegExp("y{3,4}"),b=a.test(c);if(b){this.descriptors.push(this.createDescriptor(10));return true}a=new RegExp("y{2,2}");b=a.test(c);if(b){this.descriptors.push(this.createDescriptor(2));return true}a=new RegExp("y{1,1}");b=a.test(c);if(b){this.descriptors.push(this.createDescriptor(1));return true}a=new RegExp("d{4,4}");b=a.test(c);if(b){this.descriptors.push(this.createDescriptor(101));return true}a=new RegExp("d{3,3}");b=a.test(c);if(b){this.descriptors.push(this.createDescriptor(100));return true}a=new RegExp("d{2,2}");b=a.test(c);if(b){this.descriptors.push(this.createDescriptor(30));return true}a=new RegExp("d{1,1}");b=a.test(c);if(b){this.descriptors.push(this.createDescriptor(31));return true}a=new RegExp("M{4,4}");b=a.test(c);if(b){this.descriptors.push(this.createDescriptor(27));return true}a=new RegExp("M{3,3}");b=a.test(c);if(b){this.descriptors.push(this.createDescriptor(26));return true}a=new RegExp("M{2,2}");b=a.test(c);if(b){this.descriptors.push(this.createDescriptor(20));return true}a=new RegExp("M{1,1}");b=a.test(c);if(b){this.descriptors.push(this.createDescriptor(25));return true}a=new RegExp("h{2,2}");b=a.test(c);if(b){this.descriptors.push(this.createDescriptor(46));return true}a=new RegExp("h{1,1}");b=a.test(c);if(b){this.descriptors.push(this.createDescriptor(45));return true}a=new RegExp("H{2,2}");b=a.test(c);if(b){this.descriptors.push(this.createDescriptor(48));return true}a=new RegExp("H{1,1}");b=a.test(c);if(b){this.descriptors.push(this.createDescriptor(47));return true}a=new RegExp("m{2,2}");b=a.test(c);if(b){this.descriptors.push(this.createDescriptor(50));return true}a=new RegExp("m{1,1}");b=a.test(c);if(b){this.descriptors.push(this.createDescriptor(51));return true}a=new RegExp("s{2,2}");b=a.test(c);if(b){this.descriptors.push(this.createDescriptor(60));return true}a=new RegExp("s{1,1}");b=a.test(c);if(b){this.descriptors.push(this.createDescriptor(61));return true}a=new RegExp("t{2,2}");b=a.test(c);if(b){this.descriptors.push(this.createDescriptor(251));return true}a=new RegExp("t{1,1}");b=a.test(c);if(b){this.descriptors.push(this.createDescriptor(250));return true}return false},createDescriptor:function(z,c){var a=null,b=this.maskPartsCount++;switch(z){case-1:a=new y(this,b);a.liternal=c;break;case 20:a=new i(this,b);break;case 25:a=new j(this,b);break;case 26:a=new k(this,b);break;case 27:a=new l(this,b);break;case 30:a=new m(this,b);break;case 31:a=new n(this,b);break;case 100:a=new d(this,b);break;case 101:a=new e(this,b);break;case 10:a=new h(this,b);break;case 1:a=new w(this,b);break;case 2:a=new x(this,b);break;case 45:a=new o(this,b);break;case 46:a=new p(this,b);break;case 47:a=new q(this,b);break;case 48:a=new r(this,b);break;case 250:a=new f(this,b);break;case 251:a=new g(this,b);break;case 50:a=new s(this,b);break;case 51:a=new t(this,b);break;case 60:a=new u(this,b);break;case 61:a=new v(this,b)}return a},toString:function(){if(this.inputWidget.options.showNullText&&!this.inputWidget.isFocused()&&this.inputWidget.isDateNull())return this.inputWidget.options.nullText;var e="",f=0;this.desPostions=new Array(0);for(var b=0;b<this.descriptors.length;b++){this.descriptors[b].startIndex=e.length;var c=""||this.descriptors[b].getText();e+=c;for(var d=0;d<c.length;d++){var a={};a.desc=this.descriptors[b];a.pos=d;a.text=c;a.length=c.length;this.desPostions.push(a);f++;if(this.desPostions.length!==f)throw"Fatal Error !!!!!!!!!!!!!!!";}}return e},parseDate:function(b){var a;if(this.pattern==="dddd"||this.pattern==="ddd"||typeof b=="object")try{a=new Date(b);if(isNaN(a))a=new Date}catch(c){a=new Date}else{a=Globalize.parseDate(b,this.pattern,this._getCulture());if(!a)a=this._tryParseDate(b,this.pattern);if(!a)a=new Date}return a},"set":function(a){this._internalSetDate(new Date(this.parseDate(a)));return true},haveEnumParts:function(){return false},removeLiterals:function(a){a=""+a+"";a=a.replace(new RegExp("\\s","g"),"");a=a.replace(new RegExp("[+]","g"),"");a=a.replace(new RegExp("[.]","g"),"");a=a.replace(new RegExp("[:]","g"),"");a=a.replace(new RegExp("[-]","g"),"");a=a.replace(new RegExp("[()=]","g"),"");return a},getFirstDelimiterPos:function(b,d){var c=0,a=0;while(c<d.length&&a<b.length){var e=d.charAt(c),f=b.charAt(a);if(e===f)a++;else return a-1;c++}return b.length-1},findAlikeArrayItemIndex:function(d,f){for(var c=-1,e=99999,a=0;a<d.length;a++){var b=d[a].toLowerCase().indexOf(f.toLowerCase());if(b!==-1&&b<e){e=b;c=a}}return c},_isValidDate:function(a){return this.inputWidget._isValidDate(a)},isFieldSep:function(d,c){var a=c++;if(a<this.descriptors.length){var b=this.descriptors[a];return b.type!=-1?false:d===b.text}return false},getPositionType:function(b){var a=this.desPostions[b];return a.desc.type},addToField:function(a,c,f,e){var b=this.fields[c];if(b.type==10)return this.insertAt(a,f);var h=e?b.getText()+a:a,d={val:a,pos:0,offset:0,isreset:false};this.inputWidget.element.data("typing",true);var g=b.setText(h,a.length===1?false:true,d);this.inputWidget.element.data("typing",false);return g},insertAt:function(c,i,b){if(!b)b=new wijInputResult;b.testPosition=-1;var a;if(c.length===1){a=this.desPostions[i];if(a&&a.desc.type===-1)if(a.text===c){b.testPosition=i;b.hint=b.characterEscaped;return true}}var q=c,d=i;c=this.removeLiterals(c);var f=c,m=false,p=false;if(d>0&&f.length===1){d--;i=d;a=this.desPostions[d];m=true;if(a&&(a.desc.type===-1||a.desc.getText().length!==1)){i++;d++;m=false}}var j=false,e,g;while(f.length>0&&d<this.desPostions.length){a=this.desPostions[d];if(a.desc.type===-1){d=d+a.length;continue}if(a.desc.needAdjustInsertPos()){e=f.substr(0,a.length-a.pos);e=a.text.slice(0,a.pos)+e+a.text.slice(a.pos+e.length,a.length);if(m)e=a.text+e;if(p)e=e+a.text;var o=a.desc.getText().length,k="";try{if(c.length===1)if(!a.pos)k=c;else if(a.pos>0)k=e.substring(0,a.pos+1)}catch(t){}if(o===1&&e.length>1&&c.length===1)if(a.desc.type===31||a.desc.type===25)this._disableSmartInputMode=true;g={val:c,pos:a.pos,offset:0,isreset:false};j=a.desc.setText(e,c.length===1?false:true,g);this._disableSmartInputMode=false;if(!j&&typeof k!=="undefined"&&k.length>0&&(a.desc.type===26||a.desc.type===27||a.desc.type===100||a.desc.type===101||a.desc.type===250||a.desc.type===251))j=a.desc.setText(k,c.length===1?false:true,g);if(j){b.hint=b.success;b.testPosition=d+g.offset;if(c.length===1){var l=a.desc.getText().length,n=a.pos;if(a.pos>l-1)n=l;var s=l-o;if(s>0&&a.pos===o-1)n=l-1;var u=this.toString();b.testPosition=a.desc.startIndex+n+g.offset}f=f.slice(a.length-a.pos,f.length)}else{b.hint=b.invalidInput;if(b.testPosition!==-1)b.testPosition=i;if(a.desc.type!==-1&&c.length===1)return false}d=d+a.length}else{var h=this.getFirstDelimiterPos(f,q);if(h<0)h=0;e=f.substring(0,h+1);g={val:c,pos:a.pos,offset:0,isreset:false};j=a.desc.setText(e,c.length===1?false:true,g);if(j){b.hint=b.success;b.testPosition=d+g.offset;f=f.slice(h+1,f.length)}else{b.hint=b.invalidInput;if(b.testPosition!==-1)b.testPosition=i}if(h<0)h=0;var r=h+1;d=d+r}}return j},removeAt:function(b,e,c){try{var a=this.desPostions[b];if(a.desc.needAdjustInsertPos()){var d="0",g=b;a.text=a.desc.getText();d=a.text.slice(0,a.pos)+d+a.text.slice(a.pos+d.length,a.length);var f={val:d,pos:a.pos,offset:0,isreset:true,isfullreset:false};if(e-b+1>=a.length){f.isfullreset=true;b=b+a.length;g=b}var h=a.desc.setText(d,false,f);if(h){c.hint=c.success;c.testPosition=g}else{c.hint=c.invalidInput;if(c.testPosition===-1)c.testPosition=b}}b<e&&this.removeAt(b+1,e,c);return true}catch(i){return false}},incEnumPart:function(){var a=this.fields[this.inputWidget.options.activeField];a&&a.inc();return true},decEnumPart:function(){var a=this.fields[this.inputWidget.options.activeField];a&&a.dec();return true},setValue:function(a){this.setDate(new Date(a instanceof Date?a.getTime():a));return true},getValue:function(){return this.getDate()},_disableSmartInputMode:false,_isSmartInputMode:function(){return this._disableSmartInputMode?false:this.inputWidget?this.inputWidget.options.smartInputMode:true},_getInt:function(g,e,d,f){for(var c=f;c>=d;c--){var a=g.substring(e,e+c);if(a.length<d)return null;if(b.wij.charValidator.isDigit(a))return a}return null},_tryParseDate:function(g,a){var d=this._getCulture().calendars;a=a||d.standard.patterns.d;if(a){if(a.indexOf("MMM")===-1&&a.indexOf("MMMM")===-1)a=a.replace("MM","M");a=a.replace("dd","d");a=a.replace("tt","a")}var c=a.replace("yyyy","yy"),b=d.standard["/"],f=[a,c,a.replace(new RegExp(b,"g"),"-"),c.replace(new RegExp(b,"g"),"-"),a.replace(new RegExp(b,"g"),"."),c.replace(new RegExp(b,"g"),".")],e=Globalize.parseDate(g,f,this._getCulture());return e?e:0},paddingZero:function(c,b){var a=""+c+"";while(a.length<b)a="0"+a;return a},_formatDate:function(a,e,c){if(!a.valueOf())return"&nbsp;";var b=this,d=e.replace(new RegExp("yyyy|MMMM|MMM|MM|M|mm|m|dddd|ddd|dd|d|hh|h|HH|H|ss|s|tt|t|a/p","gi"),function(e){var d;switch(e){case"yyyy":return a.getFullYear();case"MMMM":return c.dateTimeFormat.monthNames[a.getMonth()];case"MMM":return c.dateTimeFormat.abbreviatedMonthNames[a.getMonth()];case"MM":return b.paddingZero(a.getMonth()+1,2);case"M":return b.paddingZero(a.getMonth()+1,1);case"mm":return b.paddingZero(a.getMinutes(),2);case"m":return b.paddingZero(a.getMinutes(),1);case"dddd":return c.dateTimeFormat.dayNames[a.getDay()];case"ddd":return c.dateTimeFormat.abbreviatedDayNames[a.getDay()];case"dd":return b.paddingZero(a.getDate(),2);case"d":return b.paddingZero(a.getDate(),1);case"hh":d=a.getHours()%12;return b.paddingZero(d?d:12,2);case"h":d=a.getHours()%12;return b.paddingZero(d?d:12,1);case"HH":return b.paddingZero(a.getHours(),2);case"H":return b.paddingZero(a.getHours(),1);case"ss":return b.paddingZero(a.getSeconds(),2);case"s":return b.paddingZero(a.getSeconds(),1);case"tt":return a.getHours()<12?cf.AM[0]:cf.PM[0];case"t":return a.getHours()<12?cf.AM[0].length>0?cf.AM[0].charAt(0):"":cf.PM[0].length>0?cf.PM[0].charAt(0):"";case"a/p":return a.getHours()<12?"a":"p"}return"N"});return d}};var a=function(d,c,a,b){this._txtProvider=d;this.id=c;this.type=a;this.startIndex=0;this.maxLen=b||2};a.prototype={_txtProvider:null,id:0,type:0,name:null,startIndex:0,maxLen:2,getText:function(){return null},setText:function(){return false},inc:function(){},dec:function(){},needAdjustInsertPos:function(){return true},reachMaxLen:function(){var a=this.getText();do if(a.charAt(0)==="0")a=a.slice(1);else break;while(a.length>0);return a.length>=this.maxLen}};var c=function(c,b){for(var a in b.prototype)if(!c.prototype[a])c.prototype[a]=b.prototype[a]},y=function(b,d){c(y,a);a.apply(this,[b,d,-1,100])};y.prototype={liternal:"",getText:function(){return this.liternal}};var i=function(b,d){c(i,a);a.apply(this,[b,d,20]);this.name="Two-digit month"};i.prototype={getText:function(){var a=""+this._txtProvider.getMonth()+"";return a.length===1?"0"+a:a},setText:function(c,a,b){return this._txtProvider.setMonth(c,a,b)},inc:function(){this._txtProvider.setMonth(this._txtProvider.getMonth()*1+1,true)},dec:function(){this._txtProvider.setMonth(this._txtProvider.getMonth()*1-1,true)}};var j=function(b,d){c(j,a);a.apply(this,[b,d,25]);this.name="month"};j.prototype={getText:function(){return""+this._txtProvider.getMonth()+""},setText:function(c,a,b){return this._txtProvider.setMonth(c,a,b)},inc:function(){this._txtProvider.setMonth(this._txtProvider.getMonth()*1+1,true)},dec:function(){this._txtProvider.setMonth(this._txtProvider.getMonth()*1-1,true)}};var k=function(b,d){c(k,a);a.apply(this,[b,d,26,100]);this.name="AbbreviatedMonthNames"};k.prototype={getText:function(){var b=this._txtProvider.getMonth(),a=this._txtProvider._getCulture();return a.calendars.standard.months.namesAbbr[b-1]},setText:function(d,b,c){var a=-1;a=this._txtProvider.findAlikeArrayItemIndex(cf.months.namesAbbr,d);return a===-1?false:this._txtProvider.setMonth(a+1,b,c)},inc:function(){this._txtProvider.setMonth(this._txtProvider.getMonth()*1+1,true)},dec:function(){this._txtProvider.setMonth(this._txtProvider.getMonth()*1-1,true)}};var l=function(b,d){c(l,a);a.apply(this,[b,d,27,100]);this.name="MonthNames"};l.prototype={getText:function(){var b=this._txtProvider.getMonth(),a=this._txtProvider._getCulture();return a.calendars.standard.months.names[b-1]},setText:function(e,c,b){var a=-1;if(b&&b.isfullreset)a=1;else{var d=this._txtProvider._getCulture();a=this._txtProvider.findAlikeArrayItemIndex(d.calendars.standard.months.names,e);if(a===-1)return false}return this._txtProvider.setMonth(a+1,c,b)},inc:function(){this._txtProvider.setMonth(this._txtProvider.getMonth()*1+1,true)},dec:function(){this._txtProvider.setMonth(this._txtProvider.getMonth()*1-1,true)}};var m=function(b,d){c(m,a);a.apply(this,[b,d,30]);this.name="Two-digit day of month"};m.prototype={getText:function(){var a=this._txtProvider.getDayOfMonth();if(a<10)a="0"+a;return""+a+""},setText:function(c,a,b){return this._txtProvider.setDayOfMonth(c,a,b)},inc:function(){this._txtProvider.setDayOfMonth(this._txtProvider.getDayOfMonth()*1+1,true)},dec:function(){this._txtProvider.setDayOfMonth(this._txtProvider.getDayOfMonth()*1-1,true)}};var n=function(b,d){c(n,a);a.apply(this,[b,d,31]);this.name="Day of month"};n.prototype={getText:function(){var a=this._txtProvider.getDayOfMonth();return""+a+""},setText:function(c,a,b){return this._txtProvider.setDayOfMonth(c,a,b)},inc:function(){this._txtProvider.setDayOfMonth(this._txtProvider.getDayOfMonth()*1+1,true)},dec:function(){this._txtProvider.setDayOfMonth(this._txtProvider.getDayOfMonth()*1-1,true)}};var d=function(b,e){c(d,a);a.apply(this,[b,e,100,100]);this.name="AbbreviatedDayNames"};d.prototype={getText:function(){var b=this._txtProvider.getDayOfWeek(),a=this._txtProvider._getCulture();return a.calendars.standard.days.namesShort[b-1]},setText:function(c){var a=-1,b=this._txtProvider._getCulture();a=this._txtProvider.findAlikeArrayItemIndex(b.calendars.standard.days.namesShort,c);return a===-1?false:this._txtProvider.setDayOfWeek(a+1)},inc:function(){this._txtProvider.setDayOfMonth(this._txtProvider.getDayOfMonth()*1+1,true)},dec:function(){this._txtProvider.setDayOfMonth(this._txtProvider.getDayOfMonth()*1-1,true)},needAdjustInsertPos:function(){return false}};var e=function(b,d){c(e,a);a.apply(this,[b,d,101,100]);this.name="DayNames"};e.prototype={getText:function(){var b=this._txtProvider.getDayOfWeek(),a=this._txtProvider._getCulture();return a.calendars.standard.days.names[b-1]},setText:function(c){var a=-1,b=this._txtProvider._getCulture();a=this._txtProvider.findAlikeArrayItemIndex(b.calendars.standard.days.names,c);return a===-1?false:this._txtProvider.setDayOfWeek(a+1)},inc:function(){this._txtProvider.setDayOfMonth(this._txtProvider.getDayOfMonth()*1+1,true)},dec:function(){this._txtProvider.setDayOfMonth(this._txtProvider.getDayOfMonth()*1-1,true)},needAdjustInsertPos:function(){return false}};var h=function(b,d){c(h,a);a.apply(this,[b,d,10,4]);this.name="Four-digit year"};h.prototype={getText:function(){return this._txtProvider.getYear()},setText:function(h,j,a){if(this._txtProvider._isSmartInputMode()&&a){var b=2e3;if(this._txtProvider.inputWidget.options.startYear)b=this._txtProvider.inputWidget.options.startYear;var e=b+100-1;b=this._txtProvider.paddingZero(b,4);e=this._txtProvider.paddingZero(e,4);if(a.pos===0||a.pos===1){var k=new Date,c=this._txtProvider.paddingZero(this._txtProvider.getYear(),4);if(c.charAt(0)==="0"&&c.charAt(1)==="0"&&a.pos<=1){var f=a.val*1,d="00";if(f>=5)d=b.slice(0,2);else d=e.slice(0,2);var g=a.val+c.slice(3,4),i=d+g;a.offset=2-a.pos;this._txtProvider.setYear(i,a);return true}}}return this._txtProvider.setYear(h,a)},inc:function(){this._txtProvider.setYear(this._txtProvider.getYear()*1+1,null,true)},dec:function(){this._txtProvider.setYear(this._txtProvider.getYear()*1-1,null,true)}};var w=function(b,d){c(w,a);a.apply(this,[b,d,1]);this.name="One-digit year"};w.prototype={getText:function(){var a=this._txtProvider.getYear();a=""+a+"";if(a.length===4)a=a.charAt(2)+a.charAt(3);if(a.charAt(0)==="0")a=a.charAt(1);return a},setText:function(a,i,c){a=a+"";while(a.length<2)a="0"+a;var b=this._txtProvider.getYear();b=""+b+"";if(a==="00"){var g=this._txtProvider.getMonth(),d=this._txtProvider.getDayOfMonth(),f=this._txtProvider.getHours(),e=this._txtProvider.getMinutes(),h=this._txtProvider.getSeconds();if(g===1&&d===1&&!f&&!e&&!h){b="0001";a="01"}}if(b.length>=2)b=b.charAt(0)+b.charAt(1)+a.charAt(0)+a.charAt(1);return this._txtProvider.setYear(b,c)},inc:function(){this._txtProvider.setYear(this._txtProvider.getYear()*1+1,null,true)},dec:function(){this._txtProvider.setYear(this._txtProvider.getYear()*1-1,null,true)}};var x=function(b,d){c(x,a);a.apply(this,[b,d,2]);this.name="Two-digit year"};x.prototype={getText:function(){var a=this._txtProvider.getYear();a=""+a+"";if(a.length===4)a=a.charAt(2)+a.charAt(3);return a},setText:function(a,j,c){a=a+"";while(a.length<2)a="0"+a;var b=this._txtProvider.getYear();b=""+b+"";if(a==="00"){var h=this._txtProvider.getMonth(),e=this._txtProvider.getDayOfMonth(),g=this._txtProvider.getHours(),f=this._txtProvider.getMinutes(),i=this._txtProvider.getSeconds();if(h===1&&e===1&&!g&&!f&&!i){b="0001";a="01"}}if(b.length>=2)b=b.charAt(0)+b.charAt(1)+a.charAt(0)+a.charAt(1);var d=this._txtProvider.setYear(b,c);return d},inc:function(){this._txtProvider.setYear(this._txtProvider.getYear()*1+1,null,true)},dec:function(){this._txtProvider.setYear(this._txtProvider.getYear()*1-1,null,true)}};var o=function(b,d){c(o,a);a.apply(this,[b,d,45]);this.name="h"};o.prototype={getText:function(){var a=this._txtProvider.getHours();if(a>12)a=a-12;return""+a+""},setText:function(a,b){var c=this._txtProvider.getHours();if(c>12)a=a*1+12;return this._txtProvider.setHours(a,b)},inc:function(){this._txtProvider.setHours(this._txtProvider.getHours()*1+1,true)},dec:function(){this._txtProvider.setHours(this._txtProvider.getHours()*1-1,true)}};var p=function(b,d){c(p,a);a.apply(this,[b,d,46]);this.name="hh"};p.prototype={getText:function(){var a=this._txtProvider.getHours();if(a>12)a=a-12;if(a<10)a="0"+a;return""+a+""},setText:function(a,b){var c=this._txtProvider.getHours();if(c>12)a=a*1+12;return this._txtProvider.setHours(a,b)},inc:function(){this._txtProvider.setHours(this._txtProvider.getHours()*1+1,true)},dec:function(){this._txtProvider.setHours(this._txtProvider.getHours()*1-1,true)}};var q=function(b,d){c(q,a);a.apply(this,[b,d,47]);this.name="H"};q.prototype={getText:function(){var a=this._txtProvider.getHours();return""+a+""},setText:function(b,a){return this._txtProvider.setHours(b,a)},inc:function(){this._txtProvider.setHours(this._txtProvider.getHours()*1+1,true)},dec:function(){this._txtProvider.setHours(this._txtProvider.getHours()*1-1,true)}};var r=function(b,d){c(r,a);a.apply(this,[b,d,48]);this.name="HH"};r.prototype={getText:function(){var a=this._txtProvider.getHours();if(a<10)a="0"+a;return""+a+""},setText:function(b,a){return this._txtProvider.setHours(b,a)},inc:function(){this._txtProvider.setHours(this._txtProvider.getHours()*1+1,true)},dec:function(){this._txtProvider.setHours(this._txtProvider.getHours()*1-1,true)}};var f=function(b,d){c(f,a);a.apply(this,[b,d,250]);this.name="t"};f.prototype={getText:function(){var c=this._txtProvider.getHours(),a="",b=this._txtProvider._getCulture();if(c<12)a=b.calendars.standard.AM[0];else a=b.calendars.standard.PM[0];if(a.length<=0)a=" ";return a.charAt(0)},setText:function(b){var a;if(b.toLowerCase().indexOf("a")>=0){a=this._txtProvider.getHours()*1%12;this._txtProvider.setHours(a,true)}else if(b.toLowerCase().indexOf("p")>=0){a=this._txtProvider.getHours()*1%12+12;this._txtProvider.setHours(a,true)}},inc:function(){var a=(this._txtProvider.getHours()*1+12)%24;this._txtProvider.setHours(a,true)},dec:function(){var a=(this._txtProvider.getHours()*1+12)%24;this._txtProvider.setHours(a,true)}};var g=function(b,d){c(g,a);a.apply(this,[b,d,251]);this.name="tt"};g.prototype={getText:function(){var c=this._txtProvider.getHours(),a="",b=this._txtProvider._getCulture();if(c<12)a=b.calendars.standard.AM[0];else a=b.calendars.standard.PM[0];if(a.length<=0)a=" ";return a},setText:function(b){var a;if(b.toLowerCase().indexOf("a")>=0){a=this._txtProvider.getHours()*1%12;this._txtProvider.setHours(a,true)}else if(b.toLowerCase().indexOf("p")>=0){a=this._txtProvider.getHours()*1%12+12;this._txtProvider.setHours(a,true)}return true},inc:function(){var a=(this._txtProvider.getHours()*1+12)%24;this._txtProvider.setHours(a,true)},dec:function(){var a=(this._txtProvider.getHours()*1+12)%24;this._txtProvider.setHours(a,true)}};var s=function(b,d){c(s,a);a.apply(this,[b,d,50]);this.name="mm"};s.prototype={getText:function(){var a=this._txtProvider.getMinutes();if(a<10)a="0"+a;return""+a+""},setText:function(b,c,a){if(a&&a.isfullreset)b="0";return this._txtProvider.setMinutes(b,c)},inc:function(){this._txtProvider.setMinutes(this._txtProvider.getMinutes()*1+1,true)},dec:function(){this._txtProvider.setMinutes(this._txtProvider.getMinutes()*1-1,true)}};var t=function(b,d){c(t,a);a.apply(this,[b,d,51]);this.name="m"};t.prototype={getText:function(){var a=this._txtProvider.getMinutes();return""+a+""},setText:function(b,c,a){if(a&&a.isfullreset)b="0";return this._txtProvider.setMinutes(b,c)},inc:function(){this._txtProvider.setMinutes(this._txtProvider.getMinutes()*1+12,true)},dec:function(){this._txtProvider.setMinutes(this._txtProvider.getMinutes()*1-12,true)}};var u=function(b,d){c(u,a);a.apply(this,[b,d,60]);this.name="ss"};u.prototype={getText:function(){var a=this._txtProvider.getSeconds();if(a<10)a="0"+a;return""+a+""},setText:function(b,c,a){if(a&&a.isfullreset)b="0";return this._txtProvider.setSeconds(b,c)},inc:function(){this._txtProvider.setSeconds(this._txtProvider.getSeconds()*1+12,true)},dec:function(){this._txtProvider.setSeconds(this._txtProvider.getSeconds()*1-12,true)}};var v=function(b,d){c(v,a);a.apply(this,[b,d,61]);this.name="s"};v.prototype={getText:function(){var a=this._txtProvider.getSeconds();return""+a+""},setText:function(b,c,a){if(a&&a.isfullreset)b="0";return this._txtProvider.setSeconds(b,c)},inc:function(){this._txtProvider.setSeconds(this._txtProvider.getSeconds()*1+12,true)},dec:function(){this._txtProvider.setSeconds(this._txtProvider.getSeconds()*1-12,true)}}})(jQuery);
(function(b){"use strict";var a={editOptional:1,editRequired:2,separator:4,literal:8};b.widget("wijmo.wijinputmask",b.extend(true,{},wijinputcore,{options:{text:null,mask:"",promptChar:"_",hidePromptOnLeave:false,resetOnPrompt:true,allowPromptAsInput:false,passwordChar:"",resetOnSpace:true,skipLiterals:true},_createTextProvider:function(){this._textProvider=new c(this,this.options.mask,false)},_beginUpdate:function(){this.element.addClass("wijmo-wijinput-mask");this.element.data("isPassword",this.options.passwordChar.length>0&&this.element.attr("type")!=="password");this.element.data("defaultText",this.options.text)},_onTriggerClicked:function(){this._popupComboList()},_setOption:function(d,a){b.Widget.prototype._setOption.apply(this,arguments);wijinputcore._setOption.apply(this,arguments);switch(d){case"text":this.setText(a);break;case"mask":case"culture":if(typeof a==="undefined"||a.length<=0)return;var c=this.getText();this._textProvider.mask=a;this._textProvider.initialMask=a;this._textProvider.initialize();this._textProvider.set(c);this._updateText();break;case"promptChar":if(!!this._textProvider){this._textProvider.updatePromptChar();this._updateText()}break;case"hidePromptOnLeave":case"resetOnPrompt":this._updateText();break;case"passwordChar":this.element.data("isPassword",(a+"").length>0);this._updateText()}},_resetData:function(){var b=this.options,a=this.element.data("defaultText");if(a===undefined||a===null)a=this.element.data("elementValue");if(a===undefined||a===null)a="";this.setText(a)},_isPassword:function(){return!!this.element.data("isPassword")},_getTextWithPrompts:function(){return!this._isInitialized()?this.element.val():this._textProvider.toString(true,true,false)},_getTextWithLiterals:function(){return!this._isInitialized()?this.element.val():this._textProvider.toString(true,false,true)},_getTextWithPromptAndLiterals:function(){return!this._isInitialized()?this.element.val():this._textProvider.toString(true,true,true)},_onChange:function(){if(!this.element)return;var b=this.element.val(),a=this.getText();if(a!==b){a=this._getTextWithPrompts();if(a!==b){a=this._getTextWithPromptAndLiterals();a!==b&&this.setText(b)}}},_afterFocused:function(){(this._isNullText()||!!this.options.hidePromptOnLeave)&&this._doFocus()}}));var c=function(c,b,a){this.inputWidget=c;this.mask=b;this.asciiOnly=a;this.descriptors=[];this.noMask=false;this.initialize()};c.prototype={inputWidget:undefined,noMask:false,mask:"",testString:"",assignedCharCount:0,requiredCharCount:0,asciiOnly:false,initialize:function(){this.noMask=!this.mask||this.mask.length<=0;if(this.noMask)return;this.testString="";this.assignedCharCount=0;this.requiredCharCount=0;this.descriptors=new Array(0);for(var i="none",k=false,n=0,c=a.literal,e="",h=this.inputWidget._getCulture(),j=0;j<this.mask.length;j++){var b=false,g=this.mask.charAt(j);if(k){k=false;b=true}if(!b){var f=g;if(f<="C"){switch(f){case"#":case"9":case"?":case"C":g=this.getPromtChar();c=a.editOptional;b=true;break;case"$":e=h.numberFormat.currency.symbol;c=a.separator;b=true;break;case"%":case"-":case";":case"=":case"@":case"B":c=a.literal;b=true;break;case"&":case"0":case"A":g=this.getPromtChar();c=a.editRequired;b=true;break;case",":e=h.numberFormat[","];c=a.separator;b=true;break;case".":e=h.numberFormat["."];c=a.separator;b=true;break;case"/":e=h.calendars.standard["/"];c=a.separator;b=true;break;case":":e=h.calendars.standard[":"];c=a.separator;b=true;break;case"<":i="lower";continue;case">":i="upper";continue}if(!b){c=a.literal;b=true}}if(!b){if(f<="\\"){switch(f){case"L":g=this.getPromtChar();c=a.editRequired;b=true;break;case"\\":k=true;c=a.literal;continue}if(!b){c=a.literal;b=true}}if(!b){if(f==="a"){g=this.getPromtChar();c=a.editOptional;b=true}if(!b){if(f!=="|"){c=a.literal;b=true}if(!b){i="none";continue}}}}}if(b){var l=new d(j,c);if(this.isEditDesc(l))l.caseConversion=i;if(c!==a.separator)e=g;for(var m=0;m<e.length;m++){var o=e.charAt(m);this.testString=this.testString+o;this.descriptors[this.descriptors.length]=l;n++}}}this.testString.Capacity=this.testString.length},getAllowPromptAsInput:function(){return!!this.inputWidget?this.inputWidget.options.allowPromptAsInput:false},getPasswordChar:function(){return!!this.inputWidget?this.inputWidget.options.passwordChar:"*"},isPassword:function(){return!!this.inputWidget?this.inputWidget._isPassword():false},getResetOnPrompt:function(){return!!this.inputWidget?this.inputWidget.options.resetOnPrompt:true},getResetOnSpace:function(){return!!this.inputWidget?this.inputWidget.options.resetOnSpace:true},getSkipLiterals:function(){return!!this.inputWidget?this.inputWidget.options.skipLiterals:true},getHidePromptOnLeave:function(){return!!this.inputWidget?this.inputWidget.options.hidePromptOnLeave:false},_trueOR:function(a,b){return(a>>>1|b>>>1)*2+(a&1|b&1)},setValue:function(){return false},getValue:function(){return null},getPromtChar:function(){return!!this.inputWidget?this.inputWidget.options.promptChar:"_"},updatePromptChar:function(){if(this.noMask)return;for(var c=0;c<this.descriptors.length;c++){var d=this.descriptors[c];if(d.charType===a.editOptional||d.charType===a.editRequired)if(!d.isAssigned)this.testString=b.wij.charValidator.setChar(this.testString,this.getPromtChar(),c)}},resetChar:function(c){var d=this.descriptors[c];if(this.isEditPos(c)&&d.isAssigned){d.isAssigned=false;this.testString=b.wij.charValidator.setChar(this.testString,this.getPromtChar(),c);this.assignedCharCount--;if(d.charType===a.editRequired)this.requiredCharCount--}},getAdjustedPos:function(a){if(this.noMask){if(a>=this.testString.length)a=this.testString.length-1}else if(a>=this.descriptors.length)a=a-1;return Math.max(0,a)},incEnumPart:function(){return!this.noMask},decEnumPart:function(){return!this.noMask},findNonEditPositionInRange:function(c,d,b){return this.findPositionInRange(c,d,b,this._trueOR(a.literal,a.separator))},findPositionInRange:function(a,b,e,f){a=Math.max(0,a);b=Math.min(b,this.testString.length-1);if(a<=b)while(a<=b){var c=e?a++:b--,d=this.descriptors[c];if((d.charType&4294967295&f&4294967295)===d.charType)return c}return-1},findAssignedEditPositionInRange:function(c,d,b){return this.assignedCharCount===0?-1:this.findEditPositionInRange(c,d,b,a.editRequired)},findEditPositionInRange:function(c,d,e,g){do{var b=this.findPositionInRange(c,d,e,this._trueOR(a.editRequired,a.editOptional));if(b===-1)break;var f=this.descriptors[b];switch(g){case a.editOptional:if(!f.isAssigned)return b;break;case a.editRequired:if(f.isAssigned)return b;break;default:return b}if(e)c++;else d--}while(c<=d);return-1},findAssignedEditPositionFrom:function(d,c){if(!this.assignedCharCount)return-1;var a,b;if(c){a=d;b=this.testString.length-1}else{a=0;b=d}return this.findAssignedEditPositionInRange(a,b,c)},findEditPositionFrom:function(d,c){var a,b;if(c){a=d;b=this.testString.length-1}else{a=0;b=d}return this.findEditPositionInRange(a,b,c,0)},setChar:function(c,e,d){e=e<0?0:e;if(!d)d=this.descriptors[e];if(this.testEscapeChar(c,e,d))this.resetChar(e);else{if(b.wij.charValidator.isLetter(c))if(b.wij.charValidator.isUpper(c)){if(d.caseConversion==="lower")c=c.toLowerCase()}else if(d.caseConversion==="upper")c=c.toUpperCase();this.testString=b.wij.charValidator.setChar(this.testString,c,e);if(!d.isAssigned){d.isAssigned=true;this.assignedCharCount++;if(d.charType===a.editRequired)this.requiredCharCount++}}},internalInsertAt:function(h,e,a,j){if(h.length===0){a.testPosition=e;a.hint=a.noEffect;return true}if(!this._testString(h,e,a))return false;var b=this.findEditPositionFrom(e,true),g=this.findAssignedEditPositionInRange(b,a.testPosition,true)!==-1,k=this.findAssignedEditPositionFrom(this.testString.length-1,false);if(g&&a.testPosition===this.testString.length-1){a.hint=a.unavailableEditPosition;a.testPosition=this.testString.length;return false}var c=this.findEditPositionFrom(a.testPosition+1,true);if(g){var d=new wijInputResult;d.hint=d.unknown;var f=true;while(f){f=false;if(c===-1){a.hint=a.unavailableEditPosition;a.testPosition=this.testString.length;return false}var l=this.descriptors[b];if(l.isAssigned&&!this.testChar(this.testString.charAt(b),c,d)){a.hint=d.hint;a.testPosition=c;return false}if(b!==k){b=this.findEditPositionFrom(b+1,true);c=this.findEditPositionFrom(c+1,true);f=true;continue}}if(d.hint>a.hint)a.hint=d.hint}if(!j){if(g)while(b>=e){var i=this.descriptors[b];if(i.isAssigned)this.setChar(this.testString.charAt(b),c);else this.resetChar(c);c=this.findEditPositionFrom(c-1,false);b=this.findEditPositionFrom(b-1,false)}this.setString(h,e)}return true},insertAt:function(c,a,b){if(b===undefined)b=new wijInputResult;if(c===undefined)throw"InsertAt: input";if(this.noMask){this.testString=this.testString.substring(0,a)+c+this.testString.substring(a,this.testString.length);b.testPosition=a+c.length-1;return true}if(a>=0&&a<this.testString.length)return this.internalInsertAt(c,a,b,false);b.testPosition=a;b.hint=b.positionOutOfRange;return false},clear:function(a){if(this.noMask){this.testString="";a.hint=a.success;return}if(!this.assignedCharCount)a.hint=a.noEffect;else{a.hint=a.success;for(var b=0;b<this.testString.length;b++)this.resetChar(b)}},isLiteral:function(b){return!b?false:b.charType!==a.literal?b.charType===a.separator:true},testEscapeChar:function(b,a,c){a=a<0?0:a;if(!c)c=this.descriptors[a];return this.isLiteral(c)?this.getSkipLiterals()?b===this.testString.charAt(a):false:(!this.getResetOnPrompt()||b!==this.getPromtChar())&&(!this.getResetOnSpace()||b!==" ")?false:true},testChar:function(c,e,a){if(!b.wij.charValidator.isPrintableChar(c)){a.hint=a.invalidInput;return false}var d=this.descriptors[e];if(!d)return false;if(this.isLiteral(d)){if(this.getSkipLiterals()&&c===this.testString.charAt(e)){a.hint=a.characterEscaped;return true}a.hint=a.nonEditPosition;return false}if(c===this.getPromtChar()){if(this.getResetOnPrompt()){if(this.isEditDesc(d)&&d.isAssigned)a.hint=a.sideEffect;else a.hint=a.characterEscaped;return true}if(!this.getAllowPromptAsInput()){a.hint=a.promptCharNotAllowed;return false}}if(c===" "&&this.getResetOnSpace()){if(this.isEditDesc(d)&&d.isAssigned)a.hint=a.sideEffect;else a.hint=a.characterEscaped;return true}switch(this.mask.charAt(d.maskPosition)){case"L":if(!b.wij.charValidator.isLetter(c)){a.hint=a.letterExpected;return false}if(!b.wij.charValidator.isAsciiLetter(c)&&this.asciiOnly){a.hint=a.asciiCharacterExpected;return false}break;case"a":if(!b.wij.charValidator.isAlphanumeric(c)&&c!==" "){a.hint=a.alphanumericCharacterExpected;return false}if(!b.wij.charValidator.isAciiAlphanumeric(c)&&this.asciiOnly){a.hint=a.asciiCharacterExpected;return false}break;case"?":if(!b.wij.charValidator.isLetter(c)&&c!==" "){a.hint=a.letterExpected;return false}if(b.wij.charValidator.isAsciiLetter(c)||!this.asciiOnly)break;a.hint=a.asciiCharacterExpected;return false;case"A":if(!b.wij.charValidator.isAlphanumeric(c)){a.hint=a.alphanumericCharacterExpected;return false}if(b.wij.charValidator.isAciiAlphanumeric(c)||!this.asciiOnly)break;a.hint=a.asciiCharacterExpected;return false;case"C":if(!b.wij.charValidator.isAscii(c)&&this.asciiOnly&&c!==" "){a.hint=a.asciiCharacterExpected;return false}break;case"9":if(!b.wij.charValidator.isDigit(c)&&c!==" "){a.hint=a.digitExpected;return false}break;case"#":if(!b.wij.charValidator.isDigit(c)&&c!=="-"&&c!=="+"&&c!==" "){a.hint=a.digitExpected;return false}break;case"&":if(!b.wij.charValidator.isAscii(c)&&this.asciiOnly){a.hint=a.asciiCharacterExpected;return false}break;case"0":if(!b.wij.charValidator.isDigit(c)){a.hint=a.digitExpected;return false}}if(c===this.testString.charAt(e)&&d.isAssigned)a.hint=a.noEffect;else a.hint=a.success;return true},_testString:function(c,f,a){a.hint=a.unknown;a.testPosition=f;if(c.length){var b=new wijInputResult;b.testPosition=a.testPosition;b.hint=a.hint;for(var d=0;d<c.length;d++){var e=c.charAt(d);if(a.testPosition>this.testString.length){a.hint=a.unavailableEditPosition;return false}if(!this.testEscapeChar(e,a.testPosition)){a.testPosition=this.findEditPositionFrom(a.testPosition,true);if(a.testPosition===-1){a.testPosition=this.testString.length;a.hint=a.unavailableEditPosition;return false}}if(!this.testChar(e,a.testPosition,b)){a.hint=b.hint;return false}if(b.hint>a.hint)a.hint=b.hint;a.testPosition+=1;if(a.testPosition==this.testString.length)break}a.testPosition-=1}return true},"set":function(b,a){if(a===undefined)a=new wijInputResult;if(b===undefined)throw"SetFromPos: input parameter is null or undefined.";a.hint=a.unknown;a.testPosition=0;if(!b.length){this.clear(a);return true}if(this.noMask){this.testString=b;return true}if(!this.testSetString(b,a.testPosition,a))return false;var c=this.findAssignedEditPositionFrom(a.testPosition+1,true);c!==-1&&this.resetString(c,this.testString.length-1);return true},resetString:function(a,b){if(this.noMask){this.testString="";return}a=this.findAssignedEditPositionFrom(a,true);if(a!==-1){b=this.findAssignedEditPositionFrom(b,false);while(a<=b){a=this.findAssignedEditPositionFrom(a,true);this.resetChar(a);a++}}},setString:function(c,a){for(var b=0;b<c.length;b++){var d=c.charAt(b);if(!this.testEscapeChar(d,a))a=this.findEditPositionFrom(a,true);if(a<0||a>=this.testString.length)return;this.setChar(d,a);a++}},testSetString:function(a,b,c){if(a.length>this.testString.length)a=a.substring(0,this.testString.length);if(this._testString(a,b,c)){this.setString(a,b);return true}return false},toString:function(e,g,f,c,d){var j=this.inputWidget.options.text||"";j=j.trim();if(this.inputWidget.options.showNullText&&!this.inputWidget.isFocused()&&(j===""||j===this.inputWidget.options.nullText))return this.inputWidget.options.nullText;e=e===undefined?!this.isPassword():e;g=g===undefined?this.getHidePromptOnLeave()?this.inputWidget.isFocused():true:g;f=f===undefined?true:f;if(this.noMask){if(!e){for(var n="",m=0;m<this.testString.length;m++)n+=this.getPasswordChar();return n}return this.testString}c=c===undefined?0:c;d=d===undefined?this.testString.length:d;if(d<=0)return"";if(c<0)c=0;if(c>=this.testString.length)return"";var k=this.testString.length-c;if(d>k)d=k;if((!this.isPassword()||e)&&g&&f)return this.testString.substring(c,d-c);for(var b="",p=c+d-1,i=c;i<=p;i++){var h=this.testString.charAt(i),l=this.descriptors[i];switch(l.charType){case a.editOptional:case a.editRequired:if(!l.isAssigned)break;if(!this.isPassword()||e){b=b+h;continue}b=b+this.getPasswordChar();continue;case a.editRequired|a.editOptional:b=b+h;continue;case a.separator:case a.literal:if(!f)continue;b=b+h;continue;default:b=b+h;continue}if(g){b=b+h;continue}b=b+" ";continue}return b},isEditDesc:function(b){return this.noMask?true:b.charType!==a.editRequired?b.charType===a.editOptional:true},isEditPos:function(a){if(this.noMask)return true;if(a<0||a>=this.testString.length)return false;var b=this.descriptors[a];return this.isEditDesc(b)},internalRemoveAt:function(d,e,b,m){if(this.noMask){try{this.testString=this.testString.substring(0,d)+this.testString.substring(e+1,this.testString.length);b.testPosition=d}catch(q){}return true}var k=new wijInputResult,j,i,f=this.findAssignedEditPositionFrom(this.testString.length-1,false),c=this.findEditPositionInRange(d,e,true,0);b.hint=b.noEffect;if(c===-1||c>f){b.testPosition=d;return true}b.testPosition=d;var n=e<f;if(this.findAssignedEditPositionInRange(d,e,true)!==-1)b.hint=b.success;if(n){var a=this.findEditPositionFrom(e+1,true),o=a;d=c;var h=true;while(h){h=false;j=this.testString.charAt(a);var p=this.descriptors[a];if((j!==this.getPromtChar()||p.isAssigned)&&!this.testChar(j,c,k)){b.hint=k.hint;b.testPosition=c;return false}if(a!==f){a=this.findEditPositionFrom(a+1,true);c=this.findEditPositionFrom(c+1,true);h=true;continue}}if(b.sideEffect>b.hint)b.hint=b.sideEffect;if(m)return true;a=o;c=d;var g=true;while(g){g=false;i=this.testString.charAt(a);var l=this.descriptors[a];if(i===this.getPromtChar()&&!l.isAssigned)this.resetChar(c);else{this.setChar(i,c);this.resetChar(a)}if(a!==f){a=this.findEditPositionFrom(a+1,true);c=this.findEditPositionFrom(c+1,true);g=true;continue}}d=c+1}d<=e&&this.resetString(d,e);return true},removeAt:function(c,b,a){if(typeof b==="undefined")b=c;if(!a)a=new wijInputResult;if(b>=this.testString.length){a.testPosition=b;a.hint=a.positionOutOfRange;return false}if(c>=0&&c<=b)return this.internalRemoveAt(c,b,a,false);a.testPosition=c;a.hint=a.positionOutOfRange;return false}};var d=function(b,a){this.caseConversion="none";this.maskPosition=b;this.charType=a};d.prototype={isAssigned:false,maskPosition:0}})(jQuery);
(function(a){"use strict";a.widget("wijmo.wijinputnumber",a.extend(true,{},wijinputcore,{options:{type:"numeric",value:null,minValue:-1e9,maxValue:1e9,showGroup:false,decimalPlaces:2,increment:1,valueChanged:null,valueBoundsExceeded:null},_createTextProvider:function(){this._textProvider=new c(this,this.options.type)},_beginUpdate:function(){var a=this.options;this.element.addClass("wijmo-wijinput-numeric");this.element.data({defaultValue:a.value,preValue:a.value}).attr({"aria-valuemin":a.minValue,"aria-valuemax":a.maxValue,"aria-valuenow":a.value||0})},_onTriggerClicked:function(){this._popupComboList()},_setOption:function(c,b){a.Widget.prototype._setOption.apply(this,arguments);wijinputcore._setOption.apply(this,arguments);switch(c){case"minValue":this.element.attr("aria-valuemin",b);this._updateText();break;case"maxValue":this.element.attr("aria-valuemax",b);this._updateText();break;case"value":this.setValue(b);this._updateText();break;case"showGroup":case"decimalPlaces":case"culture":this._textProvider.updateStringFormat();this._updateText()}},_setData:function(a){this.setValue(a)},_resetData:function(){var a=this.element.data("defaultValue");if(a===undefined||a===null){a=this.element.data("elementValue");if(a===undefined||a===null&&a==="")a=0}this.setValue(a)},_validateData:function(){this._textProvider.checkAndRepairBounds(true,false)&&this._updateText()},_raiseDataChanged:function(){var a=this.options.value,b=this.element.data("preValue");this.element.data("preValue",a);if(b!==a){this.element.attr("aria-valuenow",a);this._trigger("valueChanged",null,{value:a})}},getValue:function(){var a=this._textProvider.getValue();if(a===undefined||a===null)a=this.getText();return a},setValue:function(a,b){try{b=!!b;if(typeof a==="boolean")a=a?"1":"0";else if(typeof a==="string")a=this._textProvider.tryParseValue(a);if(this._textProvider.setValue(a))this._updateText();else if(b){var c="";c=this.getText();this.setText(a);a=a.trim();var d=this.getText().trim();d!==a&&this.setText(c)}else this.setText(a);return true}catch(e){return false}},isValueNull:function(){try{return this._textProvider.isValueNull()}catch(a){return true}},getPostValue:function(){if(!this._isInitialized())return this.element.val();if(this.options.showNullText&&this.isValueNull())return"0";var a=this.options.value?this.options.value:0;if(this.options.type==="percent")a=(a/100).toFixed(10);return a.toString()},_updateText:function(){if(!this._isInitialized())return;this.options.value=this._textProvider.getValue();wijinputcore._updateText.apply(this,arguments);!this._textProvider.checkAndRepairBounds(false,false)&&this._trigger("valueBoundsExceeded")},_doSpin:function(e,c){e=!!e;c=!!c;if(!this._allowEdit())return;if(c&&this.element.data("breakSpinner"))return;var d=this.element.wijtextselection(),b=new wijInputResult;if(this.element.data("focusNotCalledFirstTime")!==-9&&+new Date-this.element.data("focusNotCalledFirstTime")<600){this.element.data("focusNotCalledFirstTime",-9);this.element.data("prevCursorPos",0)}if(this.element.data("prevCursorPos")===-1)this.element.data("prevCursorPos",d.start);else d.start=this.element.data("prevCursorPos");b.testPosition=d.start;this._textProvider[e?"incEnumPart":"decEnumPart"](d.start,b,this.options.increment);this._updateText();this.element.data("prevCursorPos",b.testPosition);this.selectText(b.testPosition,b.testPosition);c&&!this.element.data("breakSpinner")&&window.setTimeout(a.proxy(function(){this._doSpin(e,true)},this),this._calcSpinInterval())}}));var c=function(a,c){this.inputWidget=a;this._type=c;this._stringFormat=new b(this._type,this.inputWidget.options.decimalPlaces,this.inputWidget.options.showGroup,this._getCulture());this._stringFormat._setValueFromJSFloat(this.getValue())};c.prototype={_type:"numeric",_stringFormat:null,_getCulture:function(){return this.inputWidget._getCulture()},getDecimalSeparator:function(){return this._getCulture().numberFormat["."]},tryParseValue:function(a){return this._stringFormat.tryParseValue(a)},toString:function(){return this.inputWidget.options.showNullText&&!this.inputWidget.isFocused()&&this.isValueNull()?this.inputWidget.options.nullText:this._stringFormat.getFormattedValue()},isValueNull:function(){var a=this.inputWidget.options,b=Math.max(0,a.minValue);return null===a.value||undefined===a.value||b===a.value},"set":function(a,b){this.clear();this.insertAt(a,0,b);return true},clear:function(){this._stringFormat.clear()},checkAndRepairBounds:function(a,c){var b=true;if(typeof a==="undefined")a=false;var d=this.inputWidget.options.minValue,e=this.inputWidget.options.maxValue;if(typeof c!=="undefined"&&c)return this._stringFormat.checkMinValue(d,false,true);if(!this._stringFormat.checkMinValue(d,a,false))b=false;if(!this._stringFormat.checkMaxValue(e,a))b=false;this.inputWidget.options.decimalPlaces>=0&&this._stringFormat.checkDigitsLimits(this.inputWidget.options.decimalPlaces);return b},countSubstring:function(c,b){var d=0,a=c.indexOf(b);while(a!==-1){d++;a=c.indexOf(b,a+1)}return d},getAdjustedPositionFromLeft:function(b){for(var e=this._stringFormat._currentText,c=0;c<e.length;c++){var d=e.charAt(c);if(!a.wij.charValidator.isDigit(d)&&d!==","&&d!=="."||d==="0"){if(this._stringFormat.isZero()){if(b<c)b++}else if(b<=c)b++}else break}return b},getDecimalSeparatorPos:function(){var a=this._stringFormat._currentText;return a.indexOf(this.getDecimalSeparator())},insertAt:function(b,d,c){var h=this._getCulture().numberFormat;if(b===h["."])b=h["."];if(!c)c=new wijInputResult;if(b.length===1){if(b==="+"){this._stringFormat.setPositiveSign();this.checkAndRepairBounds(true,false);return true}if(b==="-"||b===")"||b==="("){this._stringFormat.invertSign();this.checkAndRepairBounds(true,false);c.testPosition=d;if(this._stringFormat.isNegative())c.testPosition=d;else c.testPosition=d-2;return true}if(!a.wij.charValidator.isDigit(b)){if(b==="."){var j=this.getDecimalSeparatorPos();if(j>=0){c.testPosition=j;return true}}if(b!==","&&b!=="."&&b!==")"&&b!=="+"&&b!=="-"&&b!=="("&&b!==this.getDecimalSeparator())if(this._type==="percent"&&b===h.percent.symbol){c.testPosition=d;return true}else if(this._type==="currency"&&b===h.currency.symbol){c.testPosition=d;return true}else return false}}d=this.getAdjustedPositionFromLeft(d);var g=d,e=this._stringFormat._currentText;if(g>e.length)g=e.length-1;if(b.length===1)if(e.charAt(g)===b){c.testPosition=g;return true}var f=e.substring(0,g),i=e.substring(g,e.length);if(this._stringFormat.isZero())i=i.replace(new RegExp("[0]"),"");c.testPosition=f.length+b.length-1;this._stringFormat.deFormatValue(f+b+i);this.checkAndRepairBounds(true,false);try{if(b.length===1)if(this.inputWidget.options.showGroup){var l=this._stringFormat._currentText.substring(0,f.length);if(this.countSubstring(l,this._stringFormat._groupSeparator)!==this.countSubstring(f,this._stringFormat._groupSeparator))c.testPosition=c.testPosition+1}else{var k=f.charAt(f.length-1),m=this._stringFormat._currentText.charAt(c.testPosition-1);if(m!==k)c.testPosition=c.testPosition-1}}catch(n){}return true},removeAt:function(b,e,a){var f=this._getCulture().numberFormat;if(!a)a=new wijInputResult;a.testPosition=b;try{var c=this._stringFormat._currentText;if(b===e&&c.substring(b,e+1)===this.getDecimalSeparator())return false;var d=c.slice(0,b)+c.slice(e+1);if(d==="")d="0";this._stringFormat.deFormatValue(d);if(b===e&&this.inputWidget.options.showGroup)try{var g=this._stringFormat._currentText.substring(0,b);if(this.countSubstring(g,this._stringFormat._groupSeparator)!==this.countSubstring(d,this._stringFormat._groupSeparator)){a.testPosition=a.testPosition-1;if(c.indexOf(f.currency.symbol)===a.testPosition||c.indexOf(f.percent.symbol)===a.testPosition)a.testPosition=a.testPosition+1}}catch(h){}this.checkAndRepairBounds(true,false);return true}catch(i){}this.checkAndRepairBounds(true,false);return true},incEnumPart:function(c,a,b){if(!a)a=new wijInputResult;this._stringFormat.increment(b);return this.checkAndRepairBounds(true,false)},decEnumPart:function(c,a,b){if(!a)a=new wijInputResult;this._stringFormat.decrement(b);return this.checkAndRepairBounds(true,false)},getValue:function(){return this._stringFormat.getJSFloatValue()},setValue:function(a){try{this._stringFormat._setValueFromJSFloat(a);this.checkAndRepairBounds(true,false);return true}catch(b){return false}},updateStringFormat:function(){var a="0";if(typeof this._stringFormat!=="undefined")a=this._stringFormat._currentValueInString;this._stringFormat=new b(this._type,this.inputWidget.options.decimalPlaces,this.inputWidget.options.showGroup,this._getCulture());this._stringFormat._currentValueInString=a}};var b=function(d,a,c,b){this.type=d;this.digitsPlaces=a;this.showGroup=c;this.culture=b};b.prototype={_currentValueInString:"0",_currentText:"0",_groupSeparator:" ",type:"numeric",digitsPlaces:0,showGroup:false,culture:null,isNegtive:function(a){return a.indexOf("-")!==-1||a.indexOf("(")!==-1},stripValue:function(a){var b=this.culture.numberFormat,g=this.isNegtive(a);a=a.replace("(","");a=a.replace(")","");a=a.replace("-","");a=a.replace(b.percent.symbol,"");a=a.replace(b.currency.symbol,"");var d=b[","],e=b["."];switch(this.type){case"percent":d=b.percent[","];e=b.percent["."];break;case"currency":d=b.currency[","];e=b.currency["."]}this._groupSeparator=d;var c=new RegExp("["+d+"]","g");a=a.replace(c,"");c=new RegExp("["+e+"]","g");a=a.replace(c,".");c=new RegExp("[ ]","g");a=a.replace(c,"");try{var h=new RegExp("([\\d\\.])+"),f=h.exec(a);if(f)a=f[0];if(g)a="-"+a;return a}catch(i){}return null},tryParseValue:function(a){a=this.stripValue(a);if(a===null)return 0;try{a=parseFloat(a);if(isNaN(a))a=0}catch(b){a=0}return a},deFormatValue:function(a){a=this.stripValue(a);if(a===null)return;this._currentValueInString=a;this._currentText=this.formatValue(a)},formatValue:function(c){var a=this.culture.numberFormat;c=""+c+"";var j=this.digitsPlaces,g=" ",e=".",f=2,i=this.isNegtive(c),d=new Array(3);d.push(3);var h="n";switch(this.type){case"numeric":h=i?a.pattern[0]:"n";g=a[","];e=a["."];f=a.decimals;d=a.groupSizes;break;case"percent":h=a.percent.pattern[i?0:1];g=a.percent[","];e=a.percent["."];f=a.percent.decimals;d=a.percent.groupSizes;break;case"currency":h=a.currency.pattern[i?0:1];g=a.currency[","];e=a.currency["."];f=a.currency.decimals;d=a.currency.groupSizes}if(j!==-2)f=j;if(!this.showGroup)d=[0];c=c.replace(new RegExp("^[0]+"),"");var b=this.formatDigit(c,g,e,f,d);b=b.replace(new RegExp("^[0]+"),"");if(b.indexOf(e)===0)b="0"+b;if(b==="")b="0";this._currentValueInString=c;this._currentText=this.applyFormatPattern(h,b,a.percent.symbol,a.currency.symbol);return this._currentText},getFormattedValue:function(){return this.formatValue(this._currentValueInString)},getJSFloatValue:function(){try{return this._currentValueInString===""?0:parseFloat(this._currentValueInString)}catch(a){return Number.NaN}},clear:function(){this._currentValueInString="0";this._currentText="0"},_setValueFromJSFloat:function(a){try{this._currentValueInString=""+a+"";this.formatValue(a);return true}catch(b){return false}},isZero:function(b){try{if(b===undefined)b=this._currentValueInString;var a=b.replace("-","");a=a.replace("(","");a=a.replace(")","");if(!a.length)a="0";var c=parseFloat(a);if(!isNaN(c)&&!c)return true}catch(d){}return false},setPositiveSign:function(){this._currentValueInString=this._currentValueInString.replace("-","");this._currentValueInString=this._currentValueInString.replace("(","");this._currentValueInString=this._currentValueInString.replace(")","")},isNegative:function(){return this._currentValueInString.indexOf("-")!==-1||this._currentValueInString.indexOf("(")!==-1},invertSign:function(){var a=this.isNegative();if(a)this.setPositiveSign();else this._currentValueInString=!this._currentValueInString.length?"0":"-"+this._currentValueInString;if(this.isZero())this._currentValueInString=a?"0":"-0";this.formatValue(this._currentValueInString)},increment:function(b){if(b===undefined)b=1;try{var a=this._currentValueInString.split(".");this._currentValueInString=a[0]*1+b+""+(a.length>1?"."+a[1]:"")}catch(c){}},decrement:function(b){if(b===undefined)b=1;try{var a=this._currentValueInString.split(".");this._currentValueInString=a[0]*1-b+""+(a.length>1?"."+a[1]:"")}catch(c){}},checkDigitsLimits:function(f){try{var a=this._currentValueInString.split(".");if(!a.length||a.length===1&&a[0]==="")return;var d="";if(a.length>1)d=a[1];for(var b="",c=0;c<f;c++){var e="0";if(d.length>c)e=d.charAt(c);b=b+e}if(b.length>0)this._currentValueInString=a[0]+"."+b;else this._currentValueInString=a[0]}catch(g){}},checkMinValue:function(g,i,h){if(typeof h==="undefined")h=false;var d=true;try{var a=this._currentValueInString.split("."),b=parseFloat(a[0]===""||a[0]==="-"?"0":a[0]),c=0;if(a.length>1&&parseFloat(a[1])>0)c=parseFloat("1."+a[1]);if(b<0||a[0]==="-")c=c*-1;g=""+g+"";a=g.split(".");var e=parseFloat(a[0]),f=0;if(a.length>1&&parseFloat(a[1])>0)f=parseFloat("1."+a[1]);if(b>e)return true;if(b<e||h&&b===e&&c<=f)d=false;else if(b===e&&b<0&&c>f)d=false;else if(b===e&&b>=0&&c<f)d=false;if(!d&&i)this._currentValueInString=""+g+""}catch(j){}return d},checkMaxValue:function(f,h){var c=true;try{var a=this._currentValueInString.split("."),b=parseFloat(a[0]===""||a[0]==="-"?"0":a[0]),d=0;if(a.length>1&&parseFloat(a[1])>0)d=parseFloat("1."+a[1]);if(b<0||a[0]==="-")d=d*-1;f=""+f+"";a=f.split(".");var e=parseFloat(a[0]),g=0;if(a.length>1&&parseFloat(a[1])>0)g=parseFloat("1."+a[1]);if(b<e)return true;if(b>e)c=false;if(b===e&&b>=0&&d>g)c=false;if(b===e&&b<0&&d<g)c=false;if(!c&&h)this._currentValueInString=""+f+""}catch(i){}return c},applyFormatPattern:function(f,e,d,c){var a=f,b=new RegExp("[n]","g");a=a.replace(b,e);b=new RegExp("[%]","g");a=a.replace(b,d);b=new RegExp("[$]","g");a=a.replace(b,c);return a},formatDigit:function(l,k,g,j,i){var a=""+l+"";a=a.replace("-","");a=a.replace("(","");a=a.replace(")","");var c=a.indexOf(g);if(c===-1)c=a.indexOf(".");if(c===-1)c=a.indexOf(",");if(c===-1)c=a.length;for(var b="",f=0,h=0,e,d=a.length-1;d>=0;d--){e=a.charAt(d);if(d<c){b=e+b;h++;if(h===i[f]*1&&i[f]*1&&d){b=k+b;h=0;if(i.length-1>f)f++}}}if(j>0){b=b+g;for(d=0;d<j;d++){e="0";if(d+c+1<a.length)e=a.charAt(d+c+1);b=b+e}}if(j===-1)if(c<a.length-1){b=b+g;b=b+a.substr(c+1)}return b}}})(jQuery);
(function(a){"use strict";a.widget("wijmo.wijgrid",{options:{allowColMoving:false,allowColSizing:false,allowEditing:false,allowKeyboardNavigation:false,allowPaging:false,allowSorting:false,alwaysParseData:true,cellStyleFormatter:undefined,columns:[],columnsAutogenerationMode:"merge",culture:"",customFilterOperators:[],data:null,ensureColumnsPxWidth:false,filterOperatorsSortMode:"alphabeticalCustomFirst",groupAreaCaption:"Drag a column here to group by that column.",groupIndent:10,highlightCurrentCell:false,nullString:undefined,pageIndex:0,pageSize:10,pagerSettings:{mode:"numeric",pageButtonCount:10,position:"bottom"},readAttributesFromData:false,rowStyleFormatter:undefined,scrollMode:"none",selectionMode:"singleRow",showFilter:false,showFooter:false,showGroupArea:false,showRowHeader:false,staticColumnIndex:-1,staticRowIndex:-1,afterCellEdit:null,afterCellUpdate:null,beforeCellEdit:null,beforeCellUpdate:null,columnDragging:null,columnDragged:null,columnDropping:null,columnDropped:null,columnGrouping:null,columnGrouped:null,columnResizing:null,columnResized:null,columnUngrouping:null,columnUngrouped:null,currentCellChanging:null,currentCellChanged:null,filterOperatorsListShowing:null,filtering:null,filtered:null,groupAggregate:null,groupText:null,invalidCellValue:null,pageIndexChanging:null,pageIndexChanged:null,selectionChanged:null,sorting:null,sorted:null,ajaxError:null,dataLoading:null,dataLoaded:null,loading:null,loaded:null,rendering:null,rendered:null},_data$prefix:"wijgrid",_customSortOrder:1e3,_reverseKey:false,_pageSizeKey:10,_ajaxError:function(b,a,c){this._trigger("ajaxError",null,{XMLHttpRequest:b,textStatus:a,errorThrown:c});this.outerDiv.removeClass("wijmo-wijgrid-loading")},_dataLoading:function(){this._trigger("dataLoading");this.outerDiv.addClass("wijmo-wijgrid-loading")},_dataLoaded:function(a){this._trigger("dataLoaded");this.outerDiv.removeClass("wijmo-wijgrid-loading");this.doRefresh(a);this._trigger("loaded")},ensureControl:function(c,b){this._trigger("loading");if(!a.isPlainObject(b))b={data:null,afterRefresh:null,beforeRefresh:null};if(this._initialized){this._ownerise(false);this._widgetsToOptions()}else this._prepareColumnOptions(false);this._ownerise(true);if(c===true)this._dataStore.load(b);else{this.doRefresh(b);this._trigger("loaded")}},doRefresh:function(g){if(!this._initialized)try{this._prepareColumnOptions(true)}catch(n){throw n;}finally{this._ownerise(true);this._initialized=true}else g&&a.isFunction(g.beforeRefresh)&&g.beforeRefresh.apply(this);this._rebuildLeaves();var f=this._dataStore.getDataSlice(),m=f.data,k,c,h,d,b,e,j,i,l;a.each(this._field("leaves"),function(){this._totalsValue=f.totals?f.totals[this.dataKey]:undefined});this._setPageCount(f);k=this._field("leaves");this.dataTable=[];if(h=m.length)for(c=0;c<h;c++){d=m[c];b=[];for(e=0,j=k.length;e<j;e++){i=k[e];if(a.wijmo.wijgrid.validDataKey(i.dataKey)){b.push({value:d.values[i.dataKey],__attr:d.attributes?d.attributes.cellsAttributes[i.dataKey]:{},__style:{}});b.originalRowIndex=d.originalRowIndex}}b.rowType=a.wijmo.wijgrid.rowType.data;if(c%2!==0)b.rowType|=a.wijmo.wijgrid.rowType.dataAlt;b.__style={};b.__attr=d.attributes?d.attributes.rowAttributes:{};this.dataTable.push(b)}else if(f.emptyData&&(h=f.emptyData.length))for(c=0;c<h;c++){d=f.emptyData[c];b=[];l=this._field("visibleLeaves").length;for(e=0,j=d.length;e<j;e++)b.push({html:d[e],__attr:{colSpan:l>0&&c===h-1?l-c:1},__style:{}});b.rowType=a.wijmo.wijgrid.rowType.emptyDataRow;b.__style={};b.__attr={};this.dataTable.push(b)}this._trigger("rendering");this._refresh();this._trigger("rendered");g&&a.isFunction(g.afterRefresh)&&g.afterRefresh.apply(this)},getFilterOperatorsByDataType:function(b){var a=this.filterOperatorsCache.getByDataType(b||"string");this.filterOperatorsCache.sort(a,this.options.filterOperatorsSortMode);return a},setSize:function(d,c){var b=this._view(),e={type:"",hScrollValue:null,vScrollValue:null},g=this.outerDiv,f=this._field("frozener"),h=this._field("visibleLeaves");if(b&&b.getScrollValue)e=b.getScrollValue();if(d||d===0){this._autoWidth=false;g.width(d)}if(c||c===0){this._autoHeight=false;g.height(c)}a.each(h,function(c){var e=b.getHeaderCell(c),d=b.getJoinedCols(c);a(e).css("width","");a.each(d,function(c,b){a(b).css("width","")})});this._updateSplits(e);f&&f.refresh()},_prepareColumnOptions:function(g){a.wijmo.wijgrid.traverse(this.options.columns,function(b){b.isBand=a.isArray(b.columns)||b.clientType==="c1band"});(new a.wijmo.wijgrid.bandProcessor)._getVisibleHeight(this.options.columns,true);var f=[],c,e=this._originalHeaderRowData(),d=this._originalFooterRowData(),b=(this.options.columnsAutogenerationMode||"").toLowerCase();if(g){c=this._dataStore.dataMode()===a.wijmo.wijgrid.dataMode.dom;b!=="none"&&new a.wijmo.wijgrid.columnsGenerator(this).generate(b,this._dataStore,this.options.columns)}a.wijmo.wijgrid.setTraverseIndex(this.options.columns);a.wijmo.wijgrid.traverse(this.options.columns,function(b){b.isBand=a.isArray(b.columns)||b.clientType==="c1band";a.wijmo.wijgrid.shallowMerge(b,a.wijmo.c1basefield.prototype.options);if(!b.isBand){a.wijmo.wijgrid.shallowMerge(b,a.wijmo.c1field.prototype.options);if(!b.clientType)b.clientType="c1field"}else b.clientType="c1band";b.isLeaf&&!b.isBand&&f.push(b)});this._field("leaves",f);g&&a.each(f,function(h,f){var g=typeof f.dataKey==="number"?f.dataKey:h;if(b==="merge"||f.dynamic===true)if(f.headerText===undefined)if(c&&e&&g<e.length)f.headerText=a.trim(e[g]);else if(a.wijmo.wijgrid.validDataKey(f.dataKey))f.headerText=""+f.dataKey;if(c&&d&&g<d.length)f._footerTextDOM=a.trim(d[g])})},_rebuildLeaves:function(){var b=[],d=[],c;if(this.options.showRowHeader){c=a.wijmo.wijgrid.createDynamicField({clientType:"c1basefield",dataIndex:-1,travIdx:-1,parentVis:true,allowMoving:false,allowSizing:false,allowSort:false,isRowHeader:true});c.owner=this;b.push(c)}a.each(this.options.columns,function(c,a){b.push(a)});this._field("spanTable",(new a.wijmo.wijgrid.bandProcessor).generateSpanTable(b,d));this._field("leaves",d);this._onLeavesCreated()},_onLeavesCreated:function(){var d=this._field("leaves"),c=0,b=0,e=this;this._field("visibleLeaves",a.grep(d,function(d,f){d.leavesIdx=f;if(a.wijmo.wijgrid.validDataKey(d.dataKey))d.dataIndex=c++;else d.dataIndex=-1;if(!d.isBand){e._ensureDataParser(d);if(a.isFunction(d.dataParser))d.dataParser=new d.dataParser}if(d.parentVis){d.visLeavesIdx=b++;return true}return false}))},_create:function(){if(!this.element.is("table"))throw"invalid markup";this.destroyed=false;var b=this.element[0].style.height,c=this.element[0].style.width;this._dataStore=new a.wijmo.wijgrid.dataStore(this);this._originalHtml=this.element.html();this.element.addClass("wijmo-wijgrid-root");this.element.wrap('<div class="ui-widget wijmo-wijgrid ui-widget-content ui-corner-all"></div>');this.outerDiv=this.element.parent();b&&this.outerDiv.css("height",this.element[0].style.height);if(b!==""&&b!=="auto")this._autoHeight=false;else this._autoHeight=true;c&&this.outerDiv.css("width",this.element[0].style.width);if(c!==""&&c!=="auto")this._autoWidth=false;else this._autoWidth=true;this.element.css({height:"",width:""});this.filterOperatorsCache=new a.wijmo.wijgrid.filterOperatorsCache;this._registerFilterOperator(a.wijmo.wijgrid.embeddedFilters);this.options.disabled&&this.disable();this.cellFormatter=new a.wijmo.wijgrid.cellFormatterHelper;this.rowStyleFormatter=new a.wijmo.wijgrid.rowStyleFormatterHelper(this);this.cellStyleFormatter=new a.wijmo.wijgrid.cellStyleFormatterHelper(this)},_init:function(){this.$superPanelHeader=null;this.$topPagerDiv=null;this.$bottomPagerDiv=null;this.$groupArea=null;this.filterOperatorsCache.removeCustom();a.each(this.options.customFilterOperators,function(b,a){if(a)a.custom=true});this._registerFilterOperator(this.options.customFilterOperators);this._field("closestCulture",Globalize.findClosestCulture(this.options.culture)||Globalize.findClosestCulture("default"));if(!this.options.data){!this._field("thead")&&this._field("thead",a.wijmo.wijgrid.readTableSection(this.element,1));!this._field("tfoot")&&this._field("tfoot",a.wijmo.wijgrid.readTableSection(this.element,3))}this._initialized=this._initialized||false;this.ensureControl(true)},_setOption:function(c,b){var g=this["_preset_"+c],e=this.options[c],f,d;if(g!==undefined)b=g.apply(this,[b,e]);f=b!==e;a.Widget.prototype._setOption.apply(this,[c,b]);if(f){d=this["_postset_"+c];d!==undefined&&d.apply(this,[b,e])}},destroy:function(){var b,c=this;try{this._view().dispose();this._detachEvents(true);(b=this._field("resizer"))&&b.dispose();(b=this._field("frozener"))&&b.dispose();a.wijmo.wijgrid.iterateChildrenWidgets(this.outerDiv,function(b,a){a!==c&&a.destroy()});(b=this._field("selectionui"))&&b.dispose();(b=this._field("dragndrop"))&&b.dispose();a.wijmo.wijgrid.remove$dataByPrefix(this.element,this._data$prefix);this.element.removeClass("wijmo-wijgrid-root");this.element.html(this._originalHtml);this.element.insertBefore(this.outerDiv);this.outerDiv.remove();a.Widget.prototype.destroy.apply(this,arguments)}finally{this.destroyed=true}},columns:function(){return this._field("columns")||[]},currentCell:function(c,d){var b;if(arguments.length===0){b=this._field("currentCell");!b&&this._field("currentCell",b=a.wijmo.wijgrid.cellInfo.prototype.outsideValue);return b}else{b=arguments.length===1?c._clone():new a.wijmo.wijgrid.cellInfo(c,d);if(!b.isEqual(a.wijmo.wijgrid.cellInfo.prototype.outsideValue)){if(!b._isValid())throw"invalid arguments";b._clip(this._getDataCellsRange());if(b.rowIndex()>=0&&!(this.dataTable[b.rowIndex()].rowType&a.wijmo.wijgrid.rowType.data))return}b._setGridView(this);this._changeCurrentCell(b);return this._field("currentCell")}},data:function(){return this._dataStore.dataSource().items},selection:function(){var b=this._field("selection");!b&&this._field("selection",b=new a.wijmo.wijgrid.selection(this));return b},beginEdit:function(){return this._beginEditInternal(null)},endEdit:function(){return this._endEditInternal(null)},pageCount:function(){return this.options.allowPaging?this._field("pageCount")||1:1},_dragndrop:function(){var b=this._field("dragndrop");!b&&this._field("dragndrop",b=new a.wijmo.wijgrid.dragAndDropHelper(this));return b},_headerRows:function(){var b=this._field("headerRowsAccessor"),c;if(!b){c=this.options.showFilter?1:0;this._field("headerRowsAccessor",b=new a.wijmo.wijgrid.rowAccessor(this._view(),1,0,c))}return b},_filterRow:function(){if(this.options.showFilter){var b=new a.wijmo.wijgrid.rowAccessor(this._view(),1,0,0);return b.item(b.length()-1)}return null},_localizeFilterOperators:function(b){var c=this;a.each(b,function(d,a){if(a.name){var b=c.filterOperatorsCache.getByName(a.name);if(b)b.displayName=a.displayName}})},_rows:function(){var b=this._field("rowsAccessor");!b&&this._field("rowsAccessor",b=new a.wijmo.wijgrid.rowAccessor(this._view(),2,0,0));return b},_selectionui:function(){var b=this._field("selectionui");!b&&this._field("selectionui",b=new a.wijmo.wijgrid.selectionui(this));return b},_setPageCount:function(a){this._field("pageCount",Math.ceil(a.totalRows/this.options.pageSize)||1)},_registerFilterOperator:function(b){var d=this,c=b&&(a.isArray(b)||a.isPlainObject(b)&&!b.operator)?b:arguments;a.each(c,function(b,a){d.filterOperatorsCache.add(a)})},_postset_allowColMoving:function(c){var b=this;a.each(this.columns(),function(d,a){if(c)b._dragndrop().attach(a);else b._dragndrop().detach(a)});a.each(this._field("groupedWidgets"),function(d,a){if(c)b._dragndrop().attach(a);else b._dragndrop().detach(a)})},_postset_allowSorting:function(){this.ensureControl(false)},_postset_columns:function(){throw"read-only";},_postset_allowPaging:function(){this.ensureControl(true)},_postset_culture:function(){throw"read-only";},_postset_customFilterOperators:function(b){this.filterOperatorsCache.removeCustom();a.each(this.options.customFilterOperators,function(b,a){a.custom=true});this._registerFilterOperator(b)},_postset_data:function(){throw"read-only";},_postset_disabled:function(c){var d=this,b=this._view();a.wijmo.wijgrid.iterateChildrenWidgets(this.outerDiv,function(b,a){a!==d&&a.option("disabled",c)});b&&b.ensureDisabledState()},_postset_groupIndent:function(){this.ensureControl(false)},_postset_groupAreaCaption:function(b){var a=this._field("groupedColumns");this.$groupArea&&(!a||!a.length)&&this.$groupArea.html(b||"&nbsp;")},_postset_highlightCurrentCell:function(b){var a=this.currentCell();a&&a._isValid()&&this._highlightCellPosition(a,b)},_preset_pageIndex:function(a,c){if(isNaN(a))throw"out of range";var b=this.pageCount();if(a>b-1)a=b-1;if(a<0)a=0;if(this.options.allowPaging&&a!==c)if(!this._onPageIndexChanging({newPageIndex:a}))a=c;return a},_postset_pageIndex:function(){this.options.allowPaging&&this.ensureControl(true,{afterRefresh:function(){this._onPageIndexChanged()}})},_preset_pageSize:function(a){if(isNaN(a))throw"out of range";if(a<=0)a=1;return a},_postset_pageSize:function(){this.options.pageIndex=0;this.options.allowPaging&&this.ensureControl(true)},_postset_pagerSettings:function(){this.ensureControl(false)},_postset_scrollMode:function(b,a){if(b==="none"||a==="none")this.ensureControl(false);else this._view().refreshPanel()},_postset_selectionMode:function(d){var c=this.selection(),b=this.currentCell();c.beginUpdate();c.clear();b&&b._isValid()&&c._selectRange(new a.wijmo.wijgrid.cellInfoRange(b,b),false,false,0,null);c.endUpdate();this._view().toggleDOMSelection(d==="none")},_postset_showFilter:function(){this.ensureControl(false)},_postset_showGroupArea:function(){this.ensureControl(false)},_postset_showRowHeader:function(){this.ensureControl(false)},_postset_staticRowIndex:function(){this.options.scrollMode!=="none"&&this.ensureControl(false)},_postset_staticColumnIndex:function(){this.options.scrollMode!=="none"&&this.ensureControl(false)},_columnWidgetsFactory:function(e,b){var c,d=b.clientType;if(!d&&b.isBand)d="c1band";b=a.extend({owner:this},b,{disabled:this.options.disabled});switch(d){case"c1basefield":c=e.c1basefield(b);break;case"c1band":c=e.c1band(b);break;default:c=e.c1field(b)}return c},_field:function(c,b){return a.wijmo.wijgrid.dataPrefix(this.element[0],this._data$prefix,c,b)},_removeField:function(b){var a=this._data$prefix+b;this.element.removeData(a)},_changeRenderState:function(c,b,f){var d=a.wijmo.wijgrid.dataPrefix,e=d(c,this._data$prefix,"renderState");if(f){b=e|b;d(c,this._data$prefix,"renderState",b)}else{b=e&~b;d(c,this._data$prefix,"renderState",b)}return b},_prepareFilterRequest:function(d){var b=this._field("leaves"),c;if(!b)return[];c=a.map(b,a.proxy(function(b){if(!b.isBand&&a.wijmo.wijgrid.validDataKey(b.dataKey)&&b.filterOperator){var f=a.extend(true,{},{foo:b.filterValue}).foo,e=a.extend(true,{},{foo:b.filterOperator}).foo,c=a.wijmo.wijgrid.filterHelper.verify(e,f,b.dataType,this.filterOperatorsCache);if(c)return d?[{column:b,filterOperator:c.filterOperator,filterValue:c.filterValue}]:[{dataKey:b.dataKey,filterOperator:c.filterOperator,filterValue:c.filterValue}]}return null},this));return c},_preparePageRequest:function(){return this.options.allowPaging?{pageIndex:this.options.pageIndex,pageSize:this.options.pageSize}:null},_prepareSortRequest:function(){var c=this._field("leaves"),b;if(!c||!this.options.allowSorting)return[];b=a.map(c,function(b){var c=null;if(!b.isBand&&b.allowSort&&a.wijmo.wijgrid.validDataKey(b.dataKey)){if(b.groupInfo&&b.groupInfo.position!=="none"&&b.sortDirection==="none")b.sortDirection="ascending";c=b.sortDirection==="ascending"||b.sortDirection==="descending"?[{dataKey:b.dataKey,sortDirection:b.sortDirection,sortOrder:b.sortOrder||0}]:null}return c});b.sort(function(a,b){return a.sortOrder-b.sortOrder});a.each(b,function(b,a){delete a.sortOrder});return b},_prepareTotalsRequest:function(d){var b=this._field("leaves"),c;if(!b||!this.options.showFooter)return[];c=a.map(b,function(b){return!b.isBand&&a.wijmo.wijgrid.validDataKey(b.dataKey)&&b.aggregate&&b.aggregate!=="none"?d?[{column:b,aggregate:b.aggregate}]:[{dataKey:b.dataKey,aggregate:b.aggregate}]:null});return c},_widgetsToOptions:function(){var b=a.wijmo.wijgrid.flatten(this.options.columns);a.each(this.columns(),function(e,c){delete c.options.columns;var d=b[c.options.travIdx];a.extend(true,d,c.options);d.filterValue=c.options.filterValue;d.filterOperator=c.options.filterOperator})},_recreateColumnWidgets:function(){a.each(this.columns(),function(b,a){a.destroy()});var h=[],f=this._headerRows(),b,d,i,c,g,j,e;if(f&&f.length()){b=[];a.wijmo.wijgrid.traverse(this.options.columns,function(a){a.parentVis&&b.push(a)});for(d=0,i=b.length;d<i;d++){c=b[d];g=f.item(c.thY);j=(new a.wijmo.wijgrid.rowAccessor).getCell(g,c.thX);e=this._columnWidgetsFactory(a(j),c);h.push(e.data(e.data(a.wijmo.c1basefield.prototype._data$prefix+"widgetName")))}}this._field("columns",h)},_ownerise:function(b){if(b){var c=this;a.wijmo.wijgrid.traverse(this.options.columns,function(d){d.owner=c;var a,b,e;if(a=d.groupInfo){a.owner=d;if(a.expandInfo)for(b=0,e=a.expandInfo.length;b<e;b++)a.expandInfo[b].owner=a}})}else a.wijmo.wijgrid.traverse(this.options.columns,function(c){delete c.owner;var a,b,d;if(a=c.groupInfo){delete a.owner;if(a.expandInfo)for(b=0,d=a.expandInfo.length;b<d;b++)delete a.expandInfo[b].owner}})},_updateSplits:function(a){this._view().updateSplits!==null&&this._view().updateSplits(a)},_refresh:function(){var b=this._view(),c,e,d,g={type:"",hScrollValue:null,vScrollValue:null},f=[];if(b&&b.getScrollValue)g=b.getScrollValue();this._detachEvents(false);this.element.detach();this.element.empty();this.outerDiv.empty();this.outerDiv.append(this.element);if(this._field("selectionui")){this._field("selectionui").dispose();this._field("selectionui",null)}this._field("headerRowsAccessor")&&this._field("headerRowsAccessor",null);this._field("rowsAccessor")&&this._field("rowsAccessor",null);this._field("resizer")&&this._field("resizer").dispose();this._field("frozener")&&this._field("frozener").dispose();(new a.wijmo.wijgrid.grouper).group(this,this.dataTable,this._field("leaves"));(new a.wijmo.wijgrid.merger).merge(this.dataTable,this._field("visibleLeaves"));if(this.options.scrollMode!=="none")this._field("view",b=new a.wijmo.wijgrid.fixedView(this));else this._field("view",b=new a.wijmo.wijgrid.flatView(this));this._render();this._ownerise(false);this._recreateColumnWidgets();this._ownerise(true);if(this.options.allowPaging){this.$topPagerDiv&&this.$topPagerDiv.wijpager(this._pagerSettings2PagerWidgetSettings()).css("zIndex",5);this.$bottomPagerDiv&&this.$bottomPagerDiv.wijpager(this._pagerSettings2PagerWidgetSettings()).css("zIndex",5)}this._attachEvents();b.focusableElement().attr("tabIndex",0);if(this.currentCell()._isValid()&&this.currentCell(this.currentCell()))this.currentCell()._isEdit(false);else this.currentCell(this._getFirstDataRowCell(0));this._field("selection",null);c=this.currentCell();if(c._isValid()){this.selection()._startNewTransaction(c);this.selection()._selectRange(new a.wijmo.wijgrid.cellInfoRange(c,c),false,false,0,null)}this._selectionui();e=new a.wijmo.wijgrid.resizer(this);a.each(this.columns(),function(c,b){var a=b.options;a.visible&&a.parentVis&&a.isLeaf&&e.addElement(b)});this._field("resizer",e);this._updateSplits(g);if(this.options.scrollMode!=="none"){d=new a.wijmo.wijgrid.frozener(this);d.addVElement(this._getStaticIndex(false));d.addHElement(this._getStaticIndex(true));d.attachDivEvent();this._field("frozener",d)}a.each(this.columns(),function(c,a){if(!a.options.isBand&&a.options.showFilter===true){var b=a._getFilterEditorWidth();b!==undefined&&f.push({widget:a,width:b})}});a.each(f,function(b,a){a.widget._setFilterEditorWidth(a.width)})},_render:function(){var d=this._view(),b=this.options,c;d.render();c=this.outerDiv;if(b.scrollMode!=="none")c=this.outerDiv.find("div.wijmo-wijgrid-scroller:first");this.$superPanelHeader=null;if(this.$topPagerDiv){this.$topPagerDiv.data("wijpager")&&this.$topPagerDiv.wijpager("destroy");this.$topPagerDiv.remove()}this.$topPagerDiv=null;if(b.allowPaging&&(b.pagerSettings.position==="top"||b.pagerSettings.position==="topAndBottom"))if(!this.$topPagerDiv){c.prepend(this.$superPanelHeader=a('<div class="wijmo-wijsuperpanel-header"></div>'));this.$superPanelHeader.prepend(this.$topPagerDiv=a('<div class="wijmo-wijgrid-header ui-widget-header ui-corner-top"></div>'))}if(b.showGroupArea)this._processGroupArea(c);else this.$groupArea=null;if(this.$bottomPagerDiv){this.$bottomPagerDiv.data("wijpager")&&this.$bottomPagerDiv.wijpager("destroy");this.$bottomPagerDiv.remove()}this.$bottomPagerDiv=null;if(b.allowPaging&&(b.pagerSettings.position==="bottom"||b.pagerSettings.position==="topAndBottom"))!this.$bottomPagerDiv&&c.append(this.$bottomPagerDiv=a('<div class="wijmo-wijgrid-footer wijmo-wijsuperpanel-footer ui-state-default ui-corner-bottom"></div>'))},_processGroupArea:function(e){var b=this,d=this._field("groupedColumns"),c=[];this.$groupArea=a('<div class="ui-widget-content ui-helper-clearfix"></div>');if(d.length>0)a.each(d,function(f,d){var e=a('<a href="#"></a>').appendTo(b.$groupArea);e.c1groupedfield(a.extend({owner:b},{allowMoving:d.allowMoving,allowSort:d.allowSort,dataIndex:d.dataIndex,headerText:d.headerText,isBand:d.isBand,isLeaf:d.isLeaf,linearIdx:d.linearIdx,parentIdx:d.parentIdx,sortDirection:d.sortDirection,travIdx:d.travIdx,groupedIndex:d.groupedIndex},{disabled:b.options.disabled}));c.push(e.data("c1groupedfield"))});else this.$groupArea.addClass("wijmo-wijgrid-group-area").html(this.options.groupAreaCaption||"&nbsp;");this._field("groupedWidgets",c);!this.$superPanelHeader&&e.prepend(this.$superPanelHeader=a('<div class="wijmo-wijsuperpanel-header"></div>'));this.$superPanelHeader.prepend(this.$groupArea);this._dragndrop().attachGroupArea(this.$groupArea)},_attachEvents:function(){var b=this._view(),c=b.focusableElement();c.bind("keydown."+this.widgetName,a.proxy(this._onKeyDown,this));c.bind("keypress."+this.widgetName,a.proxy(this._onKeyPress,this));a.each(b.subTables(),a.proxy(function(d,c){var b=c.element();if(b){b.tHead&&a(b.tHead).bind("click."+this.widgetName,a.proxy(this._onClick,this));b.tBodies.length&&a(b.tBodies[0]).bind("click."+this.widgetName,a.proxy(this._onClick,this)).bind("dblclick."+this.widgetName,a.proxy(this._onDblClick,this)).bind("mousemove."+this.widgetName,a.proxy(this._onMouseMove,this)).bind("mouseout."+this.widgetName,a.proxy(this._onMouseOut,this)).find("> tr.wijmo-wijgrid-groupheaderrow > td .wijmo-wijgrid-grouptogglebtn").bind("click."+this.widgetName,a.proxy(this._onGroupBtnClick,this))}},this))},_detachEvents:function(e){var b=this._view(),c=this,d;if(b){d=b.focusableElement();d.unbind("keydown."+this.widgetName);d.unbind("keypress."+this.widgetName);a.each(b.subTables(),function(){var b=this.element();if(b){b.tHead&&a(b.tHead).unbind("."+c.widgetName);b.tBodies.length&&a(b.tBodies[0]).unbind("."+c.widgetName)}});e&&a.each(b.getJoinedTables(true,0),function(d,b){b&&typeof b!=="number"&&a(b.element()).find("> tbody").find("> tr.wijmo-wijgrid-groupheaderrow > td .wijmo-wijgrid-grouptogglebtn").unbind("."+c.widgetName)})}},_handleSort:function(c,f){var g=this.options.columns,e=c.travIdx,d,b;if(c&&this.options.allowSorting){d=c.sortDirection==="none"?"ascending":c.sortDirection==="ascending"?"descending":"ascending";b={column:c,sortDirection:d};if(this._onColumnSorting(b)){b.column.sortDirection=b.sortDirection;if(f)b.column.sortOrder=this._customSortOrder++;else{this._customSortOrder=1e3;a.each(this.columns(),function(b,a){a.options.sortOrder=0;if(a.options.travIdx!==e&&!(a.options.groupInfo&&a.options.groupInfo.position!=="none"))a.options.sortDirection="none"});a.wijmo.wijgrid.traverse(g,function(a){a.sortOrder=0;if(a.travIdx!==e&&!(a.groupInfo&&a.groupInfo.position!=="none"))a.sortDirection="none"})}this.ensureControl(true,{afterRefresh:function(){this._onColumnSorted({column:b.column})}})}}},_pagerSettings2PagerWidgetSettings:function(){return a.extend({},this.options.pagerSettings,{disabled:this.options.disabled,pageCount:this.pageCount(),pageIndex:this.options.pageIndex,pageIndexChanging:a.proxy(this._onPagerWidgetPageIndexChanging,this),pageIndexChanged:a.proxy(this._onPagerWidgetPageIndexChanged,this)})},_handleDragnDrop:function(i,j,d,e,f){var c=a.wijmo.wijgrid.getColumnByTravIdx(this.options.columns,i),b=a.wijmo.wijgrid.getColumnByTravIdx(this.options.columns,j),g=e?"groupArea":"columns",h=f?"groupArea":"columns";if(f)this._onColumnGrouping({drag:c.found,drop:b?b.found:null,dragSource:g,dropSource:h,at:d})&&this.ensureControl(true,{beforeRefresh:function(){if(!b)c.found.groupedIndex=0;else switch(d){case"left":c.found.groupedIndex=b.found.groupedIndex-.5;break;case"right":c.found.groupedIndex=b.found.groupedIndex+.5}!e&&a.extend(true,c.found,{groupInfo:{position:"header"}})},afterRefresh:function(){this._onColumnGrouped({drag:c.found,drop:b?b.found:null,dragSource:g,dropSource:h,at:d})}});else this._onColumnDropping({drag:c.found,drop:b.found,at:d})&&this.ensureControl(false,{beforeRefresh:function(){c.at.splice(c.found.linearIdx,1);switch(d){case"left":if(c.at===b.at&&c.found.linearIdx<b.found.linearIdx)b.at.splice(b.found.linearIdx-1,0,c.found);else b.at.splice(b.found.linearIdx,0,c.found);break;case"right":if(c.at===b.at&&c.found.linearIdx<b.found.linearIdx)b.at.splice(b.found.linearIdx,0,c.found);else b.at.splice(b.found.linearIdx+1,0,c.found);break;case"center":b.found.columns.push(c.found)}a.wijmo.wijgrid.setTraverseIndex(this.options.columns)},afterRefresh:function(){this._onColumnDropped({drag:c.found,drop:b.found,at:d})}})},_handleFilter:function(a,f,g){var c=this.filterOperatorsCache.getByName(f),b,e;if(c){if(c.arity>1){b=this._parse(a.options,g);e=b!==null&&(a.options.dataType==="string"||!isNaN(b))}else e=true;if(e){var d={column:a.options,operator:c.name,value:b};if(this._onColumnFiltering(d)){a.options.filterValue=d.value;a.options.filterOperator=d.operator;this.options.pageIndex=0;this.ensureControl(true,{afterRefresh:function(){this._onColumnFiltered({column:a.options})}})}}}},_handleUngroup:function(c){var b=a.wijmo.wijgrid.getColumnByTravIdx(this.options.columns,c);if(b&&b.found){b=b.found;this._onColumnUngrouping({column:b})&&this.ensureControl(false,{beforeRefresh:function(){delete b.groupedIndex;a.extend(true,b,{groupInfo:{position:"none"}})},afterRefresh:function(){this._onColumnUngrouped({column:b})}})}},_onColumnDropping:function(a){return this._trigger("columnDropping",null,a)},_onColumnDropped:function(a){this._trigger("columnDropped",null,a)},_onColumnGrouping:function(a){return this._trigger("columnGrouping",null,a)},_onColumnGrouped:function(a){this._trigger("columnGrouped",null,a)},_onColumnUngrouping:function(a){return this._trigger("columnUngrouping",null,a)},_onColumnUngrouped:function(a){this._trigger("columnUngrouped",null,a)},_onColumnFiltering:function(a){return this._trigger("filtering",null,a)},_onColumnFiltered:function(a){this._trigger("filtered",null,a)},_onColumnSorting:function(a){return this._trigger("sorting",null,a)},_onColumnSorted:function(a){this._trigger("sorted",null,a)},_onCurrentCellChanged:function(){var b=this.options;if(b.allowKeyboardNavigation){var a=this._field("currentCell");b.scrollMode!=="none"&&a&&!a.isEqual(a.outsideValue)&&this._view().scrollTo(a)}this._trigger("currentCellChanged")},_onPageIndexChanging:function(a){return this._trigger("pageIndexChanging",null,a)},_onPageIndexChanged:function(){this._trigger("pageIndexChanged")},_onPagerWidgetPageIndexChanging:function(b,a){a.handled=true},_onPagerWidgetPageIndexChanged:function(b,a){this._setOption("pageIndex",a.newPageIndex)},_onClick:function(d){if(!this._canInteract()||!d.target)return;var j=this._view(),i=this._getParentSubTable(d.target,["td","th"],j.subTables()),h,g,b,f=0,e,c;if(i){h=i[0];g=a(h).closest("tr");if(!(g.is(".wijmo-wijgrid-datarow")||g.is(".wijmo-wijgrid-headerrow")))return;if(!g.length)return;b=j.getAbsoluteCellInfo(h)._absToData(this._getDataToAbsOffset());if(b.cellIndex()<0||b.rowIndex()<0)if(b.rowIndex()>=0){b=new a.wijmo.wijgrid.cellInfo(0,b.rowIndex());f=2}else{b=this._getFirstDataRowCell(b.cellIndex());f=1}this._changeCurrentCell(b);e=this.currentCell();c=this.selection();(!d.shiftKey||!c._multipleRangesAllowed()&&this.options.selectionMode.toLowerCase()!=="singlerange")&&c._startNewTransaction(e);c.beginUpdate();if(d.shiftKey&&d.ctrlKey)c._clearRange(new a.wijmo.wijgrid.cellInfoRange(e,e),f);else c._selectRange(new a.wijmo.wijgrid.cellInfoRange(c._anchorCell(),e),d.ctrlKey,d.shiftKey,f,null);c.endUpdate()}},_onDblClick:function(a){this._beginEditInternal(a)},_onGroupBtnClick:function(e){var g=a(e.target).closest("tr"),f=new a.wijmo.wijgrid.groupHelper,c=f.getGroupInfo(g[0]),d,b;if(c){d=f.getColumnByGroupLevel(this._field("leaves"),c.level);if(d){b=d.groupInfo.expandInfo[c.index];if(b.isExpanded)b.collapse(e.shiftKey);else b.expand(e.shiftKey);this._view().ensureHeight()}}},_onKeyDown:function(b){if(!this._canInteract)return true;var e=b.target.tagName.toLowerCase(),g=false,f,h,d,c;if((e==="input"||e==="option"||e==="select"||e==="textarea")&&a(b.target).closest("tr.wijmo-wijgrid-datarow").length===0)return true;if(this.options.allowEditing)if((b.which===a.ui.keyCode.ESCAPE||b.which===113)&&this.currentCell()._isValid()&&this.currentCell()._isEdit()){this._endEditInternal(b);return false}else if(b.which===113){this._beginEditInternal(b);return false}if(!this.options.allowKeyboardNavigation)return true;switch(b.which){case a.ui.keyCode.LEFT:case a.ui.keyCode.RIGHT:case a.ui.keyCode.DOWN:case a.ui.keyCode.UP:case a.ui.keyCode.PAGE_DOWN:case a.ui.keyCode.PAGE_UP:case a.ui.keyCode.HOME:case a.ui.keyCode.END:case a.ui.keyCode.TAB:f=this._getNextCurrencyPos(this._getDataCellsRange(),this.currentCell(),b.keyCode,b.shiftKey);g=this._canMoveToAnotherCell(b.target,b.which)}if(g){this._changeCurrentCell(new a.wijmo.wijgrid.cellInfo(f.cellIndex,f.rowIndex));d=this.currentCell();h=this._getDOMDataCell(d);c=this.selection();(!b.shiftKey||!c._multipleRangesAllowed()&&this.options.selectionMode.toLowerCase()!=="singlerange")&&c._startNewTransaction(d);c.beginUpdate();c._selectRange(new a.wijmo.wijgrid.cellInfoRange(c._anchorCell(),d),false,b.shiftKey,0,null);c.endUpdate();return false}return true},_onKeyPress:function(c){if(this._canInteract()&&this.options.allowEditing){var g=c.which,f=this.currentCell(),b,d,e;if(g&&f._isValid()&&!f._isEdit()){b=c.target.tagName.toLowerCase();if(b!=="input"&&b!=="option"&&b!=="select"&&b!=="textarea"){d=a(c.target).closest(".wijmo-wijgrid-table");if(d.length){e=a.map(this._view().subTables(),function(a){return a.element()});if(a.inArray(d[0],e)>=0)if(a.wij.charValidator.isPrintableChar(String.fromCharCode(g))){this._beginEditInternal(c);return false}}}}}},_onMouseMove:function(k){if(!this._canInteract())return;var i=this._view(),h=this._getParentSubTable(k.target,["td","th"],i.subTables()),g,e,f,b,d,c,j=a.wijmo.wijgrid.renderState;if(h){g=h[0];e=a(g).closest("tr");if(!e.length||e.is(".wijmo-wijgrid-foorow")||!(e.is(".wijmo-wijgrid-datarow")||e.is(".wijmo-wijgrid-headerrow")))return;f=i.getAbsoluteCellInfo(g)._absToData(this._getDataToAbsOffset());b=this._field("hoveredRow");if(b!==undefined&&f.rowIndex()!==b){d=this._rows().item(b);if(d){c=this._createRowInfo(d);c.state=this._changeRenderState(c.$rows,j.hovered,false);this.rowStyleFormatter.format(c)}}b=f.rowIndex();this._field("hoveredRow",b);if(b>=0){d=this._rows().item(b);if(d){c=this._createRowInfo(d);c.state=this._changeRenderState(c.$rows,j.hovered,true);this.rowStyleFormatter.format(c)}}}},_onMouseOut:function(e){if(a(e.relatedTarget).closest(".wijmo-wijgrid-data").length===0){var d=this._field("hoveredRow"),c,b;if(d>=0){c=this._rows().item(d);if(c){b=this._createRowInfo(c);b.state=this._changeRenderState(b.$rows,a.wijmo.wijgrid.renderState.hovered,false);this.rowStyleFormatter.format(b)}}}},_fieldResized:function(b,c,a){if(c<0)c=0;if(a<=0)a=1;if(this._trigger("columnResizing",null,{column:b.options,oldWidth:c,newWidth:a})!==false){b.option("width",a);this._trigger("columnResized",null,{column:b.options})}},_changeCurrentCell:function(b){var a=this.currentCell(),c=this._getDataCellsRange(),f,e,d=this.options.highlightCurrentCell;if(c._isValid()&&c._containsCellInfo(b)||b.isEqual(b.outsideValue))if(a.cellIndex()!==b.cellIndex()||a.rowIndex()!==b.rowIndex()){f={cellIndex:b.cellIndex(),rowIndex:b.rowIndex(),oldCellIndex:a.cellIndex(),oldRowIndex:a.rowIndex()};if(this._trigger("currentCellChanging",null,f)){e=false;if(!this.options.allowEditing||!a._isEdit()||(e=this._endEditInternal(null))){d&&c._containsCellInfo(a)&&this._highlightCellPosition(a,false);a=b._clone();a._setGridView(this);d&&this._highlightCellPosition(a,true);this._field("currentCell",a);this._onCurrentCellChanged()}}}else d&&this._highlightCellPosition(a,true)},_highlightCellPosition:function(d,i){if(d&&d._isValid()){var j=d._clone()._dataToAbs(this._getDataToAbsOffset()),f=j.cellIndex(),k=j.rowIndex(),h=a.wijmo.wijgrid.renderState,g=this._view(),b,c,e;b=g.getHeaderCell(f);if(b){c=this._createRowInfo(this._headerRows().item(d.column().thY));b=a(b);e=this._changeRenderState(b,h.current,i);this.cellStyleFormatter.format(b,f,d.column(),c,e)}b=g.getJoinedRows(k,0);if(b){c=this._createRowInfo(b);c.state=this._changeRenderState(c.$rows,h.current,i);this.rowStyleFormatter.format(c)}b=g.getCell(f,k);if(b){b=a(b);e=this._changeRenderState(b,h.current,i);this.cellStyleFormatter.format(b,f,d.column(),c,e)}}},_beginEditInternal:function(d){if(this._canInteract()&&this.options.allowEditing){var c=this.currentCell().column(),b;if(c&&!c.readOnly){b=(new a.wijmo.wijgrid.cellEditorHelper).currentCellEditStart(this,d);b;return b}}return false},_endEditInternal:function(c){if(this._canInteract()&&this.options.allowEditing){var b=(new a.wijmo.wijgrid.cellEditorHelper).currentCellEditEnd(this,c);b&&this._view().ensureHeight(this.currentCell().rowIndex());return b}return false},_createRow:function(a){return a.insertRow(-1)},_createCell:function(c){var b=a.wijmo.wijgrid.rowType;switch(c){case b.header:return'<th><div class="wijmo-wijgrid-innercell"></div></th>';case b.filter:return"<td />";default:return'<td><div class="wijmo-wijgrid-innercell"></div></td>'}},_cellCreated:function(b,d,f,e,c,h,g){a.wijmo.wijgrid.dataPrefix(b,this._data$prefix,"renderState",c);this.cellStyleFormatter.format(b,d,f,e,c,h,g);this._changeRenderState(b,a.wijmo.wijgrid.renderState.rendering,false)},_rowCreated:function(b,d,c){a.wijmo.wijgrid.dataPrefix(true,b.$rows,this._data$prefix,{dataTableRowIndex:b._dataTableRowIndex,dataRowIndex:b.dataRowIndex,rowType:b.type,dataItemIndex:b.dataItemIndex,virtualDataItemIndex:b.virtualDataItemIndex,renderState:b.state});this.rowStyleFormatter.format(b,d,c);this._changeRenderState(b.$rows,a.wijmo.wijgrid.renderState.rendering,false)},_createRowInfo:function(j,i,h,d,g,f,e){var m=this.dataTable,l=null,b=j[1]?a(j):a(j[0]),k,c=a.wijmo.wijgrid.dataPrefix;if(isNaN(i))i=c(b,this._data$prefix,"rowType");if(isNaN(h))h=c(b,this._data$prefix,"renderState");if(isNaN(d))d=c(b,this._data$prefix,"dataTableRowIndex");if(isNaN(g))g=c(b,this._data$prefix,"dataRowIndex");if(isNaN(f))f=c(b,this._data$prefix,"dataItemIndex");if(isNaN(e))e=c(b,this._data$prefix,"virtualDataItemIndex");if(d>=0){k=m[d].originalRowIndex;if(k>=0)l=this.data()[k]}return{$rows:b,state:h,type:i,data:l,dataRowIndex:g,dataItemIndex:f,virtualDataItemIndex:e,_dataTableRowIndex:d}},_ensureDataParser:function(b){switch(b.dataType){case undefined:case"string":if(!b.dataParser)b.dataParser=a.wijmo.wijgrid.embeddedParsers.stringParser;break;case"boolean":if(!b.dataParser)b.dataParser=a.wijmo.wijgrid.embeddedParsers.boolParser;break;case"number":if(!b.dataParser)b.dataParser=a.wijmo.wijgrid.embeddedParsers.numberParser;break;case"currency":if(!b.dataParser)b.dataParser=a.wijmo.wijgrid.embeddedParsers.currencyParser;break;case"datetime":if(!b.dataParser)b.dataParser=a.wijmo.wijgrid.embeddedParsers.dateTimeParser;break;default:throw a.wijmo.wijgrid.stringFormat('Unsupported dataType value: "{0}"',b.dataType);}},_parseDOM:function(a,b){return a.dataParser.parseDOM(b,this._field("closestCulture"),a.dataFormatString,this.options.nullString,true)},_parse:function(b,c){var a=b.dataParser.parse(c,this._field("closestCulture"),b.dataFormatString,this.options.nullString,true);switch(b.dataType){case"datetime":if(a!==null&&!(a instanceof Date))throw"invalid value.";break;case"number":case"currency":if(a!==null&&(typeof a!=="number"||isNaN(a)))throw"invalid value.";break;case"boolean":if(a!==null&&(typeof a!=="boolean"||isNaN(a)))throw"invalid value.";}return a},_toStr:function(a,b){return a.dataParser.toStr(b,this._field("closestCulture"),a.dataFormatString,this.options.nullString,true)},_funcOptions:function(){return["cellStyleFormatter","rowStyleFormatter","afterCellEdit","afterCellUpdate","beforeCellEdit","beforeCellUpdate","columnDragging","columnDragged","columnDropping","columnDropped","columnResizing","columnResized","columnGrouping","columnGrouped","columnUngrouping","columnUngrouped","currentCellChanging","currentCellChanged","filtering","filtered","filterOperatorsListShowing","groupAggregate","groupText","invalidCellValue","pageIndexChanging","pageIndexChanged","selectionChanged","sorting","sorted","ajaxError","dataLoading","dataLoaded","loading","loaded","rendering","rendered"]},_canInteract:function(){return!this.options.disabled},_canMoveToAnotherCell:function(d,c){var h=d.tagName.toLowerCase(),f,e,b,g;switch(h){case"input":if(a(d).hasClass("wijgridinput")){if(d.type==="text"){f=d.value.length;e=new a.wijmo.wijgrid.domSelection(d).getSelection();b=a.ui.keyCode;g=c===b.UP||c===b.DOWN||c===b.PAGE_DOWN||c===b.PAGE_UP||e.length===0&&(e.start===0&&(c===b.LEFT||c===b.HOME)||e.end>=f&&(c===b.RIGHT||c===b.END));return g}return true}return false;case"textarea":case"select":return false}return true},_getDataToAbsOffset:function(){var c=0,a=0,b=this._headerRows();if(this.options.showRowHeader)c++;if(b)a+=b.length();if(this._filterRow())a++;return{x:c,y:a}},_getDataCellsRange:function(){var d=0,e=0,b=this._field("visibleLeaves").length-1,c=this.dataTable.length-1;if(this.options.showRowHeader)b--;if(b<0||c<0)d=e=b=c=-1;return new a.wijmo.wijgrid.cellInfoRange(new a.wijmo.wijgrid.cellInfo(d,e),new a.wijmo.wijgrid.cellInfo(b,c))},_getDOMDataCell:function(a){if(a){a=a._clone()._dataToAbs(this._getDataToAbsOffset());if(a._isValid())return this._view().getCell(a.cellIndex(),a.rowIndex())}return null},_getFirstDataRowCell:function(d){for(var c,e=a.wijmo.wijgrid.rowType,b=0;c=this.dataTable[b];b++)if(c.rowType&e.data)return new a.wijmo.wijgrid.cellInfo(d,b);return a.wijmo.wijgrid.cellInfo.prototype.outsideValue},_getNextCurrencyPos:function(b,f,h,g){var d=f.cellIndex(),c=f.rowIndex(),e;switch(h){case a.ui.keyCode.PAGE_UP:if(this._reverseKey&&c===b.topLeft().rowIndex())c=b.bottomRight().rowIndex();else{c-=this._pageSizeKey;if(c<(e=b.topLeft().rowIndex()))c=e}break;case a.ui.keyCode.PAGE_DOWN:if(this._reverseKey&&c===b.bottomRight().rowIndex())c=b.TopLeft().RowIndex();else{c+=this._pageSizeKey;if(c>(e=b.bottomRight().rowIndex()))c=e}break;case a.ui.keyCode.END:d=this._reverseKey&&d===b.bottomRight().cellIndex()?b.topLeft().cellIndex():b.bottomRight().cellIndex();break;case a.ui.keyCode.HOME:d=this._reverseKey&&d===b.topLeft().cellIndex()?b.bottomRight().cellIndex():b.topLeft().cellIndex();break;case a.ui.keyCode.LEFT:if(d>b.topLeft().cellIndex())d--;else if(this._reverseKey)d=b.bottomRight().cellIndex();break;case a.ui.keyCode.UP:if(c>b.topLeft().rowIndex())c--;else if(this._reverseKey)c=b.bottomRight().rowIndex();break;case a.ui.keyCode.RIGHT:if(d<b.bottomRight().cellIndex())d++;else if(this._reverseKey)d=b.topLeft().cellIndex();break;case a.ui.keyCode.ENTER:case a.ui.keyCode.DOWN:if(c<b.bottomRight().rowIndex())c++;else if(this._reverseKey)c=b.topLeft().rowIndex();break;case a.ui.keyCode.TAB:if(0)if(g){d--;if(d<b.topLeft().cellIndex()){d=b.bottomRight().cellIndex();c--;if(c<b.topLeft().rowIndex())c=b.bottomRight().rowIndex()}}else{d++;if(d>b.bottomRight().cellIndex()){d=b.topLeft().cellIndex();c++;if(c>b.bottomRight().rowIndex())c=b.topLeft().rowIndex()}}}return{cellIndex:d,rowIndex:c}},_getParentSubTable:function(b,g,h){for(var f=a.map(h,function(a){return a.element()}),c=null,d=null,e;b!==null&&c===null;b=b.parentNode){e=b.tagName?b.tagName.toLowerCase():undefined;if(a.inArray(e,g)>=0)d=b;else if(a.inArray(b,f)>=0)c=b}return d&&c?[d,c]:null},_getStaticIndex:function(f){var e=false,d=this.options,b,c;a.each(this._field("leaves"),function(b,a){if(a.rowMerge!=="none"||a.groupInfo&&a.groupInfo.position!=="none"){e=true;return false}});if(e)return-1;if(f){b=d.staticRowIndex;c=this.dataTable.length-1}else{b=d.staticColumnIndex;c=this._field("visibleLeaves").length-(d.showRowHeader?1:0)-1}if(b<-1)b=-1;else if(b>c)b=c;return b},_getRealStaticColumnIndex:function(f){var d,b,c=0,e=this._getStaticIndex(false),a;if(this.options.showRowHeader===true)c++;if(f)return c;a=e+c;if(e>=0){d=this._field("visibleLeaves");b=d.length;for(;a<b;a++)if(d[a].parentIdx===-1)break;if(a>=b)a=b-1}return a},_getRealStaticRowIndex:function(b){var a=this._field("spanTable").length;if(this.options.showFilter)a++;return b?a:this._getStaticIndex(true)+a},_view:function(){return this._field("view")},_originalFooterRowData:function(){var a=this._field("tfoot");return a&&a.length?a[0]:null},_originalHeaderRowData:function(){var a=this._field("thead");return a&&a.length?a[0]:null}})})(jQuery);(function(a){"use strict";a.widget("wijmo.c1basefield",{_data$prefix:"c1basefield",options:{allowMoving:true,allowSizing:true,cellFormatter:undefined,dataKey:undefined,ensurePxWidth:undefined,footerText:undefined,headerText:undefined,visible:true,width:undefined},_create:function(){var a=this.options.owner;this.element.addClass("ui-widget wijmo-c1basefield ui-state-default");this._field("owner",a);delete this.options.owner;this._field("widgetName",this.widgetName);this.options.disabled&&this.disable();a.options.allowColMoving&&a._dragndrop().attach(this)},_init:function(){this.element.wrapInner("<div class='wijmo-wijgrid-innercell'></div>");this._refreshHeaderCell()},destroy:function(){var b=this._owner();b&&b._dragndrop().detach(this);a.wijmo.wijgrid.remove$dataByPrefix(this.element,this._data$prefix);this.element.removeClass("ui-widget wijmo-c1basefield ui-state-default").html(this.element.find(".wijmo-wijgrid-headertext").contents())},_field:function(c,b){return a.wijmo.wijgrid.dataPrefix(this.element[0],this._data$prefix,c,b)},_removeField:function(b){var a=this._data$prefix+b;this.element.removeData(a)},_setOption:function(c,b,f){var h=this["_preset_"+c],e=this.options[c],g,d;if(h!==undefined)b=h.apply(this,[b,e,f]);g=b!==e;a.Widget.prototype._setOption.apply(this,[c,b]);if(g){d=this["_postset_"+c];d!==undefined&&d.apply(this,[b,e,f])}},_postset_allowMoving:function(b,c,a){this._invokeGroupedColumn("allowMoving",b,a)},_preset_clientType:function(){throw"read-only";},_postset_headerText:function(b,c,a){this._refreshHeaderCell();this._invokeGroupedColumn("headerText",b,a)},_postset_visible:function(){this._owner().ensureControl(false)},_postset_width:function(e){var c=this._owner()._view(),b=this.options.visLeavesIdx,d=a(c.getHeaderCell(b)).outerWidth();c.ensureWidth(b,e,d)},_invokeGroupedColumn:function(d,c,a){if(!a&&this.options.groupedIndex!==undefined){var b=this._owner()._field("groupedWidgets")[this.options.groupedIndex];b._setOption(d,c,true)}},_owner:function(){return this._field("owner")},_canSize:function(){return this.options.allowSizing&&this._owner().options.allowColSizing},_canDrag:function(){return this.options.allowMoving===true},_canDropTo:function(b){return a.wijmo.wijgrid.isChildOf(this._owner().options.columns,b,this)?false:true},_refreshHeaderCell:function(){var a=this.element.children(".wijmo-wijgrid-innercell").empty().html(this.options.headerText||"").wrapInner('<span class="wijmo-wijgrid-headertext" />')}})})(jQuery);(function(a){"use strict";a.widget("wijmo.c1field",a.wijmo.c1basefield,{options:{aggregate:"none",allowSort:true,dataType:"string",dataParser:undefined,dataFormatString:undefined,filterOperator:"nofilter",filterValue:undefined,groupInfo:{expandInfo:[],groupSingleRow:true,collapsedImageClass:"ui-icon-triangle-1-e",expandedImageClass:"ui-icon-triangle-1-se",position:"none",outlineMode:"startExpanded",headerText:undefined,footerText:undefined},readOnly:false,rowMerge:"none",showFilter:true,sortDirection:"none",valueRequired:false},_create:function(){a.wijmo.c1basefield.prototype._create.apply(this,arguments);this.element.addClass("ui-widget wijmo-c1field")},destroy:function(){this.element.find("*").unbind("."+this.widgetName);if(this.$filterEditor){this.$filterEditor.closest("td").find("*").unbind("."+this.widgetName);switch(this._getInputEditorType(this.options)){case"date":this.$filterEditor.wijinputdate("destroy");break;case"mask":this.$filterEditor.wijinputmask("destroy");break;case"numberCurrency":case"numberNumber":case"numberPercent":this.$filterEditor.wijinputnumber("destroy")}this.$filterEditor=null}this.element.removeClass("ui-widget wijmo-c1field").find(".wijmo-wijgrid-headertext > span.ui-icon").remove();this._removeDropDownFilterList();a.wijmo.c1basefield.prototype.destroy.apply(this,arguments)},_init:function(){a.wijmo.c1basefield.prototype._init.apply(this,arguments);this.$filterEditor=null;var b=this._owner();this.filterRow=b._filterRow();b.options.showFilter&&this.options.showFilter&&this.options.dataIndex>=0&&this._prepareFilterCell()},_postset_aggregate:function(){this._owner().ensureControl(false)},_postset_allowSort:function(b,c,a){this._refreshHeaderCell();this._invokeGroupedColumn("allowSort",b,a)},_postset_dataType:function(){throw"read-only";},_postset_dataParser:function(){this._owner().ensureControl(false)},_postset_dataFormatString:function(){this._owner().ensureControl(false)},_postset_filterOperator:function(){this._owner().ensureControl(true)},_postset_filterValue:function(){this._owner().ensureControl(true)},_postset_groupInfo:function(){this._owner().ensureControl(true)},_postset_rowMerge:function(){this._owner().ensureControl(false)},_postset_showFilter:function(){this._owner().ensureControl(false)},_postset_sortDirection:function(){this.options.sortOrder=0;this._owner().ensureControl(true)},_postset_width:function(){this._setFilterEditorWidth(1);a.wijmo.c1basefield.prototype._postset_width.apply(this,arguments);this._setFilterEditorWidth(this._getFilterEditorWidth())},_canDropTo:function(b){return a.wijmo.c1basefield.prototype._canDropTo.apply(this,arguments)?this.options.groupedIndex!==undefined&&b instanceof a.wijmo.c1groupedfield?false:true:false},_canSort:function(){var a=this._owner();return a&&a.options.allowSorting&&this.options.allowSort&&this.options.dataIndex>=0},_refreshHeaderCell:function(){if(this._canSort()){var b,c=this.element.children(".wijmo-wijgrid-innercell").empty().html(this.options.headerText||"").wrapInner('<a class="wijmo-wijgrid-headertext" href="#" role="button" />');b=c.children("a").bind("click."+this.widgetName,this,this._onHrefClick);switch(this.options.sortDirection){case"ascending":b.append(a('<span class="ui-icon ui-icon-triangle-1-n">ascending</span>'));break;case"descending":b.append(a('<span class="ui-icon ui-icon-triangle-1-s">descending</span>'))}}else a.wijmo.c1basefield.prototype._refreshHeaderCell.apply(this,arguments)},_prepareFilterCell:function(){var f=this.options.visLeavesIdx,e=null,d=null,b,c,g;if(f>=0){e=this._owner();if(this.filterRow)d=a((new a.wijmo.wijgrid.rowAccessor).getCell(this.filterRow,f));else throw"exception";this.$filterEditor=d.find("input");d.bind(a.support.selectstart?"selectstart":"mousedown",function(a){a.stopPropagation()});b=e._parse(this.options,a.wijmo.wijgrid.filterHelper.getSingleValue(this.options.filterValue));if(b===null)switch(this.options.dataType){case"boolean":b=false;break;case"number":case"currency":case"datetime":b=0;break;default:b=""}c={culture:e.options.culture,disabled:e.options.disabled,decimalPlaces:function(b){var a=/^(n|p|c){1}(\d*)$/.exec(b);if(a)if(a[2])return parseInt(a[2],10);return 2}(this.options.dataFormatString)};switch(g=this._getInputEditorType(this.options)){case"date":this.$filterEditor.wijinputdate(a.extend(c,{date:b}));break;case"mask":this.$filterEditor.wijinputmask({text:b});break;case"numberCurrency":this.$filterEditor.wijinputnumber(a.extend(c,{type:"currency",value:b}));break;case"numberNumber":this.$filterEditor.wijinputnumber(a.extend(c,{value:b}));break;case"numberPercent":this.$filterEditor.wijinputnumber(a.extend(c,{type:"percent",value:b*100}));break;default:throw a.wijmo.wijgrid.stringFormat('Unsupported editor type: "{0}"',g);}d.find(".wijmo-wijgrid-filter-trigger").attr({role:"button","aria-haspopup":"true"}).bind("mouseenter."+this.widgetName,function(){a(this).addClass("ui-state-hover")}).bind("mouseleave."+this.widgetName,function(){a(this).removeClass("ui-state-hover ui-state-active")}).bind("mouseup."+this.widgetName,this,function(){a(this).removeClass("ui-state-active")}).bind("mousedown."+this.widgetName,{column:this},this._onFilterBtnClick).bind("click."+this.widgetName,function(a){a.preventDefault()})}},_onFilterBtnClick:function(m){var b=m.data.column,j=8,c,k,g,d,f,i,e,h,l;if(b.options.disabled)return false;if(b.$dropDownFilterList){b._removeDropDownFilterList();return false}c=b._owner();k=a.wijmo.wijgrid.filterHelper.getSingleOperatorName(b.options.filterOperator).toLowerCase();g=c.filterOperatorsCache.getByDataType(b.options.dataType);c.filterOperatorsCache.sort(g,c.options.filterOperatorsSortMode);d=a.extend(true,{},{operators:g,column:b.options});c._trigger("filterOperatorsListShowing",null,d);f=[];if(d.operators)for(i in d.operators)if(d.operators.hasOwnProperty(i)){e=d.operators[i];f.push({label:e.displayName||e.name,value:e.name,selected:e.name.toLowerCase()===k})}b.$dropDownFilterList=a('<div class="wijmo-wijgrid-filterlist"></div').appendTo(document.body).wijlist({autoSize:true,maxItemsCount:j,selected:function(f,e){var a,d;switch(d=b._getInputEditorType(b.options)){case"date":a=b.$filterEditor.wijinputdate("option","date");break;case"mask":a=b.$filterEditor.wijinputmask("option","text");break;case"numberCurrency":case"numberNumber":case"numberPercent":a=b.$filterEditor.wijinputnumber("option","value");if(d==="numberPercent")a/=100}b._removeDropDownFilterList();c._handleFilter(b,e.item.value,a)}});b.$dropDownFilterList.wijlist("setItems",f).wijlist("renderList");h=b.$dropDownFilterList.width()|150;b.$dropDownFilterList.width(f.length>j?h+20:h).wijlist("refreshSuperPanel").position({of:a(this),my:"left top",at:"left bottom"});b.$dropDownFilterList.$button=a(this);l=b.$dropDownFilterList.eventGuid=+new Date;a(document).bind("mousedown."+b.widgetName+"."+l,{column:b},b._onDocMouseDown)},_onDocMouseDown:function(c){var b=a(c.target),e=b.parents(".wijmo-wijgrid-filterlist:first"),d=b.is(".wijmo-wijgrid-filter-trigger")?b:b.parents(".wijmo-wijgrid-filter-trigger:first");!(d.length&&d[0]===c.data.column.$dropDownFilterList.$button[0]||e.length&&e[0]===c.data.column.$dropDownFilterList[0])&&c.data.column._removeDropDownFilterList()},_onHrefClick:function(a){if(a.data.options.disabled)return false;a.data.options.allowSort&&a.data._owner()._handleSort(a.data.options,a.ctrlKey);return false},_removeDropDownFilterList:function(){if(this.$dropDownFilterList){var b=this.$dropDownFilterList.eventGuid;this.$dropDownFilterList.remove();this.$dropDownFilterList=null;a(document).unbind("mousedown."+this.widgetName+"."+b,this._onDocMouseDown)}},_getFilterEditorWidth:function(){if(this.$filterEditor){var b=this.$filterEditor.closest(".wijmo-wijgrid-filter"),a=b.width()-b.find(".wijmo-wijgrid-filter-trigger").width();if(!a||a<0)a=0;return a}return undefined},_setFilterEditorWidth:function(a){if(this.$filterEditor){a-=this.$filterEditor.leftBorderWidth()+this.$filterEditor.rightBorderWidth();if(a<0)a=0;switch(this._getInputEditorType(this.options)){case"date":this.$filterEditor.wijinputdate("widget").width(a);break;case"mask":this.$filterEditor.wijinputmask("widget").width(a);break;case"numberCurrency":case"numberNumber":case"numberPercent":this.$filterEditor.wijinputnumber("widget").width(a)}this.$filterEditor.setOutWidth(a)}},_getInputEditorType:function(a){switch(a.dataType){case"number":return a.dataFormatString&&a.dataFormatString.indexOf("p")===0?"numberPercent":"numberNumber";case"currency":return"numberCurrency";case"datetime":return"date";default:return"mask"}}})})(jQuery);(function(a){"use strict";a.widget("wijmo.c1groupedfield",{_data$prefix:"c1groupedfield",options:{allowMoving:true,allowSort:true,headerText:undefined,sortDirection:"none"},_create:function(){var a=this.options.owner;this.element.addClass("wijmo-wijgrid-group-button ui-state-default ui-corner-all");this._field("owner",a);delete this.options.owner;this.options.disabled&&this.disable();a.options.allowColMoving&&a._dragndrop().attach(this)},_init:function(){this._refreshHeaderCell()},destroy:function(){this.element.find("*").unbind("."+this.widgetName);var b=this._owner();b&&b._dragndrop().detach(this);a.wijmo.wijgrid.remove$dataByPrefix(this.element,this._data$prefix)},_field:function(c,b){return a.wijmo.wijgrid.dataPrefix(this.element[0],this._data$prefix,c,b)},_removeField:function(b){var a=this._data$prefix+b;this.element.removeData(a)},_setOption:function(c,b,f){var h=this["_preset_"+c],e=this.options[c],g,d;if(h!==undefined)b=h.apply(this,[b,e,f]);g=b!==e;a.Widget.prototype._setOption.apply(this,[c,b]);if(g){d=this["_postset_"+c];d!==undefined&&d.apply(this,[b,e,f])}},_postset_headerText:function(){this._refreshHeaderCell()},_postset_allowSort:function(){this._refreshHeaderCell()},_owner:function(){return this._field("owner")},_canSize:function(){return this.options.allowSizing&&this._owner().options.allowColSizing},_canDrag:function(){return this.options.allowMoving===true},_canDropTo:function(b){return!(b instanceof a.wijmo.c1groupedfield)?false:a.wijmo.wijgrid.isChildOf(this._owner().options.columns,b,this)?false:true},_canSort:function(){var a=this._owner();return a&&a.options.allowSorting&&this.options.allowSort&&this.options.dataIndex>=0},_refreshHeaderCell:function(){var b=a('<span class="wijmo-wijgrid-group-button-close ui-state-default ui-corner-all"><span class="ui-icon ui-icon-close"></span></span>').bind("click."+this.widgetName,this,this._onCloseClick);this.element.html(this.options.headerText||"").prepend(b).bind("click."+this.widgetName,this,this._onHrefClick);if(this._canSort())switch(this.options.sortDirection){case"ascending":this.element.append(a('<span class="wijmo-wijgrid-group-button-sort ui-icon ui-icon-triangle-1-n"></span>'));break;case"descending":this.element.append(a('<span class="wijmo-wijgrid-group-button-sort ui-icon ui-icon-triangle-1-s"></span>'))}},_onCloseClick:function(a){a.data._owner()._handleUngroup(a.data.options.travIdx);return false},_onHrefClick:function(e){var d=e.data._owner(),c=e.data.options,b;if(!c.disabled&&c.allowSort){b=a.wijmo.wijgrid.search(d.columns(),function(a){return a.options.travIdx===c.travIdx});b=!b.found?a.wijmo.wijgrid.getColumnByTravIdx(d.options.columns,c.travIdx).found:b.found.options;b&&d._handleSort(b,e.ctrlKey)}return false}})})(jQuery);(function(a){"use strict";a.widget("wijmo.c1band",a.wijmo.c1basefield,{options:{columns:[]},_create:function(){a.wijmo.c1basefield.prototype._create.apply(this,arguments);this.element.addClass("ui-widget wijmo-c1band")},_canDropTo:function(b){return a.wijmo.c1basefield.prototype._canDropTo.apply(this,arguments)?!(b instanceof a.wijmo.c1groupedfield):false}})})(jQuery);(function(a){"use strict";a.extend(a.wijmo.wijgrid,{bandProcessor:function(){var c,h,b,g,e,f,d;this.generateSpanTable=function(j,i){c=h=f=e=0;b=[];g=[];d=[];var a=this._generateSpanTable(j,i,true);return a};this._generateSpanTable=function(i,e,j){var d,f;c=this._getVisibleHeight(i,j);e=e||[];a.wijmo.wijgrid.traverse(i,function(a){a.isLeaf&&e.push(a);g.push(a)});h=e.length;for(d=0;d<c;d++){b[d]=[];for(f=0;f<h;f++)b[d][f]={column:null,colSpan:0,rowSpan:0}}this._setTableValues(i,0,0);return b};this._getVisibleHeight=function(b,g){var d,e,h,f,c=0;if(a.isArray(b))for(d=0,e=b.length;d<e;d++){f=this._getVisibleHeight(b[d],g);c=Math.max(c,f)}else{h=b.visible===undefined?true:b.visible;b.parentVis=h&&g;if(b.isBand){for(d=0,e=b.columns.length;d<e;d++){f=this._getVisibleHeight(b.columns[d],b.parentVis);c=Math.max(c,f)}if(!b.parentVis)return c;b.isLeaf=c===0;c++}else{b.isLeaf=true;if(b.parentVis)c=1}}return c};this._getVisibleParent=function(a){while(a){a=g[a.parentIdx];if(a&&(a.parentVis||a.parentVis===undefined))return a}return null};this._setTableValues=function(g,h,n){var i,l,m,j,o,k;if(a.isArray(g))for(i=0,l=g.length;i<l;i++)this._setTableValues(g[i],h,n);else{if(g.travIdx===undefined)throw"undefined travIdx";m=n+e;if(g.parentVis){j=m+f;b[h][j].column=g;d[g.travIdx]=j}if(g.isBand)for(i=0,l=g.columns.length;i<l;i++)this._setTableValues(g.columns[i],h+1,n);if(g.parentVis)if(e-m===0){b[h][d[g.travIdx]].rowSpan=c-h;e++}else b[h][d[g.travIdx]].colSpan=e-m;else if(!g.isBand&&c>0){k=this._getVisibleParent(g);o=k?k.isLeaf:false;if(o)f++;if(h>=c)h=c-1;j=n+e+f;b[h][j].column=g;if(!o){k&&d[k.travIdx]===j&&this._shiftTableElements(j,h);f++}}}};this._shiftTableElements=function(c,e){for(var a=0;a<e;a++){b[a][c+1]=b[a][c];b[a][c]={column:null,colSpan:0,rowSpan:0};if(b[a][c+1].column)d[b[a][c+1].column.travIdx]++}}},getAllLeaves:function(b){var a=[];this._getAllLeaves(b,a);return a},_getAllLeaves:function(d,e){var c,f,a,b;if(d)for(c=0,f=d.length;c<f;c++){a=d[c];if(a.options)a=a.options;b=a.columns;if(b&&b.length)this._getAllLeaves(b,e);else e.push(a)}},getColumnByTravIdx:function(b,d){var c,f,a,e=null;if(b&&d>=0)for(c=0,f=b.length;c<f&&!e;c++){a=b[c];if(a.options)a=a.options;if(a.travIdx===d)return{found:a,at:b};if(a.columns)e=this.getColumnByTravIdx(a.columns,d)}return e},isChildOf:function(d,a,b){if(a.options)a=a.options;if(b.options)b=b.options;if(b.isBand&&a.parentIdx>=0){if(a.parentIdx===b.travIdx)return true;if(a.parentIdx>b.travIdx)for(var c=this.flatten(d);;){a=c[a.parentIdx];if(a.travIdx===b.travIdx)return true;if(a.parentIdx===-1)break}}return false},getLeaves:function(b){var a=[];this._getLeaves(b,a);return a},_getLeaves:function(c,d){var b,e,a;if(c)for(b=0,e=c.length;b<e;b++){a=c[b];a.isLeaf&&d.push(a);a.columns&&this._getLeaves(a.columns,d)}},setTraverseIndex:function(a){return this._setTraverseIndex(a,0,-1)},_setTraverseIndex:function(d,b,f){var c,e,a;if(d)for(c=0,e=d.length;c<e;c++){a=d[c];if(a.options)a=a.options;a.linearIdx=c;a.travIdx=b++;a.parentIdx=f;if(a.columns)b=this._setTraverseIndex(a.columns,b,b-1)}return b},flatten:function(b){var a=[];this.traverse(b,function(b){a.push(b)});return a},traverse:function(e,d){var c,f,b;if(e&&a.isFunction(d))for(c=0,f=e.length;c<f;c++){b=e[c];if(b.options)b=b.options;d(b);b.columns&&this.traverse(b.columns,d)}},getAriaHeaders:function(e,h){var b,g,c,d,f=[];for(b=0,g=e.length;b<g;b++){c=e[b];d="";do d+=escape(c.headerText)+" ";while(c=h[c.parentIdx]);f[b]=a.trim(d)}return f}})})(jQuery);(function(a){"use strict";a.extend(a.wijmo.wijgrid,{getTableSection:function(a,b){if(a&&!a.nodeType)a=a[0];if(a)switch(b){case 1:return a.tHead;case 2:if(a.tBodies)return a.tBodies[0]||null;break;case 3:return a.tFoot;default:return a}return null},getTableSectionLength:function(a,b){if(a&&!a.nodeType)a=a[0];return a&&(b=this.getTableSection(a,b))?b.rows.length:0},getTableSectionRow:function(a,b,c){if(a&&!a.nodeType)a=a[0];return a&&(b=this.getTableSection(a,b))?b.rows[c]||null:null},readTableSection:function(c,f,h){var e,k,b,i,g,d,j=[],l=function(a){a=a.toLowerCase();return a==="rowspan"||a==="colspan"};if(c&&!c.nodeType)c=c[0];if(c&&(f=this.getTableSection(c,f)))for(e=0,k=f.rows.length;e<k;e++){g=f.rows[e];d=[];if(h){d.rowAttributes=null;d.cellsAttributes=[]}for(b=0,i=g.cells.length;b<i;b++){d[b]=g.cells[b].innerHTML;if(h)d.cellsAttributes[b]=a.wijmo.wijgrid.getAttributes(g.cells[b],l)}j[e]=d}return j}})})(jQuery);(function(a){"use strict";a.extend(a.wijmo.wijgrid,{dataMode:{dom:1,statical:2,remoteStatical:4,dynamical:8},dataStore:function(c){var b=null,n=this,g=false,e=null,d=null,h,m=false,l=false;this.dataMode=function(){return f()};this.dataSource=function(){return b};this.getFieldNames=function(){if(!g)throw"data is not loaded yet";var e=[],d,c;if(b.items&&b.items.length)c=b.items[0];else if(f()===a.wijmo.wijgrid.dataMode.dom&&b.header&&b.header.length)c=b.header[0];if(c)for(d in c)c.hasOwnProperty(d)&&e.push(!isNaN(d)?parseInt(d,10):d);return e};this.getDataSlice=function(){if(!g)throw"data is not loaded yet";if(!m){m=true;r(e)}if(!l){l=true;if(f()!==a.wijmo.wijgrid.dataMode.dynamical)h=s(e,b.emptyData);else h={data:e,totalRows:b.data.totalRows,totals:b.data.totals||{},emptyData:b.emptyData}}return h};this.load=function(e){if(!b)b=a.proxy(p,this)(c);if(f()===a.wijmo.wijgrid.dataMode.dynamical){e.data=q();if(b.proxy)b.proxy.options.data=a.extend(b.proxy.options.data,e.data);d=null;b.load(e,true)}else if(!g){d=null;b.load(e)}else{i(b,e);j(b,e)}};this.isLoaded=function(){return g};this.updateValue=function(a,c,b){if(!g)throw"data is not loaded yet";this.dataSource().items[a][c]=b};function p(e){var b=null,c=e.options.data,d;if(c===null)b=new wijdatasource({data:e.element,reader:new k(new o),loading:a.proxy(i,this),loaded:a.proxy(j,this)});else if(a.isArray(c))b=new wijdatasource({data:c,reader:new k(new wijarrayreader),loading:a.proxy(i,this),loaded:a.proxy(j,this)});else{b=new wijdatasource(c);b.reader=new k(c.reader);b.loading=a.proxy(function(d,b){a.isFunction(c.loading)&&c.loading(d,b);a.proxy(i,this)(d,b)},this);b.loaded=a.proxy(function(d,b){a.isFunction(c.loaded)&&c.loaded(d,b);a.proxy(j,this)(d,b)},this);if(b.proxy&&b.proxy.options){d=b.proxy.options.error;b.proxy.options.error=function(){t.apply(this,arguments);a.isFunction(d)&&d.apply(this,arguments)}}}return b}function i(d,b){if(n.dataMode()===a.wijmo.wijgrid.dataMode.dynamical||c.options.alwaysParseData)m=false;l=false;h=null;e=null;c._dataLoading(b)}function j(l,o){g=true;var h,m,b,i,j,k,p=f(),n=!d&&c.options.readAttributesFromData;if(!d)d=[];e=[];for(h=0,m=l.items.length;h<m;h++){b=l.items[h];if(n)if(p===a.wijmo.wijgrid.dataMode.dom){d.push({rowAttributes:b.rowAttributes,cellsAttributes:b.cellsAttributes});delete b.rowAttributes;delete b.cellsAttributes}else{k={};for(i in b)if(b.hasOwnProperty(i)&&a.isArray(j=b[i])){k[i]=j[1];b[i]=j[0]}d.push({rowAttributes:{},cellsAttributes:k})}e.push({values:b,originalRowIndex:h,attributes:d[h]})}c._dataLoaded(o)}function t(){c._ajaxError.apply(c,arguments)}function f(){return!b.data||b.data.jquery?a.wijmo.wijgrid.dataMode.dom:b.dynamic===true?a.wijmo.wijgrid.dataMode.dynamical:a.wijmo.wijgrid.dataMode.statical}function r(d){if(d&&d.length){var g=[],j,f,k,h,e,i,b;a.wijmo.wijgrid.traverse(c.options.columns,function(b){a.wijmo.wijgrid.validDataKey(b.dataKey)&&g.push(b)});j=Math.min(g.length,n.getFieldNames().length);for(f=0,k=d.length;f<k;f++){h=d[f];for(e=0;e<j;e++){i=null;b=g[e];if(b&&b.dataParser){i=c._parse(b,h.values[b.dataKey]);h.values[b.dataKey]=i}}}}}function s(b,h){if(b&&b.length){var d=c._prepareFilterRequest(true),f=c._preparePageRequest(true),g=c._prepareSortRequest(true),e=c._prepareTotalsRequest(true),i=(new a.wijmo.wijgrid.dataHelper).getDataSlice(c,b,d,f,g,e);return i}return{data:[],totalRows:0,totals:{},emptyData:h}}function q(){return{filtering:c._prepareFilterRequest(false),paging:c._preparePageRequest(false),sorting:c._prepareSortRequest(false),totals:c._prepareTotalsRequest(false)}}function k(b){this.read=function(c){c.items=null;b&&a.isFunction(b.read)&&b.read(c);if(!a.isArray(c.items)){c.items=[];if(a.isArray(c.data))c.items=c.data;else if(c.data&&a.isArray(c.data.rows))c.items=c.data.rows}if(f()===a.wijmo.wijgrid.dataMode.dynamical)if(!c.data||isNaN(c.data.totalRows))throw"totalRows value is missing";if(!c.items||!a.isArray(c.items))c.items=[]}}function o(){this.read=function(b){b.items=[];if(b&&b.data&&b.data.length){if(a.wijmo.wijgrid.getTableSectionLength(b.data,2)===1&&a(a.wijmo.wijgrid.getTableSectionRow(b.data,2,0)).hasClass("wijmo-wijgrid-emptydatarow"))b.emptyData=a.wijmo.wijgrid.readTableSection(b.data,2);else b.items=a.wijmo.wijgrid.readTableSection(b.data,2,c.options.readAttributesFromData);b.header=a.wijmo.wijgrid.readTableSection(b.data,1);b.data=null}else throw"invalid data source";}}},dataHelper:function(){this.getDataSlice=function(m,e,p,f,r,q){e=b(e,p,m);a.proxy(c,this)(e,r);var l=e.length,g,o,j,h,k,s,i,n={};n=d(e,q,m);if(f){i=Math.ceil(l/f.pageSize)||1;if(f.pageIndex>=i)f.pageIndex=i-1;g=Math.min(e.length-1,f.pageIndex*f.pageSize);if(g<0)g=0;o=Math.min(e.length,g+f.pageSize);j=[];for(h=g,s=0,k=0;h<o;h++,k++)j[k]=e[h];e=j}return{data:e,totalRows:l,totals:n}};function d(i,f){var b,c,e,j,g,d=[],h={};for(b=0,c=f.length;b<c;b++)d.push(new a.wijmo.wijgrid.tally);for(b=0,c=i.length;b<c;b++){g=i[b].values;for(e=0,j=d.length;e<j;e++)d[e].add(g[f[e].column.dataKey])}for(b=0,c=d.length;b<c;b++)h[f[b].column.dataKey]=d[b].getValueString(f[b].column);return h}function b(e,c,l){if(!e||!e.length||!c||!c.length)return e;a.each(c,function(c,b){if(!a.isArray(b.filterOperator))b.filterOperator=[b.filterOperator];if(!a.isArray(b.filterValue))b.filterValue=[b.filterValue];a.each(b.filterOperator,function(c,a){if(typeof a==="string")b.filterOperator[c]=a={name:a,condition:"or"};b.filterOperator[c].name=l.filterOperatorsCache.getByName(a.name)});a.each(b.filterValue,function(d,c){if(!a.isArray(c))b.filterValue[d]=l._parse(b.column,c);else a.each(c,function(d,a){c[d]=l._parse(b.column,a)})})});var h,i,b,o,m,j,p=[],n,g,q=c.length,d,f,k;for(h=0,o=e.length;h<o;h++){m=e[h];n=true;for(i=0;i<q;i++){d=c[i];j=m.values[d.column.dataKey];g=false;for(b=0;b<d.filterOperator.length;b++){f=d.filterOperator[b];k=d.filterValue[b];if(b>0&&f.condition==="and")g&=f.name.operator(j,k);else g|=f.name.operator(j,k)}n&=g}n&&p.push(m)}return p}function c(i,e){if(e.length){var b=[],d,h,c,a,f,g;b.push("var context = this;");b.push("this.sort = function(a, b)\n{\n");for(d=0,h=e.length;d<h;d++){c="arg"+d;a=e[d];f=typeof a.dataKey==="string"?'"'+a.dataKey+'"':a.dataKey;if(a.sortDirection==="ascending"||a.sortDirection==="descending")if(a.sortDirection==="ascending")b.push("var ",c," = context._sortAsc","(a.values[",f,"], b.values[",f,"]);\n");else b.push("var ",c," = context._sortDesc","(a.values[",f,"], b.values[",f,"]);\n");else b.push("var ",c," = context._sortDigitAsc","(a.originalRowIndex, b.originalRowIndex);\n");b.push("if (",c," === 0)\n");b.push("{\n")}g=e.length-1;if(g>=0){c="arg"+g;a=e[g];f=typeof a.dataKey==="string"?'"'+a.dataKey+'"':a.dataKey;if(a.sortDirection==="ascending"||a.sortDirection==="descending")if(a.sortDirection==="ascending")b.push("var ",c," = context._sortDigitAsc","(a.originalRowIndex, b.originalRowIndex);\n");else b.push("var ",c," = context._sortDigitDesc","(a.originalRowIndex, b.originalRowIndex);\n")}for(d=e.length-1;d>=0;d--){b.push("}\n");c="arg"+d;b.push("return ",c,";\n")}b.push("}");eval(b.join(""));i.sort(this.sort)}}this._sortAsc=function(a,b){if(a instanceof Date)a=a.getTime();if(b instanceof Date)b=b.getTime();return a===b?0:a===null?-1:b===null?1:a<b?-1:1};this._sortDesc=function(a,b){if(a instanceof Date)a=a.getTime();if(b instanceof Date)b=b.getTime();return a===b?0:a===null?1:b===null?-1:a<b?1:-1};this._sortDigitAsc=function(a,b){return a-b};this._sortDigitDesc=function(a,b){return b-a}}})})(jQuery);(function(a){"use strict";a.extend(a.wijmo.wijgrid,{groupRange:function(f,h,i,g,e){this.value=-1;this.isExpanded=false;this.cr=new a.wijmo.wijgrid.cellRange(-1,-1);this.sum=-1;this.position="none";this.hasHeaderOrFooter=true;if(f!==undefined)this.isExpanded=f;if(h!==undefined)this.cr=h;if(i!==undefined)this.sum=i;if(g!==undefined)this.position=g;if(e!==undefined)this.hasHeaderOrFooter=e;this.isSubRange=function(a){return this.cr.r1>=a.cr.r1&&this.cr.r2<=a.cr.r2};this.toString=function(){return this.cr.r1+"-"+this.cr.r2};this._getHeaderImageClass=function(c){var b=this.owner;return b?c?b.expandedImageClass||a.wijmo.c1field.prototype.options.groupInfo.expandedImageClass:b.collapsedImageClass||a.wijmo.c1field.prototype.options.groupInfo.collapsedImageClass:null};this.collapse=function(){var b,g,e,c,d,f;if((b=this.owner)&&(g=b.owner)&&(e=g.owner)){c=new a.wijmo.wijgrid.groupHelper;d=e._field("leaves");if(c.isParentExpanded(d,this.cr,b.level))if(b.position!=="footer"&&b.outlineMode!=="none"){f=c.getGroupedColumnsCount(d);j(c,e._rows(),d,this,f)}}};this.expand=function(i){var e,h,f,b,c,g;if((e=this.owner)&&(h=e.owner)&&(f=h.owner)){b=new a.wijmo.wijgrid.groupHelper;c=f._field("leaves");if(b.isParentExpanded(c,this.cr,e.level)){g=b.getGroupedColumnsCount(c);d(b,f._rows(),c,this,g,i,true)}}};function j(m,e,o,d,l){var j=d.owner,i=d.cr.r1,n=d.cr.r2,p,a,k,h,f,g;switch(j.position){case"header":case"headerAndFooter":b(e.item(d.cr.r1),undefined,false);i++}for(a=i;a<=n;a++)b(e.item(a),false);d.isExpanded=false;c(e,d);for(a=j.level+1;a<=l;a++){h=m.getChildGroupRanges(o,d.cr,a-1);for(g=0,k=h.length;g<k;g++){f=h[g];f.isExpanded=false;switch(f.owner.position){case"header":case"headerAndFooter":b(e.item(f.cr.r1),undefined,false)}c(e,f)}}}function d(o,e,p,g,n,k,l){var r=g.owner,h=g.cr.r1,j=g.cr.r2,s,a,m,f,i,q;switch(r.position){case"header":b(e.item(h),true,l||k);h++;break;case"footer":b(e.item(j),true);j--;break;case"headerAndFooter":b(e.item(h),true,l||k);l&&b(e.item(j),true);h++;j--}if(l){g.isExpanded=true;c(e,g)}else return;if(g.owner.level===n)for(a=h;a<=j;a++)b(e.item(a),true);else{f=o.getChildGroupRanges(p,g.cr,g.owner.level);if(f.length&&h!==f[0].cr.r1)for(a=h;a<f[0].cr.r1;a++)b(e.item(a),true);if(k)for(a=0,m=f.length;a<m;a++){i=f[a];d(o,e,p,i,n,k,true)}else for(a=0,m=f.length;a<m;a++){i=f[a];q=i.owner.position==="footer"||i.owner.outlineMode==="none"?true:false;d(o,e,p,i,n,false,q)}}}function b(a,b,c){if(a){if(a[0]){if(b!==undefined){a[0].style.display=b?"":"none";a[0]["aria-hidden"]=b?"false":"true"}if(c!==undefined)a[0]["aria-expanded"]=c?"true":false}if(a[1]){if(b!==undefined){a[1].style.display=b?"":"none";a[1]["aria-hidden"]=b?"false":"true"}if(c!==undefined)a[1]["aria-expanded"]=c?"true":false}}}function c(e,b){if(b.owner.position!=="footer"){var c=null,d=e.item(b.cr.r1);if(d)if(d[0])c=a(d[0]).find("div.wijmo-wijgrid-grouptogglebtn:first-child");if(c&&c.length){c.toggleClass(b._getHeaderImageClass(!b.isExpanded),false);c.toggleClass(b._getHeaderImageClass(b.isExpanded),true)}}}},grouper:function(){this.group=function(i,k,e){this._grid=i;this._data=k;this._leaves=e;this._groupRowIdx=0;this._groupHelper=new a.wijmo.wijgrid.groupHelper;var h=1,c,f,b,d=[],g=false,j=0;for(c=0,f=e.length;c<f;c++){b=e[c];if(b.groupInfo){delete b.groupInfo.level;delete b.groupInfo.expandInfo}if(b.groupInfo&&b.groupInfo.position&&b.groupInfo.position!=="none"&&b.dataIndex>=0){if(b.groupedIndex===undefined)g=true}else if(b.groupedIndex!==undefined)delete b.groupedIndex}if(g)for(c=0,f=e.length;c<f;c++){b=e[c];if(b.groupInfo&&b.groupInfo.position&&b.groupInfo.position!=="none"&&b.dataIndex>=0){b.groupedIndex=j++;d.push(b)}}else{d=a.map(e,function(a){return a.groupedIndex!==undefined?a:null});d.sort(function(a,b){return a.groupedIndex-b.groupedIndex});a.each(d,function(a,b){b.groupedIndex=a})}i._field("groupedColumns",d);for(c=0,f=d.length;c<f;c++){b=d[c];this._groupRowIdx=0;if(b.groupInfo&&b.groupInfo.position&&b.groupInfo.position!=="none"&&b.dataIndex>=0){b.groupInfo.level=h;b.groupInfo.expandInfo=[];this._processRowGroup(b,h++)}}delete this._grid;delete this._data;delete this._leaves};this._processRowGroup=function(j,c){var k,b,i,o,m,d,h,e,g,f,n=0,l=true;a.each(this._leaves,function(b,a){if(a.parentVis){n=b;return false}});for(k=0;k<this._data.length;k++){if(!(this._data[k].rowType&a.wijmo.wijgrid.rowType.data))continue;b=this._getGroupCellRange(k,j,c);i=true;o=j.groupInfo.outlineMode==="startCollapsed";if(o||this._groupHelper.isParentCollapsed(this._leaves,b,c)){if(j.groupInfo.groupSingleRow===false&&b.r1===b.r2)continue;i=false}if(c&&this._grid.options.groupIndent)for(m=b.r1;m<=b.r2;m++)this._addIndent(this._data[m][n],c);l=!(j.groupInfo.groupSingleRow===false&&b.r1===b.r2);switch(j.groupInfo.position){case"header":d=this._addGroupRange(j.groupInfo,b,i,l);for(f=b.r1;f<=b.r2;f++){this._data[f].__attr["aria-level"]=c+1;if(!i){this._data[f].__style.display="none";this._data[f].__attr["aria-hidden"]=true}}if(!l)break;this._updateByGroupRange(d,c);h=this._groupHelper.isParentCollapsed(this._leaves,d.cr,c);e=this._buildGroupRow(d,b,true,h);this._data.splice(b.r1,0,e);e.__attr["arial-level"]=c;e.__attr["aria-expanded"]=i;if(h){e.__style.display="none";e.__attr["aria-hidden"]=true}k=b.r2+1;break;case"footer":d=this._addGroupRange(j.groupInfo,b,true,l);if(!l)break;this._updateByGroupRange(d,c);g=this._buildGroupRow(d,b,false,false);g.__attr["aria-level"]=c;this._data.splice(b.r2+1,0,g);k=b.r2+1;h=this._groupHelper.isParentCollapsed(this._leaves,d.cr,c);if(h){g.__style.display="none";g.__attr["aria-hidden"]=true}break;case"headerAndFooter":d=this._addGroupRange(j.groupInfo,b,i,l);for(f=b.r1;f<=b.r2;f++){this._data[f].__attr["aria-level"]=c+1;if(!i){this._data[f].__style.display="none";this._data[f].__attr["aria-hidden"]=true}}if(!l)break;this._updateByGroupRange(d,c);h=this._groupHelper.isParentCollapsed(this._leaves,d.cr,c);e=this._buildGroupRow(d,b,true,h);g=this._buildGroupRow(d,b,false,false);this._data.splice(b.r2+1,0,g);g.__attr["aria-level"]=c;if(h||!i){g.__style.display="none";g.__attr["aria-hidden"]=true}this._data.splice(b.r1,0,e);e.__attr["aria-level"]=c;e.__attr["aria-expanded"]=i;if(h){e.__style.display="none";e.__attr["aria-hidden"]=true}k=b.r2+2;break;default:throw a.wijmo.wijgrid.stringFormat('Unknown Position value: "{0}"',j.groupInfo.position);}this._groupRowIdx++}};this._buildGroupRow=function(n,l,f){var e=n.owner,c=e.owner,r=c.owner,h=[],j="",k="",d,g,b,p,q,i,o,m;h.__style={};h.__attr={};h.__attr.id=(f?"GH":"GF")+this._groupRowIdx+"-"+e.level;h.rowType=f?a.wijmo.wijgrid.rowType.groupHeader:a.wijmo.wijgrid.rowType.groupFooter;if(c.dataIndex>=0&&(d=this._data[l.r1][c.dataIndex].value)!==null)j=r._toStr(c,d);this._grid.options.showRowHeader&&h.push({html:"&nbsp;"});g={html:"",__attr:{},__style:{}};if(f&&e.outlineMode!=="none")if(n.isExpanded)g.html='<div class="ui-icon '+n._getHeaderImageClass(true)+' wijmo-wijgrid-grouptogglebtn">&nbsp;</div>';else g.html='<div class="ui-icon '+n._getHeaderImageClass(false)+' wijmo-wijgrid-grouptogglebtn">&nbsp;</div>';h.push(g);if(c.aggregate&&c.aggregate!=="none")k=this._getAggregate(l,c,c,f,j);b=f?e.headerText:e.footerText;if(b==="custom"){p={data:this._data,column:c,groupByColumn:e.owner,groupText:j,text:"",groupingStart:l.r1,groupingEnd:l.r2,isGroupHeader:f,aggregate:k};if(this._grid._trigger("groupText",null,p))b=p.text}else{if(b===undefined||b===null){if(f)b="{1}: {0}";if(k||k===0)b=b?b+" {2}":"{2}"}b=a.wijmo.wijgrid.stringFormat(b,j,c&&c.headerText?c.headerText:"",k.toString())}if(!b)b="&nbsp;";g.html+="<span>"+b+"</span>";this._addIndent(g,e.level-1);q=1;i=this._grid.options.showRowHeader?1:0;o=true;for(;i<this._leaves.length;i++){d=this._leaves[i];if(d.parentVis){if(o){o=false;continue}if(d.dynamic!==true&&d.aggregate&&d.aggregate!=="none")break;q++}}for(;i<this._leaves.length;i++){d=this._leaves[i];if(d.parentVis){m=this._getAggregate(l,d,e.owner,f,j);if(!m&&m!==0)m="&nbsp;";h.push({html:m.toString(),__attr:{groupInfo:{leafIndex:d.leavesIdx,purpose:a.wijmo.wijgrid.groupRowCellPurpose.aggregateCell}}})}}g.__attr.colSpan=q;g.__attr.groupInfo={leafIndex:c.leavesIdx,purpose:a.wijmo.wijgrid.groupRowCellPurpose.groupCell};return h};this._getAggregate=function(d,b,h,i,j){var c="",g,f,e;if(!b.aggregate||b.aggregate==="none")return c;if(b.aggregate==="custom"){g={data:this._data,column:b,groupByColumn:h,groupText:j,text:"",groupingStart:d.r1,groupingEnd:d.r2,isGroupHeader:i};if(this._grid._trigger("groupAggregate",null,g))c=g.text}else{f=new a.wijmo.wijgrid.tally;for(e=d.r1;e<=d.r2;e++)f.add(this._data[e][b.dataIndex].value);c=f.getValueString(b)}return c};this._getGroupCellRange=function(c,d,h){var i=d.leavesIdx,b=new a.wijmo.wijgrid.cellRange(c,i),e=this._groupHelper.getParentGroupRange(this._leaves,b,h),g,f;if(this._data[c].rowType&a.wijmo.wijgrid.rowType.data){g=this._data[c][d.dataIndex].value;for(b.r2=c,f=this._data.length-1;b.r2<f;b.r2++){if(!(this._data[b.r2+1].rowType&a.wijmo.wijgrid.rowType.data)||e&&b.r2+1>e.r2)break;if(this._data[b.r2+1][d.dataIndex].value!==g)break}}return b};this._addGroupRange=function(b,c,j,f){var d=null,g=this._groupHelper.getChildGroupIndex(c,b.expandInfo),i,h,k,e;if(g>=0&&g<b.expandInfo.length)d=b.expandInfo[g];else{i=new a.wijmo.wijgrid.cellRange(c.r1,c.r1,c.r2,c.r2);h=b.position==="footer"||!f?true:j&&b.outlineMode!=="startCollapsed";d=new a.wijmo.wijgrid.groupRange(h,i,-1,b.position,f);d.owner=b;b.expandInfo.push(d)}if(d&&f){k=c.r1;e=c.r2;if(b.position==="headerAndFooter")e+=2;if(b.position!=="headerAndFooter")e++;d.cr.r2=e}return d};this._updateByGroupRange=function(c,i){var d,h,b,g,e,a,f;for(d=0,h=this._leaves.length;d<h;d++){b=this._leaves[d].groupInfo;if(b&&b.level<i){g=b.expandInfo?b.expandInfo.length:0;for(e=0;e<g;e++){a=b.expandInfo[e];f=c.position==="headerAndFooter"?2:1;if(a.cr.r1>=c.cr.r1&&!(a.cr.r1===c.cr.r1&&a.position==="footer"))a.cr.r1+=f;if(a.cr.r2>=c.cr.r1)a.cr.r2+=f}}}};this._addIndent=function(c,b){var a;if(b>0&&(a=this._grid.options.groupIndent))c.__style.paddingLeft=a*b+"px"}}})})(jQuery);(function(a){"use strict";a.extend(a.wijmo.wijgrid,{groupHelper:function(){this.getGroupInfo=function(d){if(d){if(!a.wijmo.wijgrid._getGroupInfoRegExp)a.wijmo.wijgrid._getGroupInfoRegExp=new RegExp(".*G([HF]){1}(\\d+)-(\\d+)$");var b=a.wijmo.wijgrid._getGroupInfoRegExp.exec(d.id),f,e,c;if(b){f=parseInt(b[3],10);e=parseInt(b[2],10);c=b[1]==="H";return{level:f,index:e,isHeader:c,toString:function(){return(this.isHeader?"GH":"GF")+this.index+"-"+this.level}}}}return null};this.getColumnByGroupLevel=function(c,e){var b,d,a;for(b=0,d=c.length;b<d;b++){a=c[b];if(a.groupInfo&&a.groupInfo.level===e)return a}return null};this.getGroupedColumnsCount=function(c){var d=0,b,e,a;for(b=0,e=c.length;b<e;b++){a=c[b].groupInfo;if(a&&(a.position==="header"||a.position==="headerAndFooter"||a.position==="footer"))d++}return d};this.getChildGroupIndex=function(f,e){var b=0,c=e.length-1,a,d;while(b<=c){a=(c-b>>1)+b;d=e[a].cr.r1-f.r1;if(d===0)return a;if(d<0)b=a+1;else c=a-1}return b};this.getParentGroupIndex=function(c,b){var a=this.getChildGroupIndex(c,b);if(a>0)a--;return a<b.length?a:-1};this.getChildGroupRanges=function(i,f,j){var g=[],a,c,b,h,e,d=this.getColumnByGroupLevel(i,j+1);if(d){a=d.groupInfo.expandInfo;e=this.getChildGroupIndex(f,a);for(b=e,h=a.length;b<h;b++){c=a[b];if(c.cr.r2<=f.r2)g.push(c);else break}}return g};this.getParentGroupRange=function(e,f,b){var c,a,d;if(b===undefined)b=65535;if(b-2>=0)for(c=e.length-1;c>=0;c--){a=e[c].groupInfo;if(!a||!a.expandInfo||a.level<0||a.level!==b-1)continue;d=this.getParentGroupIndex(f,a.expandInfo);if(d>=0)return a.expandInfo[d]}return null};this.isParentCollapsed=function(e,c,d){var b,a;if(d===1)return false;for(b=d;b>1;b--){a=this.getParentGroupRange(e,c,b);if(a&&!a.isExpanded)return true;c=a.cr}return false};this.isParentExpanded=function(e,c,d){var b,a;if(d===1)return true;for(b=d;b>1;b--){a=this.getParentGroupRange(e,c,b);if(a&&a.isExpanded)return true;c=a.cr}return false}}})})(jQuery);(function(a){"use strict";a.extend(a.wijmo.wijgrid,{cellRange:function(b,a,d,c){switch(arguments.length){case 2:this.r1=this.r2=b;this.c1=this.c2=a;break;case 4:this.r1=b;this.r2=d;this.c1=a;this.c2=c;break;default:this.r1=0;this.r2=0;this.c1=0;this.c2=0}this.isSingleCell=function(){return this.r1===this.r2&&this.c1===this.c2}},merger:function(){this.merge=function(e,c){this.leaves=c;this.data=e;var b,d,a;for(b=0,d=c.length;b<d;b++){a=c[b];a.dataIndex>=0&&!a.isBand&&(a.rowMerge==="free"||a.rowMerge==="restricted")&&this.mergeColumn(a)}delete this.data;delete this.leaves};this.mergeColumn=function(f){var e=f.dataIndex,c,h,b,g,d;for(c=0,h=this.data.length;c<h;c++){if(!(this.data[c].rowType&a.wijmo.wijgrid.rowType.data))continue;b=this.getCellRange(c,f);if(b.r1!==b.r2){g=b.r2-b.r1+1;this.data[b.r1][e].__attr.rowSpan=g;for(d=b.r1+1;d<=b.r2;d++)this.data[d][e].visible=false}c=b.r2}};this.getCellRange=function(c,h){var d=h.dataIndex,b=new a.wijmo.wijgrid.cellRange(c,d),k=this.data[c][d].value,j=this.data.length,e,g,f,i;for(b.r2=c;b.r2<j-1;b.r2++){e=this.data[b.r2+1];if(!(e.rowType&a.wijmo.wijgrid.rowType.data)||e[d].value!==k)break}g=h.leavesIdx;if(g>0&&h.rowMerge==="restricted"){f=this.leaves[g-1];if(f.dataIndex>=0){i=this.getCellRange(c,f);b.r1=Math.max(b.r1,i.r1);b.r2=Math.min(b.r2,i.r2)}}return b}}})})(jQuery);(function(a){"use strict";a.extend(a.wijmo.wijgrid,{rowType:{header:1,data:2,dataAlt:4,filter:8,groupHeader:16,groupFooter:32,footer:64,emptyDataRow:128},renderState:{none:0,rendering:1,current:2,hovered:4,selected:8},groupRowCellPurpose:{groupCell:0,aggregateCell:1},stringFormat:function(b){var a,c;if(!b)return"";for(a=1,c=arguments.length;a<c;a++)b=b.replace(new RegExp("\\{"+(a-1)+"\\}","gm"),arguments[a]);return b},validDataKey:function(a){return a&&!(a<0)||a===0},iterateChildrenWidgets:function(b,c){if(b&&c){if(b.nodeType)b=a(b);b.find(".ui-widget").each(function(b,d){a.each(a(d).data(),function(d,a){a.widgetName&&c(b,a)})})}},remove$dataByPrefix:function(c,d){var b=[];a.each(c.data(),function(a){a.indexOf(d)===0&&b.push(a)});a.each(b,function(b,a){c.removeData(a)})},domSelection:function(b){this.getSelection=function(){var a=0,c=0,d;if(b.selectionStart!==undefined){a=b.selectionStart;c=b.selectionEnd}else if(document.selection){d=document.selection.createRange().duplicate();c=d.text.length;a=Math.abs(d.moveStart("character",-b.value.length));c+=a}return{start:a,end:c,length:c-a}};this.setSelection=function(c){if(b.selectionStart!==undefined)b.setSelectionRange(c.start,c.end);else{var a=b.createTextRange();a.collapse(true);a.moveStart("character",c.start);a.moveEnd("character",c.end);a.select()}};this.toggleSelection=function(c){if(c)a(b).enableSelection().css({MozUserSelect:"",WebkitUserSelect:""});else a(b).disableSelection().css({MozUserSelect:"-moz-none",WebkitUserSelect:"none"})}},createDynamicField:function(b){return a.extend(true,{},a.wijmo.c1basefield.prototype.options,a.wijmo.c1field.prototype.options,{dynamic:true,isLeaf:true,isBand:false,parentIdx:-1},b)},bounds:function(d,e){if(d){var c=d.nodeType?a(d):d,b=c.offset();if(b)return e?{top:b.top,left:b.left,width:c[0].clientWidth||0,height:c[0].clientHeight||0}:{top:b.top,left:b.left,width:c.outerWidth(),height:c.outerHeight()}}return null},_getDOMText:function(a,c,b){if(b===undefined)b=0;if(a&&(!c||c&&b<3))if(a.nodeType===3)return a.nodeValue;else if(a.nodeType===1){switch(a.type){case"button":case"text":case"textarea":case"select-one":return a.value;case"checkbox":return a.checked.toString()}for(var e="",d=0;a.childNodes[d];d++)e+=this._getDOMText(a.childNodes[d],c,b+1);return e}return""},ensureTBody:function(a){return a?a.tBodies&&a.tBodies.length>0?a.tBodies[0]:a.appendChild(document.createElement("tbody")):null},rowTypeFromCss:function(b){var c=/wijmo-wijgrid-(\S+)row/.exec(b.attr("class"));if(c)switch(c[1]){case"header":return a.wijmo.wijgrid.rowType.header;case"filter":return a.wijmo.wijgrid.rowType.filter;case"data":return b.hasClass("wijmo-wijgrid-alternatingrow")?a.wijmo.wijgrid.rowType.data|a.wijmo.wijgrid.rowType.dataAlt:a.wijmo.wijgrid.rowType.data;case"alternating":return a.wijmo.wijgrid.rowType.data|a.wijmo.wijgrid.rowType.dataAlt;case"groupheader":return a.wijmo.wijgrid.rowType.groupHeader;case"groupheader":return a.wijmo.wijgrid.rowType.groupFooter}},dataPrefix:function(){var f=arguments.length,h,g,b,k=typeof arguments[0]==="boolean",c=k?arguments[1]:arguments[0],j=c.nodeType===undefined,i,d,e;if(f===3){b=arguments[1]+arguments[2];return j?a.data(c[0],b):a.data(c,b)}else if(k){g=arguments[3];for(h in g){e=g[h];if(g.hasOwnProperty(h)){b=arguments[2]+h;if(j)for(d=0,f=c.length;d<f;d++)i=a.data(c[d],b,e);else a.data(c,b,e)}}}else{b=arguments[1]+arguments[2];e=arguments[3];if(j){for(d=0,f=c.length;d<f;d++)i=a.data(c[d],b,e);return i}else return a.data(c,b,e)}},shallowMerge:function(d,c){if(c&&d){var a,e,b;for(a in c)if(c.hasOwnProperty(a)){e=c[a];b=typeof e;if((b==="string"||b==="boolean"||b==="number")&&d[a]===undefined)d[a]=e}}},isCustomObject:function(a){return a&&typeof a==="object"&&!(a instanceof Date)},search:function(c,d){var b,e,f=a.isFunction(d);for(b in c)if(c.hasOwnProperty(b)){e=f?d(c[b]):c[b]===d;if(e===true)return{at:b,found:c[b]}}return{at:null,found:null}},getAttributes:function(c,e){if(c){var d,h,g=0,f={},a,b;for(d=0,h=c.attributes.length;d<h;d++){b=c.attributes[d].name;if(b&&(!e||!e(b))){a=c.getAttribute(b);if(b==="style")a=typeof a==="object"?a.cssText:a;if(!a&&b==="class")a=c.getAttribute("className");if(a&&typeof a!=="function"){f[b]=a;g++}}}if(g)return f}return null}})})(jQuery);(function(a){"use strict";a.extend(a.wijmo.wijgrid,{embeddedParsers:{stringParser:{parseDOM:function(f,d,e,c,b){return this.parse(a.wijmo.wijgrid._getDOMText(f,true),d,e,c,b)},parse:function(a,d,e,c,b){switch(a){case null:return null;case c:if(b)return null;case undefined:case"&nbsp":return"";default:return""+a}},toStr:function(a,d,e,c,b){return a===null&&b?c:""+a}},numberParser:{parseDOM:function(f,d,e,c,b){return this.parse(a.wijmo.wijgrid._getDOMText(f,true),d,e,c,b)},parse:function(a,d,f,c,b){var e=typeof a;return e==="number"?isNaN(a)?NaN:a:!a&&a!==0||a==="&nbsp;"||a===c&&b?null:Globalize.parseFloat(a,10,d.name)},toStr:function(b,e,a,d,c){return b===null&&c?d:Globalize.format(b,a?a:"n",e.name)}},currencyParser:{parseDOM:function(f,d,e,c,b){return this.parse(a.wijmo.wijgrid._getDOMText(f,true),d,e,c,b)},parse:function(a,b,f,e,d){var c=typeof a;if(c==="number")return isNaN(a)?NaN:a;if(!a&&a!==0||a==="&nbsp;"||a===e&&d)return null;if(c==="string")a=a.replace(b.numberFormat.currency.symbol,"");return Globalize.parseFloat(a,10,b.name)},toStr:function(b,e,a,d,c){return b===null&&c?d:Globalize.format(b,a?a:"c",e.name)}},dateTimeParser:{parseDOM:function(f,d,e,c,b){return this.parse(a.wijmo.wijgrid._getDOMText(f,true),d,e,c,b)},parse:function(a,e,f,d,c){var b;if(a instanceof Date)return a;if(!a||a==="&nbsp;"||a===d&&c)return null;b=/^\/Date\((\d+)\)\/$/.exec(a);return b?new Date(parseInt(b[1],10)):Globalize.parseDate(a,f,e.name)},toStr:function(b,e,a,d,c){return b===null&&c?d:Globalize.format(b,a?a:"d",e.name)}},boolParser:{parseDOM:function(f,d,e,c,b){return this.parse(a.wijmo.wijgrid._getDOMText(f,true),d,e,c,b)},parse:function(b,f,g,e,d){var c=typeof b;if(c==="boolean")return b;if(c==="string")b=a.trim(b);if(!b||b==="&nbsp;"||b===e&&d)return null;switch(b.toLowerCase()){case"true":return true;case"false":return false}return NaN},toStr:function(a,d,e,c,b){return a===null&&b?c:a?"true":"false"}}}})})(jQuery);(function(a){"use strict";a.extend(a.wijmo.wijgrid,{filterOperatorsCache:function(){var b={};this.add=function(a){if(a&&a.name&&a.operator){var c=a.name.toLowerCase();if(!b[c])b[c]=a}};this.clear=function(){b.length=0};this.getByName=function(a){return b[a.toLowerCase()]};this.getByDataType=function(f){var e=[],d,c;for(d in b)if(b.hasOwnProperty(d)){c=b[d];a.inArray(f,c.applicableTo)>=0&&e.push(c)}return e};this.removeCustom=function(){var a;for(a in b)if(b[a].custom)delete b[a]};this.sort=function(a,b){switch(b.toLowerCase()){case"alphabetical":a.sort(e);break;case"alphabeticalcustomfirst":a.sort(d);break;case"alphabeticalembeddedFirst":a.sort(c)}return a};function e(c,d){var a=c.name.toLowerCase(),b=d.name.toLowerCase();if(a!==b){if(a==="nofilter")return-1;if(b==="nofilter")return 1}return a===b?0:a<b?-1:1}function c(c,d){var a=c.name.toLowerCase(),b=d.name.toLowerCase();if(a!==b){if(a==="nofilter")return-1;if(b==="nofilter")return 1}if(c.custom!==d.custom){if(c.custom)return 1;if(d.custom)return-1}return a===b?0:a<b?-1:1}function d(c,d){var a=c.name.toLowerCase(),b=d.name.toLowerCase();if(a!==b){if(a==="nofilter")return-1;if(b==="nofilter")return 1}if(c.custom!==d.custom){if(c.custom)return-1;if(d.custom)return 1}return a===b?0:a<b?-1:1}}});a.wijmo.wijgrid.embeddedFiltersImpl={_anyCmp:function(c,d,h){var e,g,b,f=false;if(!a.isArray(d))d=[d];if(!(g=d.length))return false;if(c instanceof Date)c=c.getTime();if(typeof c==="string")c=c.toLowerCase();for(e=0;e<g&&!f;e++){b=d[e];if(b instanceof Date)b=b.getTime();if(typeof b==="string")b=b.toLowerCase();f=h(c,b)}return f}};a.wijmo.wijgrid.embeddedFilters={nofilter:{name:"NoFilter",arity:1,applicableTo:["string","number","datetime","currency","boolean"],operator:function(){return true}},contains:{name:"Contains",arity:2,applicableTo:["string"],operator:function(c,b){return a.wijmo.wijgrid.embeddedFiltersImpl._anyCmp(c,b,function(a,b){return a===b||(a?a.indexOf(b)>=0:false)})}},notcontain:{name:"NotContain",arity:2,applicableTo:["string"],operator:function(c,b){return!a.wijmo.wijgrid.embeddedFilters.contains.operator(c,b)}},beginswith:{name:"BeginsWith",arity:2,applicableTo:["string"],operator:function(c,b){return a.wijmo.wijgrid.embeddedFiltersImpl._anyCmp(c,b,function(a,b){return a===b||(a?a.indexOf(b)===0:false)})}},endswith:{name:"EndsWith",arity:2,applicableTo:["string"],operator:function(c,b){return a.wijmo.wijgrid.embeddedFiltersImpl._anyCmp(c,b,function(a,b){var c=a===b;if(!c&&a){idx=a.lastIndexOf(b);if(idx>=0)c=a.length-idx===b.length}return c})}},equals:{name:"Equals",arity:2,applicableTo:["string","number","datetime","currency","boolean"],operator:function(c,b){return a.wijmo.wijgrid.embeddedFiltersImpl._anyCmp(c,b,function(b,a){return b===a})}},notequal:{name:"NotEqual",arity:2,applicableTo:["string","number","datetime","currency","boolean"],operator:function(c,b){return a.wijmo.wijgrid.embeddedFiltersImpl._anyCmp(c,b,function(b,a){return b!==a})}},greater:{name:"Greater",arity:2,applicableTo:["string","number","datetime","currency","boolean"],operator:function(c,b){return a.wijmo.wijgrid.embeddedFiltersImpl._anyCmp(c,b,function(b,a){return b>a})}},less:{name:"Less",arity:2,applicableTo:["string","number","datetime","currency","boolean"],operator:function(c,b){return a.wijmo.wijgrid.embeddedFiltersImpl._anyCmp(c,b,function(b,a){return b<a})}},greaterorequal:{name:"GreaterOrEqual",arity:2,applicableTo:["string","number","datetime","currency","boolean"],operator:function(c,b){return a.wijmo.wijgrid.embeddedFiltersImpl._anyCmp(c,b,function(b,a){return b>=a})}},lessorequal:{name:"LessOrEqual",arity:2,applicableTo:["string","number","datetime","currency","boolean"],operator:function(c,b){return a.wijmo.wijgrid.embeddedFiltersImpl._anyCmp(c,b,function(b,a){return b<=a})}},isempty:{name:"IsEmpty",arity:1,applicableTo:["string"],operator:function(b){return a.wijmo.wijgrid.embeddedFiltersImpl._anyCmp(b,undefined,function(a){return!a&&a!==0&&a!==false})}},notisempty:{name:"NotIsEmpty",arity:1,applicableTo:["string"],operator:function(b){return a.wijmo.wijgrid.embeddedFiltersImpl._anyCmp(b,undefined,function(a){return!!a||a===0||a===false})}},isnull:{name:"IsNull",arity:1,applicableTo:["string","number","datetime","currency","boolean"],operator:function(b){return a.wijmo.wijgrid.embeddedFiltersImpl._anyCmp(b,undefined,function(a){return a===null})}},notisnull:{name:"NotIsNull",arity:1,applicableTo:["string","number","datetime","currency","boolean"],operator:function(b){return a.wijmo.wijgrid.embeddedFiltersImpl._anyCmp(b,undefined,function(a){return a!==null})}}}})(jQuery);(function(a){"use strict";a.extend(a.wijmo.wijgrid,{filterHelper:{getSingleValue:function(b){if(a.isArray(b)){b=b[0];if(a.isArray(b))b=b[0]}return b},getSingleOperatorName:function(b){if(a.isArray(b))b=b[0];return b.name||b||""},verify:function(b,d,f,g){if(b)if(a.isArray(b)){var c,i,e=[],h=[];if(!a.isArray(d))d=[d];for(c=0,i=b.length;c<i;c++)if(this._verifySingleOp(b[c],d[c],f,g)){e.push({name:b[c].name||b[c],condition:b[c].condition||"or"});h.push(d?d[c]:undefined)}if(e.length)return{filterOperator:e,filterValue:h}}else if(this._verifySingleOp(b,d,f,g))return{filterOperator:b,filterValue:d};return null},_verifySingleOp:function(b,d,e,f){if(b&&(b=b.name||b)){var c;b=(b||"").toLowerCase();if(b!=="nofilter"&&(c=f.getByName(b)))if(a.inArray(e||"string",c.applicableTo)>=0)if(c.arity===1||c.arity>1&&this.getSingleValue(d)!==undefined)return true}return false}}})})(jQuery);(function(a){"use strict";a.extend(a.wijmo.wijgrid,{htmlTableAccessor:function(e){var c=[],d=0,b=e;f();function f(){var f=[],e,h,n,k,g,a,m,j,l,i;for(h=0,n=b.rows.length;h<n;h++){e=[];c[h]=e;k=b.rows[h];for(g=0,a=0,m=k.cells.length;g<m;g++,a++){j=k.cells[g];for(;f[a]>1;a++){f[a]--;e[a]={cellIdx:-1,colIdx:-1}}if(!(f[a]>1))f[a]=j.rowSpan;e[a]={cellIdx:g,colIdx:-1};e[g].colIdx=a;l=j.colSpan;for(;l>1;l--)e[++a]={cellIdx:-1,colIdx:-1}}i=f.length;for(;a<i;a++){f[a]--;e[a]={cellIdx:-1,colIdx:-1}}d=Math.max(d,i)}}this.element=function(){return e};this.getCellIdx=function(a,b){return a<d?c[b][a].cellIdx:-1};this.getColumnIdx=function(a,e){if(typeof a!=="number"){var b=a;a=b.cellIndex;e=b.parentNode.rowIndex}return a<d?c[e][a].colIdx:-1};this.getSectionLength=function(c){return a.wijmo.wijgrid.getTableSectionLength(b,c)};this.getSectionRow=function(c,d){return a.wijmo.wijgrid.getTableSectionRow(b,d,c)};this.forEachColumnCellNatural=function(c,g,h){var a,f,e,d;for(a=0,f=b.rows.length;a<f;a++){e=b.rows[a];if(c<e.cells.length){d=g(e.cells[c],c,h);if(d!==true)return d}}return true};this.forEachColumnCell=function(h,i,j){var a,f,g,d,e;for(a=0,f=c.length;a<f;a++){g=b.rows[a];d=this.getCellIdx(h,a);if(d>=0){e=i(g.cells[d],a,j);if(e!==true)return e}}return true};this.forEachRowCell=function(g,f,h){var e=b.rows[g],a,d,c;for(a=0,d=e.cells.length;a<d;a++){c=f(e.cells[a],a,h);if(c!==true)return c}return true};this.colGroupTag=function(){var a=b.getElementsByTagName("colgroup");return a!==null&&a.length>0?a[0]:null};this.colTags=function(){var a=this.colGroupTag();return a!==null?a.getElementsByTagName("col"):[]}}})})(jQuery);(function(a){"use strict";a.wijmo.wijgrid.cellInfo=function(c,b){var e=false,d=null;this.cellIndex=function(a){if(arguments.length===0)return c;c=a};this.column=function(){if(d&&this._isValid()){var a=d._getDataToAbsOffset();return d._field("visibleLeaves")[c+a.x]}return null};this.container=function(){var c=this.tableCell(),b;if(c){b=a(c).children("div.wijmo-wijgrid-innercell");if(b)return b}return null};this.isEqual=function(a){return a&&a.rowIndex()===b&&a.cellIndex()===c};this.row=function(){var a=this._row();if(a!==null){a=d._createRowInfo(a);return a}return null};this.rowIndex=function(a){if(arguments.length===0)return b;b=a};this.tableCell=function(){if(d&&this._isValid()){var a=d._getDataToAbsOffset();return d._view().getCell(c+a.x,b+a.y)}return null};this.value=function(e){var c,f;if(d&&this._isValid()){f=d.dataTable[b];if(f.rowType&a.wijmo.wijgrid.rowType.data){c=this.column();if(arguments.length===0)return f[c.dataIndex].value;else{e=d._parse(c,e);if(e===null&&c.valueRequired||c.dataType&&c.dataType!=="string"&&isNaN(e))throw"invalid value";f[c.dataIndex].value=e;d._dataStore.updateValue(f.originalRowIndex,c.dataKey,e)}}}};this.toString=function(){return c+":"+b};this._absToData=function(a){c-=a.x;b-=a.y;return this};this._clip=function(e){var d=false,a;if(c<(a=e.topLeft().cellIndex())){d=true;c=a}if(c>(a=e.bottomRight().cellIndex())){d=true;c=a}if(b<(a=e.topLeft().rowIndex())){d=true;b=a}if(b>(a=e.bottomRight().rowIndex())){d=true;b=a}return d};this._clone=function(){return new a.wijmo.wijgrid.cellInfo(c,b)};this._dataToAbs=function(a){c+=a.x;b+=a.y;return this};this._row=function(){return d&&this._isValid()?d._rows().item(b):null};this._isValid=function(){return c>=0&&b>=0};this._isEdit=function(a){if(!arguments.length)return e;e=a};this._setGridView=function(a){d=a}};a.wijmo.wijgrid.cellInfo.prototype.outsideValue=new a.wijmo.wijgrid.cellInfo(-1,-1);a.wijmo.wijgrid.cellInfoRange=function(e,d){if(!e||!d)throw"invalid arguments";var b=e._clone(),c=d._clone();this.bottomRight=function(){return c};this.isEqual=function(a){return a&&b.isEqual(a.topLeft())&&c.isEqual(a.bottomRight())};this.topLeft=function(){return b};this.toString=function(){return b.toString()+" - "+c.toString()};this._isIntersect=function(a){var d,f,e,g;if(a){d=a.bottomRight().rowIndex()-a.topLeft().rowIndex()+1;f=c.rowIndex()-b.rowIndex()+1;if(a.topLeft().rowIndex()+d-b.rowIndex()<d+f){e=a.bottomRight().cellIndex()-a.topLeft().cellIndex()+1;g=c.cellIndex()-b.cellIndex()+1;return a.topLeft().cellIndex()+e-b.cellIndex()<e+g}}return false};this._isValid=function(){return b._isValid()&&c._isValid()};this._clip=function(a){return b._clip(a)|c._clip(a)};this._clone=function(){return new a.wijmo.wijgrid.cellInfoRange(b._clone(),c._clone())};this._containsCellInfo=function(a){return a&&a.cellIndex()>=b.cellIndex()&&a.cellIndex()<=c.cellIndex()&&a.rowIndex()>=b.rowIndex()&&a.rowIndex()<=c.rowIndex()};this._containsCellRange=function(a){return a&&this._containsCellInfo(a.topLeft())&&this._containsCellInfo(a.bottomRight())};this._extend=function(d,a){if(d===1){b.rowIndex(a.topLeft().rowIndex());c.rowIndex(a.bottomRight().rowIndex())}else if(d===2){b.cellIndex(a.topLeft().cellIndex());c.cellIndex(a.bottomRight().cellIndex())}return this};this._normalize=function(){var a=b.cellIndex(),e=b.rowIndex(),d=c.cellIndex(),f=c.rowIndex();b.cellIndex(Math.min(a,d));b.rowIndex(Math.min(e,f));c.cellIndex(Math.max(a,d));c.rowIndex(Math.max(e,f))}}})(jQuery);(function(a){"use strict";a.extend(a.wijmo.wijgrid,{classFactory:function(f,g){var h="#fake#",i=/xyz/.test(function(){xyz})?/\b_base\b/:/.*/,e=f?f.prototype:function(){},c=f?new f(h):new e,a,b,d;for(a in g)if(g.hasOwnProperty(a)){b=g[a];if(e&&typeof b==="function"&&typeof e[a]==="function"&&i.test(b))c[a]=function(b,a){return function(){var d=this._base,c;this._base=e[b];c=a.apply(this,arguments);if(d!==undefined)this._base=d;else delete this._base;return c}}(a,b);else c[a]=b}d=function(a){a!==h&&this.ctor&&this.ctor.apply(this,arguments)};d.prototype=c;d.constructor=c;return d}})})(jQuery);(function(a){"use strict";a.wijmo.wijgrid.baseView=a.wijmo.wijgrid.classFactory(null,{ctor:function(a){if(!a)throw"'wijgrid' must be specified";this._rowHeaderSize=22;this._wijgrid=a;this._wijgrid.element.addClass("wijmo-wijgrid-table")},dispose:function(){this.toggleDOMSelection(true);this._wijgrid.element.removeClass("wijmo-wijgrid-table")},ensureDisabledState:function(){var b=this._wijgrid.widgetBaseClass+"-disabled ui-state-disabled",c=this._wijgrid.options.disabled;a.each(this.subTables(),function(f,e){if(e){var d=a(e.element());if(c)d.addClass(b).attr("aria-disabled",true);else d.removeClass(b).attr("aria-disabled",false)}})},ensureWidth:function(a,b){this._setColumnWidth(a,b)},ensureHeight:function(){},getVisibleAreaBounds:function(){throw"not implemented";},getFixedAreaVisibleBounds:function(){throw"not implemented";},render:function(){this._preRender();this._renderContent();this._postRender()},toggleDOMSelection:function(b){a.each(this.subTables(),function(d,c){new a.wijmo.wijgrid.domSelection(c.element()).toggleSelection(b)})},updateSplits:function(){throw"not implemented";},focusableElement:function(){throw"not implemented";},forEachColumnCell:function(){throw"not implemented";},forEachRowCell:function(){throw"not implemented";},getAbsoluteCellInfo:function(){throw"not implemented";},getAbsoluteRowIndex:function(){throw"not implemented";},getCell:function(){throw"not implemented";},getColumnIndex:function(){throw"not implemented";},getHeaderCell:function(){throw"not implemented";},getJoinedCols:function(){throw"not implemented";},getJoinedRows:function(){throw"not implemented";},getJoinedTables:function(){throw"not implemented";},subTables:function(){throw"not implemented";},_getMappedScrollMode:function(){var c=this._wijgrid.options.scrollMode,b="auto",a="auto";switch(c){case"horizontal":b="hidden";a="visible";break;case"vertical":b="visible";a="hidden";break;case"both":b="visible";a="visible"}return{vScrollBarVisibility:b,hScrollBarVisibility:a}},_postRender:function(){this.toggleDOMSelection(this._wijgrid.options.selectionMode==="none");this.ensureDisabledState()},_preRender:function(){throw"not implemented";},_renderContent:function(){throw"not implemented";},_setColumnWidth:function(c,b){var e=this.getHeaderCell(c),d=this.getJoinedCols(c);if(b){a(e).setOutWidth(b);a.each(d,function(d,c){a(c).setOutWidth(b)})}},_getColumnWidth:function(l,j){var c,b,d,g,k,f,i,e,m,h;if(j){c=this._wijgrid._field("visibleLeaves")[l];if(c._realWidth!==undefined)b={width:c._realWidth,real:true};else if(c.isRowHeader)b={width:this._rowHeaderSize,real:true};else{d=0;g=this.getJoinedTables(true,l);k=g[2];for(f=0;f<2;f++){i=g[f];if(i!==null){e=i.element().rows;if(e.length>0){m=e[e.length-1].cells[k];h=a(m).outerWidth();if(h>d)d=h}}}b={width:d,real:false}}j.push(b)}},_setTableWidth:function(d,c,f,g){var e,b;a.each(d,function(b,a){a.css("table-layout","fixed").setOutWidth(c)});e=d[0].outerWidth();b=e-c;b!==0&&this._setColumnWidth(g,f-b)},_sumWidthArray:function(e,b,c){var d=0;a.each(e,function(a,e){if(b!==undefined&&c!==undefined&&(a<b||a>c))return true;d+=e.width});return d},_adjustWidthArray:function(j,k,d,n,c){var h=this._sumWidthArray(j),l=this._sumWidthArray(k),b=[],e,f=0,g,i,m=true;if(h<=d){a.extend(true,b,j);if(h==d||n)return b;else e=d-h}else{a.extend(true,b,k);if(l>=d)return b;else e=d-l}a.each(b,function(b,a){if(!a.real)f++});if(f!==0){if(c!==undefined&&c>-1&&c<b.length&&!b[c].real){b[c].width+=e;return b}g=Math.floor(e/f);i=e-g*f;a.each(b,function(b,a){if(!a.real){a.width+=g;if(m){a.width+=i;m=false}}})}return b}})})(jQuery);(function(a){"use strict";a.wijmo.wijgrid.flatView=a.wijmo.wijgrid.classFactory(a.wijmo.wijgrid.baseView,{ctor:function(a){this._base(a);this._dataTable=null;this._contentArea=null},ensureWidth:function(e,b,c){var d=a(this._dataTable.element()),f=d.width()+b-c;this._base(e,b,c);this._setTableWidth([d],f,b,e)},getVisibleAreaBounds:function(){var b=a.wijmo.wijgrid.bounds(this._dataTable.element()),c;if(this._wijgrid.options.scrollMode==="none")return b;else{c=a.wijmo.wijgrid.bounds(this._wijgrid.outerDiv.find(".wijmo-wijgrid-split-area-se:first")[0]);return{top:b.top,left:b.left,width:Math.min(c.width,b.width),height:Math.min(c.height,b.height)}}},updateSplits:function(){var f=this,e=this._wijgrid,h=e.options,g=e.element,i=[],j=[],b=[],d=e._field("visibleLeaves"),l=e.outerDiv,k,c;g.css({"table-layout":"",width:""});a.each(d,function(d,b){var c,a=b.width;if(a||a===0){c=typeof a==="string"&&a.length>1&&a[a.length-1]==="%";if(c)a=l.width()*parseFloat(a)/100;else a=parseFloat(a);if(b.ensurePxWidth||b.ensurePxWidth===undefined&&h.ensureColumnsPxWidth)b._realWidth=a;f._setColumnWidth(d,a)}});a.each(d,function(a){f._getColumnWidth(a,i)});g.css("width","1px");a.each(d,function(a){f._getColumnWidth(a,j)});k=l.innerWidth();b=this._adjustWidthArray(i,j,k,h.ensureColumnsPxWidth,h.autoExpandColumnIndex);a.each(b,function(a,c){var b=d[a];if(b._realWidth!==undefined){delete b._realWidth;return}f._setColumnWidth(a,c.width)});c=b.length-1;c!==-1&&this._setTableWidth([g],this._sumWidthArray(b,0,c),b[c].width,c)},focusableElement:function(){return a(this._dataTable.element())},forEachColumnCell:function(a,b,c){return this._dataTable.forEachColumnCell(a,b,c)},forEachRowCell:function(b,a,c){return this._dataTable.forEachRowCell(b,a,c)},getAbsoluteCellInfo:function(b){return new a.wijmo.wijgrid.cellInfo(this.getColumnIndex(b),b.parentNode.rowIndex)},getAbsoluteRowIndex:function(a){return a.rowIndex},getCell:function(d,b){var c=this._dataTable.getCellIdx(d,b),a;if(c>=0){a=this.getJoinedRows(b,0);if(a[0])return a[0].cells[c]}return null},getColumnIndex:function(a){return this._dataTable.getColumnIdx(a)},getHeaderCell:function(d){var b=this._wijgrid._field("visibleLeaves")[d],c;return b&&(c=this._wijgrid._headerRows())?(new a.wijmo.wijgrid.rowAccessor).getCell(c.item(b.thY),b.thX):null},getJoinedCols:function(c){var b=a(this._dataTable.element()).find("> colgroup");if(b.length)if(c<b[0].childNodes.length)return[b[0].childNodes[c],null];return[null,null]},getJoinedRows:function(a,b){return[this._dataTable.getSectionRow(a,b),null]},getJoinedTables:function(b,a){return[this._dataTable,null,a]},subTables:function(){return[this._dataTable]},_postRender:function(){this._wijgrid.element.find("> tbody").addClass("ui-widget-content wijmo-wijgrid-data");this._dataTable=new a.wijmo.wijgrid.htmlTableAccessor(this._wijgrid.element[0]);this._wijgrid.element.attr({role:"grid",cellpadding:"0",border:"0",cellspacing:"0"}).css("border-collapse","separate");this._base()},_preRender:function(){},_renderContent:function(){var n=this._wijgrid._field("visibleLeaves"),q=this._wijgrid.element[0],r=null,p,k,I,j,G,i,K,d,f,o,l,u,h,w,J,z,y,H,b,B,t,D,e,x,v,E,g,F,C,L=-1,A=0,c=a.wijmo.wijgrid.rowType,m=a.wijmo.wijgrid.renderState,s;p=this._wijgrid._field("spanTable");if(p&&p.length){r=q.createTHead();I=p[0].length;for(j=0,G=p.length;j<G;j++){i=this._wijgrid._createRow(r,c.header,j);g=this._wijgrid._createRowInfo([i],c.header,m.rendering,-1,-1,-1,-1);K=0;for(d=0;d<I;d++){k=p[j][d];if(k.column&&k.column.parentVis){k.column.thX=K++;k.column.thY=j;f=a(this._wijgrid._createCell(c.header,j,d,k.column));o=f.children("div");i.appendChild(f[0]);this._wijgrid.cellFormatter.format(o,k.column,k.column.headerText,g);this._wijgrid._cellCreated(f,d,k.column,g,m.rendering,{colSpan:k.colSpan,rowSpan:k.rowSpan})}}this._wijgrid._rowCreated(g)}}if(this._wijgrid.options.showFilter){if(!r)r=q.createTHead();i=this._wijgrid._createRow(r,c.filter,-1);g=this._wijgrid._createRowInfo([i],c.filter,m.rendering,-1,-1,-1,-1);for(l=0,u=n.length;l<u;l++){h=n[l];f=a(this._wijgrid._createCell(c.filter,undefined,l,h));i.appendChild(f[0]);this._wijgrid.cellFormatter.format(f,h,a.wijmo.wijgrid.filterHelper.getSingleValue(h.filterValue),g);this._wijgrid._cellCreated(f,l,h,g,m.rendering)}this._wijgrid._rowCreated(g)}w=document.createElement("colgroup");for(l=0,u=n.length;l<u;l++){J=document.createElement("col");w.appendChild(J)}q.appendChild(w);z=this._wijgrid.dataTable;y=a.wijmo.wijgrid.ensureTBody(q);if(this._wijgrid._dataStore.dataMode()===a.wijmo.wijgrid.dataMode.dynamical)A=this._wijgrid.options.pageIndex*this._wijgrid.options.pageSize;for(j=0,H=z.length;j<H;j++){b=z[j];B=b.length;s=(b.rowType&c.data)!==0;i=this._wijgrid._createRow(y,b.rowType,b.originalRowIndex);g=this._wijgrid._createRowInfo([i],b.rowType,m.rendering,j,s?++L:-1,s?b.originalRowIndex:-1,s?A+b.originalRowIndex:-1);for(d=0,t=n.length;d<t;d++){h=n[d];D=h.dataIndex;e=0;x=false;switch(b.rowType){case c.data:case c.data|c.dataAlt:e=D;if(e>=0&&(!b[e]||b[e].visible===false))continue;break;case c.emptyDataRow:case c.groupHeader:case c.groupFooter:e=d;if(e>=B)x=true}if(x)break;f=a(this._wijgrid._createCell(b.rowType,b.originalRowIndex,e,h));o=f.children("div");i.appendChild(f[0]);if(b.rowType&c.data&&h.dataParser){v=null;if(e>=0){E=b[e].value;v=this._wijgrid._toStr(h,E)}this._wijgrid.cellFormatter.format(o,h,v,g)}else e>=0&&o.html(b[e].html);F=e>=0?b[e].__attr:null;C=e>=0?b[e].__style:null;this._wijgrid._cellCreated(f,d,h,g,m.rendering,F,C)}if(!i.cells.length)y.removeChild(i);else this._wijgrid._rowCreated(g,b.__attr,b.__style)}if(this._wijgrid.options.showFooter){i=this._wijgrid._createRow(q.createTFoot(),c.footer,-1);g=this._wijgrid._createRowInfo([i],c.footer,m.rendering,-1,-1,-1,-1);for(d=0,t=n.length;d<t;d++){h=n[d];f=a(this._wijgrid._createCell(c.footer,undefined,d,h));o=f.children("div");i.appendChild(f[0]);this._wijgrid.cellFormatter.format(o,h,"",g);this._wijgrid._cellCreated(f,l,h,g,m.rendering)}this._wijgrid._rowCreated(g)}}})})(jQuery);(function(a){"use strict";a.wijmo.wijgrid.fixedView=a.wijmo.wijgrid.classFactory(a.wijmo.wijgrid.baseView,{ctor:function(b){this._base(b);this._verScrollBarSize=18;this._mouseWheelHandler=a.proxy(this._onMouseWheel,this);this._rowsCount=null;this._viewTables={};this._table00=null;this._table01=null;this._table10=null;this._table11=null;this._scroller=null;this.element=b.element},dispose:function(){this._base();this._wijgrid.outerDiv.unbind("mousewheel",this._mouseWheelHandler)},ensureWidth:function(g,h,p){var d=this._wijgrid,e=d.options,i=d._getRealStaticColumnIndex(),k=g<=i,b=a(this._table00.element()),f=a(this._table01.element()),j=a(this._table10.element()),c=a(this._table11.element()),m=k?[b,j]:[f,c],n=(k?b.width():f.width())+h-p,o=d._field("frozener"),l=this.getScrollValue();this._scroller.data("wijsuperpanel")&&this._scroller.wijsuperpanel("destroy");this._base(g,h);this._setTableWidth(m,n,h,g);try{if(i>=0)e.splitDistanceX=b[0].offsetWidth;else e.splitDistanceX=0}catch(q){}this._updateSplitAreaBounds(0);c.css("height","");this._adjustRowHeight();c.height(Math.max(c.height(),j.height()));try{if(d._getRealStaticRowIndex()>=0)e.splitDistanceY=Math.max(b[0].offsetHeight,f[0].offsetHeight);else e.splitDistanceY=0}catch(q){}this._updateSplitAreaBounds(1);this.refreshPanel(l);o.refresh()},ensureHeight:function(k){var b,d=this._wijgrid,e=d.options,h=a(this._table00.element()),g=a(this._table01.element()),i=a(this._table10.element()),c=a(this._table11.element()),j=d._field("frozener"),f=this.getScrollValue();this._scroller.data("wijsuperpanel")&&this._scroller.wijsuperpanel("destroy");if(arguments.length>0){b=this.getJoinedRows(k,2);this._setRowHeight(b,this._getRowHeight(b))}c.css("height","");c.height(Math.max(c.height(),i.height()));try{if(d._getRealStaticRowIndex()>=0)e.splitDistanceY=Math.max(h[0].offsetHeight,g[0].offsetHeight);else e.splitDistanceY=0}catch(l){}this._updateSplitAreaBounds(1);this.refreshPanel(f);j.refresh()},getScrollValue:function(){var a=this._getSuperPanel();return a?{type:"fixed",hScrollValue:a.options.hScroller.scrollValue,vScrollValue:a.options.vScroller.scrollValue}:{type:"fixed",hScrollValue:null,vScrollValue:null}},getVisibleAreaBounds:function(){return a.wijmo.wijgrid.bounds(this._wijgrid.outerDiv.find(".wijmo-wijsuperpanel-contentwrapper:first"))},getFixedAreaVisibleBounds:function(){var b=this.getVisibleAreaBounds(),f=a.wijmo.wijgrid.bounds(this._wijgrid.outerDiv.find(".wijmo-wijgrid-split-area-ne:first")),c=a.wijmo.wijgrid.bounds(this._wijgrid.outerDiv.find(".wijmo-wijgrid-split-area-nw:first")),d=null,e=null;if(f.height||c.height)d={left:b.left,top:b.top,width:b.width,height:Math.min(f.height||c.height,b.height)};if(c.width)e={left:b.left,top:b.top,width:Math.min(c.width,b.width),height:b.height};return[d,e]},refreshPanel:function(d){var e=this,b=this._wijgrid,c=b.options,g=this._getGridWidth(c.scrollMode),f=this._getMappedScrollMode(),h=this._testNeedVBar(b.outerDiv,b.element,a(this._table01.element()),c.scrollMode,b._autoHeight);this._scroller.width(g);b.outerDiv.find(".wijmo-wijgrid-split-area-ne").width(g-c.splitDistanceX-(h?this._verScrollBarSize:0));if(!this._scroller.data("wijsuperpanel"))this._scroller.wijsuperpanel({disabled:b.options.disabled,scroll:a.proxy(this._onScroll,this),bubbleScrollingEvent:true,vScroller:{scrollBarVisibility:f.vScrollBarVisibility,scrollValue:d.type==="fixed"?d.vScrollValue:null},hScroller:{scrollBarVisibility:f.hScrollBarVisibility,scrollValue:d.type==="fixed"?d.hScrollValue:null},hScrollerActivating:function(g,f){var a,d;if(b._autoHeight){a=b.element.height()+c.splitDistanceY-f.contentLength;if(a>0){e._scroller.height(e._scroller.height()+a);e._scroller.wijsuperpanel("paintPanel");return false}}d=b.outerDiv.find(".wijmo-wijgrid-split-area-sw");d.height(f.contentLength-c.splitDistanceY)}});else this._scroller.wijsuperpanel("paintPanel");this._scroller.find(".wijmo-wijsuperpanel-hbarcontainer, .wijmo-wijsuperpanel-vbarcontainer").css("zIndex",5)},scrollTo:function(s){var u=this._wijgrid,v=u.options,m=this._getSuperPanel(),t=s.tableCell(),n=t.nodeType?a(t):t,l,r,d,f,k,i,q,b,c,j,h,e=null,g=null,x,o,w,p;if(m&&n.is(":visible")){l=m.getContentElement();r=l.parent();d=parseInt((l.css("left")+"").replace("px",""),10)*-1;f=parseInt((l.css("top")+"").replace("px",""),10)*-1;k=r.outerWidth()-v.splitDistanceX;i=r.outerHeight()-v.splitDistanceY;q=n.position();b=q.left;c=q.top;j=n.outerWidth();h=n.outerHeight();x=u._getStaticIndex(true);o=u._getStaticIndex(false);w=s.rowIndex();p=s.cellIndex();if(w<=x)if(p<=o){e=0;g=0}else{b+=d;if(b+j>d+k)d=e=b+j-k;if(b<d)e=b;g=0}else if(p<=o){c+=f;if(c+h>f+i)f=g=c+h-i;if(c<f)g=c;e=0}else{b-=v.splitDistanceX;if(c+h>f+i)f=g=c+h-i;if(b+j>d+k)d=e=b+j-k;if(c<f)g=c;if(b<d)e=b}e!==null&&m.hScrollTo(e);g!==null&&m.vScrollTo(g)}},updateSplits:function(s){var g=this._wijgrid,c=g.options,r,o,j,l=this,d=[],q=[],p=[],h=g._getRealStaticColumnIndex(),b,t=c.scrollMode,m=g._field("visibleLeaves"),e=a(this._table11.element()),f=a(this._table01.element()),k=a(this._table10.element()),i=a(this._table00.element()),n=g.outerDiv;this._scroller.data("wijsuperpanel")&&this._scroller.wijsuperpanel("destroy");n.unbind("mousewheel",this._mouseWheelHandler);r=e.find("tbody .wijmo-wijgrid-row:not(.wijmo-wijgrid-groupheaderrow):first");this.fooRow=o=r.clone().removeAttr("datarowindex").addClass("wijmo-wijgrid-foorow").appendTo(r.parent()).show().height(0).css({"font-size":"0"});this.fooRowCells=o.find(">td").height(0).css({"border-top":"0","border-bottom":"0"}).find(">div.wijmo-wijgrid-innercell").css({"padding-top":"0px","padding-bottom":"0px"}).empty();o.css("visibility","hidden");o.length===0&&g.element.css("width","100%");a.each([e,f,k,i],function(b,a){a.css({"table-layout":"",width:""})});a.each(m,function(e,b){var d,a=b.width;if(a||a===0){d=typeof a==="string"&&a.length>1&&a[a.length-1]==="%";if(d)a=n.width()*parseFloat(a)/100;else a=parseFloat(a);if(b.ensurePxWidth||b.ensurePxWidth===undefined&&c.ensureColumnsPxWidth)b._realWidth=a;l._setColumnWidth(e,a)}});a.each(m,function(a){l._getColumnWidth(a,p)});a.each([i,f,k,e],function(b,a){a.css({width:"1px"})});a.each(m,function(a){l._getColumnWidth(a,q)});j=n.innerWidth();d=this._adjustWidthArray(p,q,j,c.ensureColumnsPxWidth,c.autoExpandColumnIndex);a.each(d,function(a,c){var b=m[a];if(b._realWidth!==undefined){delete b._realWidth;return}l._setColumnWidth(a,c.width)});if(h>=0){b=h;this._setTableWidth([i,k],this._sumWidthArray(d,0,b),d[b].width,b)}try{if(h>=0)c.splitDistanceX=i[0].offsetWidth;else c.splitDistanceX=0}catch(u){}this._updateSplitAreaBounds(0);!c.ensureColumnsPxWidth&&f.parent().width(j-c.splitDistanceX);b=d.length-1;b!==-1&&this._setTableWidth([f,e],this._sumWidthArray(d,h+1,b),d[b].width,b);e.css("height","");this._adjustRowHeight();e.height(Math.max(e.height(),k.height()));try{if(g._getRealStaticRowIndex()>=0)c.splitDistanceY=Math.max(i[0].offsetHeight,f[0].offsetHeight);else c.splitDistanceY=0}catch(u){}this._updateSplitAreaBounds(1);if(!c.ensureColumnsPxWidth)if(this._testNeedVBar(g.outerDiv,e,f,t,g._autoHeight)){j-=this._verScrollBarSize;d=this._adjustWidthArray(p,q,j,c.ensureColumnsPxWidth,c.autoExpandColumnIndex);a.each(d,function(b,a){!a.real&&l._setColumnWidth(b,a.width)});if(h>=0){b=h;this._setTableWidth([i,k],this._sumWidthArray(d,0,b),d[b].width,b)}try{if(h>=0)c.splitDistanceX=i[0].offsetWidth;else c.splitDistanceX=0}catch(u){}this._updateSplitAreaBounds(0);f.parent().width(j-c.splitDistanceX);b=d.length-1;b!==-1&&this._setTableWidth([f,e],this._sumWidthArray(d,h+1,b),d[b].width,b);e.css("height","");this._adjustRowHeight();e.height(Math.max(e.height(),k.height()));try{if(g._getRealStaticRowIndex()>=0)c.splitDistanceY=Math.max(i[0].offsetHeight,f[0].offsetHeight);else c.splitDistanceY=0}catch(u){}this._updateSplitAreaBounds(1)}this.refreshPanel(s);n.bind("mousewheel",this._mouseWheelHandler)},focusableElement:function(){return this._wijgrid.outerDiv},forEachColumnCell:function(f,d,e){var b=this.getJoinedTables(true,f),c,a;if(b[0]!==null){c=b[2];a=b[0].forEachColumnCell(c,d,e);if(a!==true)return a;if(b[1]!==null){a=b[1].forEachColumnCell(c,d,e);if(a!==true)return a}}return true},forEachRowCell:function(h,f,g){var c=this.getJoinedTables(false,h),d=c[0],e=c[1],b,a;if(d!==null){b=c[2];if(b<d.element().rows.length){a=d.forEachRowCell(b,f,g);if(a!==true)return a}if(e!==null&&b<e.element().rows.length){a=e.forEachRowCell(b,f,g);if(a!==true)return a}}return true},getAbsoluteCellInfo:function(b){return new a.wijmo.wijgrid.cellInfo(this.getColumnIndex(b),this.getAbsoluteRowIndex(b.parentNode))},getAbsoluteRowIndex:function(b){var c=b.rowIndex,a=b.parentNode;while(a.tagName.toLowerCase()!=="table")a=a.parentNode;return a===this._table00.element()||a===this._table01.element()?c:c+this._wijgrid._getRealStaticRowIndex()+1},getCell:function(g,h){var a=this.getJoinedTables(false,h),c,e,d,b,f;if(a[0]!==null){c=this.getJoinedTables(true,g);if(c[0]!==null){e=a[2];d=c[2];b=null;if(a[1]!==null)b=g===d?a[0]:a[1];else b=a[0];f=b.getCellIdx(d,e);if(f>=0)return b.element().rows[e].cells[f]}}return null},getColumnIndex:function(e){for(var a=null,b=null,d=false,c,a=e.parentNode;a.tagName.toLowerCase()!=="table";a=a.parentNode);if(a!==null){if(a===this._table00.element())b=this._table00;else if(a===this._table01.element()){b=this._table01;d=true}else if(a===this._table10.element())b=this._table10;else if(a===this._table11.element()){b=this._table11;d=true}if(b!==null){c=b.getColumnIdx(e);if(d)c+=this._wijgrid._getRealStaticColumnIndex()+1;return c}}return-1},getHeaderCell:function(d){var b=this._wijgrid._field("visibleLeaves")[d],c;return b&&(c=this._wijgrid._headerRows())?(new a.wijmo.wijgrid.rowAccessor).getCell(c.item(b.thY),b.thX):null},getJoinedCols:function(d){var c=[],b=this.getJoinedTables(true,d),e=b[2];b.splice(b.length-1,1);a.each(b,function(d,b){c.push(b?a(b.element()).find("col")[e]:null)});return c},getJoinedRows:function(c,e){var f=null,g=null,a=null,d=null,l=this._wijgrid._getRealStaticRowIndex(),b=this._wijgrid._getRealStaticColumnIndex(),m=this._wijgrid._field("visibleLeaves").length-1,n=this._rowsCount-1,k=l===n,h=l<0,j=!k&&!h,i=0;if(k||j){if(b>=0&&b<m){a=this._table00;d=this._table01}else a=b<0?this._table01:this._table00;i=a.getSectionLength(e);if(c<i){f=a.getSectionRow(c,e);if(d!==null)g=d.getSectionRow(c,e)}}if(h||j&&f===null){if(!h)c-=i;if(b>=0&&b<m){a=this._table10;d=this._table11}else a=b<0?this._table11:this._table10;f=a.getSectionRow(c,e);if(d!==null)g=d.getSectionRow(c,e)}return f===null&&g===null?null:[f,g]},getJoinedTables:function(h,g){var a=null,b=null,c=g,f=this._wijgrid,e=f._getRealStaticRowIndex(),d=f._getRealStaticColumnIndex();if(h){if(g<=d){a=this._table00;b=this._table10}else{a=this._table01;b=this._table11;c=c-(d+1)}if(e<0)a=null;if(e===this._rowsCount-1)b=null}else{if(g<=e){a=this._table00;b=this._table01}else{a=this._table10;b=this._table11;c=c-(e+1)}if(d<0)a=null;if(d===f._field("leaves").length-1)b=null}if(a===null){a=b;b=null}return[a,b,c]},subTables:function(){return[this._table00,this._table01,this._table10,this._table11]},_getGridWidth:function(e){var b=this._wijgrid,c=b.element.outerWidth(true)+b.options.splitDistanceX,d=b.outerDiv.innerWidth();if(this._testNeedVBar(b.outerDiv,b.element,a(this._table01.element()),e,b._autoHeight))c+=this._verScrollBarSize;if(c>d)c=d;return c},_getSuperPanel:function(){return this._scroller?this._scroller.data("wijsuperpanel"):null},_postRender:function(){var b;for(b in this._viewTables)this._viewTables.hasOwnProperty(b)&&a(this._viewTables[b]).addClass("wijmo-wijgrid-table").attr("role","grid").find("> tbody").addClass("ui-widget-content wijmo-wijgrid-data");this._table00=new a.wijmo.wijgrid.htmlTableAccessor(this._viewTables.nw);this._table01=new a.wijmo.wijgrid.htmlTableAccessor(this._viewTables.ne);this._table10=new a.wijmo.wijgrid.htmlTableAccessor(this._viewTables.sw);this._table11=new a.wijmo.wijgrid.htmlTableAccessor(this._viewTables.se);this._rowsCount=Math.max(this._viewTables.nw.rows.length,this._viewTables.ne.rows.length)+Math.max(this._viewTables.sw.rows.length,this._viewTables.se.rows.length);a.each([this._viewTables.nw,this._viewTables.sw,this._viewTables.ne,this._viewTables.se],function(c,b){a(b).attr({cellpadding:"0",border:"0",cellspacing:"0"}).css("border-collapse","separate")});this._base()},_preRender:function(){this._wijgrid.outerDiv.wrapInner('<div class="wijmo-wijgrid-fixedview"><div class="wijmo-wijgrid-scroller"><div class="wijmo-wijgrid-split-area-se wijmo-wijgrid-content-area"></div></div></div>');this._scroller=this._wijgrid.outerDiv.find(".wijmo-wijgrid-scroller");this._scroller.after('<div class="wijmo-wijgrid-split-area wijmo-wijgrid-split-area-nw" style="overflow:hidden;position:absolute;z-index:4;top:0px;left:0px;"></div>');this._scroller.after('<div class="wijmo-wijgrid-split-area wijmo-wijgrid-split-area-ne" style="overflow:hidden;position:absolute;z-index:4;top:0px;left:0px;"></div>');this._scroller.after('<div class="wijmo-wijgrid-split-area wijmo-wijgrid-split-area-sw" style="overflow:hidden;position:absolute;z-index:4;top:0px;left:0px;"></div>')},_renderContent:function(){var b=this._wijgrid,q=b._field("visibleLeaves"),y=document.createDocumentFragment(),x=b._field("spanTable"),L=b._getStaticIndex(true),t=b._getRealStaticColumnIndex(),W=t===-1?-1:q[t].leavesIdx,r={},T,l,R,c,M,e,d,V,h,n,f,m,U,k,p,w,v,C,B,J,o={},S,A,O,j,E,u,D,P,G,F,I,H,Q,N,i,X=-1,K=0,g=a.wijmo.wijgrid.rowType,s=a.wijmo.wijgrid.renderState,z;this._viewTables={nw:y.appendChild(document.createElement("table")),ne:y.appendChild(document.createElement("table")),sw:y.appendChild(document.createElement("table")),se:y.appendChild(b.element[0])};if(x&&x.length){r.nw=this._viewTables.nw.createTHead();r.ne=this._viewTables.ne.createTHead();T=x[0].length;for(l=0,R=x.length;l<R;l++){e=null;d=null;e=b._createRow(r.nw,g.header,l);d=b._createRow(r.ne,g.header,l);i=b._createRowInfo([e,d],g.header,s.rendering,-1,-1,-1,-1);V=0;for(h=0;h<T;h++){n=x[l][h];if(n.column&&n.column.parentVis){n.column.thX=V++;n.column.thY=l;f=a(b._createCell(g.header,l,h,n.column));u=f.children("div");if(h<=W)e.appendChild(f[0]);else d.appendChild(f[0]);b.cellFormatter.format(u,n.column,n.column.headerText,i);b._cellCreated(f,h,n.column,i,s.rendering,{colSpan:n.colSpan,rowSpan:n.rowSpan})}}b._rowCreated(i)}}if(b.options.showFilter){if(r.nw)e=b._createRow(r.nw,g.filter,-1);if(r.ne)d=b._createRow(r.ne,g.filter,-1);i=b._createRowInfo([e,d],g.filter,s.rendering,-1,-1,-1,-1);for(m=0,U=q.length;m<U;m++){k=q[m];f=a(b._createCell(g.filter,undefined,m,k));if(m<=t)e.appendChild(f[0]);else d.appendChild(f[0]);b.cellFormatter.format(f,k,a.wijmo.wijgrid.filterHelper.getSingleValue(k.filterValue),i);b._cellCreated(f,m,k,i,s.rendering)}b._rowCreated(i)}p={t0:this._viewTables.nw,t1:this._viewTables.sw};for(w in p)if(p.hasOwnProperty(w)){v=document.createElement("colgroup");for(m=0;m<=t;m++){C=document.createElement("col");v.appendChild(C)}B=p[w];B.appendChild(v)}p={t0:this._viewTables.ne,t1:this._viewTables.se};for(w in p)if(p.hasOwnProperty(w)){v=document.createElement("colgroup");for(m=t+1;m<q.length;m++){C=document.createElement("col");v.appendChild(C)}B=p[w];B.appendChild(v)}J=b.dataTable;o={nw:a.wijmo.wijgrid.ensureTBody(this._viewTables.nw),ne:a.wijmo.wijgrid.ensureTBody(this._viewTables.ne),sw:a.wijmo.wijgrid.ensureTBody(this._viewTables.sw),se:a.wijmo.wijgrid.ensureTBody(this._viewTables.se)};if(b._dataStore.dataMode()===a.wijmo.wijgrid.dataMode.dynamical)K=b.options.pageIndex*b.options.pageSize;for(l=0,S=J.length;l<S;l++){c=J[l];M=c.length;z=(c.rowType&g.data)!==0;e=null;d=null;if(l<=L){e=b._createRow(o.nw,c.rowType,c.originalRowIndex);d=b._createRow(o.ne,c.rowType,c.originalRowIndex)}else{e=b._createRow(o.sw,c.rowType,c.originalRowIndex);d=b._createRow(o.se,c.rowType,c.originalRowIndex)}i=b._createRowInfo([e,d],c.rowType,s.rendering,l,z?++X:-1,z?c.originalRowIndex:-1,z?K+c.originalRowIndex:-1);for(h=0,A=q.length;h<A;h++){k=q[h];O=k.dataIndex;j=0;E=false;switch(c.rowType){case g.data:case g.data|g.dataAlt:j=O;if(j>=0&&(!c[j]||c[j].visible===false))continue;break;case g.emptyDataRow:case g.groupHeader:case g.groupFooter:j=h;if(j>=M)E=true}if(E)break;f=a(b._createCell(c.rowType,c.originalRowIndex,j,k));u=f.children("div");if(h<=t)e.appendChild(f[0]);else d.appendChild(f[0]);if(c.rowType&g.data&&k.dataParser){D=null;if(j>=0){P=c[j].value;D=b._toStr(k,P)}b.cellFormatter.format(u,k,D,i)}else j>=0&&u.html(c[j].html);Q=j>=0?c[j].__attr:null;N=j>=0?c[j].__style:null;b._cellCreated(f,h,k,i,s.rendering,Q,N)}if(l<=L){if(!e.cells.length){o.nw.removeChild(e);e=null}if(!d.cells.length){o.ne.removeChild(d);d=null}(e||d)&&b._rowCreated(i,c.__attr,c.__style)}else{if(!e.cells.length){o.sw.removeChild(e);e=null}if(!d.cells.length){o.se.removeChild(d);d=null}(e||d)&&b._rowCreated(i,c.__attr,c.__style)}}if(b.options.showFooter){e=b._createRow(this._viewTables.sw.createTFoot(),g.footer,-1);d=b._createRow(this._viewTables.se.createTFoot(),g.footer,-1);i=b._createRowInfo([e,d],g.footer,s.rendering,-1,-1,-1,-1);for(h=0,A=q.length;h<A;h++){k=q[h];f=a(b._createCell(g.footer,undefined,h,k));u=f.children("div");if(h<=t)e.appendChild(f[0]);else d.appendChild(f[0]);b.cellFormatter.format(u,k,"",i);b._cellCreated(f,m,k,i,s.rendering)}b._rowCreated(i)}G=b.outerDiv.find(".wijmo-wijgrid-split-area-nw");F=b.outerDiv.find(".wijmo-wijgrid-split-area-ne");I=b.outerDiv.find(".wijmo-wijgrid-split-area-sw");H=b.outerDiv.find(".wijmo-wijgrid-content-area");G[0].innerHTML="";F[0].innerHTML="";I[0].innerHTML="";H[0].innerHTML="";a(this._viewTables.nw).appendTo(G);a(this._viewTables.ne).appendTo(F);a(this._viewTables.sw).appendTo(I);a(this._viewTables.se).appendTo(H)},_getRowHeight:function(b){if(b[0]&&b[1]){var e=[a(b[0]),a(b[1])],c,d;a.each(e,function(b,a){a.css("height","")});c=e[0].height();d=e[1].height();if(c>d)return c;else if(c<d)return d}return null},_setRowHeight:function(c,b){if(c[0]&&c[1]){var e=[a(c[0]),a(c[1])],d;if(b===null)return;b+=1;a.each(e,function(c,a){a.height(b);d=b-a.height();d&&a.height(b+d)})}},_adjustRowHeight:function(){var q=this._wijgrid,s=q._getRealStaticColumnIndex(),t=q._field("visibleLeaves").length-1,b,d,k,g,m,h,n,i,o,j,p,f,a,r,c,e;if(s>-1&&s<t){var l=[];b=q._getRealStaticRowIndex();d=this._rowsCount-1;k=this._viewTables;if(b>-1&&b<=d){g=k.ne;m=g.parentNode;h=k.nw;n=h.parentNode;c=h.rows;e=g.rows;f=c.length;for(a=0;a<f;a++)l.push(this._getRowHeight([c[a],e[a]]))}if(b>=-1&&b<d){i=k.se;o=i.parentNode;j=k.sw;p=j.parentNode;c=j.rows;e=i.rows;f=c.length;for(a=0;a<f;a++)l.push(this._getRowHeight([c[a],e[a]]))}if(b>-1&&b<=d){n.removeChild(h);m.removeChild(g)}if(b>=-1&&b<d){p.removeChild(j);o.removeChild(i)}if(b>-1&&b<=d){c=h.rows;e=g.rows;f=c.length;for(a=0,r=0;a<f;a++)this._setRowHeight([c[a],e[a]],l[r++])}if(b>=-1&&b<d){c=j.rows;e=i.rows;f=c.length;for(a=0;a<f;a++)this._setRowHeight([c[a],e[a]],l[r++])}if(b>-1&&b<=d){n.appendChild(h);m.appendChild(g)}if(b>=-1&&b<d){p.appendChild(j);o.appendChild(i)}}},_onScroll:function(e,a){var b,c,d={};if(a.dir==="h"){b=this._wijgrid.outerDiv.find(".wijmo-wijgrid-split-area-ne");c="scrollLeft"}else{b=this._wijgrid.outerDiv.find(".wijmo-wijgrid-split-area-sw");c="scrollTop"}if(a.animationOptions){d[c]=a.position;b.animate(d,a.animationOptions)}else b[0][c]=a.position},_onScrolled:function(){this._wijgrid.outerDiv.find(".wijmo-wijgrid-split-area-ne")[0].scrollLeft=parseInt((this._wijgrid.outerDiv.find(".wijmo-wijsuperpanel-templateouterwrapper").css("left")+"").replace("px",""),10)*-1;this._wijgrid.outerDiv.find(".wijmo-wijgrid-split-area-sw")[0].scrollTop=parseInt((this._wijgrid.outerDiv.find(".wijmo-wijsuperpanel-templateouterwrapper").css("top")+"").replace("px",""),10)*-1},_onMouseWheel:function(b,f){var d,g=f>0?"top":"bottom",c=false,e;if(this._wijgrid._canInteract()){d=this.getFixedAreaVisibleBounds(),a.each(d,function(e,d){if(d&&a.ui.isOver(b.pageY,b.pageX,d.top,d.left,d.height,d.width)){c=true;return false}});if(c&&this._scroller.data("wijsuperpanel")){e=this._scroller.wijsuperpanel("option","vScroller").scrollValue;this._scroller.wijsuperpanel("doScrolling",g);if(e!==this._scroller.wijsuperpanel("option","vScroller").scrollValue){b.stopPropagation();b.preventDefault()}}}},_testNeedVBar:function(h,i,n,d,k){var b,a=this._wijgrid,m=n.width()+a.options.splitDistanceX,f=i.height()+a.options.splitDistanceY,l=h.width(),j=h.height(),c,g=0,e=0;if(a.$superPanelHeader!==null)g=a.$superPanelHeader.outerHeight(true);if(a.$bottomPagerDiv!==null)e=a.$bottomPagerDiv.outerHeight(true);c=j-g-e;if(d==="both"||d==="vertical")b=true;else b=d==="auto"&&(f>c||!k&&m>l&&f>c-this._verScrollBarSize);return b},_updateSplitAreaBounds:function(g){var b=this._wijgrid,c=b.options,d,h,e=0,l=0,j=b.outerDiv.find(".wijmo-wijgrid-split-area-nw"),i=b.outerDiv.find(".wijmo-wijgrid-split-area-ne"),f=b.outerDiv.find(".wijmo-wijgrid-split-area-sw"),k=b.outerDiv.find(".wijmo-wijgrid-split-area-se");if(g===0||g===2){j.width(c.splitDistanceX);f.width(c.splitDistanceX);k.css("marginLeft",c.splitDistanceX);i.css("marginLeft",c.splitDistanceX)}if(g===1||g===2){this._scroller.css("height","");k.css("marginTop",0);d=b.outerDiv.height();if(!b._autoHeight)this._scroller.height(d);else this._scroller.height(d+c.splitDistanceY);j.height(c.splitDistanceY);i.height(c.splitDistanceY);if(b.$superPanelHeader!==null)e=b.$superPanelHeader.outerHeight(true);if(b.$bottomPagerDiv!==null)l=b.$bottomPagerDiv.outerHeight(true);h=d-e-l;b.$superPanelHeader!==null&&a.each([j,i],function(b,a){a.css("top",e+"px")});if(!b._autoHeight)f.height(h-c.splitDistanceY);else f.height(h);f.css("top",c.splitDistanceY+e);k.css("marginTop",c.splitDistanceY)}}})})(jQuery);(function(a){"use strict";a.wijmo.wijgrid.selection=function(b){var g=0,k,d=new a.wijmo.wijgrid.cellInfoOrderedCollection(b),c=new a.wijmo.wijgrid.cellInfoOrderedCollection(b),e=new a.wijmo.wijgrid.cellInfoOrderedCollection(b),f=new a.wijmo.wijgrid.cellInfoOrderedCollection(b),h=null,j=null,i={singlecell:[0,0,0],singlecolumn:[1,1,1],singlerow:[2,2,2],singlerange:[0,1,2],multicolumn:[1,1,1],multirow:[2,2,2],multirange:[0,1,2]};this.selectedCells=function(){return e};this.addColumns=function(b,a){if(!a&&a!==0)a=b;this.addRange(b,0,a,16777215)};this.addRange=function(c,f,e,g){if(!c&&arguments.length===1)throw"invalid argument";var d=arguments.length===4?new a.wijmo.wijgrid.cellInfoRange(new a.wijmo.wijgrid.cellInfo(c,f),new a.wijmo.wijgrid.cellInfo(e,g)):c._clone();d._normalize();if(!d._isValid())throw"invalid argument";this.beginUpdate();this._startNewTransaction(b._field("currentCell"));this._selectRange(d,false,true,0,null);this.endUpdate()};this.addRows=function(b,a){if(!a&&a!==0)a=b;this.addRange(0,b,16777215,a)};this.removeRange=function(c,f,e,g){if(!c&&arguments.length===1)throw"invalid argument";var d=arguments.length===4?new a.wijmo.wijgrid.cellInfoRange(new a.wijmo.wijgrid.cellInfo(c,f),new a.wijmo.wijgrid.cellInfo(e,g)):c._clone();d._normalize();if(!d._isValid())throw"invalid argument";this.beginUpdate();this._startNewTransaction(b._field("currentCell"));this._clearRange(d,0);this.endUpdate()};this.removeColumns=function(b,a){if(!a&&a!==0)a=b;this.removeRange(b,0,a,16777215)};this.removeRows=function(b,a){if(!a&&a!==0)a=b;this.removeRange(0,b,16777215,a)};this.addRows=function(b,a){if(!a&&a!==0)a=b;this.addRange(0,b,65535,a)};this.clear=function(){this.beginUpdate();c._clear();c._addFrom(e);this.endUpdate()};this.selectAll=function(){this.beginUpdate();this._selectRange(b._getDataCellsRange(),false,false,0,null);this.endUpdate()};this.beginUpdate=function(){g++};this.endUpdate=function(){if(g>0){g--;if(g===0){l();if(d.length()||c.length()){h!==null&&h.UnderlyingDataChanged();j!==null&&j.UnderlyingDataChanged();b._trigger("selectionChanged",null,{addedCells:d,removedCells:c})}d=new a.wijmo.wijgrid.cellInfoOrderedCollection(b);c._clear()}}};this._multipleRangesAllowed=function(){var a=b.options.selectionMode;return a&&((a=a.toLowerCase())==="multicolumn"||a==="multirow"||a==="multirange")};this._anchorCell=function(){return k};this._startNewTransaction=function(c){if(c){k=c._clone();f=new a.wijmo.wijgrid.cellInfoOrderedCollection(b)}};this._clearRange=function(g,l){var h=b.options.selectionMode.toLowerCase(),a,n,m,p,q,o,d,k,f,j=b._getDataCellsRange();if(g._isValid()&&h!=="none"&&e.length()>0){a=g._clone();a._normalize();a._clip(j);if(!g._isValid())return;a._extend(i[h][l],j);this.beginUpdate();for(d=0,k=e.length();d<k;d++){f=e.item(d);a._containsCellInfo(f)&&c._add(f)}this.endUpdate()}};this._selectRange=function(k,n,j,l,g){var e=b.options.selectionMode.toLowerCase(),d,h=b._getDataCellsRange();if(e!=="none"&&k._isValid()){d=k._clone();d._normalize();d._clip(h);if(!d._isValid())return;this.beginUpdate();if(!this._multipleRangesAllowed())this.clear();else if(n||j){if(j){c._clear();c._addFrom(f)}}else this.clear();switch(e){case"singlecell":case"singlecolumn":case"singlerow":d=g===null?new a.wijmo.wijgrid.cellInfoRange(d.topLeft(),d.topLeft()):new a.wijmo.wijgrid.cellInfoRange(g,g)}d._extend(i[e][l],h);m(d,true);this.endUpdate()}};function l(){var r=b._getDataToAbsOffset(),p=r.x,q=r.y,s=b._view(),h,k,g,j,i,o,t=a.wijmo.wijgrid.renderState,m,n,l=-1;for(h=0,k=c.length();h<k;h++){g=c.item(h);if(d.indexOf(g)<0){j=s.getCell(g.cellIndex()+p,g.rowIndex()+q);if(j){if(l!==g.rowIndex()){m=b._createRowInfo(g._row());l=g.rowIndex()}i=a(j);n=b._changeRenderState(i,t.selected,false);b.cellStyleFormatter.format(i,g.cellIndex(),g.column(),m,n)}e._remove(g);f._remove(g)}else{c._removeAt(h);h--;k--}}l=-1;for(h=0,k=d.length();h<k;h++){g=d.item(h);o=e.indexOf(g);if(o<0){j=s.getCell(g.cellIndex()+p,g.rowIndex()+q);if(j){if(l!==g.rowIndex()){m=b._createRowInfo(g._row());l=g.rowIndex()}i=a(j);n=b._changeRenderState(i,t.selected,true);b.cellStyleFormatter.format(i,g.cellIndex(),g.column(),m,n)}e._insertUnsafe(g,~o);f._add(g)}else{d._removeAt(h);h--;k--}}}function m(h,n){var j=h.topLeft().cellIndex(),l=h.topLeft().rowIndex(),k=h.bottomRight().cellIndex(),m=h.bottomRight().rowIndex(),i,e,f,g;if(n){i=d.length();for(e=l;e<=m;e++)if(b.dataTable[e].rowType&a.wijmo.wijgrid.rowType.data)for(f=j;f<=k;f++){g=new a.wijmo.wijgrid.cellInfo(f,e);if(i===0)d._appendUnsafe(g);else d._add(g)}}else{i=c.length();for(e=l;e<=m;e++)for(f=j;f<=k;f++){g=new a.wijmo.wijgrid.cellInfo(f,e);if(i===0)c._appendUnsafe(g);else c._add(g)}}}};a.wijmo.wijgrid.cellInfoOrderedCollection=function(c){if(!c)throw"argument is null";var b=[];this.item=function(a){return b[a]};this.length=function(){return b.length};this.indexOf=function(e,h){if(arguments.length===1){h=e.rowIndex();e=e.cellIndex()}var d=0,g=b.length-1,c,f,a;while(d<=g){c=d+(g-d>>1);f=b[c];a=f.rowIndex()-h;if(a===0)a=f.cellIndex()-e;if(a<0)d=c+1;else if(a>0)g=c-1;else return c}return~d};this.toString=function(){var d="",a,c;for(a=0,c=b.length;a<c;a++)d+=b[a].toString()+"\n";return d};this._add=function(a){var d=this.indexOf(a);if(d<0){b.splice(~d,0,a);a._setGridView(c);return true}return false};this._addFrom=function(d){if(d){var e=d.length(),f=b.length,a;if(f===0){b.length=e;for(a=0;a<e;a++){b[a]=d.item(a);b[a]._setGridView(c)}}else for(a=0;a<e;a++)this._add(d.item(a))}};this._appendUnsafe=function(a){b[b.length]=a;a._setGridView(c)};this._insertUnsafe=function(c,a){b.splice(a,0,c)};this._clear=function(){b.length=0};this._remove=function(c){var a=this.indexOf(c);if(a>=0){b.splice(a,1);return true}return false};this._removeAt=function(a){b.splice(a,1)};this._getColumnsIndicies=function(){var e=[],d=b.length,c,a,f;if(d){c=[];for(a=0;a<d;a++)c[b[a].cellIndex()]=1;d=c.length;f=0;for(a=0;a<d;a++)if(c[a])e[f++]=a}return e};this._getSelectedRowsIndicies=function(){var f=[],d=b.length,c,a,e;if(d){c=[];for(a=0;a<d;a++)c[b[a].rowIndex()]=1;d=c.length;e=0;for(a=0;a<d;a++)if(c[a])f[e++]=a}return f};this._rectangulate=function(){var i=b.length,e=4294967295,g=4294967295,f=0,h=0,d,c;if(i){for(d=0;d<i;d++){c=b[d];e=Math.min(e,c.cellIndex());g=Math.min(g,c.rowIndex());f=Math.max(f,c.cellIndex());h=Math.max(h,c.rowIndex())}return new a.wijmo.wijgrid.cellInfoRange(new a.wijmo.wijgrid.cellInfo(e,g),new a.wijmo.wijgrid.cellInfo(f,h))}return null}}})(jQuery);(function(a){"use strict";a.extend(a.wijmo.wijgrid,{selectionui:function(b){var q=10,u="{0}."+b.widgetName+".selectionui",c=new a.wijmo.wijgrid.cellInfoOrderedCollection(b),k,f,h,e,i=false,j=false,d=b._view(),t=b._field("visibleLeaves").length,r=d.focusableElement();r.bind(g("mousedown"),p);this.dispose=function(){r.unbind(g("mousedown"),p);l()};function p(e){if(!b._canInteract()||b.options.selectionMode.toLowerCase()==="none")return;var c=d.getVisibleAreaBounds(),g={x:e.pageX,y:e.pageY},i=e.target&&e.target.tagName!==undefined?e.target.tagName.toLowerCase():undefined,h=a(e.target);if((!i||h.is("td.wijgridtd, th.wijgridtd, div.wijmo-wijgrid-innercell"))&&g.x>c.left&&g.x<c.left+c.width&&g.y>c.top&&g.y<c.top+c.height){s();k=g;f=m(k)}}function n(B){if(!f||!f._isValid())return;var x={x:B.pageX,y:B.pageY},y,j,s,r,A,z,u,l,n,t,g,p,v,o,w,C=a.wijmo.wijgrid.renderState;if(!i)i=Math.abs(k.x-x.x)>q||Math.abs(k.y-x.y)>q;if(i){y=m(x);if(!y._isValid())return;h=y;j=new a.wijmo.wijgrid.cellInfoRange(f,h);j._normalize();j._clip(b._getDataCellsRange());if(j._isValid()&&!j.isEqual(e)){s=b._getDataToAbsOffset();e=j;r=new a.wijmo.wijgrid.cellInfoOrderedCollection(b);A=j.bottomRight().rowIndex();z=j.bottomRight().cellIndex();for(u=j.topLeft().rowIndex();u<=A;u++)if(b.dataTable[u].rowType&a.wijmo.wijgrid.rowType.data)for(l=j.topLeft().cellIndex();l<=z;l++)r._appendUnsafe(new a.wijmo.wijgrid.cellInfo(l,u));o=-1;for(n=0,t=c.length();n<t;n++){g=c.item(n);if(r.indexOf(g)<0){if(b.selection().selectedCells().indexOf(g)<0){l=d.getCell(g.cellIndex()+s.x,g.rowIndex()+s.y);if(l){if(o!==g.rowIndex()){v=b._createRowInfo(g._row());o=g.rowIndex()}p=a(l);w=b._changeRenderState(p,C.selected,false);b.cellStyleFormatter.format(p,g.cellIndex(),g.column(),v,w)}}c._removeAt(n);n--;t--}}o=-1;for(n=0,t=r.length();n<t;n++){g=r.item(n);if(c.indexOf(g)<0&&b.selection().selectedCells().indexOf(g)<0)if(c._add(g)){l=d.getCell(g.cellIndex()+s.x,g.rowIndex()+s.y);if(l){if(o!==g.rowIndex()){v=b._createRowInfo(g._row());o=g.rowIndex()}p=a(l);w=b._changeRenderState(p,C.selected,true);b.cellStyleFormatter.format(p,g.cellIndex(),g.column(),v,w)}}}}}}function o(k){l();if(i){i=false;if(e&&e._isValid()){b._changeCurrentCell(h);(!k.shiftKey||!b.selection()._multipleRangesAllowed()&&b.options.selectionMode.toLowerCase()!=="singleRange")&&b.selection()._startNewTransaction(f);b.selection().beginUpdate();b.selection()._selectRange(e,k.shiftKey,k.ctrlKey,0,h);b.selection().endUpdate();var s=b._view(),o=b._getDataToAbsOffset(),g,r,d,m,j,n=-1,p,q,t=a.wijmo.wijgrid.renderState;for(g=0,r=c.length();g<r;g++){d=c.item(g);if(b.selection().selectedCells().indexOf(d)<0){m=s.getCell(d.cellIndex()+o.x,d.rowIndex()+o.y);if(m!==null){if(n!==d.rowIndex()){p=b._createRowInfo(d._row());n=d.rowIndex()}j=a(m);q=b._changeRenderState(j,t.selected,false);b.cellStyleFormatter.format(j,d.cellIndex(),d.column(),p,q)}}}c._clear();f=h=e=null;return false}}}function s(){if(!j)try{a(document).bind(g("mousemove"),n).bind(g("mouseup"),o)}finally{j=true}}function l(){if(j)try{a(document).unbind(g("mousemove"),n).unbind(g("mouseup"),o)}finally{j=false}}function g(b){return a.wijmo.wijgrid.stringFormat(u,b)}function m(k){var f=0,g=t-1,c=0,m=-1,e,h=new a.wijmo.wijgrid.rowAccessor(d,2,0,0),i,j,l,n;while(f<=g){c=(g-f>>1)+f;e=a.wijmo.wijgrid.bounds(d.getHeaderCell(c));if(!e){j=h.item(0);e=a.wijmo.wijgrid.bounds(h.getCell(j,c))}if(!e)break;if(k.x<e.left)g=c-1;else if(k.x>e.left+e.width)f=c+1;else{m=c;break}}if(m===-1)return a.wijmo.wijgrid.cellInfo.prototype.outsideValue;h=new a.wijmo.wijgrid.rowAccessor(d,0,0,0);i=-1;f=0;g=h.length()-1;c=0;while(f<=g){c=(g-f>>1)+f;j=h.item(c);e=a.wijmo.wijgrid.bounds(h.getCell(j,0));if(k.y<e.top)g=c-1;else if(k.y>e.top+e.height)f=c+1;else{i=c;break}}if(i===-1)return a.wijmo.wijgrid.cellInfo.prototype.outsideValue;l=b._getDataToAbsOffset();n=new a.wijmo.wijgrid.cellInfo(m-l.x,i-l.y);n._clip(b._getDataCellsRange());return n}}})})(jQuery);(function(a){"use strict";a.wijmo.wijgrid.rowAccessor=function(d,c,a,b){if(!a)a=0;if(!b)b=0;this.item=function(b){var e=this.length();return b<e?d.getJoinedRows(b+a,c):null};this.length=function(){var g=d.getJoinedTables(true,0),e=0,f;if(f=g[0])e=f.getSectionLength(c);if(f=g[1])e+=f.getSectionLength(c);e-=a+b;if(e<0)e=0;return e};this.iterateCells=function(d,e,j){if(d&&e){var i=0,b,h,a,c,f,g;for(b=0,h=d.length;b<h;b++){a=d[b];if(a)for(c=0,f=a.cells.length;c<f;c++){g=e(a.cells[c],i++,j);if(g!==true)return}}}};this.getCell=function(d,b){var a,c;if(d&&(a=d[0])){c=a.cells.length;if(b<c)return a.cells[b];b-=c;if(a=d[1]){c=a.cells.length;if(b<c)return a.cells[b]}}return null};this.cellsCount=function(b){var c=0,a;if(b&&(a=b[0])){c=a.cells.Length;if(a=b[1])c+=a.cells.Length}return c}}})(jQuery);(function(a){"use strict";a.extend(a.wijmo.wijgrid,{cellEditorHelper:function(){this.currentCellEditStart=function(e,j){var g=false,b=e.currentCell(),d,h,f,i;if(b._isValid()&&!b._isEdit()&&b.column().dataIndex>=0){d=b._row();if(d&&d.length){i=a.wijmo.wijgrid.dataPrefix(d[0],e._data$prefix,"rowType");if(i&a.wijmo.wijgrid.rowType.data){h={cell:b,event:j,handled:false};if(g=e._trigger("beforeCellEdit",null,h))if(!h.handled)g=c(e,h);if(g){b._isEdit(true);if(e.options.showRowHeader){f=a(d[0].cells[0]).children("div.wijmo-wijgrid-innercell");if(f.length){f.empty();f.append(a("<div>&nbsp;</div>").addClass("ui-icon ui-icon-pencil"))}}}}}}return g};this.currentCellEditEnd=function(f,j){var b=f.currentCell(),g=false,h,l,k,c,i,m,n;if(!b._isValid()||!b._isEdit())return;h=b._row();if(h&&h.length){l=a.wijmo.wijgrid.dataPrefix(h[0],f._data$prefix,"rowType");if(!(l&a.wijmo.wijgrid.rowType.data))return g;k=j&&j.which===a.ui.keyCode.ESCAPE;if(!j||!k){c={cell:b,value:undefined};if(g=f._trigger("beforeCellUpdate",null,c)){if(c.value===undefined)c.value=e(f,b);i=false;if(c.cell.column().dataType==="datetime"){m=c.value?c.value.getTime():null;n=b.value()?b.value().getTime():null;i=m!==n}else i=c.value!==b.value();if(i){try{b.value(c.value)}catch(o){g=false;f._trigger("invalidCellValue",null,{cell:b,value:c.value})}g&&f._trigger("afterCellUpdate",null,{cell:b})}}}else g=true;if(g){c={cell:b,event:j,handled:false};f._trigger("afterCellEdit",null,c);if(!c.handled)g=d(f,c);g&&b._isEdit(false);f.options.showRowHeader&&a(h[0].cells[0]).children("div.wijmo-wijgrid-innercell").html("&nbsp;");window.setTimeout(function(){if(!f.destroyed){f.element.focus();a(f._view().focusableElement()).focus();b.tableCell().focus()}},50)}}return g};function c(k,d){var j=d.cell.column(),h=false,f,g,c,i,e;if(j.dataIndex>=0){f=d.cell.value();h=true;try{g=d.cell.container();if(j.dataType==="boolean"){c=g.children("input");c.focus();if(d.event&&d.event.type==="keypress")c.one("keyup",function(b){if(b.which===a.ui.keyCode.SPACE){b.preventDefault();c[0].checked=!f}})}else{c=a("<input />").attr("type","text").addClass("wijgridinput wijmo-wijinput ui-state-focus").bind("keydown",k,b);c.bind(a.support.selectstart?"selectstart":"mousedown",function(a){a.stopPropagation()});if(d.event&&d.event.type==="keypress"&&d.event.which)c.val(String.fromCharCode(d.event.which));else switch(d.cell.column().dataType){case"currency":case"number":if(f!==null){c.val(f);break}default:c.val(k._toStr(d.cell.column(),f))}g.empty().append(c);i=c.val().length;new a.wijmo.wijgrid.domSelection(c[0]).setSelection({start:i,end:i});c.focus();a.browser.msie&&setTimeout(function(){c.focus()},0);if(a.browser.mozilla&&document.createEvent&&c[0].dispatchEvent){e=document.createEvent("KeyboardEvent");e.initKeyEvent("keypress",false,true,null,false,false,false,false,0,a.ui.keyCode.SPACE);c[0].dispatchEvent(e);e=document.createEvent("KeyboardEvent");e.initKeyEvent("keypress",false,true,null,false,false,false,false,a.ui.keyCode.BACKSPACE,0);c[0].dispatchEvent(e)}}}catch(l){alert(l.message);h=false}}return h}function d(c,b){var a=b.cell.column(),g=false,d,e,f,i,h;if(a.dataIndex>=0){g=true;try{d=b.cell.container();e=c._toStr(a,b.cell.value());f=c.dataTable[b.cell.rowIndex()];i=c.data()[f.originalRowIndex];if(a.dataType==="boolean"){h=d.children("input");if(e==="true")h.attr("checked","checked");else h.removeAttr("checked")}else c.cellFormatter.format(d,a,e,f.rowType,i)}catch(j){alert("defaultAfterCellEdit: "+j.message);g=false}}return g}function b(b){if(b.which===a.ui.keyCode.ENTER){var c=b.data;if(c){c._endEditInternal(b);return false}}}function e(d,c){var a=c.container().find(":input:first"),b=null;if(a.length){b=a.attr("type")==="checkbox"?a[0].checked:a.val();b=d._parse(c.column(),b)}return b}}})})(jQuery);(function(a){"use strict";a.extend(a.wijmo.wijgrid,{resizer:function(h){var i=[],t=10,s=1,v="{0}."+h.widgetName+".resizer",e=false,b=null,r,f=null,d=null,g=null;this.addElement=function(a){if(a&&a.element){a.element.bind(c("mousemove"),q).bind(c("mousedown"),p).bind(c("mouseout"),j);i.push(a)}};this.dispose=function(){a.each(i,function(b,a){a.element.unbind(c("mousemove"),q).unbind(c("mousedown"),p).unbind(c("mouseout"),j)});m()};this.inProgress=function(){return e};function q(c){if(!e){var a=o({x:c.pageX,y:c.pageY});if(a&&a._canSize()&&h._canInteract()){a.element.css("cursor","e-resize");b=a;c.stopPropagation()}else j(c)}}function j(){if(!e)if(b){b.element.css("cursor","");b=null}}function p(c){b=o({x:c.pageX,y:c.pageY});if(b&&b._canSize()&&h._canInteract())try{b.element.css("cursor","");r=document.body.style.cursor;document.body.style.cursor="e-resize";f=d=a.wijmo.wijgrid.bounds(b.element);g=a('<div class="wijmo-wijgrid-resizehandle ui-state-highlight">&nbsp;</div>');var i=h._view().getVisibleAreaBounds();g.css({left:c.pageX,top:f.top,height:i.height+i.top-f.top});a(document.body).append(g)}finally{u();e=true;c.stopPropagation()}}function k(a){var b=s*Math.round((a.pageX-d.left)/s);d={left:d.left+b,top:a.pageY};g.css("left",d.left)}function l(){try{document.body.style.cursor=r;g.remove();f!==d&&h._fieldResized(b,f.width,d.left-f.left)}finally{b=null;g=null;m();e=false}}function n(a){a.preventDefault()}function u(){if(!e){a(document).bind(c("mousemove"),k).bind(c("mouseup"),l);a(document.body).disableSelection();a.browser.msie&&a(document.body).bind("selectstart",n)}}function m(){if(e){a(document).unbind(c("mousemove"),k).unbind(c("mouseup"),l);a(document.body).enableSelection();a.browser.msie&&a(document.body).unbind("selectstart",n)}}function o(e){var c,f,d,b,g;for(c=0,f=i.length;c<f;c++){d=i[c];b=a.wijmo.wijgrid.bounds(d.element);g=a.ui.isOver(e.y,e.x,b.top,b.left+b.width-t,b.height,t);if(g)return d}return null}function c(b){return a.wijmo.wijgrid.stringFormat(v,b)}}})})(jQuery);(function(a){"use strict";a.extend(a.wijmo.wijgrid,{frozener:function(b){var s,r,z,y,F="{0}."+b.widgetName+".frozener",d=false,x,f=null,e=null,h=null,g=null,n=a('<div class="wijmo-wijgrid-frozener-v ui-widget-header"></div>'),m=a('<div class="wijmo-wijgrid-frozener-h ui-widget-header"></div>'),k=null,j=null,c=b.outerDiv.find(".wijmo-wijgrid-fixedview"),l=10;this.refresh=function(){this.dispose();this.addVElement(b._getStaticIndex(false));this.addHElement(b._getStaticIndex(true));this.attachDivEvent()};this.attachDivEvent=function(){c.bind("mousemove",u).bind("mouseout",q).bind("mousedown",t)};this.addVElement=function(h){var e=a.wijmo.wijgrid.bounds(c.find(".wijmo-wijgrid-split-area-nw")),f=a.wijmo.wijgrid.bounds(c),d=b._view().getVisibleAreaBounds(),g=e.left+e.width;if(g<=d.left+d.width){n.css({left:g-f.left-1,top:e.top-f.top,width:"0px",height:d.height+d.top-e.top}).appendTo(c);s=b._getRealStaticColumnIndex(true);z=h}};this.addHElement=function(h){var e=a.wijmo.wijgrid.bounds(c.find(".wijmo-wijgrid-split-area-nw")),f=a.wijmo.wijgrid.bounds(c),d=b._view().getVisibleAreaBounds(),g=e.top+e.height;if(g<=d.top+d.height){m.css({left:e.left-f.left,top:g-f.top-1,width:d.width+d.left-e.left,height:"0px"}).appendTo(c);r=b._getRealStaticRowIndex(true);y=h}};this.dispose=function(){n.remove();m.remove();c.unbind("mousemove",u).unbind("mouseout",q).unbind("mousedown",t);v()};this.inProgress=function(){return d};function u(f){var e,h,g=b._view().getVisibleAreaBounds();if(!d)if(b._canInteract()&&a.ui.isOver(f.pageY,f.pageX,g.top,g.left,g.height,g.width)){e=a.wijmo.wijgrid.bounds(n);h=e.left+e.width/2;if(Math.abs(f.pageX-h)<l){c.css("cursor","pointer");return}e=a.wijmo.wijgrid.bounds(m);h=e.top+e.height/2;if(Math.abs(f.pageY-h)<l){c.css("cursor","pointer");return}q(f)}}function q(){!d&&c.css("cursor","")}function t(i){var o,q,t,p=b._view().getVisibleAreaBounds();if(b._canInteract()&&a.ui.isOver(i.pageY,i.pageX,p.top,p.left,p.height,p.width)){o=a.wijmo.wijgrid.bounds(n);q=o.left+o.width/2;if(Math.abs(i.pageX-q)<l){if(z===-1)f=h=-1;else f=h=b._getRealStaticColumnIndex()-s;k=a('<div class="wijmo-wijgrid-resizehandle ui-widget-header"></div>');i.data={bVertical:true};a(document.body).append(k)}else{o=a.wijmo.wijgrid.bounds(m);q=o.top+o.height/2;if(Math.abs(i.pageY-q)<l){if(y===-1)e=g=-1;else e=g=b._getRealStaticRowIndex()-r;j=a('<div class="wijmo-wijgrid-resizehandle ui-widget-header"></div>');i.data={bVertical:false};a(document.body).append(j)}}if(i.data){c.css("cursor","");x=document.body.style.cursor;document.body.style.cursor="pointer";B(i.data);d=true}}}function o(c){var a=b._view()._getSuperPanel();if(c.data.bVertical&&a.options.hScroller.scrollValue)a.hScrollTo(0);else!c.data.bVertical&&a.options.vScroller.scrollValue&&a.vScrollTo(0);G(c)}function p(a){try{document.body.style.cursor=x;if(a.data.bVertical){k.remove();f!==h&&b.option("staticColumnIndex",h)}else{j.remove();e!==g&&b.option("staticRowIndex",g)}}finally{if(a.data.bVertical)k=null;else j=null;v();d=false}}function w(a){a.preventDefault()}function B(b){if(!d){if(b.bVertical)a(document).bind(i("mousemove"),{bVertical:true},o).bind(i("mouseup"),{bVertical:true},p);else a(document).bind(i("mousemove"),{bVertical:false},o).bind(i("mouseup"),{bVertical:false},p);a(document.body).disableSelection();a.browser.msie&&a(document.body).bind("selectstart",w)}}function v(){if(d){a(document).unbind(i("mousemove"),o).unbind(i("mouseup"),p);a(document.body).enableSelection();a.browser.msie&&a(document.body).unbind("selectstart",w)}}function G(d){var i,c,p,t,q,u,v,w,o=b._view().getVisibleAreaBounds();if(d.data.bVertical){c=a.wijmo.wijgrid.bounds(n);p=c.left+c.width/2;if(Math.abs(d.pageX-p)<l){h=f;k.hide();return}i=D({x:d.pageX,y:d.pageY});if(i){c=a.wijmo.wijgrid.bounds(i.element);p=c.left+c.width/2;q=i.options.visLeavesIdx-s;u=A(q);t=d.pageX<p?u!==f:q===f;v=t?c.left:c.left+c.width;if(!a.ui.isOverAxis(v,o.left-1,o.width+2))return;h=t?u:q;k.show().css({left:v,top:c.top,width:3,height:o.height+o.top-c.top})}}else{c=a.wijmo.wijgrid.bounds(m);p=c.top+c.height/2;if(Math.abs(d.pageY-p)<l){g=e;j.hide();return}i=E({x:d.pageX,y:d.pageY});if(i){c=a.wijmo.wijgrid.bounds(i);p=c.top+c.height/2;q=b._view().getAbsoluteRowIndex(i)-r;u=C(q);t=d.pageY<p?u!==e:q===e;w=t?c.top:c.top+c.height;if(!a.ui.isOverAxis(w,o.top-1,o.height+2))return;g=t?u:q;j.show().css({left:c.left,top:w,width:o.width+o.left-c.left,height:3})}}}function A(a){return a>-1?a-1:-1}function C(a){return a>-1?a-1:-1}function D(i){for(var g=b.columns(),f=0,j=g.length,c,d,e,h;f<j;f++){c=g[f];d=c.options;if(d.visible&&d.parentVis&&d.isLeaf){e=a.wijmo.wijgrid.bounds(c.element);h=a.ui.isOverAxis(i.x,e.left,e.width);if(h)return c}}return null}function E(i){for(var f=b._rows(),h=f.length(),d=0,e,c,g;d<h;d++){e=f.item(d)[0];c=a.wijmo.wijgrid.bounds(a(e));g=a.ui.isOverAxis(i.y,c.top,c.height);if(g)return e}return null}function i(b){return a.wijmo.wijgrid.stringFormat(F,b)}}})})(jQuery);(function(a){"use strict";a.extend(a.wijmo.wijgrid,{cellFormatterHelper:function(){this.format=function(j,b,g,i){if(i.type&a.wijmo.wijgrid.rowType.footer)if(b.aggregate&&b.aggregate!=="none")g=a.wijmo.wijgrid.stringFormat(b.footerText||"{0}",b._totalsValue||"");else g=b.footerText||b._footerTextDOM||"";var h=true,f=null,e={$container:j,column:b,formattedValue:g,row:i,afterDefaultCallback:null};if(a.isFunction(b.cellFormatter))h=!b.cellFormatter(e);if(h){switch(b.dataType){case"boolean":f=c;break;default:f=d}if(f){f(e);a.isFunction(e.afterDefaultCallback)&&e.afterDefaultCallback(e)}}};function d(c){switch(c.row.type){case a.wijmo.wijgrid.rowType.filter:b(c);break;default:c.$container.html(c.formattedValue?c.formattedValue:"&nbsp;")}}function c(c){var d,g,i="disabled='disabled'",f,h,e=a.wijmo.wijgrid.rowType;switch(c.row.type){case e.data:case e.data|e.dataAlt:d=c.column.owner;g=d.options.allowEditing&&c.column.readOnly!==true;if(g)i="";if(d._parse(c.column,c.row.data[c.column.dataKey])===true)c.$container.html("<input class='wijgridinput' type='checkbox' checked='checked' "+i+" />");else c.$container.html("<input class='wijgridinput' type='checkbox' "+i+" />");g&&c.$container.children("input").bind("mousedown",function(){f=c.$container.parent()[0];h=d.currentCell();h.tableCell()!==f&&d._onClick({target:f});!h._isEdit()&&d.beginEdit()}).bind("keydown",function(b){if(b.which===a.ui.keyCode.ENTER){d._endEditInternal(b);return false}});break;case e.filter:b(c)}}function b(a){if(a.column.dataIndex>=0&&!a.column.isBand&&a.column.showFilter)a.$container.html('<div class="wijmo-wijgrid-filter ui-widget ui-state-default ui-corner-all"><input type="text" class="wijmo-wijgrid-filter-input" style="width:1px" /><a class="wijmo-wijgrid-filter-trigger ui-corner-right ui-state-default" href="#"><span class="ui-icon ui-icon-triangle-1-s"></span></a></div>');else a.$container.html("&nbsp;")}}})})(jQuery);(function(a){"use strict";a.extend(a.wijmo.wijgrid,{dragAndDropHelper:function(c){var i="scope_"+ +new Date,d=null,e=null,b=null,g=false,h,p='<div class="ui-widget wijmo-wijgrid ui-widget-content ui-corner-all"><table class="wijmo-wijgrid-root wijmo-wijgrid-table"><tr class="wijmo-wijgrid-headerrow"></tr></table></div>';this.attachGroupArea=function(e){var d;e.droppable({scope:i,tolerance:"pointer",greedy:true,accept:function(b){if(c.options.allowColMoving){d=f(b);if(d)return d instanceof a.wijmo.c1groupedfield&&d.options.groupedIndex===c._field("groupedColumns").length-1?false:!d.options.isBand&&(d.options.groupedIndex===undefined||d instanceof a.wijmo.c1groupedfield)}return false},drop:function(b,a){if(!l(b,a.draggable)&&(d=f(a.draggable)))g=true},over:function(){var a=c._field("groupedWidgets").length;h=a>0;b=a>0?c._field("groupedWidgets")[a-1]:e;e.data("thisDroppableWijField",b)},out:function(){if(b===e.data("thisDroppableWijField"))b=null}})};this.attach=function(d){var e,j;if(!d||!(e=d.element))return;e.draggable({helper:function(){return d instanceof a.wijmo.c1groupedfield?e.clone().addClass("wijmo-wijgrid-dnd-helper"):e.clone().wrap(p).width(e.width()).height(e.height()).closest(".wijmo-wijgrid").addClass("wijmo-wijgrid-dnd-helper")},appendTo:"body",scope:i,drag:function(c,f){m();if(b&&!l(c,e)){var a=b.element;if(!a)a=b;o(a,k(d,b,c,f))}},start:function(){if(c._canInteract()&&c.options.allowColMoving&&!c._field("resizer").inProgress()){var b=d.options,g=d.options.travIdx,e=d instanceof a.wijmo.c1groupedfield,f=e?"groupArea":"columns";if(e){b=a.wijmo.wijgrid.search(c.columns(),function(a){return a.options.travIdx===g});b=!b.found?a.wijmo.wijgrid.getColumnByTravIdx(c.options.columns,g).found:b.found.options}if(d._canDrag()&&c._trigger("columnDragging",null,{drag:b,dragSource:f})){c._trigger("columnDragged",null,{drag:b,dragSource:f});return true}}return false},stop:function(f,e){m();try{if(g)if(!b.element)c._handleDragnDrop(d.options.travIdx,-1,"left",d instanceof a.wijmo.c1groupedfield,true);else c._handleDragnDrop(d.options.travIdx,b.options.travIdx,k(d,b,f,e),d instanceof a.wijmo.c1groupedfield,b instanceof a.wijmo.c1groupedfield)}finally{b=null;g=false}}}).droppable({hoverClass:"ui-state-hover",scope:i,tolerance:"pointer",greedy:true,accept:function(a){if(c.options.allowColMoving)if(e[0]!==a[0]){j=f(a);if(j)return j._canDropTo(d)}return false},drop:function(b,a){if(j=f(a.draggable))g=true},over:function(){h=false;b=d;e.data("thisDroppableWijField",b)},out:function(){if(b===d.element.data("thisDroppableWijField"))b=null}})};this.detach=function(b){var a;if(b&&(a=b.element)){a.data("draggable")&&a.draggable("destroy");a.data("droppable")&&a.droppable("destroy")}};this.dispose=function(){if(e){e.remove();e=null}if(d){d.remove();d=null}};function f(b){var c=b.data(a.wijmo.c1basefield.prototype._data$prefix+"widgetName");return!c?b.data(a.wijmo.c1groupedfield.prototype._data$prefix):b.data(c)}function o(a,b){n().show().position({my:"center",at:b+" top",of:a});j().show().position({my:"center",at:b+" bottom",of:a})}function m(){n().hide();j().hide()}function n(){if(!e)e=a("<div />").addClass("wijmo-wijgrid-dnd-arrow-top").append(a("<span />").addClass("ui-icon ui-icon-arrowthick-1-s")).hide().appendTo(document.body);return e}function j(){if(!d)d=a("<div />").addClass("wijmo-wijgrid-dnd-arrow-bottom").append(a("<span />").addClass("ui-icon ui-icon-arrowthick-1-n")).hide().appendTo(document.body);return d}function l(c,d){var b=a.wijmo.wijgrid.bounds(d,false);return c.pageX>b.left&&c.pageX<b.left+b.width&&c.pageY>b.top&&c.pageY<b.top+b.height}function k(e,b,i){if(!b.element)return"left";if(h)return"right";var f=a.wijmo.wijgrid.bounds(b.element,false),j=f.width/6,g=f.left+f.width/2,d="right",c;if(i.pageX<g)d="left";if(b instanceof a.wijmo.c1groupedfield){if(e instanceof a.wijmo.c1groupedfield){c=b.options.groupedIndex-e.options.groupedIndex;if(Math.abs(c)===1)d=c<0?"left":"right"}return d}c=b.options.linearIdx-e.options.linearIdx;if(b.options.isBand&&e.options.parentIdx!==b.options.travIdx&&Math.abs(i.pageX-g)<j)return"center";if(e.options.parentIdx===b.options.parentIdx&&Math.abs(c)===1)d=c<0?"left":"right";return d}}})})(jQuery);(function(a){"use strict";a.extend(a.wijmo.wijgrid,{cellStyleFormatterHelper:function(b){if(!b)throw"invalid arguments";this.format=function(q,l,i,m,j,h,p){var k=a.wijmo.wijgrid.renderState,o=a.wijmo.wijgrid.rowType,n=m.type,f,g=null;if(l===0&&b.options.showRowHeader)i=null;if(n===o.groupHeader||n===o.groupFooter){i=null;if(h&&(g=h.groupInfo)){i=b._field("leaves")[g.leafIndex];delete h.groupInfo}}f={$cell:q,state:j,row:m,column:i,_cellIndex:l,_purpose:g?g.purpose:undefined};if(j===k.rendering)c(f,h,p);else{e(f,j&k.current);d(f,j&k.selected)}a.isFunction(b.options.cellStyleFormatter)&&b.options.cellStyleFormatter(f)};function c(c,i,h){var f=a.wijmo.wijgrid.rowType,d,j,e=c.column,g=c.row.type;if(g!==f.header&&g!==f.filter)c.$cell.addClass("wijgridtd");else g===f.header&&c.$cell.addClass("wijgridth");if(i)for(d in i)if(i.hasOwnProperty(d)){j=i[d];if((d==="colSpan"||d==="rowSpan")&&!(j>1))continue;if(d==="class")c.$cell.addClass(j);else c.$cell.attr(d,j)}if(h)for(d in h)if(h.hasOwnProperty(d)){if(d==="paddingLeft"){c.$cell.children(".wijmo-wijgrid-innercell").css(d,h[d]);continue}c.$cell.css(d,h[d])}if(c._cellIndex===0&&b.options.showRowHeader)c.$cell.attr({role:"rowheader",scope:"row"}).addClass("ui-state-default ui-widget-content wijmo-wijgrid-rowheader");else switch(g){case f.header:c.$cell.attr({role:"columnheader",scope:"col"});break;case f.footer:c.$cell.attr({role:"columnfooter",scope:"col"});break;default:c.$cell.attr("role","gridcell")}if(g&f.data)if(c._cellIndex>=0&&e&&e.dataParser){c.$cell.attr("headers",escape(e.headerText));e.readOnly&&c.$cell.attr("aria-readonly",true);e.dataIndex>=0&&c.$cell.addClass("wijdata-type-"+(e.dataType||"string"))}if(g===f.groupHeader||g===f.groupFooter)e&&c._purpose===a.wijmo.wijgrid.groupRowCellPurpose.aggregateCell&&c.$cell.addClass("wijdata-type-"+(e.dataType||"string"))}function e(b,d){var c=a.wijmo.wijgrid.rowType;if(d){b.$cell.addClass("ui-state-active");if(b.row.type===c.header)b.$cell.addClass("wijmo-wijgrid-current-headercell");else b.$cell.addClass("wijmo-wijgrid-current-cell")}else{b.$cell.removeClass("ui-state-active");if(b.row.type===c.header)b.$cell.removeClass("wijmo-wijgrid-current-headercell");else b.$cell.removeClass("wijmo-wijgrid-current-cell")}}function d(a,b){if(b)a.$cell.addClass("ui-state-highlight").attr("aria-selected","true");else a.$cell.removeClass("ui-state-highlight").removeAttr("aria-selected")}}})})(jQuery);(function(a){"use strict";a.extend(a.wijmo.wijgrid,{rowStyleFormatterHelper:function(b){if(!b)throw"invalid arguments";this.format=function(j,l,k){var i=a.wijmo.wijgrid.renderState,h=j.state,g=j;if(h===i.rendering)c(g,l,k);else{e(g,h&i.current);f(g,h&i.hovered);d(g,h&i.selected)}a.isFunction(b.options.rowStyleFormatter)&&b.options.rowStyleFormatter(g)};function c(e,f,h){var c="wijmo-wijgrid-row ui-widget-content",g="wijmo-wijgrid-row ui-widget-content",d=a.wijmo.wijgrid.rowType,b;e.$rows.attr("role","row");if(f)for(b in f)if(f.hasOwnProperty(b))if(b==="class")e.$rows.addClass(f[b]);else e.$rows.attr(b,f[b]);if(h)for(b in h)h.hasOwnProperty(b)&&e.$rows.css(b,h[b]);switch(e.type&~d.dataAlt){case d.header:c="wijmo-wijgrid-headerrow";break;case d.data:c=g+" wijmo-wijgrid-datarow";if(e.type&d.dataAlt)c+=" wijmo-wijgrid-alternatingrow";break;case d.emptyDataRow:c=g+" wijmo-wijgrid-emptydatarow";break;case d.filter:c="wijmo-wijgrid-filterrow";break;case d.groupHeader:c=g+" wijmo-wijgrid-groupheaderrow";break;case d.groupFooter:c=g+" wijmo-wijgrid-groupfooterrow";break;case d.footer:c="wijmo-wijgrid-footerrow ui-state-highlight";break;default:throw a.wijmo.wijgrid.stringFormat("unknown rowType: {0}",e.row.type);}e.$rows.addClass(c)}function e(c,d){if(b.options.showRowHeader)if(d)a(c.$rows[0].cells[0]).addClass("ui-state-active wijmo-wijgrid-current-rowheadercell");else a(c.$rows[0].cells[0]).removeClass("ui-state-active wijmo-wijgrid-current-rowheadercell")}function f(a,b){if(b)a.$rows.addClass("ui-state-hover");else a.$rows.removeClass("ui-state-hover")}function d(b,a){a}}})})(jQuery);(function(a){"use strict";a.extend(a.wijmo.wijgrid,{tally:function(){var h=0,i=0,a=0,b=0,f=0,g=0,d,c;this.add=function(e){if(e===null||e==="")return;b++;if(typeof e==="string"){if(d===undefined||e<d)d=e;if(c===undefined||e>c)c=e}if(typeof e==="number"){if(a===0){g=e;f=e}a++;h+=e;i+=e*e;if(e<g)g=e;if(e>f)f=e}};this.getValueString=function(f){if(a){var h=e(f.aggregate),g=f.owner;return g._toStr(f,h)}if(b)switch(f.aggregate){case"max":return c;case"min":return d;case"count":return b.toString()}return""};function e(d){switch(d){case"average":return a===0?0:h/a;case"count":return b;case"max":return f;case"min":return g;case"sum":return h;case"std":return a<=1?0:Math.sqrt(e("var"));case"stdPop":return a<=1?0:Math.sqrt(e("varPop"));case"var":return a<=1?0:e("varPop")*a/(a-1);case"vapPop":if(a<=1)return 0;var c=h/a;return i/a-c*c}return 0}}})})(jQuery);(function(a){"use strict";a.extend(a.wijmo.wijgrid,{columnsGenerator:function(){this.generate=function(f,b,e){switch(f){case"append":c(b,e);break;case"merge":d(b,e);break;default:throw a.wijmo.wijgrid.stringFormat('Unsupported value: "{0}"',f);}};function c(f,g){var c=f.getFieldNames(),a,e,d;for(a=0,e=c.length;a<e;a++){d=b(c[a]);g.push(d)}}function d(l,i){var g=[],h=l.getFieldNames(),d={},e,k,c,j,f;for(e=0,k=h.length;e<k;e++)d[j=h[e]]=j;a.wijmo.wijgrid.traverse(i,function(b){if(b.isLeaf&&!b.isBand){c=b.dataKey;if(a.wijmo.wijgrid.validDataKey(c)){if(d[c]!==undefined)delete d[c]}else c!==null&&g.push(b)}});if(g.length){e=0;for(c in d)if(d.hasOwnProperty(c)){f=g[e++];if(f){f.dataKey=d[c];delete d[c]}}}for(c in d)if(d.hasOwnProperty(c)){f=b(d[c]);i.push(f)}}function b(b){return a.wijmo.wijgrid.createDynamicField({dataKey:b})}}})})(jQuery);
(function(){"use strict";if(!window.Raphael)return;$.extend({round:function(a,b){return!a?0:Globalize.parseFloat(a.toFixed(b))},toOADate:function(b){var c=864e5,a=b-new Date(1900,0,1)+2*c;return a},fromOADate:function(a){var c=864e5,b=new Date(a-2*c+ +new Date(1900,0,1));return b}});$.wijraphael={isSVGElem:function(a){var b="http://www.w3.org/2000/svg";return a.nodeType===1&&a.namespaceURI===b},addClass:function(b,a){a=a||"";$.each(b,function(){if($.wijraphael.isSVGElem(this)){var b=this;$.each(a.split(/\s+/),function(d,c){var a=b.className?b.className.baseVal:b.getAttribute("class");if($.inArray(c,a.split(/\s+/))===-1){a+=(a?" ":"")+c;if(b.className)b.className.baseVal=a;else b.setAttribute("class",a)}})}else $(this).addClass(a)})},getPositionByAngle:function(e,f,c,d){var a={},b=Raphael.rad(d);a.x=e+c*Math.cos(-1*b);a.y=f+c*Math.sin(-1*b);return a},hasClass:function(a,b){if(!b||b.length===0)return false;if($.wijraphael.isSVGElem(a)){var d=a.className?a.className.baseVal:a.getAttribute("class"),c=false;$.each(d.split(/\s+/),function(d,a){if(a===b){c=true;return false}});return c}else return $(a).hasClass(b)},sector:function(b,c,a,d,e){var f=$.wijraphael.getPositionByAngle(b,c,a,d),g=$.wijraphael.getPositionByAngle(b,c,a,e);return["M",b,c,"L",f.x,f.y,"A",a,a,0,+(e-d>180),0,g.x,g.y,"z"]}};$.expr.filter.CLASS=function(a,c){var b=!$.wijraphael.isSVGElem(a)?a.className:a.className?a.className.baseVal:a.getAttribute("class");return(" "+b+" ").indexOf(c)>-1};$.expr.preFilter.CLASS=function(c,e,f,g,i,h){var b=0,a=null,d=null;c=" "+c[1].replace(/\\/g,"")+" ";if(h)return c;for(b=0,a={};a;b++){a=e[b];if(!a)try{a=e.item(b)}catch(j){}if(a){d=!$.wijraphael.isSVGElem(a)?a.className:(a.className?a.className.baseVal:"")||a.getAttribute("class");if(i^(d&&(" "+d+" ").indexOf(c)>-1))!f&&g.push(a);else if(f)e[b]=false}}return false};Raphael.fn.tri=function(b,c,e){var g=b,j=c-e,a=Math.cos(Math.PI/6)*e,d=Math.tan(Math.PI/3)*a,h=b+a,k=c+d,i=b-a,l=c+d,f=["M",g,j,"L",h,k,"L",i,l,"z"];return this.path(f.concat(" "))};Raphael.fn.invertedTri=function(b,c,e){var g=b,j=c+e,a=Math.cos(Math.PI/6)*e,d=Math.tan(Math.PI/3)*a,h=b+a,k=c-d,i=b-a,l=c-d,f=["M",g,j,"L",h,k,"L",i,l,"z"];return this.path(f.concat(" "))};Raphael.fn.box=function(b,c,e){var a=Math.cos(Math.PI/4)*e,d=["M",b-a,c-a,"L",b+a,c-a,"L",b+a,c+a,"L",b-a,c+a,"z"];return this.path(d.concat(" "))};Raphael.fn.diamond=function(b,c,a){var d=["M",b,c-a,"L",b+a,c,"L",b,c+a,"L",b-a,c,"z"];return this.path(d.concat(" "))};Raphael.fn.cross=function(b,c,e){var a=Math.cos(Math.PI/4)*e,d=["M",b-a,c-a,"L",b+a,c+a,"M",b-a,c+a,"L",b+a,c-a];return this.path(d.concat(" "))};Raphael.fn.paintMarker=function(f,d,e,b){var c=this,a=null;if(!f)f="circle";switch(f){case"circle":a=c.circle(d,e,b);break;case"tri":a=c.tri(d,e,b);break;case"invertedTri":a=c.invertedTri(d,e,b);break;case"box":a=c.box(d,e,b);break;case"diamond":a=c.diamond(d,e,b);break;case"cross":a=c.cross(d,e,b)}return a};Raphael.prototype.htmlText=function(k,l,a,i,e,d){function h(b,a,d){var f=/<(b|strong)>/,e=/<(i|em)>/,c=/href=[\"\']([^\"\']+)[\"\']/,g=/<a/;d&&b.attr(d);f.test(a)&&b.attr("font-weight","bold");e.test(a)&&b.attr("font-style","italic");if(g.test(a))a.match(c)[1]&&b.attr("href",a.match(c)[1])}var j=a.toString().split(/<br\s?\/>|\\r/i),g=this,b=g.set(),c=0,f=0;e=e||3;d=d||5;$.each(j,function(m,k){var j=0,l=k.split("|||");k=k.replace(/<([A-Za-z]+(.|\n)*?)>/g,"|||<$1>").replace(/<\/([A-Za-z]*)>/g,"</$1>|||");$.each(l,function(o,l){var k=null,d=null,m=0,n=0;if(l!==""){k=l;k=$.trim(k.replace(/<(.|\n)*?>/g,""));a=g.text(0,0,k);h(a,l,i);d=a.wijGetBBox();m=d.width/2+c;n=-d.height/2+f;c=c+d.width+e;a.translate(m,n);b.push(a);if(j<d.height)j=d.height}});f+=j+d;c=j=0});f=0;b.transform(Raphael.format("...t{0},{1}",k-b.getBBox().x,l-b.getBBox().y));return b};Raphael.fn.line=function(a,b,c,d){return this.path(["M",a,b,"L",c,d])};Raphael.fn.roundRect=function(l,m,e,d,k,i,h,j){var a=[],c=[-1,1,1,1,1,-1,-1,-1],g=["v","h","v","h"],b=null,f=null;$.each([k,i,h,j],function(c,b){if(typeof b==="number")a=a.concat({x:b,y:b});else if(typeof b==="object")a=a.concat(b);else a=a.concat({x:0,y:0})});b=["M",l+a[0].x,m];f=[d-a[0].y-a[1].y,e-a[1].x-a[2].x,a[2].y+a[3].y-d,a[3].x+a[0].x-e];$.each(a,function(d,a){if(a.x&&a.y)b=b.concat("a",a.x,a.y,0,0,0,c[2*d]*a.x,c[2*d+1]*a.y);b=b.concat(g[d],f[d])});b.push("z");return this.path(b)};Raphael.fn.wrapText=function(n,o,m,g,l,f){var h=this,b=f.rotation,j=b?$.extend(true,{},f,{rotation:0}):f,i=o,d=h.set(),a=null,c=null,e=[];function k(j,i,g){var b=null,f=null,a=j.split(" "),e=[],c=[],d="";while(a.length){d+=" "+a[0];b=h.text(-1e3,-1e3,d);b.attr(g);f=b.wijGetBBox();if(f.width>i){if(c.length){e.push(c);d=a[0]}c=[a.shift()]}else c.push(a.shift());a.length===0&&e.push(c);b.wijRemove();b=null}return e}$.each(k(m,g,j),function(q,p){var m=p.join(" "),o=l||"near",c=h.text(n,i,m),f=0,k=0;c.attr(j);a=c.wijGetBBox();switch(o){case"near":f=g-a.width/2;break;case"center":f+=g/2;break;case"far":f+=a.width/2}if(b){k+=a.height/2/Math.abs(Math.sin(b));i+=a.height/Math.abs(Math.sin(b))}else{k+=a.height/2;i+=a.height}a.x+=f;a.y+=k;if(b)c.attr({x:c.attr("x")+f,y:c.attr("y")+k});else c.transform(Raphael.format("...T{0},{1}",f,k));d.push(c);e.push(a)});if(b){a=d.wijGetBBox();if(d.length>1){$.each(d,function(c,b){b.attr({y:b.attr("y")-a.height/2});e[c].y-=a.height/2});c={x:a.x+a.width/2,y:a.y+a.height/2};$.each(d,function(l,g){var f=Math,h=e[l],d={x:h.x+h.width/2,y:h.y+h.height/2},j=f.sqrt(f.pow(d.x-c.x,2)+f.pow(d.y-c.y,2)),a=0,i=null,k=null;g.attr({rotation:b});if(j===0)return true;i=g.wijGetBBox();a=Raphael.deg(f.asin(f.abs(d.y-c.y)/j));if(d.y>c.y)if(d.x>c.x)a-=360;else a=-1*(a+180);else if(d.x>c.x)a*=-1;else a=-1*(180-a);k=$.wijraphael.getPositionByAngle(c.x,c.y,j,-1*(b+a));g.attr({y:g.attr("y")+k.y-i.y-i.height/2})})}else d[0].transform(Raphael.format("...R{0}",b))}return d};Raphael.fn.getSVG=function(){function l(e,b){var a="<"+e+" ",c=null,d=false;$.each(b,function(b,c){if(b==="text"||b==="opacity"||b==="transform"||b==="path"||b==="w"||b==="h"||b==="translation")return true;if(c){if(b==="stroke"&&c===0)c="none";a+=b+"='"+c+"' "}});if(b.opacity){c=b.opacity;a+="opacity='"+c+"' style='opacity:"+c+";";d=true}if(b.transform&&b.transform.length>0){c=b.transform;if(d)a+="transform:"+c;else{a+="style='transform:"+c;d=true}}if(d)a+="'";if(b.text){c=b.text;a+="><tspan>"+c+"</tspan>"}else a+=">";a+="</"+e+">";return a}for(var g=this,j='<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" version="1.1" width="'+g.canvas.offsetWidth+'" height="'+g.canvas.offsetHeight+'"><desc>Created with Raphael</desc><defs></defs>',c="",h,f,d,e=0,k=0,b=0,i=0,a=g.bottom;a;a=a.next)if(a&&a.type)switch(a.type){case"path":for(e=0,k=a.attrs.path.length;e<k;e++){f=a.attrs.path[e];for(b=0,i=f.length;b<i;b++){d=f[b];if(b<1)c+=d;else if(b===i-1)c+=d;else c+=d+","}}if(c&&c.length>0)a.attrs.d=c.replace(/,/g," ");break;case"text":if(!a.attrs["text-anchor"])a.attrs["text-anchor"]="middle";break;case"image":h=a.transformations;a.attrs.transform=h?h.join(" "):"";break;case"ellipse":case"rect":j+=l(a.type,a.attrs)}j+="</svg>";return j};Raphael.el.wijRemove=function(){var a=this,b;if(a.removed)return;if(a.node.parentNode){b=$(a.node).data();b&&$(a.node).removeData();a.remove()}};Raphael.st.wijRemove=function(){$.each(this,function(b,a){a.wijRemove&&a.wijRemove()})};Raphael.el.wijGetBBox=function(){return this.getBBox()};Raphael.el.wijAnimate=function(a,g,b,e){if(!a||$.isEmptyObject(a))return;var d=this.shadow,c=0,f={easeInCubic:">",easeOutCubic:"<",easeInOutCubic:"<>",easeInBack:"backIn",easeOutBack:"backOut",easeOutElastic:"elastic",easeOutBounce:"bounce"};if(f[b])b=f[b];this.animate(a,g,b,e);if(d&&d.offset){c=d.offset;if(a.x)a.x+=c;if(a.y)a.y+=c;this.shadow.animate(a,g,b,e)}};Raphael.el.wijAttr=function(a,c){this.attr(a,c);if(this.shadow)if(typeof a==="object"){var b=$.extend(true,{},a);if(b.fill)delete b.fill;if(b.stroke)delete b.stroke;if(b["stroke-width"])delete b["stroke-width"];this.shadow.attr(b,c)}else if(typeof a==="string")switch(a){case"clip-rect":case"cx":case"cy":case"fill-opacity":case"font":case"font-family":case"font-size":case"font-weight":case"height":case"opacity":case"path":case"r":case"rotation":case"rx":case"ry":case"scale":case"stroke-dasharray":case"stroke-linecap":case"stroke-linejoin":case"stroke-miterlimit":case"stroke-opacity":case"stroke-width":case"translation":case"width":this.shadow.attr(a,c);break;case"x":this.shadow.attr(a,c);this.shadow.attr("transform","...t1,0");break;case"y":this.shadow.attr(a,c);this.shadow.attr("transform","...t0,1")}};Raphael.st.wijAttr=function(b,a){$.each(this.items,function(d,c){c.wijAttr(b,a)});return this};Raphael.st.wijAnimate=function(f,g,e,d){var a=0,c=0,b=null;for(a=0,c=this.items.length;a<c;a++){b=this.items[a];b.wijAnimate(f,g,e,d)}return this};Raphael.st.wijGetBBox=function(){for(var b=[],c=[],j=[],i=[],g=Math.max,h=Math.min,e="push",d="apply",a=null,f=0,f=this.items.length-1;f>=0;f--){a=this.items[f].wijGetBBox();b[e](a.x);c[e](a.y);j[e](a.x+a.width);i[e](a.y+a.height)}b=h[d](0,b);c=h[d](0,c);return{x:b,y:c,width:g[d](0,j)-b,height:g[d](0,i)-c}}})();
(function(a){"use strict";if(!window.Raphael)return;a.wijchart={getDiffAttrs:function(d,b){var c={};a.each(b,function(a){if(typeof d==="undefined")return true;else if(typeof d[a]==="undefined")c[a]=b[a];else if(d[a]!==b[a])c[a]=b[a]});return c},paintShadow:function(c,e,f){if(c.removed)return;var a=c.clone(),b=e||1,d=f||"#cccccc";a.insertBefore(c);a.attr({transform:Raphael.format("...T{0},{1}",b,b),stroke:d,"stroke-width":b});a.toBack();a.offset=b;c.shadow=a},getScaling:function(b,d,e,c){var a=d-e;if(a===0)a=1;if(b)a=-a;return c/a},getTranslation:function(d,b,e,f,c){var a=0;if(d){a=b.y;a-=c*e}else{a=b.x;a-=c*f}return a},getXSortedPoints:function(e){var b=e.data.x,f=[].concat(b),g=[].concat(e.data.y),d=[],c=b;if(b.length===0)return;function h(a,b){return a-b}if(typeof b[0]==="number")c=[].concat(b).sort(h);a.each(c,function(c,b){a.each(f,function(e,a){if(b===a){if(typeof a!=="number")a=c;d.push({x:a,y:g[e]});f.splice(e,1);g.splice(e,1);return false}})});return d},sector:function(c,d,b,e,f){var g=a.wijraphael.getPositionByAngle(c,d,b,e),h=a.wijraphael.getPositionByAngle(c,d,b,f);return["M",c,d,"L",g.x,g.y,"A",b,b,0,+(f-e>180),0,h.x,h.y,"z"]},donut:function(e,f,c,b,g,h){var d=a.wijraphael.getPositionByAngle(e,f,c,g),l=a.wijraphael.getPositionByAngle(e,f,c,h),k=a.wijraphael.getPositionByAngle(e,f,b,g),j=a.wijraphael.getPositionByAngle(e,f,b,h),i=h-g>180;return["M",d.x,d.y,"A",c,c,0,+i,0,l.x,l.y,"L",j.x,j.y,"A",b,b,0,+i,1,k.x,k.y,"L",d.x,d.y,"z"]},getFirstValidListValue:function(c){var b;a.each(c,function(c,a){if(a===null)return true;else if(typeof a==="undefined")return true;b=a;return false});return b},getLastValidListValue:function(b){var c=[].concat(b).reverse();return a.wijchart.getFirstValidListValue(c)},isHole:function(a,b){return a===null?true:typeof a==="undefined"?true:typeof a!=="undefined"?a===b?true:false:false}};var b={content:"",contentStyle:{},title:"",titleStyle:{},style:{fill:"white","fill-opacity":.5},closeBehavior:"auto",mouseTrailing:true,triggers:"hover",animated:"fade",showAnimated:null,hideAnimated:null,duration:500,showDuration:500,hideDuration:500,easing:null,showEasing:null,hideEasing:null,showDelay:150,hideDelay:150,relativeTo:"mouse",compass:"east",offsetX:0,offsetY:0,showCallout:true,calloutFilled:false,calloutFilledStyle:{fill:"black"},calloutLength:12,calloutOffset:0,calloutAnimation:{easing:null,duration:500},windowCollisionDetection:true,calloutSide:null,width:null,height:null,beforeShowing:null};Raphael.fn.closeBtn=function(c,d,b){var a=Math.cos(Math.PI/4)*b,f=this.set(),h=["M",c-a,d-a,"L",c+a,d+a,"M",c-a,d+a,"L",c+a,d-a],g=this.path(h.concat(" ")),e=null;g.attr({cursor:"pointer"});f.push(g);e=this.rect(c-b,d-b,b*2,b*2);e.attr({fill:"white","fill-opacity":0,cursor:"pointer",stroke:"none"});f.push(e);return f};Raphael.fn.tooltip=function(p,Y){var c=a.extend(true,{},b,Y),g=this,A=null,P=0,Q=0,f,i,h,e,d,y=null,x=null,n=null,m=5,l=null,u=g.tooltip.animations,t=c.calloutOffset,C=c.width,B=c.height,s=c.calloutLength/2,q=0,j=0,k=0,o,U=function(c,d){var a=c.getBBox(),b={x:0,y:0};switch(d.toLowerCase()){case"east":b.x=a.x+a.width;b.y=a.y+a.height/2;break;case"eastnorth":b.x=a.x+a.width;b.y=a.y;break;case"eastsouth":b.x=a.x+a.width;b.y=a.y+a.height;break;case"west":b.x=a.x;b.y=a.y+a.height/2;break;case"westnorth":b.x=a.x;b.y=a.y;break;case"westsouth":b.x=a.x;b.y=a.y+a.height;break;case"north":b.x=a.x+a.width/2;b.y=a.y;break;case"northeast":b.x=a.x+a.width;b.y=a.y;break;case"northwest":b.x=a.x;b.y=a.y;break;case"south":b.x=a.x+a.width/2;b.y=a.y+a.height;break;case"southeast":b.x=a.x+a.width;b.y=a.y+a.height;break;case"southwest":b.x=a.x;b.y=a.y+a.height}return b},G=function(a){if(a){window.clearTimeout(a);a=null}},z=function(g){if(l){var a,b,j;if(c.hideAnimated||c.animated){a=c.hideAnimated;if(!a)a=c.animated;if(a&&u[a]){j={animated:a,duration:c.hideDuration||c.duration,easing:c.hideEasing||c.easing,context:l,show:false};u[a](j)}}b=c.hideDuration;if(g)b=g;window.setTimeout(function(){var a,b;if(f){f.wijRemove();f=null}if(i){i.wijRemove();i=null}if(h){h.wijRemove();h=null}if(e){for(a=0,b=e.length;a<b;a++)e[a].unclick();e.wijRemove();e=null}if(d){d.wijRemove();d=null}n=null;l=null},b)}},L=function(){y&&G(y);x&&G(x)},v=function(){L();if(c.hideDelay)x=window.setTimeout(function(){z()},c.hideDelay);else z()},D=function(b){var a="";switch(b.toLowerCase()){case"east":a="right-middle";j=2;k=0;break;case"eastnorth":a="right-top";j=2;k=-2;break;case"eastsouth":a="right-bottom";j=2;k=2;break;case"west":a="left-middle";j=-2;k=0;break;case"westnorth":a="left-top";j=-2;k=-2;break;case"westsouth":a="left-bottom";j=-2;k=2;break;case"north":a="top-middle";j=0;k=-2;break;case"northeast":a="top-right";j=2;k=-2;break;case"northwest":a="top-left";j=-2;k=-2;break;case"south":a="bottom-middle";j=0;k=2;break;case"southeast":a="bottom-right";j=2;k=2;break;case"southwest":a="bottom-left";j=-2;k=2}return a},K=function(b,a){var d=[],e=c.compass;if(c.calloutSide)e=c.calloutSide;switch(e.toLowerCase()){case"east":case"eastsouth":case"eastnorth":d=["M",b.x+a,b.y+a,"l",-a,-a,"l",a,-a,"Z"];break;case"west":case"westsouth":case"westnorth":d=["M",b.x-a,b.y-a,"l",a,a,"l",-a,a,"Z"];break;case"north":case"northeast":case"northwest":d=["M",b.x-a,b.y-a,"l",a,a,"l",a,-a,"Z"];break;case"south":case"southeast":case"southwest":d=["M",b.x-a,b.y+a,"l",a,-a,"l",a,a,"Z"]}return d},M=function(e,d){if(a.isFunction(e)){var h=null,f,c={target:null,fmt:e},b;if(d&&d.target){b=d.target;if(!b.raphael||!b.raphaelid)b=b.parentNode;if(b.raphael&&b.raphaelid){f=g.getById(b.raphaelid);c.target=f}else c.target=d.target}h=a.proxy(c.fmt,c);return h().toString()}return e},H=function(a){if(c.calloutSide){var b=s||q;switch(c.calloutSide){case"south":case"north":if(a)d.animate({translation:-C/2+b+t+",0"},a);else d.translate(-C/2+b+t,0);break;case"east":case"west":if(a)d.animate({translation:"0,"+(-B/2+b+t)},a);else d.translate(0,-B/2+b+t)}}},V=/\{([^\}]+)\}/g,S=/(?:(?:^|\.)(.+?)(?=\[|\.|$|\()|\[('|")(.+?)\2\])(\(\))?/g,W=function(c,d,b){var a=b;d.replace(S,function(f,b,e,c,d){b=b||c;if(a){if(a[b]!=="string")a=a[b];if(typeof a==="function"&&d)a=a()}});a=(a===null||a===b?c:a).toString();return a},ab=function(b,a){return String(b).replace(V,function(b,c){return W(b,c,a)})},N=function(i,u,s,t,h){var o=u.split("-"),e=5,p=s.getBBox(),d=Math.round(p.width),b=Math.round(p.height),j=Math.round(p.x)-e,k=Math.round(p.y)-e,a=0,f=0,m=0,n=0,q=null,l=null,r=null;if(c.width)d=d>c.width?d:c.width;if(c.height)b=b>c.height?b:c.height;C=d;B=b;a=Math.min(b/4,d/4,t);if(h)h=Math.min(b/4,d/4,h);if(h){f=h;q={top:"M{x},{y}h{w4},{w4},{w4},{w4}a{r},{r},0,0,1,{r},{r}v{h4},{h4},{h4},{h4}a{r},{r},0,0,1,-{r},{r}l-{right},0-{offset},0,-{left},0a{r},{r},0,0,1-{r}-{r}v-{h4}-{h4}-{h4}-{h4}a{r},{r},0,0,1,{r}-{r}z",bottom:"M{x},{y}l{left},0,{offset},0,{right},0a{r},{r},0,0,1,{r},{r}v{h4},{h4},{h4},{h4}a{r},{r},0,0,1,-{r},{r}h-{w4}-{w4}-{w4}-{w4}a{r},{r},0,0,1-{r}-{r}v-{h4}-{h4}-{h4}-{h4}a{r},{r},0,0,1,{r}-{r}z",right:"M{x},{y}h{w4},{w4},{w4},{w4}a{r},{r},0,0,1,{r},{r}v{h4},{h4},{h4},{h4}a{r},{r},0,0,1,-{r},{r}h-{w4}-{w4}-{w4}-{w4}a{r},{r},0,0,1-{r}-{r}l0-{bottom},0-{offset},0-{top}a{r},{r},0,0,1,{r}-{r}z",left:"M{x},{y}h{w4},{w4},{w4},{w4}a{r},{r},0,0,1,{r},{r}l0,{top},0,{offset},0,{bottom}a{r},{r},0,0,1,-{r},{r}h-{w4}-{w4}-{w4}-{w4}a{r},{r},0,0,1-{r}-{r}v-{h4}-{h4}-{h4}-{h4}a{r},{r},0,0,1,{r}-{r}z"}}else q={top:"M{x},{y}h{w4},{w4},{w4},{w4}a{r},{r},0,0,1,{r},{r}v{h4},{h4},{h4},{h4}a{r},{r},0,0,1,-{r},{r}l-{right},0-{gap},{gap}-{gap}-{gap}-{left},0a{r},{r},0,0,1-{r}-{r}v-{h4}-{h4}-{h4}-{h4}a{r},{r},0,0,1,{r}-{r}z",bottom:"M{x},{y}l{left},0,{gap}-{gap},{gap},{gap},{right},0a{r},{r},0,0,1,{r},{r}v{h4},{h4},{h4},{h4}a{r},{r},0,0,1,-{r},{r}h-{w4}-{w4}-{w4}-{w4}a{r},{r},0,0,1-{r}-{r}v-{h4}-{h4}-{h4}-{h4}a{r},{r},0,0,1,{r}-{r}z",right:"M{x},{y}h{w4},{w4},{w4},{w4}a{r},{r},0,0,1,{r},{r}v{h4},{h4},{h4},{h4}a{r},{r},0,0,1,-{r},{r}h-{w4}-{w4}-{w4}-{w4}a{r},{r},0,0,1-{r}-{r}l0-{bottom}-{gap}-{gap},{gap}-{gap},0-{top}a{r},{r},0,0,1,{r}-{r}z",left:"M{x},{y}h{w4},{w4},{w4},{w4}a{r},{r},0,0,1,{r},{r}l0,{top},{gap},{gap}-{gap},{gap},0,{bottom}a{r},{r},0,0,1,-{r},{r}h-{w4}-{w4}-{w4}-{w4}a{r},{r},0,0,1-{r}-{r}v-{h4}-{h4}-{h4}-{h4}a{r},{r},0,0,1,{r}-{r}z"};l=([{x:j+e,y:k,w:d,w4:d/4,h4:b/4,left:0,right:d-a*2-f*2,top:0,bottom:b-a*2-f*2,r:e,h:b,gap:a,offset:f*2},{x:j+e,y:k,w:d,w4:d/4,h4:b/4,left:d/2-a-f,right:d/2-a-f,top:b/2-a-f,bottom:b/2-a-f,r:e,h:b,gap:a,offset:f*2},{x:j+e,y:k,w:d,w4:d/4,h4:b/4,right:0,left:d-a*2-f*2,bottom:0,top:b-a*2-f*2,r:e,h:b,gap:a,offset:f*2}])[o[1]==="middle"?1:(o[1]==="left"||o[1]==="top")*2];r=g.path(ab(q[o[0]],l));switch(o[0]){case"top":m=i.x-(j+e+l.left+a+h);n=i.y-(k+e+b+e+a+h);break;case"bottom":m=i.x-(j+e+l.left+a+h);n=i.y-(k-a-h);break;case"left":m=i.x-(j+e+d+e+a+h);n=i.y-(k+e+l.top+a+h);break;case"right":m=i.x-(j-a-f);n=i.y-(k+e+l.top+a+f)}r.translate(m,n);s.translate(m,n);return r},F=function(n,o,d,e,p,q){var c=n.getBBox(),f=0,b=o,h=c.x+p,i=c.y+q,m=g.width,l=g.height,j=d,k=e;if(g.raphael.vml){m=a(g.canvas).width();l=a(g.canvas).height()}if(h+d<0)if(b.toLowerCase().indexOf("west")===-1){if(h+c.width/2+c.width-d<=m){f++;b=b.toLowerCase()+"east";j=0-d}}else if(h+c.width+c.width-d<=m){f++;b=b.toLowerCase().replace("west","east");j=0-d}if(i+e<0)if(b.toLowerCase().indexOf("north")===-1){if(i+c.height/2+c.height-e<=l){f++;b=b.toLowerCase()+"south";k=0-e}}else if(i+c.height+c.height-e<=l){f++;b=b.toLowerCase().replace("north","south");k=0-e}if(h+c.width+d>m)if(b.toLowerCase().indexOf("east")===-1){if(h-c.width/2-d>=0){f++;b=b.toLowerCase()+"west";j=0-d}}else if(h-c.width-d>=0){f++;b=b.toLowerCase().replace("east","west");j=0-d}if(i+c.height+e>l)if(b.toLowerCase().indexOf("south")===-1){if(i-c.height/2-e>=0){f++;b=b.toLowerCase()+"north";k=0-e}}else if(i-c.height-e>=0){f++;b=b.toLowerCase().replace("south","north");k=0-e}return f?{compass:b,offsetX:j,offsetY:k}:false},w=function(E,A,z,M,I,J,L){var x,t,B,p=g.set(),C=null,r=null,P=null,Q=0,R=0,S=250,G=0,O=0,b,o={x:E.x,y:E.y},y=null;B=D(I);o.x+=J+j;o.y+=L+k;l=g.set();if(i){a.each(i,function(c,b){a(b.node).unbind(".Rtooltip")});i.wijRemove()}if(A&&A.length>0){i=g.htmlText(-1e3,-1e3,A,c.titleStyle);l.push(i);x=i.getBBox()}else x={left:-1e3,top:-1e3,width:0,height:0};if(f){a.each(f,function(c,b){a(b.node).unbind(".Rtooltip")});f.wijRemove()}if(z&&z.length>0){f=g.htmlText(-1e3,-1e3,z,c.contentStyle);l.push(f);t=f.getBBox()}else t={left:-1e3,top:-1e3,width:0,height:0};if(e){for(G=0,O=e.length;G<O;G++)e[G].unclick();e.wijRemove()}f&&f.transform(Raphael.format("...T0,{0}",x.height/2+t.height/2));if(c.closeBehavior==="sticky"){e=g.closeBtn(-1e3,-1e3,m);l.push(e);if(c.width&&c.width>x.width+m*2&&c.width>t.width+m*2)e.transform(Raphael.format("...T{0},{1}",c.width-m,m));else if(x.width>=t.width-m*2)e.transform(Raphael.format("...T{0},{1}",x.width+m,m));else e.transform(Raphael.format("...T{0},{1}",t.width-m,m));a.each(e,function(){this.click(function(a){v(a)})})}if(i){p.push(i);c.relatedElement&&i.insertBefore(c.relatedElement)}if(f){p.push(f);c.relatedElement&&f.insertBefore(c.relatedElement)}if(e){p.push(e);c.relatedElement&&e.insertBefore(c.relatedElement)}if(!c.showCallout)s=0;if(c.calloutSide||c.calloutFilled){s=0;q=c.calloutLength/2;if(c.calloutSide)B=D(c.calloutSide)}if(c.calloutSide&&p.length===0){f=g.htmlText(-1e3,-1e3," ");p.push(f);c.relatedElement&&f.insertBefore(c.relatedElement)}if(d){a(d.node).unbind(".Rtooltip");d.wijRemove()}if(h){a(h.node).unbind(".Rtooltip");h.wijRemove()}if(n){if(c.showCallout&&(c.calloutSide||c.calloutFilled)){C=K(n,q);d=g.path(C.concat(" "));c.relatedElement&&d.insertBefore(c.relatedElement);c.calloutFilled&&d.attr(c.calloutFilledStyle);c.calloutSide&&H(0)}h=N(n,B,p,s,q);c.relatedElement&&h.insertBefore(c.relatedElement);if(M){b=F(h,I,J,L,o.x-n.x,o.y-n.y);if(b){w(E,A,z,false,b.compass,b.offsetX,b.offsetY);return}}l.push(d);l.push(h);Q=o.x-n.x;R=o.y-n.y;y=Raphael.animation({transform:Raphael.format("...T{0},{1}",Q,R)},S);h&&h.animate(y);i&&i.animate(y);f&&f.animate(y);e&&e.animate(y);d&&d.animate(y)}else{if(c.showCallout&&(c.calloutSide||c.calloutFilled)){C=K(o,q);d=g.path(C.concat(" "));c.relatedElement&&d.insertBefore(c.relatedElement);c.calloutFilled&&d.attr(c.calloutFilledStyle);c.calloutSide&&H(0)}h=N(o,B,p,s,q);c.relatedElement&&h.insertBefore(c.relatedElement);if(M){b=F(h,I,J,L,0,0);if(b){w(E,A,z,false,b.compass,b.offsetX,b.offsetY);return}}l.push(d);l.push(h);if(c.showAnimated||c.animated){r=c.showAnimated;if(!r)r=c.animated;if(r&&u[r]){P={animated:r,duration:c.showDuration||c.duration,easing:c.showEasing||c.easing,context:l,show:true};u[r](P)}}}n=o;h.attr(c.style);if(c.relatedElement){i&&i.insertBefore(c.relatedElement);f&&f.insertBefore(c.relatedElement);e&&e.insertBefore(c.relatedElement)}else p.toFront()},J=function(k,d){var h=null,e=null,j=null,f=null,i,b;if(a.isFunction(c.beforeShowing)){j=null;f={target:null,options:c,fmt:c.beforeShowing};if(d&&d.target){b=d.target;if(!b.raphael||!b.raphaelid)b=b.parentNode;if(b.raphael&&b.raphaelid){i=g.getById(b.raphaelid);f.target=i}else{i=d.target;f.target=i}}j=a.proxy(f.fmt,f);j()}h=c.title;e=c.content;h=M(h,d);e=M(e,d);if(!h&&!e)return;w(k,h,e,c.windowCollisionDetection,c.compass,c.offsetX,c.offsetY)},R=function(a,b){L();if(c.showDelay)y=window.setTimeout(function(){J(a,b)},c.showDelay);else J(a,b)},r=function(e){A=a(g.canvas.parentNode).offset();P=A.left;Q=A.top;var h=c.relativeTo,d={x:0,y:0},f=null,b=e.target;switch(h){case"mouse":d.x=e.pageX-P;d.y=e.pageY-Q;break;case"element":if(!b.raphael||!b.raphaelid)b=b.parentNode;if(b.raphael&&b.raphaelid){f=g.getById(b.raphaelid);d=U(f,c.compass)}}R(d,e)},O=function(b){switch(c.triggers){case"hover":a(b.node).bind("mouseover.Rtooltip",function(a){r(a)}).bind("mouseout.Rtooltip",function(a){c.closeBehavior==="auto"&&v(a)});c.mouseTrailing&&c.relativeTo==="mouse"&&a(b.node).bind("mousemove.Rtooltip",function(a){r(a)});break;case"click":a(b.node).bind("click.Rtooltip",function(a){r(a)})}},I=function(a){var b,c;if(a)if(a.length)for(b=0,c=a.length;b<c;b++)O(a[b]);else O(a)},E=function(){if(o)switch(c.triggers){case"hover":o.live("mouseover.Rtooltip",function(a){r(a)}).live("mouseout.Rtooltip",function(a){c.closeBehavior==="auto"&&v(a)});c.mouseTrailing&&c.relativeTo==="mouse"&&o.live("mousemove.Rtooltip",function(a){r(a)});break;case"click":o.live("click.Rtooltip",function(a){r(a)})}},T=function(){var b,c;if(p)if(p.length)for(b=0,c=p.length;b<c;b++)a(p[b].node).unbind(".Rtooltip");else a(p.node).unbind(".Rtooltip");o&&o.die("Rtooltip").die(".Rtooltip")},X=function(){T();z(0)},Z=function(){this.hide=function(){v()};this.showAt=function(a){R(a)};this.resetCalloutOffset=function(e){var f=c.calloutOffset,a=c.calloutSide,b=c.calloutAnimation;if(d)if(a==="south"||a==="north")d.animate({translation:e-f+",0"},b.duration,b.easing);else(a==="east"||a==="west")&&d.animate({translation:"0,"+(e-f)},b.duration,b.easing);c.calloutOffset=e};this.destroy=function(){X()};this.getOptions=function(){return c};this.setTargets=function(a){I(a)};this.setSelector=function(a){o=a;E()};this.setOptions=function(b){c=a.extend(true,c,b)}};p&&I(p);o&&E(o);return new Z};Raphael.fn.tooltip.animations={fade:function(a){var b=a.context;if(a.show){b.attr({opacity:0});b.animate({opacity:1},a.duration,a.easing)}else b.animate({opacity:0},a.duration,a.easing)}}})(jQuery);(function(a){"use strict";a.widget("wijmo.wijchartcore",{options:{width:null,height:null,seriesList:[],seriesStyles:[{stroke:"#00cc00",opacity:.9,"stroke-width":1},{stroke:"#0099cc",opacity:.9,"stroke-width":1},{stroke:"#0055cc",opacity:.9,"stroke-width":1},{stroke:"#2200cc",opacity:.9,"stroke-width":1},{stroke:"#8800cc",opacity:.9,"stroke-width":1},{stroke:"#d9007e",opacity:.9,"stroke-width":1},{stroke:"#ff0000",opacity:.9,"stroke-width":1},{stroke:"#ff6600",opacity:.9,"stroke-width":1},{stroke:"#ff9900",opacity:.9,"stroke-width":1},{stroke:"#ffcc00",opacity:.9,"stroke-width":1},{stroke:"#ffff00",opacity:.9,"stroke-width":1},{stroke:"#ace600",opacity:.9,"stroke-width":1}],seriesHoverStyles:[{opacity:1,"stroke-width":1.5},{opacity:1,"stroke-width":1.5},{opacity:1,"stroke-width":1.5},{opacity:1,"stroke-width":1.5},{opacity:1,"stroke-width":1.5},{opacity:1,"stroke-width":1.5},{opacity:1,"stroke-width":1.5},{opacity:1,"stroke-width":1.5},{opacity:1,"stroke-width":1.5},{opacity:1,"stroke-width":1.5},{opacity:1,"stroke-width":1.5},{opacity:1,"stroke-width":1.5}],marginTop:25,marginRight:25,marginBottom:25,marginLeft:25,textStyle:{fill:"#888","font-size":10,stroke:"none"},header:{text:"",style:{fill:"none",stroke:"none"},textStyle:{"font-size":18,fill:"#666",stroke:"none"},compass:"north",orientation:"horizontal",visible:true},footer:{text:"",style:{fill:"#fff",stroke:"none"},textStyle:{fill:"#000",stroke:"none"},compass:"south",orientation:"horizontal",visible:false},legend:{text:"",textMargin:{left:2,top:2,right:2,bottom:2},style:{fill:"none",stroke:"none"},textStyle:{fill:"#333",stroke:"none"},titleStyle:{"font-weight":"bold",fill:"#000",stroke:"none"},compass:"east",orientation:"vertical",visible:true},axis:{x:{alignment:"center",style:{stroke:"#999999","stroke-width":.5},visible:true,textVisible:true,text:"",textStyle:{fill:"#888","font-size":15,"font-weight":"bold"},labels:{style:{fill:"#333","font-size":11},textAlign:"near",width:null},compass:"south",autoMin:true,autoMax:true,min:null,max:null,origin:null,autoMajor:true,autoMinor:true,unitMajor:null,unitMinor:null,gridMajor:{visible:false,style:{stroke:"#CACACA","stroke-dasharray":"- "}},gridMinor:{visible:false,style:{stroke:"#CACACA","stroke-dasharray":"- "}},tickMajor:{position:"none",style:{fill:"black"},factor:1},tickMinor:{position:"none",style:{fill:"black"},factor:1},annoMethod:"values",annoFormatString:"",valueLabels:[]},y:{alignment:"center",style:{stroke:"#999999","stroke-width":.5},visible:false,textVisible:true,text:"",textStyle:{fill:"#888","font-size":15,"font-weight":"bold"},labels:{style:{fill:"#333","font-size":11},textAlign:"center",width:null},compass:"west",autoMin:true,autoMax:true,min:null,max:null,origin:null,autoMajor:true,autoMinor:true,unitMajor:null,unitMinor:null,gridMajor:{visible:true,style:{stroke:"#999999","stroke-width":.5,"stroke-dasharray":"none"}},gridMinor:{visible:false,style:{stroke:"#CACACA","stroke-dasharray":"- "}},tickMajor:{position:"none",style:{fill:"black"},factor:1},tickMinor:{position:"none",style:{fill:"black"},factor:1},annoMethod:"values",annoFormatString:"",valueLabels:[]}},hint:{enable:true,content:null,contentStyle:{fill:"#d1d1d1","font-size":16},title:null,titleStyle:{fill:"#d1d1d1","font-size":16},style:{fill:"#000000","stroke-width":2},animated:"fade",showAnimated:"fade",hideAnimated:"fade",duration:120,showDuration:120,hideDuration:120,easing:"",showEasing:"",hideEasing:"",showDelay:0,hideDelay:150,compass:"north",offsetX:0,offsetY:0,showCallout:true,calloutFilled:false,calloutFilledStyle:{fill:"#000"}},showChartLabels:true,chartLabelStyle:{},chartLabelFormatString:"",disableDefaultTextStyle:false,shadow:true,beforeSeriesChange:null,seriesChanged:null,beforePaint:null,painted:null},innerState:{},_setOption:function(c,f){var e=this,b=e.options,j=null,i=0,d=0,k=b.axis.x.tickMajor.factor,l=b.axis.x.tickMinor.factor,m=b.axis.y.tickMajor.factor,n=b.axis.y.tickMinor.factor,h,g;if(c==="seriesList"){if(!f)f=[];j=a.Event("beforeserieschange");if(e._trigger("beforeSeriesChange",j,{oldSeriesList:b.seriesList,newSeriesList:f})===false)return false;b.seriesList=f;e._trigger("seriesChanged",null,f);e.seriesTransition=true;e._init()}else if(a.isPlainObject(b[c])){a.extend(true,b[c],f);if(c==="axis"){if(b.axis.x.tickMajor.factor<0)b.axis.x.tickMajor.factor=k;if(b.axis.x.tickMinor.factor<0)b.axis.x.tickMinor.factor=l;if(b.axis.y.tickMajor.factor<0)b.axis.y.tickMajor.factor=m;if(b.axis.y.tickMinor.factor<0)b.axis.y.tickMinor.factor=n}}else a.Widget.prototype._setOption.apply(e,arguments);c==="disabled"&&e._handleDisabledOption(f,e.chartElement);if(c==="seriesTransition"||c==="animation"||c==="disabled")return;i=b.seriesList.length;if(c==="seriesList"||c==="seriesStyles")for(h=b.seriesStyles.length,d=h;d<i;d++)b.seriesStyles[d]=b.seriesStyles[d%h];if(c==="seriesList"||c==="seriesHoverStyles"){g=b.seriesHoverStyles.length;for(d=g;d<i;d++)b.seriesHoverStyles[d]=b.seriesHoverStyles[d%g]}e.redraw()},_create:function(){var b=this,g=b.options,f=g.width||b.element.width(),e=g.height||b.element.height(),d=null,c;b.updating=0;b.innerState={};if(b.element.length>0){if(b.element.is("table")){b._parseTable();d=a("<div></div>");f&&d.css("width",f);e&&d.css("height",e);b.element.after(d);b.chartElement=d}else b.chartElement=b.element;g.disabled&&b.disable();b.chartElement.addClass("ui-widget");c=new Raphael(b.chartElement[0],f,e);b.canvas=c;c.customAttributes.rotation=function(a){return{transform:"...R"+a}};c.customAttributes.scale=function(a){return{transform:"...S"+a}};c.customAttributes.translation=function(a,b){return{transform:Raphael.format("...T{0},{1}",a,b)}};b._bindLiveEvents()}b.headerEles=[];b.footerEles=[];b.legendEles=[];b.axisEles=[];b.legends=[];b.legendIcons=[];b.legendDots=[];b.chartLabelEles=[];b.seriesEles=[]},_getDefFill:function(){return["#00cc00","#0099cc","#0055cc","#2200cc","#8800cc","#d9007e","#ff0000","#ff6600","#ff9900","#ffcc00","#ffff00","#ace600"]},_handleDisabledOption:function(b,c){var a=this;if(b){if(!a.disabledDiv)a.disabledDiv=a._createDisabledDiv(c);a.disabledDiv.appendTo("body")}else if(a.disabledDiv){a.disabledDiv.remove();a.disabledDiv=null}},_createDisabledDiv:function(h){var d=this,e=d.options,b=h||d.element,c=b.offset(),g=e.width||b.outerWidth(),f=e.height||b.outerHeight();return a("<div></div>").addClass("ui-disabled").css({"z-index":"99999",position:"absolute",width:g,height:f,left:c.left,top:c.top})},_init:function(){var b=this,c=b.options;a.each(c.seriesList,function(f,b){var d=b.data,e;if(typeof d==="undefined"||d===null){e=a.inArray(b,c.seriesList);c.seriesList.splice(e,1)}});!b.rendered&&b._paint();a.Widget.prototype._init.apply(b,arguments)},destroy:function(){var b=this;b._unbindLiveEvents();b._clearChartElement();b.chartElement.removeClass("ui-widget");a(".wijchart-canvas-object",b.chartElement[0]).die(b.widgetName).die("."+b.widgetName);b.element!==b.chartElement&&b.chartElement.remove();b.element.empty();if(b.disabledDiv){b.disabledDiv.remove();b.disabledDiv=null}a.Widget.prototype.destroy.apply(b,arguments)},getCanvas:function(){return this.canvas},addSeriesPoint:function(c,e,f){var b=this.options.seriesList,d=null,a=null;if(c>=b.length)return;d=b[c];a=d.data||[];a.x.push(e.x);a.y.push(e.y);if(f){a.x.shift();a.y.shift()}this._setOption("seriesList",b)},beginUpdate:function(){var a=this;a.updating++},endUpdate:function(){var a=this;a.updating--;a.redraw()},redraw:function(e){var a=this,d=a.options,c=0,b=0;if(a.updating>0)return;if(e&&a.rendered)return;c=d.width||a.element.width();b=d.height||a.element.height();if(c<1||b<1)return;a.canvas.setSize(c,b);a._paint()},_parseTable:function(){if(!this.element.is("table"))return;var d=this,e=d.element,b=d.options,c=a("caption",e),g=a("thead th",e),f=[],h=a("tbody tr",e);if(c.length){b.header=a.extend({visible:true,text:a.trim(a(c[0]).text())},b.header);if(c.length>1)b.footer=a.extend({visibel:true,text:a.trim(a(c[1]).text())},b.footer)}b.legend=a.extend({visible:true},b.legend);d._getSeriesFromTR(g,h,f);d.options.seriesList=f},_getSeriesFromTR:function(b,e,g){var c=[],f=null,d=null;b.length&&b.each(function(){f=a.trim(a(this).text());c.push(f)});e.length&&e.each(function(){var h=a("th",a(this)),f=a.trim(h.text()),b=[],e=a("td",a(this));e.length&&e.each(function(){var c=a(this);b.push(parseFloat(a.trim(c.text())))});d={label:f,legendEntry:true,data:{x:c,y:b}};g.push(d)})},_clearChartElement:function(){var b=this,c=b.chartElement.data("fields");if(b.headerEles.length){a.each(b.headerEles,function(b,a){a.wijRemove();a=null});b.headerEles=[]}if(b.footerEles.length){a.each(b.footerEles,function(b,a){a.wijRemove();a=null});b.footerEles=[]}if(b.legendEles.length){a.each(b.legendEles,function(b,a){a.wijRemove();a=null});b.legendEles=[]}if(b.legends.length){a.each(b.legends,function(b,a){a.wijRemove();a=null});b.legends=[]}if(b.legendIcons.length){a.each(b.legendIcons,function(b,a){a.wijRemove();a=null});b.legendIcons=[]}if(b.legendDots.length){a.each(b.legendDots,function(b,a){a.wijRemove();a=null});b.legendDots=[]}if(b.axisEles.length){a.each(b.axisEles,function(b,a){a.wijRemove();a=null});b.axisEles=[]}if(b.chartLabelEles.length){a.each(b.chartLabelEles,function(b,a){a.wijRemove();a=null});b.chartLabelEles=[]}c&&c.chartElements&&a.each(c.chartElements,function(c,b){b.length&&a.each(b,function(b,a){if(a[0]!==null)if(a.removed&&a.removed===false)a=null});b=[]});b.canvas.clear();b.innerState={}},_text:function(c,d,b){var a=this.canvas.text(c,d,b);if(this.options.disableDefaultTextStyle)a.node.style.cssText="";return a},_paint:function(){var b=this,f=b.options,a=b.element,e=a.css("display")==="none"||a.css("visibility")==="hidden",d={},c=null;if(e){d=a.css("left");c=a.css("position");a.css("left","-10000px");a.css("position","absolute");a.show()}if(a.is(":hidden")){if(e){a.css("left",d);a.css("position",c);a.hide()}return}b._clearChartElement();if(b._trigger("beforePaint")===false)return;b.canvasBounds={startX:0,endX:f.width||a.width(),startY:0,endY:f.height||a.height()};b._paintHeader();b._paintFooter();b._paintLegend();b._paintChartArea();b._paintChartLabels();b._paintTooltip();b._trigger("painted");b.rendered=true;if(e){a.css("left",d);a.css("position",c);a.hide()}},_calculatePosition:function(g,f,e){var b={x:0,y:0},c=5,d=5,a=this.canvasBounds;switch(g){case"north":b.x=(a.endX-a.startX)/2;b.y=a.startY+e/2+d;a.startY=a.startY+d*2+e;break;case"south":b.x=(a.endX-a.startX)/2;b.y=a.endY-e/2-d;a.endY=a.endY-d*2-e;break;case"east":b.x=a.endX-f/2-c;b.y=(a.endY-a.startY)/2;a.endX=a.endX-c*2-f;break;case"west":b.x=a.startX+f/2+c;b.y=(a.endY-a.startY)/2;a.startX=a.startX+c*2+f}return b},_paintHeader:function(){var g=2,d=this,m=d.options,c=m.header,h=null,b=null,k=null,j=null,i=null,f=null,l=0,e=null;if(c.text&&c.text.length>0&&c.visible){h=c.compass;b=d._text(0,0,c.text);a.wijraphael.addClass(a(b.node),"wijchart-header-text");l=d._getRotationByCompass(h);k=a.extend(true,{},m.textStyle,c.textStyle);b.attr(k);b.transform("...R"+l);j=b.wijGetBBox();i=d._calculatePosition(h,j.width,j.height);b.transform(Raphael.format("...T{0},{1}",i.x,i.y));f=b.wijGetBBox();e=d.canvas.rect(f.x-g,f.y-g,f.width+2*g,f.height+2*g);a.wijraphael.addClass(a(e.node),"wijchart-header-container");e.attr(c.style);e.toBack();d.headerEles.push(b);d.headerEles.push(e)}},_paintFooter:function(){var g=2,d=this,m=d.options,c=m.footer,h=null,b=null,k=null,j=null,i=null,f=null,l=0,e=null;if(c.text&&c.text.length>0&&c.visible){h=c.compass;b=d._text(0,0,c.text);a.wijraphael.addClass(a(b.node),"wijchart-footer-text");l=d._getRotationByCompass(h);k=a.extend(true,{},m.textStyle,c.textStyle);b.attr(k);b.transform("...R"+l);j=b.wijGetBBox();i=d._calculatePosition(h,j.width,j.height);b.transform(Raphael.format("...T{0},{1}",i.x,i.y));f=b.wijGetBBox();e=d.canvas.rect(f.x-g,f.y-g,f.width+2*g,f.height+2*g);a.wijraphael.addClass(a(e.node),"wijchart-footer-container");e.attr(c.style);e.toBack();d.footerEles.push(b);d.footerEles.push(e)}},_getRotationByCompass:function(b){var a=0;if(b==="east")a=90;else if(b==="west")a=-90;return a},_paintLegend:function(){if(!this.options.legend.visible)return;var d=this,t=d.options,f=a.extend(true,{size:{width:22,height:10}},t.legend),g=2,I=t.seriesStyles,o=[].concat(t.seriesList),r=f.compass,x=f.orientation,h,G,e,b,u=d.canvasBounds,w=u.endX-u.startX,v=u.endY-u.startY,j=f.size.width,F=f.size.height,i=0,l=0,k=0,q=0,p=0,c=1,H=0,s=0,y=0,B=0,m=0,C,z,A,n,E=[],D=0;if(f.text&&f.text.length){h=d._text(0,0,f.text);a.wijraphael.addClass(a(h.node),"wijchart-legend-title");G=a.extend(true,{},t.textStyle,f.textStyle,f.titleStyle);h.attr(G);d.legendEles.push(h)}if(f.reversed)o=o.reverse();a.each(o,function(e,b){b=a.extend(true,{legendEntry:true,display:"show"},b);function c(g){var l=f.reversed?o.length-1-D:D,i=I[l],k=a.extend(true,{fill:"none",opacity:1,stroke:"black"},i),c,h,e,b;D++;if(g.legendEntry&&g.display!=="exclude"){c=d._text(0,0,g.label);a.wijraphael.addClass(a(c.node),"wijchart-legend-text wijchart-legend");h=a.extend(true,{},t.textStyle,f.textStyle);c.attr(h);d.legends.push(c);e=a.extend(k,{"stroke-width":1});b=d.canvas.rect(0,0,j,F);a.wijraphael.addClass(a(b.node),"wijchart-legend-icon wijchart-legend");b.attr(e);d.legendIcons.push(b);E.push(e)}}if(b.type==="pie"&&b.legendEntry)a.each(b.data,function(e,d){d=a.extend({legendEntry:b.legendEntry},d);c(d)});else c(b)});e=d.legends.length;b=f.textMargin;if(h)i=h.wijGetBBox().height;a.each(d.legends,function(c,b){var a=b.wijGetBBox();if(a.width>l)l=a.width;if(a.height>k)k=a.height});if(r==="east"||r==="west"){if(x==="horizontal"){q=e*(l+j+g)+e*(b.left+b.right);if(q>w/2){c=Math.floor(w/2/l);if(c<1)c=1}else c=e}else if(x==="vertical"){p=k*e+i+e*(b.top+b.bottom);if(p>v)c=Math.ceil(p/v);else c=1}}else if(r==="south"||r==="north")if(x==="horizontal"){q=(l+j+g)*e+e*(b.left+b.right);if(q>w){c=Math.floor(e/q*w);if(c<1)c=1}else c=e}else if(x==="vertical"){p=k*e+i+e*(b.top+b.bottom);if(p>v/2){H=Math.floor(v-i)/2/k;c=Math.ceil(e/H)}else c=1}s=c*(l+j+g)+c*(b.left+b.right);y=k*Math.ceil(e/c)+i+Math.ceil(e/c)*(b.top+b.bottom);C=d._calculatePosition(r,s,y);z=C.x-s/2;A=C.y-y/2;n=d.canvas.rect(z-g,A-g,s+2*g,y+2*g);a.wijraphael.addClass(a(n.node),"wijchart-legend-container");n.attr(f.style);n.toBack();d.legendEles.push(n);h&&h.transform(Raphael.format("...T{0},{1}",z+s/2,A+i/2));B=i;a.each(d.legends,function(h,i){var p=f.reversed?o.length-1-h:h,q=i.wijGetBBox(),e=d.legendIcons[h],r=z+m*(j+l+g)+(m+1)*b.left+m*b.right,s=A+B+q.height/2+b.top,t=s-e.wijGetBBox().height/2,n;e.wijRemove();e=d.canvas.rect(r,t,j,F);a(e.node).data("index",p);a.wijraphael.addClass(a(e.node),"wijchart-legend-icon wijchart-legend");d.legendIcons[h]=e;n=E[h];n&&e.attr(n);i.transform(Raphael.format("...T{0},{1}",r+j+g+q.width/2,s));i.toFront();a(i.node).data("index",p);m++;if(m===c){m=0;B+=k+b.top+b.bottom}})},_hasAxes:function(){return this.widgetName==="wijpiechart"?false:true},_applyAxisText:function(i){var j=this,h=i.text,c=null,g=null,b=null,e=0,d=0,f=j.canvasBounds;if(h!==null&&h!==undefined&&h.length>0){g=j._text(-100,-100,h);b=a.extend(true,{},j.options.textStyle,i.textStyle);g.attr(b);c=g.wijGetBBox();if(b["margin-left"])d+=parseFloat(b["margin-left"]);if(b["margin-top"])e+=parseFloat(b["margin-top"]);if(b["margin-right"])d+=parseFloat(b["margin-right"]);if(b["margin-bottom"])e+=parseFloat(b["margin-bottom"]);switch(i.compass){case"north":f.startY+=c.height+e;break;case"south":f.endY-=c.height+e;break;case"east":f.endX-=c.height+d;break;case"west":f.startX+=c.height+d}g.wijRemove()}return c},_isSeriesDataEmpty:function(){var c=this,b=c.options.seriesList;if(!b||b.length===0)return true;a.each(b,function(b,a){if(!a.data||(!a.data.x||!a.data.y)&&!a.data.xy)return true});return false},_paintTooltip:function(){var b=this,h=b.options,d=h.hint,i=!h.disabled&&d.enable,c=d,f,e,g=a.isFunction;if(i&&!b.tooltip){c=a.extend(true,{},d,{});f=d.title;e=d.content;if(g(f))c.title=function(){return b._getTooltipText(f,this.target)};if(g(e))c.content=function(){return b._getTooltipText(e,this.target)};c.beforeShowing=function(){b._onBeforeTooltipShowing(this)};b.tooltip=b.canvas.tooltip(null,c)}},_getTooltipText:function(d,c){var b=a(c.node).data("wijchartDataObj"),e={data:b,label:b.label,x:b.x,y:b.y,target:c,fmt:d};return a.proxy(d,e)()},_onBeforeTooltipShowing:function(b){var a=b.target;if(a)b.options.style.stroke=a.attrs.stroke||a.attrs.fill},_paintChartArea:function(){var b=this,p=b.options,c=p.axis,l=2,n=null,k=null,h={},m=5,f=0,g=0,j=a.isArray(c.y),o=0,i,d,e;b._applyMargins();b.isMultiYAxis=j;if(b._isSeriesDataEmpty())return;j&&a.each(c.y,function(d,b){c.y[d]=a.extend(true,{alignment:"center",style:{stroke:"#999999","stroke-width":.5},visible:false,textVisible:true,text:"",textStyle:{fill:"#888","font-size":15,"font-weight":"bold"},labels:{style:{fill:"#333","font-size":11},textAlign:"center",width:null},compass:"west",autoMin:true,autoMax:true,min:null,max:null,origin:null,autoMajor:true,autoMinor:true,unitMajor:null,unitMinor:null,gridMajor:{visible:true,style:{stroke:"#999999","stroke-width":"0.5","stroke-dasharray":"none"}},gridMinor:{visible:false,style:{stroke:"#CACACA","stroke-dasharray":"- "}},tickMajor:{position:"none",style:{fill:"black"},factor:1},tickMinor:{position:"none",style:{fill:"black"},factor:1},annoMethod:"values",annoFormatString:"",valueLabels:[]},b)});if(b._hasAxes()){if(b.innerState.axisInfo){b.axisInfo=b.innerState.axisInfo;b.canvasBounds=b.innerState.canvasBounds}else{n=b._applyAxisText(c.x,{});b.axisInfo={x:{id:"x",tprec:0,isTime:false,offset:0,vOffset:0,max:0,min:0,majorTickRect:null,minorTickRect:null,annoFormatString:null,textBounds:n,axisTextOffset:l,autoMax:true,autoMin:true,autoMajor:true,autoMinor:true},y:{}};if(j)a.each(c.y,function(a,c){k=b._applyAxisText(c,{});b.axisInfo.y[a.toString()]={id:"y"+a,tprec:0,isTime:false,offset:0,vOffset:0,max:0,min:0,majorTickRect:null,minorTickRect:null,annoFormatString:null,textBounds:k,axisTextOffset:l,autoMax:true,autoMin:true,autoMajor:true,autoMinor:true}});else{k=b._applyAxisText(c.y,{});b.axisInfo.y["0"]={id:"y",tprec:0,isTime:false,offset:0,vOffset:0,max:0,min:0,majorTickRect:null,minorTickRect:null,annoFormatString:null,textBounds:k,axisTextOffset:l,autoMax:true,autoMin:true,autoMajor:true,autoMinor:true}}b._getSeriesGroup();h=b._getDataExtreme(j);if(c.x.autoMin&&b.axisInfo.x.autoMin)c.x.min=h.txn;else if(c.x.min&&b._isDate(c.x.min))c.x.min=a.toOADate(c.x.min);if(c.x.autoMax&&b.axisInfo.x.autoMax)c.x.max=h.txx;else if(c.x.max&&b._isDate(c.x.max))c.x.max=a.toOADate(c.x.max);a.each(h.y,function(){o++});for(i=0;i<o;i++){d=c.y[i]||c.y;e=i.toString();if(d.autoMin&&b.axisInfo.y[e].autoMin)d.min=h.y[e].tyn;else if(d.min&&b._isDate(d.min))d.min=a.toOADate(d.min);if(d.autoMax&&b.axisInfo.y[e].autoMax)d.max=h.y[e].tyx;else if(d.max&&b._isDate(d.max))d.max=a.toOADate(d.max);do{g=b._autoPosition(b.axisInfo,c,"y",e);f=b._autoPosition(b.axisInfo,c,"x",e);if(g===b.axisInfo.y[e].offset&&f===b.axisInfo.x.offset){m=0;break}if(!isNaN(f)&&!isNaN(g)){if(g!==b.axisInfo.y[e].offset&&g!==0){b.axisInfo.y[e].offset=g;b.axisInfo.y[e].vOffset=f}if(f!==b.axisInfo.x.offset&&f!==0){b.axisInfo.x.offset=f;b.axisInfo.x.vOffset=g}}m--}while(m>0)}b._adjustPlotArea(c.x,b.axisInfo.x);b._adjustPlotArea(c.y,b.axisInfo.y,true);b.innerState.axisInfo=b.axisInfo;b.innerState.canvasBounds=b.canvasBounds}b._paintAxes();b._paintPlotArea()}else b._paintPlotArea()},_getSeriesGroup:function(){var c=this,d=c.options,b={};a.each(d.seriesList,function(c,a){if(a.yAxis)if(b[a.yAxis.toString()])b[a.yAxis.toString()].push(a);else b[a.yAxis.toString()]=[a];else if(b["0"])b["0"].push(a);else b["0"]=[a]});c.seriesGroup=b},_adjustPlotArea:function(e,d,f){var c=this.canvasBounds,g,b={east:Number.MIN_VALUE,west:Number.MIN_VALUE,south:Number.MIN_VALUE,north:Number.MIN_VALUE};if(f){a.each(d,function(a){g=a});a.each(d,function(f,a){var c=e[f]||e,d=c.compass;c.max=a.max;c.min=a.min;switch(d){case"north":b.north=Math.max(a.offset,b.north);break;case"south":b.south=Math.max(a.offset,b.south);break;case"east":b.east=Math.max(a.offset,b.east);break;case"west":b.west=Math.max(a.offset,b.west)}});if(b.north!==Number.MIN_VALUE)c.startY+=b.north;if(b.south!==Number.MIN_VALUE)c.endY-=b.south;if(b.east!==Number.MIN_VALUE)c.endX-=b.east;if(b.west!==Number.MIN_VALUE)c.startX+=b.west}else{e.max=d.max;e.min=d.min;switch(e.compass){case"north":c.startY+=d.offset;break;case"south":c.endY-=d.offset;break;case"east":c.endX-=d.offset;break;case"west":c.startX+=d.offset}}},_autoPosition:function(b,a,c,d){return this._autoPositionCartesianAxis(b,a,c,d)},_autoPositionCartesianAxis:function(m,h,p,i){var e=this,o=null,b,f,k,n,s=e.canvasBounds,c,j,q,r,g=e.lastAxisOffset||{},t=0,d,l;if(p==="y"){b=m.y[i];f=h.y[i]||h.y;n=h.x;k=m.x}else{b=m.x;f=h.x;k=m.y[i];n=h.y[i]||h.y}c=f.compass;j=n.origin;q=k.max;r=k.min;if(j!==null&&e._isDate(j))j=a.toOADate(j);e._calculateParameters(b,f);o=e._getMaxExtents(b,f);switch(c){case"north":case"south":d=o.height;b.maxExtent=d;break;case"east":case"west":d=o.width;b.maxExtent=d}if(p==="y"&&g[c]){a.each(g[c],function(b,a){if(b!==i)l=a});if(l){b.preStartOffset=l;d+=l}}if(p==="y"){if(g[c]===undefined)g[c]={};g[c][i]=d+e._getAxisLabelBox(f).width;e.lastAxisOffset=g}return d},_getAxisLabelBox:function(d){var f=this,m=f.options,l=d.text,j=0,h=0,i=0,g=0,c,e,k=f._isVertical(d.compass),b=a.extend(true,{},m.textStyle,d.textStyle);if(b["margin-top"])j=parseFloat(b["margin-top"]);if(b["margin-left"])i=parseFloat(b["margin-left"]);if(b["margin-right"])h=parseFloat(b["margin-right"]);if(b["margin-bottom"])g=parseFloat(b["margin-bottom"]);c=f._text(0,0,l);c.attr(b);k&&c.transform("...R-90");e=c.wijGetBBox();c.wijRemove();return{width:e.width+i+h,height:e.height+g+j}},_getMaxExtents:function(b,c,o){var g=this,p=g.options,i=null,e={width:0,height:0},u=b.min,t=b.max,s=b.isTime,d=c.annoFormatString,r=p.is100Percent,l=0,q=c.compass,h=c.labels,f,m=false,n=g.canvasBounds,j,k;b.majorTickRect=g._getTickRect(b,c,true,true,o);b.minorTickRect=g._getTickRect(b,c,false,true,o);i=g._getMajorTickValues(b,c);if(!c.textVisible)return e;if(!d||d.length===0)d=b.annoFormatString;f=a.extend(true,{},p.textStyle,c.textStyle,h.style);k=f.transform;k&&k.length&&a.each(k,function(b,a){if(a[0].toLowerCase()==="r"){m=true;return false}});f=a.extend(true,f,b.textStyle);j=n.endX-n.startX-b.vOffset-b.axisTextOffset;if(i&&i.length){j=j/(i.length-1);a.each(i,function(p,i){var n,k,o;if(i<u||i>t)return true;if(c.annoMethod==="valueLabels"){if(i<0)return true;if(l>=c.valueLabels.length)return false;i=c.valueLabels[l];if(i.text)i=i.text;else if(typeof i.value!=="undefined"){i=i.value;if(d&&d.length)i=Globalize.format(i,d)}}else if(c.annoMethod==="values")if(d&&d.length){if(s)i=a.fromOADate(i);i=Globalize.format(i,d)}else if(r&&b.id==="y")i=Globalize.format(i,"p0");if(h.width)n=g.canvas.wrapText(-100,-100,i,h.width,h.textAlign,f);else n=g._text(-100,-100,i).attr(f);k=n.wijGetBBox();if(!g._isVertical(q)&&!m&&c.annoMethod==="valueLabels")if(k.width>j){n.attr({transform:"r-45"});k=n.wijGetBBox();if(p===0){f.transform="r-45";b.textStyle={transform:"r-45"};o=n.clone();o.attr({transform:"r0"});k=o.wijGetBBox();if(Math.sqrt(2)*k.height>j){n.attr({transform:"r-90"});f.transform="r-90";b.textStyle={transform:"r-90"}}o.wijRemove();k=n.wijGetBBox()}}n.wijRemove();if(k.width>e.width)e.width=k.width;if(k.height>e.height)e.height=k.height;l++})}if(e.width<h.width)e.width=h.width;b.labelWidth=e.width;return e},_getMajorTickValues:function(d,c){var e=[],b=c.valueLabels;b&&b.length>0&&a.each(b,function(c,a){if(typeof a.text!=="undefined"||typeof a.value!=="undefined")return false;if(typeof a==="string")b[c]={text:a,gridLine:false};else b[c]={value:a,gridLine:false}});if(c.annoMethod==="valueLabels"&&b&&b.length>0&&typeof b[0].value!=="undefined"){e=this._getSortedDataValues(d,c);return e}e=this._getTickValues(d.max,d.min,c.unitMajor,d.tprec,!d.isTime,c.autoMajor);return e},_getSortedDataValues:function(f,c){var e=this,b=[],d=c.valueLabels;a.each(d,function(f,d){var c=d.value;if(e._isDate(c))b.push(a.toOADate(c));else if(typeof c==="number")b.push(c);else b.push(f)});return b},_getMinorTickValues:function(a,b){var c=[];c=this._getTickValues(a.max,a.min,b.unitMinor,a.tprec,!a.isTime,b.autoMinor);return c},_getTickValues:function(f,b,c,g,o,l){var p=this,i=[],n=b,e=0,h=0,m=0,k=0,d=0,j=0;try{if(c===0)i=[f,b];else{if(l){if(g+1<0)g=-1;else if(g+1>15)g=14;j=a.round(p._signedCeiling(b/c)*c,g+1);if(j<f)b=j;m=parseInt(a.round(f/c,5),10);k=parseInt(a.round(b/c,5),10);d=parseInt(m-k+1,10);if(d>1){h=k*c;if(h<b){d--;b+=c}h=b+(d-1)*c;if(h>f)d--}if(d<1){d=2;b=n;c=f-b}}else{d=parseInt((f-b)/c+1,10);if(d>1){h=b+(d-1)*c;if(h>f)d--}if(d<1){d=2;c=f-b}}for(e=0;e<d;e++)if(o)if(l)i[e]=a.round(b+e*c,g+1);else i[e]=b+e*c;else i[e]=b+e*c}}catch(q){}return i},_getTickRect:function(m,d,l,e){var c=d.compass,f=0,a=null,j=3,k=2,i=2,g=d.tickMajor.factor,h=d.tickMinor.factor,b={x:0,y:0,width:0,height:0};if(l){a=d.tickMajor.position;g=g>0?g:1;f=j*g}else{a=d.tickMinor.position;h=h>0?h:1;f=k*h}if(a==="none"||a==="inside"&&e)f=0;if(c==="east"||c==="west"){b={x:0,y:-1,width:f*i,height:i};if(c==="east"&&(a==="outside"||a==="cross"&&e)||c==="west"&&a==="inside")b.width+=2;else if(!e){if(a==="cross")b.width<<=1;b.width+=2}}else{b={x:-1,y:0,width:i,height:f*i};if(c==="south"&&(a==="outside"||a==="corss"&&e)||c==="north"&&a==="inside")b.height+=2;else if(!e){if(a==="cross")b.height<<=1;b.height+=2}}return b},_applyMargins:function(){var c=this,b=c.options,a=c.canvasBounds;a.startX+=b.marginLeft;a.endX-=b.marginRight;a.startY+=b.marginTop;a.endY-=b.marginBottom},_paintAxes:function(){var b=this,h=b.options.axis,g=b.axisInfo,c=h.x,e=h.y,f=g.x,i=g.y,d;d=b._paintAxis(c,f);a.each(i,function(g,f){var a=e[g]||e;a.origin!==null&&b._translateAxisIfNeeded(d,c.compass,a.origin,a.compass,f.max,f.min)});a.each(i,function(h,g){var a=e[h]||e;d=b._paintAxis(a,g);c.origin!==null&&b._translateAxisIfNeeded(d,a.compass,c.origin,c.compass,f.max,f.min)})},_translateAxisIfNeeded:function(g,h,l,i,e,f){var j=this,k=i==="west"||i==="east",b=j.canvasBounds,c=l,d;if(j._isDate(c))c=a.toOADate(c);if(!k){if(h==="west")d=(c-f)/(e-f)*(b.endX-b.startX);else d=(c-e)/(e-f)*(b.endX-b.startX);a.each(g,function(b,a){a.transform(Raphael.format("...T{0},{1}",d,0))})}else{if(h==="south")d=(f-c)/(e-f)*(b.endY-b.startY);else d=(e-c)/(e-f)*(b.endY-b.startY);a.each(g,function(b,a){a.transform(Raphael.format("...T{0},{1}",0,d))})}},_paintAxis:function(b,c){var g=this,B=g.options,d=g.canvasBounds,e={x:0,y:0},f={x:0,y:0},q=b.compass,k=2,x=true,n=null,o=[],s=[],t=[],l=c.max,m=c.min,I=b.unitMajor,J=b.unitMinor,H=b.tickMajor.position,y=b.tickMinor.position,z=c.maxExtent,C=b.tickMajor.style,D=b.tickMinor.style,v=c.majorTickRect,w=c.minorTickRect,u=c.axisTextOffset,E=b.gridMajor,F=b.gridMinor,j=b.labels,A=0,G=[],r=0,h=b.annoFormatString,p=null,i=[];v=g._getTickRect(c,b,true,false);w=g._getTickRect(c,b,false,false);if(!h||h.length===0)h=c.annoFormatString;o=g._getMajorTickValues(c,b);if(y!=="none"){s=g._getMinorTickValues(c,b);t=g._resetMinorTickValues(s,o)}switch(q){case"south":e.x=d.startX;e.y=d.endY;f.x=d.endX;f.y=d.endY;x=false;break;case"north":e.x=d.startX;e.y=d.startY-k;f.x=d.endX;f.y=d.startY-k;x=false;break;case"east":e.x=d.endX;if(c.preStartOffset)e.x+=c.preStartOffset;e.y=d.endY;f.x=d.endX;f.y=d.startY;break;case"west":e.x=d.startX-k;if(c.preStartOffset)e.x-=c.preStartOffset;e.y=d.endY;f.x=d.startX-k;f.y=d.startY}if(b.visible){n=g.canvas.line(e.x,e.y,f.x,f.y).attr(b.style);a.wijraphael.addClass(a(n.node),"wijchart-axis");g.axisEles.push(n);i.push(n)}a.each(o,function(y,k){var d=k,x=c.isTime,w=B.is100Percent,o,n,t=false,s={};if(k<m||k>l)return true;if(b.annoMethod==="valueLabels"){if(r>=b.valueLabels.length)return false;d=b.valueLabels[r];t=d.gridLine;s=d.gridLineStyle;if(d.text)d=d.text;else if(typeof d.value!=="undefined"){d=d.value;if(h&&h.length)d=Globalize.format(d,h)}}else if(b.annoMethod==="values")if(h&&h.length){if(x)d=a.fromOADate(k);d=Globalize.format(d,h)}else if(w&&c.id==="y")d=Globalize.format(k,"p0");p=a.extend(true,{},B.textStyle,b.textStyle,j.style,c.textStyle);o=g._paintMajorMinor(l,m,k,H,I,v,q,e,f,z,u,C,d,E,b.textVisible,p,j.textAlign,j.width?c.labelWidth:null,t,s);if(o){if(o.elements)i=i.concat(o.elements);n=o.textInfo}if(n){G.push(n);if(A<n.len)A=n.len}r++});a.each(t,function(h,d){var a;if(d>m&&d<l){a=g._paintMajorMinor(l,m,d,y,J,w,q,e,f,z,u,D,null,F,b.textVisible,p,j.textAlign,j.width?c.labelWidth:null);if(a&&a.elements)i=i.concat(a.elements)}});b.text&&b.text.length>0&&i.push(g._paintAxisText(b,c));return i},_paintAxisText:function(d,f){if(!d.text||d.text.length===0)return;var j=this,z=d.text,p=d.compass,x=d.alignment,l=j.canvasBounds,m=l.startX,n=l.startY,q=l.endX,r=l.endY,h=m,i=n,c=f.textBounds,o=j._isVertical(p),k=f.axisTextOffset,s=f.majorTickRect,y=d.tickMajor.position,e=o?s.width:s.height,b=null,g=null,w=0,v=0,u=0,t=0;b=a.extend(true,{},j.options.textStyle,d.textStyle);if(b["margin-top"])w=parseFloat(b["margin-top"]);if(b["margin-left"])v=parseFloat(b["margin-left"]);if(b["margin-right"])u=parseFloat(b["margin-right"]);if(b["margin-bottom"])t=parseFloat(b["margin-bottom"]);if(y==="cross")e=e/2;else if(y==="inside")e=0;if(o){switch(x){case"near":i=r-c.width/2;break;case"center":i=(n+r)/2;break;case"far":i=n+c.width/2}if(p==="west")h=m-(f.offset+k+e+c.height/2+u);else h=q+f.offset+k+e+c.height/2+v}else{switch(x){case"near":h=m+c.width/2;break;case"center":h=(m+q)/2;break;case"far":h=q-c.width/2}if(p==="north")i=n-(f.offset+k+e+c.height/2+t);else i=r+f.offset+k+e+c.height/2+w}g=j._text(h,i,z);a.wijraphael.addClass(a(g.node),"wijchart-axis-text");j.axisEles.push(g);g.attr(b);o&&g.transform("...R-90");return g},_resetMinorTickValues:function(a,d){for(var b=0,c=0,f=null,e=null,b=a.length-1;b>=0;b--){f=a[b];for(c=d.length-1;c>=0;c--){e=d[c];f===e&&a.splice(b,1)}}return a},_paintMajorMinor:function(J,u,K,h,L,c,j,t,G,o,k,x,A,q,C,F,E,l,D,B){var f=this,e=t.x,b=t.y,m=-1,n=-1,s=true,g=f.canvasBounds,H=null,r=null,y=[],p=[],d=null,z={"stroke-width":2},i={text:null,len:0},w=null,I={},v=[];switch(j){case"south":if(h==="inside")b-=c.height;else if(h==="cross")b-=c.height/2;if(l)n=b+k+c.height;else n=b+k+c.height+o/2;s=false;break;case"west":if(h==="outside")e-=c.width;else if(h==="cross")e-=c.width/2;if(l)m=e-(k+o);else m=e-(k+o/2);break;case"north":if(h==="outside")b-=c.height;else if(h==="cross")b-=c.height/2;if(l)n=b-(k+o);else n=b-(k+o/2);s=false;break;case"east":if(h==="inside")e-=c.width;else if(h==="cross")e-=c.width/2;if(l)m=e+k+c.width;else m=e+k+c.width+o/2}if(s){b+=(K-u)/(J-u)*(G.y-t.y);p=["M",g.startX,b,"H",g.endX];if(q.visible)if(b!==g.startY&&j==="east"||b!==g.endY&&j==="west"){d=f.canvas.path(p.concat(" "));a.wijraphael.addClass(a(d.node),"wijchart-axis-gridline");d.attr(q.style);f.axisEles.push(d)}if(D)if(b!==g.startY&&j==="east"||b!==g.endY&&j==="west"){d=f.canvas.path(p.concat(" "));a.wijraphael.addClass(a(d.node),"wijchart-axis-gridline");d.attr(a.extend(true,q.style,B));f.axisEles.push(d)}n=b;if(h!=="none"){y=["M",e,b,"h",c.width];x["stroke-width"]=c.height}}else{e+=(K-u)/(J-u)*(G.x-t.x);p=["M",e,g.startY,"V",g.endY];if(q.visible)if(e!==g.startX&&j==="south"||e!==g.endX&&j==="north"){d=f.canvas.path(p.concat(" "));a.wijraphael.addClass(a(d.node),"wijchart-axis-gridline");d.attr(q.style);f.axisEles.push(d)}if(D)if(b!==g.startY&&j==="south"||b!==g.endY&&j==="north"){d=f.canvas.path(p.concat(" "));a.wijraphael.addClass(a(d.node),"wijchart-axis-gridline");d.attr(a.extend(true,{},q.style,B));f.axisEles.push(d)}if(l)m=e-l/2;else m=e;if(h!=="none"){y=["M",e,b,"v",c.height];x["stroke-width"]=c.width}}if(h!=="none"){r=f.canvas.path(y.concat(" "));a.wijraphael.addClass(a(r.node),"wijchart-axis-tick");z=a.extend(z,x);r.attr(z);f.axisEles.push(r);v.push(r)}if(A!==null&&C){if(l){i=f.canvas.wrapText(m,n,A.toString(),l,E,F);a.wijraphael.addClass(a(i.node),"wijchart-axis-label")}else{i=f._text(m,n,A.toString());a.wijraphael.addClass(a(i.node),"wijchart-axis-label");i.attr(F)}f.axisEles.push(i);v.push(i);!C&&i.hide();if(E!=="center"){w=i.getBBox();H={text:i,len:s?w.width:w.height}}}I={textInfo:H,elements:v};return I},_paintPlotArea:function(){},_paintChartLabels:function(){var c=this,b=c.options.chartLabels;b&&b.length&&a.each(b,function(e,b){var d;b=a.extend(true,{compass:"east",attachMethod:"coordinate",attachMethodData:{seriesIndex:-1,pointIndex:-1,x:-1,y:-1},offset:0,visible:false,text:"",connected:false},b);if(b.visible){d=c._getChartLabelPointPosition(b);if(typeof d.x!=="number"||typeof d.y!=="number")return false;c._setChartLabel(b,d)}})},_getChartLabelPointPosition:function(){},_setChartLabel:function(d,g,o,l){var c=this,n=d.compass,k=c.options,m=a.extend(true,{},k.textStyle,k.chartLabelStyle),e=c._text(0,0,d.text).attr(m),h=d.offset,i=0,j=0,b=null,f=null;a.wijraphael.addClass(a(e.node),"wijchart-label-text");c.chartLabelEles.push(e);b=c._getCompassTextPosition(n,e.wijGetBBox(),h,g,o);if(h&&d.connected){f=c.canvas.path("M"+g.x+" "+g.y+"L"+b.endPoint.x+" "+b.endPoint.y);a.wijraphael.addClass(a(f.node),"wijchart-label-connect");f.attr(l);c.chartLabelEles.push(f)}i=b.endPoint.x+b.offsetX;j=b.endPoint.y+b.offsetY;e.transform(Raphael.format("...T{0},{1}",i,j)).toFront()},_getCompassTextPosition:function(h,c,i,g,b){var d=0,e=0,f={x:0,y:0};switch(h.toLowerCase()){case"east":b=0;break;case"west":b=180;break;case"north":b=90;break;case"south":b=270;break;case"northeast":b=45;break;case"northwest":b=135;break;case"southeast":b=315;break;case"southwest":b=225}if(b>=0&&b<45/2||b>675/2&&b<360)d=c.width/2;else if(b>=45/2&&b<135/2){d=c.width/2;e=c.height/-2}else if(b>=135/2&&b<225/2)e=c.height/-2;else if(b>=225/2&&b<315/2){d=c.width/-2;e=c.height/-2}else if(b>=315/2&&b<405/2)d=c.width/-2;else if(b>=405/2&&b<495/2){d=c.width/-2;e=c.height/2}else if(b>=495/2&&b<585/2)e=c.height/2;else{d=c.width/2;e=c.height/2}f=a.wijraphael.getPositionByAngle(g.x,g.y,i,b);return{endPoint:f,offsetX:d,offsetY:e}},_mouseDown:function(b,a){this._trigger("mouseDown",b,a)},_mouseUp:function(b,a){this._trigger("mouseUp",b,a)},_mouseOver:function(b,a){this._trigger("mouseOver",b,a)},_mouseOut:function(b,a){this._trigger("mouseOut",b,a)},_mouseMove:function(b,a){this._trigger("mouseMove",b,a)},_click:function(b,a){this._trigger("click",b,a)},_mouseMoveInsidePlotArea:function(){},_mouseMoveOutsidePlotArea:function(){},_bindLiveEvents:function(){this._bindLegendEvents();this._bindCanvasEvents()},_bindCanvasEvents:function(){var a=this,b=a.chartElement;b.bind("mousemove",function(e){var f=b.offset(),d=a.canvasBounds,c={left:e.pageX-f.left,top:e.pageY-f.top},g=a.options.disabled;if(g)return;if(c.left>=d.startX&&c.left<=d.endX&&c.top>=d.startY&&c.top<=d.endY)a._mouseMoveInsidePlotArea(e,c);else a._mouseMoveOutsidePlotArea(e,c)})},_bindLegendEvents:function(){var b=this,d=b.options.disabled,e=b.chartElement,c=b.widgetName;a(".wijchart-legend",e[0]).live("click."+c,function(e){if(d)return;var c=a(e.target);if(c[0].tagName&&c[0].tagName==="tspan")c=c.parent();b._legendClick(c)})},_legendClick:function(l){if(typeof l.data("index")==="undefined")return;var c=this,m=c.options.legend,e=l.data("index"),i=c.chartElement.data("fields"),j=c.seriesEles,g,f=c.legendIcons[e],h=c.legends[e],b=a(h.node),k=e,d;if(i&&i.seriesEles)j=i.seriesEles;if(c.legendDots&&c.legendDots.length>e)d=c.legendDots[e];if(m.reversed)k=c.legends.length-1-e;g=j[k];if(g)if(!b.data("hidden")){c._hideSerieEles(g);!b.data("textOpacity")&&b.data("textOpacity",h.attr("opacity")||1);!b.data("iconOpacity")&&b.data("iconOpacity",f.attr("opacity")||1);d&&!b.data("dotOpacity")&&b.data("dotOpacity",f.attr("opacity")||1);h.attr("opacity","0.3");f.attr("opacity","0.3");d&&d.attr("opacity","0.3");b.data("hidden",true)}else{c._showSerieEles(g);h.attr("opacity",b.data("textOpacity"));f.attr("opacity",b.data("iconOpacity"));d&&d.attr("opacity",b.data("dotOpacity"));b.data("hidden",false)}},_showSerieEles:function(){},_hideSerieEles:function(){},_unbindLiveEvents:function(){var d=this,c=this.chartElement,b=d.widgetName;a(".wijchart-legend",c[0]).die(b).die("."+b);c.unbind("mousemove")},_isBarChart:function(){return false},_isPieChart:function(){return false},_calculateParameters:function(c,f){var d=this,b=f.max,a=f.min,o=f.autoMax&&c.autoMax,m=f.autoMin&&c.autoMin,r=f.autoMajor&&c.autoMajor,s=f.autoMinor&&c.autoMinor,h=null,k=null,p=f.annoMethod==="valueLabels",e=0,i=0,j=0,g=0,l=0,n=c.isTime,q=d.options.adjustMinValue;if(o&&b!==Number.MIN_VALUE)if(c.id!=="x"&&d._isBarChart())if(b<0&&.5*(b-a)>-b)b=0;if(m&&a!==Number.MAX_VALUE)if(c.id!=="x"&&d._isBarChart())if(a>0&&.5*(b-a)>a)a=0;if(b===a){if(a!==0)a-=1;b+=1}g=b-a;if(n){h=f.annoFormatString;if(!h||h.length===0){h=d._getTimeDefaultFormat(b,a);c.annoFormatString=h}l=d._niceTimeUnit(0,h)}k=d._nicePrecision(g);c.tprec=k;if(o)if(n){i=d._roundTime(b,l,true);if(i<b)b=i+l;else b=i}else{i=d._precCeil(-k,b);if(typeof i==="number")b=i}if(m)if(n){j=d._roundTime(a,l,false);if(j>a)a=j-l;else a=j}else{j=d._precFloor(-k,a);if(typeof j==="number")a=j}c.max=b;c.min=a;c.annoFormatString=h;c.tinc=l;if(r||s){g=b-a;d._calculateMajorMinor(f,c);e=f.unitMajor;if(o&&e!==0&&!n&&!p){g=b-parseInt(b/e,10)*e;if(g!==0){b+=e-g;b=d._precCeil(-k,b)}}if(m&&e!==0&&!n&&!p){g=a-parseInt(a/e,10)*e;if(g!==0){if(g<0)g+=e;a-=Math.abs(g);a=d._precFloor(-k,a)}}if(m&&e!==0&&!p&&(typeof q==="undefined"||q===false)&&m&&a===f.min&&a-e>=0&&c.id==="y")a-=e}c.max=b;c.min=a},_roundTime:function(k,g,e){var c=this,d=g,f=a.fromOADate(k),b,h,j,i;if(d>0){b={year:f.getFullYear(),month:f.getMonth(),day:f.getDate(),hour:f.getHours(),minute:f.getMinutes(),second:f.getSeconds()};if(d<c._tmInc.minute){b.second=c._tround(b.second,d,e);return c._getTimeAsDouble(b)}b.second=0;if(d<c._tmInc.hour){d/=c._tmInc.minute;b.minute=c._tround(b.minute,d,e);return c._getTimeAsDouble(b)}b.minute=0;if(d<c._tmInc.day){d/=c._tmInc.hour;b.hour=c._tround(b.hour,d,e);return c._getTimeAsDouble(b)}b.hour=0;if(d<c._tmInc.month){d/=c._tmInc.day;b.day=c._tround(b.day,d,e);return c._getTimeAsDouble(b)}b.day=1;if(d<c._tmInc.year){d/=c._tmInc.month;b.month=c._tround(b.month,d,e);return c._getTimeAsDouble(b)}b.month=0;d/=c._tmInc.year;b.year=c._tround(b.year,d,e);return c._getTimeAsDouble(b)}else{h=f;j=h-d;i=parseInt(j/g,10)*g;if(e&&i!==j)i+=g;h=d+i;return h}},_tround:function(c,a,d){var b=parseInt(c/a*a,10);if(d&&b!==c)b+=parseInt(a,10);return b},_getTimeAsDouble:function(b){var e=0,d=0,c=null;if(b.day<1){d=-1-b.day;b.day=1}else if(b.day>28){d=b.day-28;b.day=28}if(b.month<0){e=-1-b.day;b.month=0}else if(b.month>11){e=b.month-11;b.month=11}c=new Date(b.year,b.month,b.day,b.hour,b.minute,b.second);c.setDate(c.getDate()+d);c.setMonth(c.getMonth()+e);return a.toOADate(c)},_getTimeDefaultFormat:function(d,e){var c=this,b=d-e,a="d";if(b>2*c._tmInc.year)a="yyyy";else if(b>c._tmInc.year)a="MMM yy";else if(b>3*c._tmInc.month)a="MMM";else if(b>2*c._tmInc.week)a="MMM d";else if(b>2*c._tmInc.day)a="ddd d";else if(b>c._tmInc.day)a="ddd H:mm";else if(b>c._tmInc.hour)a="H:mm";else if(b>=1e3)a="H:mm:ss";return a},_niceTimeUnit:function(c,b){var d=this,a=c;a=d._niceTimeSpan(a,b);return a},_niceTimeSpan:function(f,e){var a=this,c=a._manualTimeInc(e),d=0,b=0;d=Math.ceil(f);if(d===0)return a._timeSpanFromTmInc(c);b=1;if(c<a._tmInc.minute){if(d<a._tmInc.minute){b=a._getNiceInc([1,2,5,10,15,30],d,c);if(b!==0)return b}c=a._tmInc.minute}if(c<a._tmInc.hour){if(d<a._tmInc.hour){b=a._getNiceInc([1,2,5,10,15,30],d,c);if(b!==0)return b}c=a._tmInc.hour}if(c<a._tmInc.day){if(d<a._tmInc.day){b=a._getNiceInc([1,3,6,12],d,c);if(b!==0)return b}c=a._tmInc.day}if(c<a._tmInc.month){if(d<a._tmInc.month){b=a._getNiceInc([1,2,7,14],d,c);if(b!==0)return b}c=a._tmInc.month}if(c<a._tmInc.year){if(d<a._tmInc.year){b=a._getNiceInc([1,2,3,4,6],d,c);if(b!==0)return b}c=a._tmInc.year}b=100*a._tmInc.year;if(d<b){b=a._getNiceInc([1,2,5,10,20,50],d,c);if(b===0)b=100*a._tmInc.year}return b},_getNiceInc:function(c,f,d){for(var b=0,a=0,e=c.length,b=0;b<e;b++){a=c[b]*d;if(f<=a)return a}return 0},_timeSpanFromTmInc:function(a){var b=1e3,d=a,c=1;if(a!==this._tmInc.maxtime)if(a>this._tmInc.tickf1)b=a;else{a+=7;while(d>0){c*=10;d--}b=c}return b},_manualTimeInc:function(a){var c=this,b=c._tmInc.second;if(!a||a.length===0)return b;if(a.indexOf("s")>=0)b=c._tmInc.second;else if(a.indexOf("m")>=0)b=c._tmInc.minute;else if(a.indexOf("h")>=0||a.indexOf("H")>=0)b=c._tmInc.hour;else if(a.indexOf("d")>=0)b=c._tmInc.day;else if(a.indexOf("M")>=0)b=c._tmInc.month;else if(a.indexOf("y")>=0)b=c._tmInc.year;return b},_tmInc:{tickf7:-7e3,tickf6:-6e3,tickf5:-5e3,tickf4:-4e3,tickf3:-3e3,tickf2:-2e3,tickf1:-1,second:1e3,minute:6e4,hour:36e5,day:864e5,week:6048e5,month:26784e5,year:31536e6,maxtime:2147483647},_niceTickNumber:function(a){if(parseFloat(a)===0)return a;else if(a<0)a=-a;var e=Math.log(a)/Math.log(10),d=parseInt(this._signedFloor(e),10),c=a/Math.pow(10,d),b=10;if(c<=1)b=1;else if(c<=2)b=2;else if(c<=5)b=5;return b*Math.pow(10,d)},_niceNumber:function(c,d,e){if(parseFloat(c)===0)return c;else if(c<0)c=-c;var b=c/Math.pow(10,d),a=10;if(e){if(b<1.5)a=1;else if(b<3)a=2;else if(b<7)a=5}else if(b<=1)a=1;else if(b<=2)a=2;else if(b<=5)a=5;return a*Math.pow(10,d)},_nicePrecision:function(a){if(a<=0||typeof a!=="number")return 0;var c=Math.log(a)/Math.log(10),b=parseInt(this._signedFloor(c),10),d=a/Math.pow(10,b);if(d<3)b=-b+1;return b},_precCeil:function(d,c){var b=Math.pow(10,d),a=c/b;a=Math.ceil(a);return a*b},_precFloor:function(d,c){var b=Math.pow(10,d),a=c/b;a=Math.floor(a);return a*b},_signedCeiling:function(a){return a<0?Math.floor(a):Math.ceil(a)},_signedFloor:function(a){return a<0?Math.ceil(a):Math.floor(a)},_getDataExtreme:function(c){var b={txx:0,txn:0,tyx:0,tyn:0},a;a=this._getDataExtremes(b,c);if(a){if(a.txn>a.txx){a.txn=0;a.txx=1}return a}else{if(b.txn>b.txx){b.txn=0;b.txx=1}return b}},_getDataExtremes:function(b){var f=this,j=f.options,l=j.seriesList,n=j.stacked,m=j.is100Percent,c=j.axis,e=f.axisInfo,d=[],k=[],h=[],g,i={y:{}};if(!l||l.length===0)return b;f.seriesGroup&&a.each(f.seriesGroup,function(l,o){var j=[];a.each(o,function(o,h){if(h.type==="pie")return true;h=a.extend(true,{display:"show"},h);var c=h.data,m=0,i=0,l=[].concat(c.xy),p=l.length,e,g;if(h.display==="exclude")return true;d=[].concat(c.x);j=[].concat(c.y);if(c.xy&&p){d=[];j=[];while(i<p){d[m]=l[i];j[m]=l[i+1];i+=2;m++;c.x=d;c.y=j}}else if(!c.x){d=[];a.each(j,function(a){d.push(a)});c.x=d}n&&o>0&&a.each(j,function(a){j[a]+=k[a]});k=j;e=f._getMinMaxValue(d);g=f._getMinMaxValue(j);if(o===0){b.txx=e.max;b.txn=e.min;b.tyx=g.max;b.tyn=g.min}else{if(b.txx<e.max)b.txx=e.max;if(b.txn>e.min)b.txn=e.min;if(b.tyx<g.max)b.tyx=g.max;if(b.tyn>g.min)b.tyn=g.min}o++});if(m){b.tyx=1;b.tyn=0}i.y[l]={tyx:b.tyx,tyn:b.tyn};i.txx=b.txx;i.txn=b.txn;b.tyx=0;b.tyn=0;if(j.length){g=a.wijchart.getFirstValidListValue(j);if(f._isDate(g))e.y[l].isTime=true;else if(typeof g!=="number"){a.each(j,function(e,d){var b=c.y.annoFormatString,a=d;if(b&&b.length>0)a=Globalize.format(a,b);else a=a.toString();h.push({text:a,value:d,gridLine:false})});c.y[parseInt(l,10)].annoMethod="valueLabels";c.y[parseInt(l,10)].valueLabels=h;c.x.max=j.length-1;c.x.min=0;c.y[parseInt(l,10)].unitMajor=1;c.x.unitMinor=.5;e.y[l].autoMax=false;e.y[l].autoMin=false;e.y[l].autoMajor=false;e.y[l].autoMinor=false}}});if(d.length){g=a.wijchart.getFirstValidListValue(d);if(f._isDate(g))e.x.isTime=true;else if(typeof g!=="number"){a.each(d,function(b,a){h.push({text:a,value:b,gridLine:false})});c.x.annoMethod="valueLabels";c.x.valueLabels=h;c.x.max=d.length-1;c.x.min=0;c.x.unitMajor=1;c.x.unitMinor=.5;e.x.autoMax=false;e.x.autoMin=false;e.x.autoMajor=false;e.x.autoMinor=false}}return i},_isDate:function(a){return!a?false:typeof a==="object"&&a.constructor===Date},_getMinMaxValue:function(c){var f=this,b={min:0,max:0},d=0,e;if(!c.length)return;e=a.wijchart.getFirstValidListValue(c);if(typeof e!=="number")if(f._isDate(e)){b.min=e;b.max=e}else{b.min=0;b.max=c.length-1;return b}else{b.min=e;b.max=e}for(d=0;d<c.length;d++){if(c[d]===null||typeof c[d]==="undefined")continue;if(c[d]<b.min)b.min=c[d];else if(c[d]>b.max)b.max=c[d]}if(f._isDate(b.min)){b.min=a.toOADate(b.min);b.max=a.toOADate(b.max)}return b},_isVertical:function(a){return a==="west"||a==="east"},_calculateMajorMinor:function(f,d){var c=this,A=c.options,n=c.canvasBounds,y=f.autoMajor,z=f.autoMinor,p=d.max,q=d.min,v=d.isTime,x=d.tinc,r=d.annoFormatString,s=null,t=null,g=null,h=null,l=null,k=null,o=null,j=null,m=null,e=p-q,w=0,u=0,i=0,b=0;if(y){m=a.extend(true,{},A.textStyle,f.textStyle,f.labels.style);if(v){s=Globalize.format(a.fromOADate(p),r);t=Globalize.format(a.fromOADate(q),r);l=c._text(-1e3,-1e3,s).attr(m);k=c._text(-1e3,-1e3,t).attr(m);g=l.wijGetBBox();h=k.wijGetBBox();l.wijRemove();k.wijRemove()}else{o=c._nicePrecision(e);j=o+1;if(j<0||j>15)j=0;l=c._text(-1e3,-1e3,a.round(p,j)).attr(m);k=c._text(-1e3,-1e3,a.round(q,j)).attr(m);g=l.wijGetBBox();h=k.wijGetBBox();l.wijRemove();k.wijRemove()}if(g.width<h.width)g.width=h.width;if(g.height<h.height)g.height=h.height;if(!c._isVertical(f.compass)){w=n.endX-n.startX-d.vOffset-d.axisTextOffset;b=w/g.width;if(Number.POSITIVE_INFINITY===b)i=0;else i=parseInt(b,10)}else{u=n.endY-n.startY-d.vOffset-d.axisTextOffset;b=u/g.height;if(Number.POSITIVE_INFINITY===b)i=0;else i=parseInt(b,10)}b=e;if(i>0){e/=i;if(v)if(e<x)b=x;else b=c._niceTimeUnit(e,d.annoFormatString);else{d.tprec=c._nicePrecision(e);b=c._niceNumber(2*e,-o,true);if(b<e)b=c._niceNumber(e,-o+1,false);if(b<e)b=c._niceTickNumber(e)}}f.unitMajor=b}if(z&&f.unitMajor&&!isNaN(f.unitMajor))f.unitMinor=f.unitMajor/2}})})(jQuery);
(function(a){"use strict";a.widget("wijmo.wijbarchart",a.wijmo.wijchartcore,{options:{horizontal:true,stacked:false,is100Percent:false,clusterOverlap:0,clusterWidth:85,clusterRadius:0,clusterSpacing:0,animation:{enabled:true,duration:400,easing:">"},seriesTransition:{enabled:true,duration:400,easing:">"},mouseDown:null,mouseUp:null,mouseOver:null,mouseOut:null,mouseMove:null,click:null},_create:function(){var b=this,c=b.options,d=b._getDefFill();c.horizontal&&a.extend(true,c.axis,{x:{compass:"west"},y:{compass:"south"}});a.extend(true,{compass:"east"},c.hint);a.each(c.seriesStyles,function(b,a){if(!a.fill)a.fill=d[b]});a.wijmo.wijchartcore.prototype._create.apply(b,arguments);b.chartElement.addClass("wijmo-wijbarchart")},_setOption:function(c,b){c==="horizontal"&&!b&&a.extend(true,this.options.axis,{x:{compass:"south"},y:{compass:"west"}});a.wijmo.wijchartcore.prototype._setOption.apply(this,arguments)},destroy:function(){var e=this,c=e.chartElement,d=c.data("fields"),b=d&&d.bars;c.removeClass("wijmo-wijbarchart");a.wijmo.wijchartcore.prototype.destroy.apply(this,arguments);b&&b.length&&a.each(b,function(b,a){a=null});c.data("fields",null)},_isBarChart:function(){return true},getBar:function(c){var a=this.chartElement,b=a.data("fields");return b.chartElements.bars[c]},_paintTooltip:function(){var c=this,d=c.chartElement,b=d.data("fields");a.wijmo.wijchartcore.prototype._paintTooltip.apply(this,arguments);if(c.tooltip)if(b&&b.trackers&&b.trackers.length){c.tooltip.setTargets(b.trackers);c.tooltip.setOptions({relatedElement:b.trackers[0]})}},_getTooltipText:function(e,d){var c=a(d.node),b,f;if(c.data("owner"))c=c.data("owner");b=c.data("wijchartDataObj");f={data:b,value:b.value,label:b.label,total:b.total,target:d,fmt:e,x:b.x,y:b.y};return a.proxy(e,f)()},_paintPlotArea:function(){var b=this,c=b.options;b.chartElement.wijbar({canvas:b.canvas,bounds:b.canvasBounds,tooltip:b.tooltip,widgetName:b.widgetName,horizontal:c.horizontal,stacked:c.stacked,axis:c.axis,seriesList:c.seriesList,seriesStyles:c.seriesStyles,seriesHoverStyles:c.seriesHoverStyles,seriesTransition:c.seriesTransition,showChartLabels:c.showChartLabels,textStyle:c.textStyle,chartLabelStyle:c.chartLabelStyle,chartLabelFormatString:c.chartLabelFormatString,shadow:c.shadow,disabled:c.disabled,clusterOverlap:c.clusterOverlap,clusterWidth:c.clusterWidth,clusterSpacing:c.clusterSpacing,is100Percent:c.is100Percent,clusterRadius:c.clusterRadius,animation:c.animation,isYTime:b.axisInfo.y[0].isTime,isXTime:b.axisInfo.x.isTime,mouseDown:a.proxy(b._mouseDown,b),mouseUp:a.proxy(b._mouseUp,b),mouseOver:a.proxy(b._mouseOver,b),mouseOut:a.proxy(b._mouseOut,b),mouseMove:a.proxy(b._mouseMove,b),click:a.proxy(b._click,b)})},_showSerieEles:function(b){a.each(b,function(b,a){if(a.bar){a.bar.show();a.bar.shadow&&a.bar.shadow.show();a.bar.tracker&&a.bar.tracker.show()}a.dcl&&a.dcl.show();a.animatedBar&&a.animatedBar.show()})},_hideSerieEles:function(b){a.each(b,function(b,a){if(a.bar){a.bar.hide();a.bar.shadow&&a.bar.shadow.hide();a.bar.tracker&&a.bar.tracker.hide()}a.dcl&&a.dcl.hide();a.animatedBar&&a.animatedBar.hide()})},_calculateParameters:function(c,e){a.wijmo.wijchartcore.prototype._calculateParameters.apply(this,arguments);if(c.id==="x"){var d=e.unitMinor,b=this._getBarAdjustment(c);if(b===0)b=d;else if(d<b&&d!==0)b=Math.floor(b/d)*d;c.min-=b;c.max+=b;this._calculateMajorMinor(e,c)}},_getBarAdjustment:function(c){for(var a=0,h=this.options,e=c.max,b=c.min,g=h.seriesList,f=0,d=0,f=0;f<g.length;f++){d=g[f].data.x.length;if(a<d)a=d}if(a>1)return(e-b)/a*h.clusterWidth*.0125;else if(a===1){if(b===0&&e===1){b=-1;c.min=b}return(e-b)*.0125}else return 0}});a.fn.extend({wijbar:function(b){var C=function(c,d,e){b.shadow&&a.wijchart.paintShadow(c,d,e)},t=a.wijraphael.addClass,D=a.wijchart.getScaling,z=a.wijchart.getTranslation,d=this,e=b.canvas,h=b.widgetName,c=b.horizontal,k=b.stacked,s=[].concat(b.seriesList),u=s.length,B=[].concat(b.seriesStyles.slice(0,u)),y=[].concat(b.seriesHoverStyles.slice(0,u)),q=b.bounds,p=b.animation,H=p&&p.enabled,o={x:q.startX,y:q.startY},N=q.endX-o.x,L=q.endY-o.y,l=b.axis.x,w=b.axis.y,j=b.disabled,E=b.mouseDown,J=b.mouseUp,G=b.mouseOver,I=b.mouseOut,F=b.mouseMove,M=b.click,K=b.tooltip,v=D(c,l.max,l.min,c?L:N),O=z(c,o,l.max,l.min,v),r,x,f=d.data("fields")||{},m=f.chartElements||{},i=f.aniBarsAttr,g,Z=b.isYTime,Y=b.isXTime;function W(d){for(var a=Number.MAX_VALUE,e=d.length,c,b=1;b<e;b++){c=d[b].x-d[b-1].x;if(c<a&&c>0)a=c}return a===Number.MAX_VALUE?2:a}function V(b){a.each(b,function(b,a){a.stackValues()});return b}function A(f){var b=[],d=a.wijchart.getXSortedPoints;function c(c){var b=this;b.x=c;b.paSpec=[];b.stackValues=function(){var d=b.paSpec.length,c;if(d>1){c=b.paSpec[0];a.each(b.paSpec,function(b,a){if(b===0)return true;a.y+=c.y;c=a})}}}function e(n,m){var h=d(m),l=m.length,f=null,o=0,e=0,g=0,k=true,i=0,j=false;if(h)o=h.length;if(b)g=b.length;a.each(h,function(d,a){if(k){k=false;i=a.x}else{if(i===a.x)j=true;else j=false;i=a.x}while(e<g&&b[e].x<a.x)e++;if(e<g)if(b[e].x!==a.x){f=new c(a.x,l);b.splice(e,0,f);g=b.length}else f=b[e];else{f=new c(a.x,l);b.push(f);g=b.length}f.paSpec.push({y:a.y,sIdx:n,pIdx:d,dupl:j})})}a.each(f,function(b,a){e(b,a)});return b}function n(a,c,b){return a<c?c:a>b?b:a}function R(c,d,e,f,g,b){a.each(b,function(j,a){var h=a.x,i=a.y,b=0;a.x=d*h+f;a.y=e*i+g;if(c){b=a.x;a.x=a.y;a.y=b}});return b}function P(d,n,m,l){var i=a.extend(true,{},b.textStyle,b.chartLabelStyle),h=c?{x:d.x+d.width,y:d.y+d.height/2}:{x:d.x+d.width/2,y:d.y},k=b.chartLabelFormatString,j,f,g=n;if(l)i=a.extend(true,i,l);if(m)g=a.fromOADate(n);if(k&&k.length)g=Globalize.format(g,b.chartLabelFormatString);else if(!m)g=a.round(g,2);f=e.text(h.x,h.y,g).attr(i);t(a(f.node),"wijbarchart-label");j=f.getBBox();if(c)f.attr({x:h.x+j.width/2});else f.attr({y:h.y-j.height/2});return f}function X(g,A,Q,t,u,r,G,E,D,M,o,B,O,L,J){var N=b.is100Percent,x=t.min,w=t.max,z=u.min,y=u.max,T=t.scale,U=t.late,H=u.scale,K=u.late,v,d,F,f,s=null,j,I=r,m=r["stroke-width"],S=r.stroke,i,p,l,h,q=-1;if(J.origin!==null)q=H*J.origin+K;if(k)if(N){if(B>0)g.height=A/B;if(o||o===0){g.y=o/B;g.height-=g.y}}else{g.height=A;if(o||o===0){g.height-=o;g.y=o}}else if(o||o===0){g.x+=g.width*(1-M);g.height=A}d=[{x:g.x,y:g.y},{x:g.x+g.width,y:g.y+g.height}];F=(x<=d[0].x&&d[0].x<=w||x<=d[1].x&&d[1].x<=w)&&(z<=d[0].y&&d[0].y<=y||z<=d[1].y&&d[1].y<=y);d[0].x=n(d[0].x,x,w);d[0].y=n(d[0].y,z,y);d[1].x=n(d[1].x,x,w);d[1].y=n(d[1].y,z,y);d=R(c,T,H,U,K,d);if(d[0].x>d[1].x){v=d[0].x;d[0].x=d[1].x;d[1].x=v}if(d[0].y>d[1].y){v=d[0].y;d[0].y=d[1].y;d[1].y=v}f={x:d[0].x,y:d[0].y,width:d[1].x-d[0].x,height:d[1].y-d[0].y};if(F){if(f.width===0)f.width=.5;if(f.height===0)f.height=.5}if(b.showChartLabels)s=P(f,A,O,L);j=r.r?r.r:b.clusterRadius;if(j)I=a.extend(true,{},r,{r:0});if(S!=="none"&&m)m=parseInt(m,10);if(!m||isNaN(m))m=0;p=f.width-m;l=f.height-m;if(p<0)p=0;if(l<0)l=0;if(G){if(q===-1)if(c)q=D.x;else q=D.y+Q-m;if(j){if(c){i=e.roundRect(f.x,f.y,p,l,0,0,j,j).hide();h=e.rect(q,f.y,0,l)}else{i=e.roundRect(f.x,f.y,p,l,j,0,0,j).hide();h=e.rect(f.x,q,f.width,0)}C(h,E);h.wijAttr(I);h.bar=i}else{if(c)i=e.rect(q,f.y,0,l);else i=e.rect(f.x,q,f.width,0);h=i}if(s){s.attr({opacity:0});h.chartLabel=s}h.left=f.x;h.top=f.y;h.width=p;h.height=l;h.r=j}else if(j)i=e.roundRect(f.x,f.y,p,l,0,0,j,j);else i=e.rect(f.x,f.y,p,l);C(i,E);if(G&&j)i.shadow&&i.shadow.hide();i.wijAttr(r);return{rect:f,dcl:s,animatedBar:h,bar:i}}function T(i,J,F,K,v,C,p,q,n,y){var f=b.clusterOverlap/100,I=b.clusterWidth/100,u=1,G=b.clusterSpacing+u,o=i.length,d,g,l=[],E=[],s=[],j=[],B=[],h=[],m=e.set();if(n||y){a.each(i,function(d,c){var b=a.extend(true,{},c);b.data&&b.data.y&&b.data.y.length&&n&&a.each(b.data.y,function(d,c){b.data.y[d]=a.toOADate(c)});b.data&&b.data.x&&b.data.x.length&&y&&a.each(b.data.x,function(d,c){b.data.x[d]=a.toOADate(c)});B.push(b)});d=A(B)}else d=A(i);if(k)d=V(d);g=W(d)*I;if(o>1&&!k){f-=d.length*(o-1)*G/(c?p:C);g/=o*(1-f)+f}a.each(d,function(o,B){var e=B.paSpec,G=e.length,y,A,d,b;if(k)y=g;else y=g*(G*(1-f)+f);A={x:B.x-y/2,y:0,width:g,height:e[0].y};a.each(e,function(g,N){if(!j[g])j[g]=[];if(!h[g])h[g]=[];var I=N.sIdx,L=J[I],y=i[I],k,M=y.yAxis||0,B=w[M]||w,G=v[M]||v;r=D(!c,B.max,B.min,c?C:p);x=z(!c,q,B.max,B.min,r);G.late=x;G.scale=r;b=X(A,N.y,p,K,G,L,H,u,q,f,g>0?e[g-1].y:null,e[e.length-1].y,n,y.textStyle,B);d=b.bar;k=d.clone().attr({opacity:.01,fill:"white","stroke-width":0,"fill-opacity":.01});t(a(d.node),"wijchart-canvas-object wijbarchart");a(d.node).data("wijchartDataObj",a.extend(true,{index:o,bar:d,type:"bar",style:L,hoverStyle:F[I],x:y.data.x[o],y:y.data.y[o]},y));a(k.node).data("owner",a(d.node));t(a(k.node),"wijbarchart bartracker");b.bar.tracker=k;m.push(k);E.push(d);b.animatedBar&&s.push(b.animatedBar);b.dcl&&l.push(b.dcl);j[g][o]=b.rect;h[g][o]=b})});a.each(l,function(b,a){a.toFront()});m.toFront();return{bars:E,animatedBars:s,rects:j,chartLabels:l,seriesEles:h,trackers:m}}function U(k){var e=b.seriesTransition,g,h,j=[],d;if(H){g=p.duration||2e3;h=p.easing||"linear";a.each(k,function(f,b){var k=c?{width:b.width,x:b.left}:{height:b.height,y:b.top};if(i&&e.enabled)if(i.length>f){d=a.wijchart.getDiffAttrs(i[f],b.attr());if(c){d.x=i[f].x;d.width=i[f].width}else{d.y=i[f].y;d.height=i[f].height}if(d.path)delete d.path;b.attr(d);g=e.duration;h=e.easing}j.push(a.extend(true,{},b.attr(),k));b.tracker&&b.tracker.hide();b.stop().wijAnimate(k,g,h,function(){var a=this,c=a.r,b=a;a.chartLabel&&a.chartLabel.wijAnimate({opacity:1},250);if(a.tracker){a.tracker.show();a.tracker.attr({width:a.width,height:a.height,x:a.attr("x"),y:a.attr("y")})}if(c){b=a.bar;b.show();b.shadow&&b.shadow.show();if(a.shadow){a.shadow.wijRemove();a.shadow=null}a.wijRemove();a=null}})});f.aniBarsAttr=j}}function S(){var b=a.isFunction;K&&K.setTargets(m.bars);a(".wijbarchart",d[0]).live("mousedown."+h,function(f){if(j)return;if(b(E)){var c=a(f.target),e;if(c.data("owner"))c=c.data("owner");e=c.data("wijchartDataObj");E.call(d,f,e)}}).live("mouseup."+h,function(f){if(j)return;if(b(J)){var c=a(f.target),e;if(c.data("owner"))c=c.data("owner");e=c.data("wijchartDataObj");J.call(d,f,e)}}).live("mouseover."+h,function(f){if(j)return;if(b(G)){var c=a(f.target),e;if(c.data("owner"))c=c.data("owner");e=c.data("wijchartDataObj");G.call(d,f,e)}}).live("mouseout."+h,function(g){if(j)return;var e=a(g.target),c,f;if(e.data("owner"))e=e.data("owner");c=e.data("wijchartDataObj");f=c.bar;if(!c.hoverStyle)f&&f.attr({opacity:"1"});else f.attr(c.style);b(I)&&I.call(d,g,c)}).live("mousemove."+h,function(g){if(j)return;var e=a(g.target),c,f;if(e.data("owner"))e=e.data("owner");c=e.data("wijchartDataObj");f=c.bar;if(!c.hoverStyle)f&&f.attr({opacity:"0.8"});else f.attr(c.hoverStyle);b(F)&&F.call(d,g,c)}).live("click."+h,function(f){if(j)return;if(b(M)){var c=a(f.target),e;if(c.data("owner"))c=c.data("owner");e=c.data("wijchartDataObj");M.call(d,f,e)}})}function Q(){a(".wijbarchart",d[0]).die(h).die("."+h)}Q();if(c&&!k){s.reverse();B.reverse();y.reverse()}if(u===0)return;g=T(s,B,y,{min:l.min,max:l.max,late:O,scale:v},w,N,L,o,Z,Y);d.data("plotInfos",{xscale:v,xlate:O,yscale:r,ylate:x,rects:g.rects});U(g.animatedBars);m.bars=g.bars;m.animatedBars=g.animatedBars;m.chartLabels=g.chartLabels;f.seriesEles=g.seriesEles;f.trackers=g.trackers;if(!f.chartElements)f.chartElements={};c&&!k&&f.seriesEles.reverse();a.extend(true,f.chartElements,m);d.data("fields",f);S()}})})(jQuery);
(function(a){"use strict";if(!window.Raphael)return;a.widget("wijmo.wijlinechart",a.wijmo.wijchartcore,{options:{stacked:false,hole:null,type:"line",animation:{enabled:true,direction:"horizontal",duration:2e3,easing:">"},seriesTransition:{enabled:true,duration:2e3,easing:">"},mouseDown:null,mouseUp:null,mouseOver:null,mouseOut:null,mouseMove:null,click:null},_create:function(){var b=this,c=b.options;a.wijmo.wijchartcore.prototype._create.apply(b,arguments);b.chartElement.addClass("wijmo-wijlinechart");c.type==="area"&&b.chartElement.addClass("wijmo-wijareachart")},destroy:function(){var b=this,c=b.options;b.chartElement.removeClass("wijmo-wijlinechart");c.type==="area"&&b.chartElement.removeClass("wijmo-wijareachart");a.wijmo.wijchartcore.prototype.destroy.apply(b,arguments);if(b.aniPathsAttr&&b.aniPathsAttr.length){a.each(b.aniPathsAttr,function(b,a){a=null});b.aniPathsAttr=null}},getLinePath:function(c){var d=this,b=d.chartElement.data("fields"),a,e;if(b&&b.chartElements){a=b.chartElements;if(a.paths&&a.paths.length)return a.paths[c]}return e},getLineMarkers:function(b){var e=this,d=e.options,c=e.chartElement.data("fields"),a,f;if(d.seriesList&&d.seriesList[b].markers&&d.seriesList[b].markers.visible)if(c&&c.chartElements){a=c.chartElements;if(a.markersSet&&a.markersSet.length)return a.markersSet[b]}return f},_showSerieEles:function(b){var d=this.options,c;b.markers&&a.each(b.markers,function(d,c){var b=a(c.node).data("wijchartDataObj");if(b&&b.lineSeries&&b.lineSeries.markers)if(!b.lineSeries.markers.visible)return true;c.show()});b.dcl&&a.each(b.dcl,function(b,a){d.showChartLabels&&a.show()});if(b.path){c=a(b.path.node).data("wijchartDataObj");if(c.visible||c.display==="show"){b.path.show();b.path.shadow&&b.path.shadow.show();b.path.area&&b.path.area.show();b.path.tracker&&b.path.tracker.show()}}},_hideSerieEles:function(b){b.markers&&a.each(b.markers,function(b,a){a.hide()});b.dcl&&a.each(b.dcl,function(b,a){a.hide()});if(b.path){b.path.hide();b.path.shadow&&b.path.shadow.hide();b.path.area&&b.path.area.hide();b.path.tracker&&b.path.tracker.hide()}},_paintLegend:function(){var d=this,k=d.options,b=0,n=0,m=0,i=null,l=k.seriesList,q=k.seriesStyles,c=null,j=null,e=null,o=0,p=0,g=null,h=null,f=null;a.extend(true,k,{legend:{size:{width:30,height:3}}});a.wijmo.wijchartcore.prototype._paintLegend.apply(d,arguments);if(k.legend.visible){if(d.legends.length&&d.legendIcons.length)for(b=0,n=d.legendIcons.length;b<n;b++){i=d.legendIcons[b];i.attr({fill:i.attr("stroke")})}if(!k.legend.reversed)for(b=0,n=l.length;b<n;b++){c=l[b];j=q[b];if(c.legendEntry&&c.display!=="exclude"){if(c.markers&&c.markers.visible){i=d.legendIcons[m];e=i.wijGetBBox();o=e.x+e.width/2;p=e.y+e.height/2;g=c.markerStyle;g=a.extend({fill:j.stroke,stroke:j.stroke,opacity:1},g);h=c.markers.type;if(!h)h="circle";f=d.canvas.paintMarker(h,o,p,3);a.wijraphael.addClass(a(f.node),"chart-legend-dot wijchart-legend");f.attr(g);a(f.node).data("index",b);d.legendDots.push(f)}m++}}else for(b=l.length-1;b>=0;b--){c=l[b];j=q[b];if(c.legendEntry&&c.display!=="exclude"){if(c.markers&&c.markers.visible){i=d.legendIcons[m];e=i.wijGetBBox();o=e.x+e.width/2;p=e.y+e.height/2;g=c.markerStyle;g=a.extend({fill:j.stroke,stroke:j.stroke,opacity:1},g);h=c.markers.type;if(!h)h="circle";f=d.canvas.paintMarker(h,o,p,3);a.wijraphael.addClass(a(f.node),"chart-legend-dot wijchart-canvas-object wijchart-legend");f.attr(g);a(f.node).data("index",b);d.legendDots.push(f)}m++}}}},_mouseDown:function(){a.wijmo.wijchartcore.prototype._mouseDown.apply(this,arguments)},_mouseUp:function(){a.wijmo.wijchartcore.prototype._mouseUp.apply(this,arguments)},_mouseOver:function(d,c){var b=this;if(!c||c.type!=="line")return;a.wijmo.wijchartcore.prototype._mouseOver.apply(this,arguments);if(c.path.removed)return;if(b.hoverLine!==c){b.isNewLine=true;if(b.hoverLine)if(!b.hoverLine.path.removed){b.hoverLine.path.wijAttr(b.hoverLine.lineStyle);if(b.hoverPoint&&!b.hoverPoint.isSymbol){b.hoverPoint.marker.wijAttr(b.hoverPoint.markerStyle);b.hoverPoint.marker.transform("s1")}}c.lineHoverStyle&&c.path.wijAttr(c.lineHoverStyle);b.hoverLine=c;b.hoverPoint=null}},_mouseOut:function(){a.wijmo.wijchartcore.prototype._mouseOut.apply(this,arguments)},_mouseMove:function(){a.wijmo.wijchartcore.prototype._mouseMove.apply(this,arguments)},_click:function(){a.wijmo.wijchartcore.prototype._click.apply(this,arguments)},_mouseMoveInsidePlotArea:function(t,s){var b=this,f=b.tooltip,h=b.options.hint,g,d=0,l,e,j,k,r=null,c=null,i=null,q=h.title,p=h.content,n=a.isFunction(q),m=a.isFunction(p),o=0;if(f)i=f.getOptions();if(b.hoverLine){if(b.isNewLine){h.enable&&f&&f.hide();b.isNewLine=false}g=b.hoverLine.lineMarkers;d=-1;l={x:0,y:0};a.each(g,function(f,b){if(b.removed)return true;var a=b.wijGetBBox(),e=a.x+a.width/2,c=Math.abs(e-s.left);if(f===0||c<o){o=c;d=f;l={x:e,y:a.y+a.height/2}}});if(b.hoverPoint&&b.hoverPoint.index===d)return;if(d>-1){if(g[d].removed)return;e=a(g[d].node).data("wijchartDataObj");if(e){if(b.hoverPoint&&!b.hoverPoint.isSymbol)if(!b.hoverPoint.removed){b.hoverPoint.marker.wijAttr(b.hoverPoint.markerStyle);b.hoverPoint.marker.transform("s1")}if(!e.isSymbol)!e.marker.removed&&e.marker.wijAttr(e.markerHoverStyle)}b.hoverPoint=e}if(f){c=b.hoverPoint;j=c.valX;k=c.valY;if(n||m){if(n)i.title=function(){var b={pointIndex:d,lineIndex:c.lineSeries.index,x:j,y:k,label:c.lineSeries.label,data:c,fmt:q},e=a.proxy(b.fmt,b),f=e();return f};if(m)i.content=function(){var b={pointIndex:d,lineIndex:c.lineSeries.index,x:j,y:k,label:c.lineSeries.label,data:c,fmt:p},f=a.proxy(b.fmt,b),e=f();return e}}r=a.extend({stroke:b.hoverLine.path.attr("stroke")},h.style);i.style.stroke=r.stroke;f.showAt(l)}}a.wijmo.wijchartcore.prototype._mouseMoveInsidePlotArea.apply(b,arguments)},_mouseMoveOutsidePlotArea:function(){var b=this;b._clearHoverState();a.wijmo.wijchartcore.prototype._mouseMoveOutsidePlotArea.apply(b,arguments)},_clearHoverState:function(){var a=this,b=a.tooltip,c=a.options.hint;c.enable&&b&&b.hide();if(a.hoverLine)if(!a.hoverLine.path.removed){a.hoverLine.path.wijAttr(a.hoverLine.lineStyle);if(a.hoverPoint&&!a.hoverPoint.isSymbol){a.hoverPoint.marker.wijAttr(a.hoverPoint.markerStyle);a.hoverPoint.marker.transform("s1")}}a.hoverLine=null;a.hoverPoint=null},_paintPlotArea:function(){var b=this,c=b.options,d;if(!b.aniPathsAttr)b.aniPathsAttr=[];d={bounds:b.canvasBounds,widgetName:b.widgetName,canvas:b.canvas,tooltip:b.tooltip,stacked:c.stacked,hole:c.hole,type:c.type,axis:c.axis,animation:c.animation,seriesTransition:c.seriesTransition,seriesList:c.seriesList,seriesStyles:c.seriesStyles,seriesHoverStyles:c.seriesHoverStyles,showChartLabels:c.showChartLabels,chartLabelStyle:c.chartLabelStyle,chartLabelFormatString:c.chartLabelFormatString,isXTime:b.axisInfo.x.isTime,isYTime:b.axisInfo.y.isTime||b.axisInfo.y[0].isTime,disabled:c.disabled,hint:c.hint,aniPathsAttr:b.aniPathsAttr,chartLabelEles:b.chartLabelEles,mouseDown:a.proxy(b._mouseDown,b),mouseUp:a.proxy(b._mouseUp,b),mouseOver:a.proxy(b._mouseOver,b),mouseOut:a.proxy(b._mouseOut,b),mouseMove:a.proxy(b._mouseMove,b),click:a.proxy(b._click,b)};b.chartElement.wijline(d)}})})(jQuery);(function(a){"use strict";if(!window.Raphael)return;a.wijchart._line=function(e,b){var f=this,p=b.bounds,n=b.widgetName,s=b.canvas,t=b.animation,q=b.seriesTransition,C=b.hint,A=b.tooltip,u=b.mouseDown,z=b.mouseUp,w=b.mouseOver,y=b.mouseOut,v=b.mouseMove,B=b.click,l=[],r=[],k=[],h=[],j=[],x=b.disabled,g=s.set(),d=b.aniPathsAttr,i=[],o,c=e.data("fields")||{},m=[];f.render(b,i,d,h,j,l,g,r,k,m);(t.enabled||q.enabled)&&f.playAnimation(t,q,g,p,h,d);d.length=0;a.each(i,function(b,a){d.push(a)});f.unbindLiveEvents(e,n);f.bindLiveEvents(e,s,p,n,u,z,w,y,v,B,x,C,k,A);o={paths:h,shadowPaths:j,markersSet:l,animationSet:g,symbols:r};if(!c.chartElements)c.chartElements={};c.seriesEles=m;a.extend(true,c.chartElements,o);e.data("fields",c)};a.wijchart._line.prototype.playAnimation=function(g,b,h,i,j,c){var f=this,d=g.duration,e=g.easing;if(g.direction==="horizontal"){if(c&&c.length&&b.enabled){d=b.duration;e=b.easing}f.playHAnimation(d,e,h,i)}else a.each(j,function(g,a){if(c&&c.length&&b.enabled){d=b.duration;e=b.easing;f.playVAnimation(a,c,g,d,e)}else a.straight&&f.playVStraightAnimation(a,d,e)})};a.wijchart._line.prototype.playVAnimation=function(b,g,h,e,f){var c,d;b.shadow&&b.shadow.hide();b.tracker&&b.tracker.hide();c=g[h];d=a.wijchart.getDiffAttrs(c.path,b.attr());if(!a.isEmptyObject(d)){b.attr(c.path);b.wijAnimate(d,e,f,function(){b.shadow&&b.shadow.show();b.tracker&&b.tracker.show()})}a.each(b.markers,function(g,b){var d=a.wijchart.getDiffAttrs(c.markers[g],b.attr());if(!a.isEmptyObject(d)){b.attr(c.markers[g]);b.wijAnimate(d,e,f)}});b.labels&&a.each(b.labels,function(h,d){var g=a.wijchart.getDiffAttrs(c.labels[h],d.attr()),b=c.labels[h];if(b&&b.text)delete b.text;if(!a.isEmptyObject(g)){d.attr(b);d.wijAnimate(g,e,f)}});if(b.area){d=a.wijchart.getDiffAttrs(c.area,b.area.attr());if(!a.isEmptyObject(d)){b.area.attr(c.area);b.area.wijAnimate(d,e,f)}}};a.wijchart._line.prototype.playVStraightAnimation=function(b,f,g){var d,e,c;b.shadow&&b.shadow.hide();b.tracker&&b.tracker.hide();d=b.straight;e=b.attr().path;b.attr({path:d});b.wijAnimate({path:e},f,g,function(){b.shadow&&b.shadow.show();b.tracker&&b.tracker.show()});a.each(b.markers,function(c,a){if(a.straight){var b=a.attr().cy;a.attr({cy:a.straight});a.wijAnimate({cy:b},f,g)}});if(b.area){c=b.area;d=c.straight;e=c.attr().path;c.attr({path:d});c.wijAnimate({path:e},f,g)}};a.wijchart._line.prototype.playHAnimation=function(e,f,c,b){var g=b.endX-b.startX+20,d=b.endY-b.startY+20;c.wijAttr("clip-rect",b.startX-10+" "+(b.startY-10)+" 0 "+d);c.wijAnimate({"clip-rect":b.startX-10+" "+(b.startY-10)+" "+g+" "+d},e,f,function(){if(Raphael.vml){var b=null,d=null,c=this.node;if(c&&c.clipRect){b=this.attrs;delete b["clip-rect"];c.clipRect=null;d=a(c).parent();d.before(c);d.remove();this.attr(b);b.src&&b.src.length&&this.attr({src:b.src})}}})};a.wijchart._line.prototype.render=function(b,F,t,l,p,J,u,M,I,K){var s=this,w=b.bounds,k=b.canvas,q=b.stacked,O=b.hole,P=b.type,N=b.axis,Q=b.animation,L=b.seriesTransition,n=false,v=b.seriesList,A=b.seriesStyles,B=b.seriesHoverStyles,D=b.showChartLabels,C=b.chartLabelStyle,z=b.chartLabelFormatString,y=b.isXTime,h=b.isYTime,E=b.chartLabelEles,e,f,g,x,r,c,H=[],G=[],d,j,i,o,m;a.each(v,function(W,b){var Y=[],Z=[],ab=[],T,S,V,R,U,X;if(b.display==="exclude")return true;X=A[W];b=a.extend(true,{display:"show",fitType:"line",markers:{visible:false,type:"circle"},visible:true},b);T=b.data;S=a.extend({stroke:"black",opacity:1,fill:"none","stroke-linejoin":"round","stroke-linecap":"round"},X);R=b.markerStyle;R=a.extend({fill:S.stroke,stroke:S.stroke,opacity:1,width:3},R);V=B[W];U=a.extend(true,{},V,{transform:"s1.5","stroke-width":1},v.markerHoverStyle);r=[].concat(T.x);c=[].concat(T.y);i=k.set();j=[];x=b.fitType;o=false;if(b.markers.symbol&&b.markers.symbol.length)o=true;e=k.set();if(!t||t.length===0||Q.enabled&&!L.enabled)n=true;if(n)if(c.length>0){f=a.wijchart.getFirstValidListValue(c);if(h)f=a.toOADate(f);g=a.wijchart.getLastValidListValue(c);if(h)g=a.toOADate(g)}m=s.processYValues(c,b.display,O,q,H);a.each(c,function(l,p){d=r[l];if(y)d=a.toOADate(d);p=c[l];if(m[l].isHole){if(b.display==="excludeHole")return true;if(!m[l].isValue)return true}if(h)p=a.toOADate(p);if(d===undefined)return false;j=s.renderPoint(w,k,ab,j,i,Y,u,e,Z,E,z,n,f,g,d,p,T.y[l],N,x,y,h,l,R,U,b,o,D,M,r,c,m,b.display,q)});s.renderPath(k,w,b,l,p,I,V,R,U,i,J,u,j,F,ab,S,C,Y,Z,e,W,P,G,q);K.push({markers:i,path:l[l.length-1],shadowPath:p[p.length-1],dcl:e})});a.each(l,function(b,a){a.tracker&&a.tracker.toFront()})};a.wijchart._line.prototype.renderPath=function(t,g,d,D,H,I,x,G,E,l,J,z,b,A,h,e,F,w,y,n,i,L,B,K){var c,v,C,j,f,u,m,s,p,o,q,k,r;c=t.path(b.join(" "));c.straight=h.join(" ");a.wijchart.paintShadow(c);if(i===0){B.length=0;if(b.length>1){f=b[1];u=b[b.length-2]}else{f=g.startX;u=g.endX}a.merge(B,["L",f,g.endY,"L",u,g.endY])}m=t.path(b.join(" "));c.tracker=m;if(e["stroke-width"])s=10+parseFloat(e["stroke-width"]);else s=10;m.attr({"stroke-width":s,stroke:"#C0C0C0",opacity:.01});a.wijraphael.addClass(a(m.node),"wijchart-canvas-object wijlinechart linetracker");a(m.node).data("owner",a(c.node));if(L==="area"){if(e.fill&&e.fill!=="none"){v=e.fill;delete e.fill}else v=e.stroke;C=.5;c.wijAttr(e);if(b.length>1)f=b[1];else f=g.startX;if(K)if(i>0){o=Raphael.parsePathString(D[i-1].attr("path"));if(o.length>0){for(r=o.length-1;r>=0;r--){q=o[r];if(q.length===3){b.push("L");b.push(q[1]);b.push(q[2])}}b.push("Z")}}else{b.push("V");b.push(g.endY);b.push("H");b.push(f);b.push("Z")}else{k=Raphael.parsePathString(c.attr("path"));if(k.length>0){b=[];a.each(k,function(d,c){a.each(c,function(c,a){b.push(a)});if(c[0]==="M")f=c[1];if(d<k.length-1&&k[d+1][0]==="M"){b.push("V");b.push(g.endY);b.push("H");b.push(f);b.push("Z")}if(d===k.length-1){b.push("V");b.push(g.endY);b.push("H");b.push(f);b.push("Z")}})}}j=t.path(b.join(" "));a.wijraphael.addClass(a(j.node),"wijlinechart-area");j.wijAttr({fill:v,opacity:C,stroke:"none"});h.push("V");h.push(g.endY);h.push("H");h.push(f);h.push("Z");j.straight=h.join(" ");c.area=j;z.push(j);A.push({path:a.extend(true,{},c.attr()),area:a.extend(true,{},j.attr()),markers:w,labels:y})}else{c.wijAttr(e);A.push({path:a.extend(true,{},c.attr()),markers:w,labels:y})}c.markers=l;D.push(c);if(c.shadow)H[i]=c.shadow;z.push(c);I[i]={lineStyle:e,lineHoverStyle:x,markerStyle:G,markerHoverStyle:E};(!d.markers.visible||d.display==="hide")&&l.hide();if(!d.visible||d.display==="hide"){c.hide();c.shadow&&c.shadow.hide();c.area&&c.area.hide()}d.markers.style&&l.attr(d.markers.style);l.toFront();if(n.length){p=a.extend(true,{},F);if(d.textStyle)p=a.extend(true,p,d.textStyle);n.attr(p);n.toFront();c.labels=n}J[i]=l;d.index=i;d.type="line";d.path=c;d.lineMarkers=l;d.lineStyle=e;d.lineHoverStyle=x;a.wijraphael.addClass(a(c.node),"wijchart-canvas-object wijlinechart");a(c.node).data("wijchartDataObj",d)};a.wijchart._line.prototype.renderPoint=function(d,C,p,q,S,J,M,H,L,K,F,w,x,O,n,t,W,l,Q,R,z,c,v,G,y,N,I,U,A,B,i,P,T){var s=this,X=d.endX-d.startX,V=d.endY-d.startY,j=l.x.min,m=l.y.min,D=l.x.max,Y=l.y.max,E=X/(D-j),u=V/(Y-m),r,e,o,f=0,g,h,b,k;if(isNaN(n)||typeof n==="string")o=c;else o=n;f=d.startX+(o-j)*E;g=d.endY-(t-m)*u;i[c].x=f;i[c].y=g;if(w){h=x+(O-x)/(D-j)*(o-j);h=d.endY-(h-m)*u;p.push(i[c].idx?"L":"M");p.push(f);p.push(h)}if(!i[c].isHole)q=s.getPathArrByFitType(q,Q,c,B.length,d,A,B,f,g,R,z,n,t,E,u,j,m,i,P,T);if(I){k=s.renderChartLabel(C,z,t,F,f,g);K.push(k);H.push(k);L.push(a.extend(true,{},k.attr()))}r=s.renderMarker(C,U,N,y.markers,c,f,g,v);e=r.dot;if(w)e.straight=h;b={};b.valX=A[c];b.valY=W;b.marker=e;b.index=c;b.type="marker";b.lineSeries=y;b.x=f;b.y=g;b.isSymbol=r.isSymbol;b.markerStyle=v;b.markerHoverStyle=G;a(e.node).data("wijchartDataObj",b);S.push(e);J.push(a.extend(true,{},e.attr()));M.push(e);return q};a.wijchart._line.prototype.processYValues=function(d,i,e,g,c){var h=[],b=0,f=0;a.each(d,function(k,l){if(!b)f=k;var j={isHole:false,isValue:true,idx:b,firstYIdx:f,x:0,y:0};b++;if(a.wijchart.isHole(l,e))if(g)d[k]=0;else{j.isHole=true;if(i==="excludeHole"){b--;j.idx=0}else{b=0;j.idx=0}if(!a.wijchart.isHole(e)&&l===e)j.isValue=true;else j.isValue=false}h.push(j);if(g&&k<c.length)d[k]+=c[k]});c.length=0;a.merge(c,d);return h};a.wijchart._line.prototype.renderMarker=function(h,n,l,c,m,j,k,d){var i,b=null,g=false,f,e;if(l){i=c.symbol;a.each(i,function(c,a){if(a.index===m){b=h.image(a.url,j-a.width/2,k-a.height/2,a.width,a.height);n.push(b);g=true;return false}})}if(b===null){f=c.type;e=d.width;b=h.paintMarker(f,j,k,e);c.visible&&b.attr(d)}a.wijraphael.addClass(a(b.node),"wijchart-canvas-object wijlinechart wijchart-canvas-marker");return{dot:b,isSymbol:g}};a.wijchart._line.prototype.renderChartLabel=function(h,g,f,d,i,j){var c,b,e;c=g?a.fromOADate(f):f;if(d&&d.length)c=Globalize.format(c,d);b=h.text(i,j,c);a.wijraphael.addClass(a(b.node),"wijlinechart-label");e=b.wijGetBBox();b.transform(Raphael.format("...T{0},{1}",0,-e.height));return b};a.wijchart._line.prototype.getAnchors=function(j,k,a,b,l,m){var n=(a-j)/2,o=(l-a)/2,c=Math.atan((a-j)/Math.abs(b-k)),d=Math.atan((l-a)/Math.abs(b-m)),e=0,f=0,h=0,g=0,i=0;c=k<b?Math.PI-c:c;d=m<b?Math.PI-d:d;e=Math.PI/2-(c+d)%(Math.PI*2)/2;f=n*Math.sin(e+c);h=n*Math.cos(e+c);g=o*Math.sin(e+d);i=o*Math.cos(e+d);return{x1:a-f,y1:b+h,x2:a+g,y2:b+i}};a.wijchart._line.prototype.getPathArrByFitType=function(b,n,c,h,q,C,D,d,e,A,B,w,I,x,H,v,F,g,z,u){var G=this,p=null,t=0,y=0,r=0,s=0,o=null,m=null,E=g[c],l=false,j=E.idx,f,i=c-1,k=c+1;if(z==="excludeHole"&&!u){if(c>0&&c<h-1){k=-1;i=-1;for(f=c+1;f<h;f++){l=true;if(g[f].isHole)continue;k=f;l=false;break}for(f=c-1;f>=0;f--){if(g[f].isHole)continue;i=f;break}if(i>-1){r=g[i].x;t=g[i].y}}}else{if(c<h-1)l=g[k].isHole;if(c>0&&c<h-1){r=g[i].x;t=g[i].y}}if(u)n="line";if(n==="line")b=b.concat([j?"L":"M",d,e]);else if(n==="spline")if(!j)if(c===h-1)b=b.concat(["M",d,e]);else if(l)b=b.concat(["M",d,e]);else b=b.concat(["M",d,e,"C",d,e]);else if(j&&c<h-1&&!l){p=D[k];if(B)p=a.toOADate(p);y=q.endY-(p-F)*H;if(isNaN(w)||typeof w==="string")s=q.startX+(k-v)*x;else{o=C[k];if(A)o=a.toOADate(o);s=q.startX+(o-v)*x}m=G.getAnchors(r,t,d,e,s,y);b=b.concat([m.x1,m.y1,d,e,m.x2,m.y2])}else b=b.concat([d,e,d,e]);else if(n==="bezier")if(!j)b=b.concat(["M",d,e]);else if(c<h-1&&g[c+1].isHole&&j%2===1||c===h-1&&j%2===1)b=b.concat(["Q",d,e,d,e]);else if(j%2===0)b=b.concat([d,e]);else b=b.concat(["Q",d,e]);return b};a.wijchart._line.prototype.bindLiveEvents=function(b,o,m,d,f,j,h,i,g,k,e){var c={element:b,mousedown:function(g){if(e)return;var c=a(g.target),d,h=null;if(c.data("owner"))c=c.data("owner");d=c.data("wijchartDataObj");if(c.hasClass("wijchart-canvas-marker")){h=d.lineSeries;if(!h.markers.visible)f.call(b,g,h);else f.call(b,g,d)}else f.call(b,g,d)},mouseup:function(f){if(e)return;var c=a(f.target),d,g=null;if(c.data("owner"))c=c.data("owner");d=c.data("wijchartDataObj");if(c.hasClass("wijchart-canvas-marker")){g=d.lineSeries;if(!g.markers.visible)j.call(b,f,g);else j.call(b,f,d)}else j.call(b,f,d)},mouseover:function(f){if(e)return;var c=a(f.target),d,g=null,i=null,j=0;if(c.data("owner"))c=c.data("owner");d=c.data("wijchartDataObj");if(c.hasClass("wijchart-canvas-marker")){g=d.lineSeries;if(!g.markers.visible)h.call(b,f,g);else h.call(b,f,d)}else h.call(b,f,d)},mouseout:function(f){if(e)return;var c=a(f.target),d,g=null;if(c.data("owner"))c=c.data("owner");d=c.data("wijchartDataObj");if(c.hasClass("wijchart-canvas-marker")){g=d.lineSeries;if(!g.markers.visible)i.call(b,f,g);else i.call(b,f,d)}else i.call(b,f,d)},mousemove:function(f){if(e)return;var c=a(f.target),d,h=null;if(c.data("owner"))c=c.data("owner");d=c.data("wijchartDataObj");if(c.hasClass("wijchart-canvas-marker")){h=d.lineSeries;if(!h.markers.visible)g.call(b,f,h);else g.call(b,f,d)}else g.call(b,f,d)},click:function(f){if(e)return;var c=a(f.target),d,g=null;if(c.data("owner"))c=c.data("owner");d=c.data("wijchartDataObj");if(c.hasClass("wijchart-canvas-marker")){g=d.lineSeries;if(!g.markers.visible)k.call(b,f,g);else k.call(b,f,d)}else k.call(b,f,d)}},r=null,p=b.offset();a(".wijlinechart",b[0]).live("mousedown."+d,a.proxy(c.mousedown,c)).live("mouseup."+d,a.proxy(c.mouseup,c)).live("mouseover."+d,a.proxy(c.mouseover,c)).live("mouseout."+d,a.proxy(c.mouseout,c)).live("mousemove."+d,a.proxy(c.mousemove,c)).live("click."+d,a.proxy(c.click,c))};a.wijchart._line.prototype.unbindLiveEvents=function(c,b){a(".wijlinechart",c[0]).die(b).die("."+b)};a.fn.extend({wijline:function(b){new a.wijchart._line(this,b)}})})(jQuery);
(function(a){"use strict";a.widget("wijmo.wijpiechart",a.wijmo.wijchartcore,{options:{radius:null,innerRadius:0,animation:{enabled:true,duration:400,easing:">",offset:10},seriesTransition:{enabled:true,duration:1e3,easing:"bounce"},seriesList:[],mouseDown:null,mouseUp:null,mouseOver:null,mouseOut:null,mouseMove:null,click:null},_create:function(){var b=this,c=b._getDefFill();a.wijmo.wijchartcore.prototype._create.apply(b,arguments);b.chartElement.addClass("wijmo-wijpiechart");a.each(this.options.seriesStyles,function(b,a){if(!a.fill)a.fill=c[b]})},destroy:function(){var f=this,e=f.chartElement,b=e.data("fields"),c=b&&b.sectors,d=b&&b.labels;e.removeClass("wijmo-wijpiechart");a.wijmo.wijchartcore.prototype.destroy.apply(this,arguments);c&&c.length&&a.each(c,function(b,a){a=null});d&&d.length&&a.each(d,function(b,a){a=null});e.data("fields",null)},_isPieChart:function(){return true},getSector:function(b){var a=this.chartElement.data("fields");return a&&a.chartElements?a.chartElements.sectors[b]:null},_getSeriesFromTR:function(i,e,h){var d=null,g=null,b=null,f=null,c=null;e.length&&e.each(function(){g=a("th",a(this));d=a.trim(g.text());b=a("td",a(this));if(b.length)f=parseFloat(a.trim(a(b[0]).text()));c={label:d,legendEntry:true,data:f};h.push(c)})},_showSerieEles:function(a){var b=this.options.showChartLabels;if(a.sector){a.sector.show();a.sector.shadow&&a.sector.shadow.show();a.sector.tracker&&a.sector.tracker.show()}a.label&&b&&a.label.show()},_hideSerieEles:function(a){if(a.sector){a.sector.hide();a.sector.shadow&&a.sector.shadow.hide();a.sector.tracker&&a.sector.tracker.hide()}a.label&&a.label.hide()},_hasAxes:function(){return false},_mouseDown:function(){a.wijmo.wijchartcore.prototype._mouseDown.apply(this,arguments)},_mouseUp:function(){a.wijmo.wijchartcore.prototype._mouseUp.apply(this,arguments)},_mouseOver:function(){a.wijmo.wijchartcore.prototype._mouseOver.apply(this,arguments)},_mouseOut:function(){a.wijmo.wijchartcore.prototype._mouseOut.apply(this,arguments)},_mouseMove:function(){a.wijmo.wijchartcore.prototype._mouseMove.apply(this,arguments)},_click:function(){a.wijmo.wijchartcore.prototype._click.apply(this,arguments)},_paintTooltip:function(){var c=this,d=c.chartElement,b=d.data("fields");a.wijmo.wijchartcore.prototype._paintTooltip.apply(this,arguments);if(c.tooltip&&b)if(b.trackers&&b.trackers.length){c.tooltip.setSelector(a(".wijchart-canvas-object",d[0]));c.tooltip.setOptions({relatedElement:b.trackers[0]})}},_paintPlotArea:function(){var b=this,c=b.options,e=b.canvasBounds,g=e.endX-e.startX,f=e.endY-e.startY,d=c.radius;if(!d)d=Math.min(g,f)/2;else{if(g<2*d)d=g/2;if(f<2*d)d=f/2}c.radius=d;e.startX+=g/2-d;e.endX=e.startX+2*d;e.startY+=f/2-d;e.endY=e.startY+2*d;if(b.chartElement.data("fields"))b.chartElement.data("fields").seriesEles=null;b.chartElement.wijpie({canvas:b.canvas,tooltip:b.tooltip,bounds:e,radius:d,widgetName:b.widgetName,innerRadius:c.innerRadius,seriesList:c.seriesList,seriesStyles:c.seriesStyles,seriesHoverStyles:c.seriesHoverStyles,seriesTransition:c.seriesTransition,showChartLabels:c.showChartLabels,disabled:c.disabled,textStyle:c.textStyle,chartLabelStyle:c.chartLabelStyle,shadow:c.shadow,animation:c.animation,mouseDown:a.proxy(b._mouseDown,b),mouseUp:a.proxy(b._mouseUp,b),mouseOver:a.proxy(b._mouseOver,b),mouseOut:a.proxy(b._mouseOut,b),mouseMove:a.proxy(b._mouseMove,b),click:a.proxy(b._click,b)})},_getTooltipText:function(e,d){var c=a(d.node),b,f;if(c.data("owner"))c=c.data("owner");b=c.data("wijchartDataObj");f={data:b,value:b.value,label:b.label,total:b.total,target:d,fmt:e};return a.proxy(e,f)()}})})(jQuery);(function(a){"use strict";a.fn.extend({wijpie:function(b){var A=function(c,d,e){b.shadow&&a.wijchart.paintShadow(c,d,e)},z=a.wijchart.getDiffAttrs,u=a.wijraphael.addClass,q=a.wijraphael.getPositionByAngle,c=this,L=b.bounds,g=b.widgetName,h=b.canvas,e=b.animation,E=b.seriesList,S=b.seriesStyles,N=b.seriesHoverStyles,l=b.radius,n=b.innerRadius,j=b.seriesTransition,Q=b.showChartLabels,P=b.chartLabelStyle,k=b.disabled,F=b.mouseDown,J=b.mouseUp,H=b.mouseOver,I=b.mouseOut,G=b.mouseMove,M=b.click,K=b.tooltip,d=c.data("fields")||{},m=d.chartElements||{},r=d.aniSectorAttrs,s=d.aniLabelAttrs,B=[],C=[],w=[],o=[],t=[],i=0,x=0,T=L.startX,U=L.startY,D=[],y,f,p;function R(){var b={x:0,y:0},d=a.isFunction;K&&K.setTargets(t);a(".wijpiechart",c[0]).live("mousedown."+g,function(f){if(k)return;var b=a(f.target),e;if(b.data("owner"))b=b.data("owner");e=b.data("wijchartDataObj");if(!e)return;d(F)&&F.call(c,f,e)}).live("mouseup."+g,function(f){if(k)return;var b=a(f.target),e;if(b.data("owner"))b=b.data("owner");e=b.data("wijchartDataObj");if(!e)return;d(J)&&J.call(c,f,e)}).live("mouseover."+g,function(o){if(k)return;var l=a(o.target),h,n,p=e&&e.enabled,m,f,g,i,j;if(l.data("owner"))l=l.data("owner");h=l.data("wijchartDataObj");if(!h)return;n=h.pieID||"";m=h.index;f=c.data("fields").chartElements["sectors"+n][m];g=f.showAnimationTimer;i=f.hideAnimationTimer;j=f.explodeAnimationShowing;d(H)&&H.call(c,o,h);if(f.removed)return;f.wijAttr(h.hoverStyle);if(p){if(i){window.clearTimeout(i);i=null;f.hideAnimationTimer=i}if(g){window.clearTimeout(g);g=null;f.showAnimationTimer=null}if(j)return;g=window.setTimeout(function(){var a=e.duration,c=e.easing;if(f.removed)return;b=f.getOffset(e.offset||10);f.offset=b;f.wijAnimate({transform:Raphael.format("t{0},{1}",b.x,b.y)},a,c);f.tracker&&!f.tracker.removed&&f.tracker.wijAnimate({transform:Raphael.format("t{0},{1}",b.x,b.y)},a,c);j=true;f.explodeAnimationShowing=j},150);f.showAnimationTimer=g}}).live("mouseout."+g,function(o){if(k)return;var l=a(o.target),g,n,p=e&&e.enabled,m,f,i,h,j;if(l.data("owner"))l=l.data("owner");g=l.data("wijchartDataObj");if(!g)return;n=g.pieID||"";m=g.index;f=c.data("fields").chartElements["sectors"+n][m];i=f.showAnimationTimer;h=f.hideAnimationTimer;j=f.explodeAnimationShowing;d(I)&&I.call(c,o,g);if(f.removed)return;if(g.style.segment)delete g.style.segment;f.wijAttr(g.style);if(p){if(h){window.clearTimeout(h);h=null;f.hideAnimationTimer=h}if(i){window.clearTimeout(i);i=null;f.showAnimationTimer=i}if(!j)return;h=window.setTimeout(function(){var a=e.duration,c=e.easing;b=f.offset;!f.removed&&f.wijAnimate({transform:"t0,0"});f.tracker&&!f.tracker.removed&&f.tracker.wijAnimate({transform:"t0,0"});b={x:0,y:0};j=false;f.explodeAnimationShowing=j},150);f.hideAnimationTimer=h}}).live("mousemove."+g,function(f){if(k)return;var b=a(f.target),e;if(b.data("owner"))b=b.data("owner");e=b.data("wijchartDataObj");if(!e)return;d(G)&&G.call(c,f,e)}).live("click."+g,function(f){if(k)return;var b=a(f.target),e;if(b.data("owner"))b=b.data("owner");e=b.data("wijchartDataObj");if(!e)return;d(M)&&M.call(c,f,e)})}function O(){a(".wijpiechart",c[0]).die(g).die("."+g)}h.customAttributes.segment=function(h,i,d,b,g,f){var e=null,c=.01;if(b-d>360-c)b-=c;else if(b-d<c)b+=c;if(f)e=a.wijchart.donut(h,i,g,f,d,b);else e=a.wijchart.sector(h,i,g,d,b);return{path:e}};a.each(E,function(b,a){if(a&&typeof a.data==="number")x+=a.data});var v=h.set();a.each(E,function(d,c){var m=a.extend({opacity:1,stroke:"gray","stroke-width":1},S[d]),H=360*c.data/x,E=T+l,F=U+l,I,b,k,G,e,g;p=c.pieID;c=a.extend(true,{offset:0},c);if(c.offset){I=q(E,F,c.offset,i+H/2);E=I.x;F=I.y}y=[E,F,i,i+H,l,n].concat(" ");if(r&&j.enabled){m.segment=y;if(d<r.length)f=r[d];else{f=a.extend(true,{},m);f.segment=[E,F,0,360,l,n].concat(" ")}b=h.path().attr(f);m=z(f,m);!b.removed&&b.wijAnimate(m,j.duration,j.easing,function(){A(b);g&&!g.removed&&!b.removed&&g.attr({path:b.attr("path")});delete m.segment})}else{b=h.path().attr({segment:y});A(b);b.wijAttr(m)}b.angles={start:i,end:i+H};b.getOffset=function(c){var a=q(E,F,c,(b.angles.start+b.angles.end)/2);return{x:a.x-E,y:a.y-F}};b.center={x:E,y:F};b.radius=l;if(n)b.innerRadius=n;g=b.clone();if(a.browser.msie&&a.browser.version<9)g.attr({opacity:.01,fill:"white","stroke-width":0,"fill-opacity":.01});else g.attr({opacity:.01,fill:"white","fill-opacity":.01});u(a(g.node),"wijchart-canvas-object wijpiechart pietracker wijchart-tracker"+d);a(g.node).data("owner",a(b.node));b.tracker=g;v.push(g);u(a(b.node),"wijchart-canvas-object wijpiechart wijmo-wijpiechart-series-"+d);a(b.node).data("wijchartDataObj",c);if(Q){G=q(E,F,c.offset+l*2/3,i+H/2);e=a.extend(true,{},e,P);if(c.textStyle)e=a.extend(true,e,c.textStyle);if(s&&j.enabled)if(d<s.length){f=s[d];f.text=c.label;k=h.text(0,0,"").attr(f);e=z(f,e);e.x=G.x;e.y=G.y;k.wijAnimate(e,j.duration,j.easing)}else k=h.text(G.x,G.y,c.label).attr(e);else k=h.text(G.x,G.y,c.label).attr(e);u(a(k.node),"wijchart-canvas-object wijpiechart");a(k.node).data("wijchartDataObj",c);t.push(k);o.push(k);C[d]=k.attr()}D.push({label:o[d],sector:b});B[d]=b.attr();w.push(b);t.push(b);c.style=m;c.hoverStyle=N[d];c.index=d;c.value=c.data;c.y=c.data;c.total=x;c.type="pie";i+=H});m.sectors=w;if(p){m["sectors"+p]=w;m["labels"+p]=o}m.labels=o;if(!d.chartElements)d.chartElements={};v.toFront();a.extend(true,d.chartElements,m);d.aniSectorAttrs=B;d.aniLabelAttrs=C;d.seriesEles=D;d.trackers=v;c.data("fields",d);O();R()}})})(jQuery);
(function(a){"use strict";a.widget("wijmo.wijtree",{options:{allowDrag:false,allowDrop:false,allowEdit:false,allowSorting:true,allowTriState:true,autoCheckNodes:true,autoCollapse:false,disabled:false,expandCollapseHoverUsed:false,showCheckBoxes:false,showExpandCollapse:true,expandAnimation:{effect:"blind",easing:"easeOutExpo",duration:200},expandDelay:0,collapseAnimation:{effect:"blind",easing:"easeOutExpo",duration:200},collapseDelay:0,draggable:null,droppable:null,dropVisual:null,nodeBlur:null,nodeClick:null,nodeCheckChanged:null,nodeCollapsed:null,nodeExpanded:null,nodeDragging:null,nodeDragStarted:null,nodeBeforeDropped:null,nodeDropped:null,nodeMouseOver:null,nodeMouseOut:null,nodeTextChanged:null,selectedNodeChanged:null,nodeExpanding:null,nodeCollapsing:null},_create:function(){this._initState();this._createTree();this._attachEvent();this._attachNodeEvent()},_setOption:function(f,c){var b=this,e=false,d;switch(f){case"allowDrag":b._setAllowDrag(c);break;case"allowDrop":b._setAllowDrop(c);break;case"showCheckBoxes":b._setCheckBoxes(c);break;case"showExpandCollapse":if(b.options.showExpandCollapse!==c)e=true;break;case"disabled":if(c)b.widgetDom.addClass("ui-state-disabled");else b.widgetDom.removeClass("ui-state-disabled");d=b.element.find(":wijmo-wijtreecheck");d.length&&d.wijtreecheck("option","disabled",c)}a.Widget.prototype._setOption.apply(b,arguments);e===true&&b._setHitArea(c)},_initState:function(){var a=this;a._selectedNodes=[];a._checkedNodes=[];a._enabled=true;a._insertPosition="unKnown";a.nodeWidgetName="wijtreenode"},_createTree:function(){var b=this,d=b.options,c=[],e="wijmo-wijtree ui-widget ui-widget-content ui-helper-clearfix ui-corner-all";if(b.element.is("ul")){b.$nodes=b.element;b.element.wrap("<div></div>");b.widgetDom=b.element.parent()}else if(b.element.is("div")){b.widgetDom=b.element;b.$nodes=b.widgetDom.children("ul:eq(0)")}if(b.$nodes.length){b.widgetDom.addClass(e).attr({role:"tree","aria-multiselectable":true});b.$nodes.addClass("wijmo-wijtree-list ui-helper-reset");d.showExpandCollapse===false&&b.$nodes.addClass("wijmo-wijtree-allexpanded");c=b._createChildNodes();b._hasChildren=c.length>0;b._setField("nodes",c);b.nodes=c;b.widgetDom.append(a("<div>").css("clear","both"))}d.disabled&&b.disable()},_createChildNodes:function(){var b=this,d={},c=[];b.$nodes.children("li").each(function(){var e=a(this);b._createNodeWidget(e,d);c.push(b._getNodeWidget(a(this)))});return c},_createNodeWidget:function(c,b){var e=this,d=e.nodeWidgetName;if(a.fn[d]){c.data("owner",this);if(!!b&&a.isPlainObject(b)){a.extend(b,{treeClass:this.widgetBaseClass});c[d](b)}else c[d]({treeClass:this.widgetBaseClass})}return c},_attachEvent:function(){var b=this;b.element.bind(a.browser.msie?"focusin.":"focus."+b.widgetName,a.proxy(b._onFocus,b)).bind("mouseover."+this.widgetName,a.proxy(b._onMouseOver,b));b.options.allowDrop&&b._attachDroppable()},_attachDroppable:function(){var b=this,e=b.options,d={accept:"li",scope:"tree"},f=function(a){e.showCheckBoxes&&e.allowTriState&&!a.element.is(":"+b.widgetBaseClass)&&a._getField("nodes").length>0&&a._getField("nodes")[0]._setParentCheckState()},c=e.droppable;a.extend(d,c);d.drop=function(o,d){var l=d.draggable,g=b._getNodeWidget(l),j,k,e,h,p,m,n,i=-1;if(b._trigger("nodeBeforeDropped",o,d)===false||!g)return;j=g._dropTarget;k=g._insertPosition;if(j&&k!=="unKnown"){e=l.data("owner");if(e)n=l.index();if(k==="end"){i=j._getField("nodes").length;h=j}else if(k==="before"||k==="after"){h=j._getField("owner");p=h._getField("nodes");m=a.inArray(j,p);if(m!==-1)i=k==="before"?m:m+1}if(c&&a.isFunction(c.drop)){d.oldParent=e.element;d.newParent=h.element;d.oldIndex=n;d.newIndex=i;c.drop.call(b.element,o,d)}else{e&&e.remove(l);i!==-1&&h.add(l,i)}a("a:eq(0)",l).blur();g._tree._isDragging=false;g.options.selected&&g._setSelected(false);f(e);f(h);a.extend(d,{sourceParent:e?e.element:null,sIndex:n,targetParent:h.element,tIndex:i,widget:g});b._trigger("nodeDropped",o,d)}};b.widgetDom.droppable(d)},_attachNodeEvent:function(){this.element.bind("click."+this.widgetName,a.proxy(this._onClick,this)).bind("mouseout."+this.widgetName,a.proxy(this._onMouseOut,this)).bind("keydown."+this.widgetName,a.proxy(this._onKeyDown,this))},_onClick:function(b){this._callEvent(b,"_onClick");a.browser.webkit&&this.widgetDom.focus()},_onFocus:function(a){this._callEvent(a,"_onFocus")},_onKeyDown:function(a){this._callEvent(a,"_onKeyDown")},_onMouseOut:function(a){this._callEvent(a,"_onMouseOut")},_onMouseOver:function(a){this._callEvent(a,"_onMouseOver")},_callEvent:function(b,d){var c=b.target,a;if(c){a=this._getNodeWidgetByDom(c);if(a===null)return;a[d](b)}},_nodeSelector:function(){return":wijmo-wijtreenode"},getSelectedNodes:function(){return this._selectedNodes},getCheckedNodes:function(){var b=this,d=[],c=b.nodeWidgetName;a(b._nodeSelector(),b.element).each(function(){a(this)[c]("option","checked")&&a(this)[c]("option","checkState")!=="indeterminate"&&d.push(a(this))});return d},destroy:function(){var b=this,c=b.$nodes,d="wijmo-wijtree ui-widget ui-widget-content ui-helper-clearfix ui-corner-all";b.widgetDom.removeClass(d).removeAttr("role").removeAttr("aria-multiselectable");b.widgetDom.data("droppable")&&b.widgetDom.droppable("destroy");b.widgetDom.children("div[style]:last").remove();c.removeData("nodes").removeClass("wijmo-wijtree-list ui-helper-reset");c.children("li").each(function(){var c=b._getNodeWidget(a(this));c&&c.destroy()});a.Widget.prototype.destroy.apply(this)},add:function(b,f){var c=null,k={},d,g,e=this,h,i,l="<li><a href='{0}'>{1}</a></li>",j;if(typeof b==="string"){d=a(l.replace(/\{0\}/,"#").replace(/\{1\}/,b));e._createNodeWidget(d,k);c=d.data(d.data("widgetName"))}else if(b.jquery){!b.data("widgetName")&&e._createNodeWidget(b,k);c=b.data(b.data("widgetName"))}else if(b.nodeType){d=a(b);e._createNodeWidget(d,k);c=d.data(d.data("widgetName"))}else if(a.isPlainObject(b)){d=a(l.replace(/\{0\}/,b.url?b.url:"#").replace(/\{1\}/,b.text));e._createNodeWidget(d,b);c=d.data(d.data("widgetName"))}if(c===null)return;g=e._getField("nodes");if(!f||f>g.length)f=g.length;j=c._getField("nodes");c._tree=e;for(h=0;h<j.length;h++)j[h]._tree=e;c._setField("owner",this);i=g.length;if(i>0&&i!==f)c.element.get(0)!==g[f].element.get(0)&&c.element.insertBefore(g[f].element);else e.$nodes.append(c.element);e._changeCollection(f,c);c._initNodeClass()},remove:function(b){var a=-1,d,c;if(b.jquery)a=b.index();else if(typeof b==="number")a=b;c=this._getField("nodes");if(a<0||a>=c.length)return;d=c[a];d.element.detach();this._changeCollection(a)},_changeCollection:function(c,a){var b=this._getField("nodes");if(a)b.splice(c,0,a);else b.splice(c,1)},getNodes:function(){return this.nodes},findNodeByText:function(c){var b=a(".wijmo-wijtree-node a>span",this.$nodes).filter(function(){return a(this).text()===c});return b.length?this._getNodeWidgetByDom(b.get(0)):null},_setAllowDrag:function(f){var c=this,b,d=c._nodeSelector(),e=c.nodeWidgetName;if(f){b=c.element.find(d);b.each(function(){var b=a(this).data(e);if(!a(this).data("draggable")&&!b.$navigateUrl.data("events").mousedown)b.$navigateUrl.one("mousedown",b,b._onMouseDown)})}else{b=c.element.find(d+":ui-draggable");b.draggable("destroy")}},_setAllowDrop:function(a){if(a)!this.widgetDom.data("droppable")&&this._attachDroppable();else this.widgetDom.droppable&&this.widgetDom.droppable("destroy")},_setCheckBoxes:function(c){var b=this;b.$nodes.children("li").each(function(){var d=b._getNodeWidget(a(this));d!==null&&d._setCheckBoxes(c)})},_setHitArea:function(c){var b=this;b.$nodes[c?"addClass":"removeClass"]("wijmo-wijtree-allexpanded");b.$nodes.children("li").each(function(){var d=b._getNodeWidget(a(this));d!==null&&d._setHitArea(c)})},_getNodeWidget:function(a){return a.is(this._nodeSelector())?a.data(a.data("widgetName")):null},_getNodeWidgetByDom:function(b){var a=this._getNodeByDom(b);return this._getNodeWidget(a)},_getNodeByDom:function(b){return a(b).closest(this._nodeSelector())},_refreshNodesClass:function(){for(var b=this._getField("nodes"),a=0;a<b.length;a++)b[a]._initNodeClass()},_getField:function(a){return this.element.data(a)},_setField:function(b,a){return this.element.data(b,a)}})})(jQuery);(function(a){a.widget("wijmo.wijtreenode",{options:{accessKey:"",checked:false,collapsedIconClass:"",expanded:false,expandedIconClass:"",itemIconClass:"",navigateUrl:"",selected:false,text:"",toolTip:"",hasChildren:false,params:{}},_setOption:function(e,c){var b=this,d;switch(e){case"accessKey":b.$navigateUrl!==null&&b.$navigateUrl.attr("accesskey",c);break;case"checked":b._checkState=c?"checked":"unChecked";b._setChecked(c);break;case"collapsedIconClass":case"expandedIconClass":case"itemIconClass":b.options[e]=c;b._initNodeImg();break;case"expanded":b._setExpanded(c);break;case"selected":b._setSelected(c);break;case"text":b._setText(c);break;case"toolTip":b._setToolTip(c);break;case"navigateUrl":b._setNavigateUrlHref(c);break;case"disabled":if(b._isClosestDisabled()&&c===true)return;d=b.element.find(":wijmo-wijtreecheck");d.length&&d.wijtreecheck("option","disabled",c)}a.Widget.prototype._setOption.apply(b,arguments)},_initState:function(){this._tree=null;this._dropTarget=null;this._checkState="unChecked";this._value=this._text=this._navigateUrl="";this._insertPosition="unKnown";this._hasNodes=false},_create:function(){this._initState();this._createTreeNode();this._initNode();this.element.data("widgetName",this.widgetName)},_createTreeNode:function(){var c=this.element,b=this,d=[];this.$navigateUrl=c.children("a");if(b._tree===null)b._tree=b._getTree();b.$nodeBody=null;b.$checkBox=null;b.$nodeImage=a("<span>");b.$hitArea=null;b.$nodes=null;b.$nodeBody=a("<div>").attr({role:"treeitem","aria-expanded":false,"aria-checked":false,"aria-selected":false});if(b._tree.options.showCheckBoxes===true)b.$checkBox=a("<div>");if(b.$navigateUrl.length===0){b.$navigateUrl=c.children("div");b.$navigateUrl.addClass("wijmo-wijtree-template");b._isTemplate=true}if(b.$navigateUrl.length===0){b.$navigateUrl=a("<a>");b.$navigateUrl.attr("href","#")}if(!b._isTemplate){b.$text=b.$navigateUrl.find("span:eq(0)");if(b.$text.length===0){b.$navigateUrl.wrapInner("<span></span>");b.$text=b.$navigateUrl.find("span:eq(0)")}}b._hasChildren=b._getChildren();b.$inner=a("<span></span>").addClass("ui-helper-clearfix wijmo-wijtree-inner ui-corner-all");d=b._createChildNodes(c);b.$inner.append(b.$nodeImage);if(b.$checkBox!==null){b.$inner.append(b.$checkBox);b.$checkBox.wijtreecheck()}b.$inner.append(b.$navigateUrl);b.$nodeBody.append(b.$inner);b._setField("nodes",d);c.prepend(b.$nodeBody)},_createChildNodes:function(c){var b=this,d=[];if(b._hasChildren){c.addClass("wijmo-wijtree-parent");b.$nodeBody.addClass("wijmo-wijtree-node wijmo-wijtree-header ui-state-default");b.$hitArea=a("<span>");b.$inner.prepend(b.$hitArea);b.$nodes=c.find("ul:eq(0)").addClass("wijmo-wijtree-list ui-helper-reset wijmo-wijtree-child");d=b._createChildNode()}else{c.addClass("wijmo-wijtree-item");b.$nodeBody.addClass("wijmo-wijtree-node ui-state-default")}return d},_createChildNode:function(){var b=this,c=[];b.$nodes.children().filter("li").each(function(f){var e=a(this),d;e.data("owner",b);e.wijtreenode(b.options);d=b._getNodeWidget(e);d._index=f;c.push(d)});return c},_initNode:function(){var a=this,b=a.options;if(!a._initialized){a._initialized=true;a._initNavigateUrl();if(!a._isTemplate&&a.$text){a._text=a.$text.html();b.text=a.$text.html()}a._hasChildren=a._getChildren();a._initNodesUL();a._initNodeClass();a._initNodeImg();a._initCheckBox();a.$navigateUrl.one("mousedown",a,a._onMouseDown)}},_initNodeClass:function(){var b=this,c=b.options,e,d="ui-icon "+(c.expanded?"ui-icon-triangle-1-se":"ui-icon-triangle-1-e");if(b._tree.options.showExpandCollapse)if(b._hasChildren||!!c.hasChildren){if(b.$hitArea!==null)b.$hitArea.removeClass("ui-icon ui-icon-triangle-1-se ui-icon-triangle-1-e").addClass(d);else{b.$hitArea=a("<span>").addClass(d).prependTo(b.$inner);b.element.removeClass("wijmo-wijtree-node ui-state-default ui-corner-all").addClass("wijmo-wijtree-parent")}if(b._hasChildren){e=c.expanded?"":"none";b.$nodes.css({display:e})}}else if(b.$hitArea){b.$hitArea.remove();b.$hitArea=null;b.element.removeClass("wijmo-wijtree-parent").addClass("wijmo-wijtree-node ui-state-default ui-corner-all")}c.selected&&b.$inner&&b.$inner.addClass("ui-state-active")},_initCheckBox:function(){var a=this,b=a.options;if(a.$checkBox&&b.checkState)switch(b.checkState){case"checked":a.$checkBox.wijtreecheck("option","checkState","check");break;case"indeterminate":a.$checkBox.wijtreecheck("option","checkState","triState");break;case"unChecked":a.$checkBox.wijtreecheck("option","checkState","unCheck");break;default:a.$checkBox.wijtreecheck("option","checkState","unCheck")}},_initNodesUL:function(){var a=this;if(a._tree.options.showExpandCollapse)a._hasChildren&&a.$nodes[a._expanded?"show":"hide"]()},_initNavigateUrl:function(){var a=this,b=a.$navigateUrl.attr("href");a.$navigateUrl.bind("blur."+a.widgetName,a,a._onBlur);if(!this._isTemplate){a._navigateUrl=!!b?b:"";a._setNavigateUrlHref(b)}},_initNodeImg:function(){var b=this,c=b.options,d=b.element;if(b.$nodeImage===null||!b.$nodeImage.length)b.$nodeImage=a("<span>");if(d.attr("expandediconclass")){c.expandedIconClass=d.attr("expandediconclass");d.removeAttr("expandediconclass")}if(d.attr("collapsediconclass")){c.collapsedIconClass=d.attr("collapsediconclass");d.removeAttr("collapsediconclass")}if(d.attr("itemiconclass")){c.itemIconClass=d.attr("itemiconclass");d.removeAttr("itemiconclass")}if(c.collapsedIconClass!==""&&c.expandedIconClass!==""){b.$nodeImage.removeClass().addClass("ui-icon").addClass(c.expanded?c.expandedIconClass:c.collapsedIconClass);!b._tree.options.showExpandCollapse&&b.$nodeImage.addClass(c.expandedIconClass);b.$nodeImage.insertBefore(b.$checkBox)}else if(c.itemIconClass!==""){b.$nodeImage.removeClass().addClass("ui-icon");b.$nodeImage.addClass(c.itemIconClass);b.$nodeImage.insertBefore(b.$checkBox)}},_setNavigateUrlHref:function(a){if(this.$navigateUrl){if(a===""||typeof a==="undefined")a="#";this.$navigateUrl.attr("href",a)}},_editNode:function(){this._tree._editMode=true;this.$navigateUrl.hide();if(!this.$editArea)this.$editArea=a('<input type="text">').wijtextbox();this.$editArea.val(this.$text.html());this.$editArea.insertBefore(this.$navigateUrl);this.$editArea.bind("blur",this,this._editionComplete);this.$editArea.focus()},_editionComplete:function(c){var a=c.data,b;a._tree._editMode=false;if(a.$editArea){b=a.$editArea.val();a.$editArea.remove()}a.$navigateUrl.show();a.$editArea=null;a._changeText(b)},_changeText:function(b){var a=this,c=a.options;if(a.$text!==null&&b!==""){a.$text.text(b);c.text=b;a._tree._trigger("nodeTextChanged",null,a)}},_expandCollapseItem:function(){var a=this,b=a.options;if(!a._tree.options.disabled&&!a._isClosestDisabled())(a._hasChildren||b.hasChildren)&&a._setExpanded(!b.expanded)},_expandNode:function(c){var a=this,b=a._tree.options,d=c?"nodeExpanding":"nodeCollapsing";if(a._tree._trigger(d,null,{node:this,params:this.options.params})===false)return;a.$nodeBody.attr("aria-expanded",c);a._expanded=c;a.options.expanded=c;if(!b.disabled&&!a._isClosestDisabled())if(c)if(b.expandDelay>0){if(typeof a._expandTimer!=="undefined")a._expandTimer=window.clearTimeout(a._expandTimer);a._expandTimer=window.setTimeout(function(){a._expandNodeVisually()},b.expandDelay)}else a._expandNodeVisually();else if(b.collapseDelay>0){a._collapseTimer=window.clearTimeout(a._collapseTimer);a._collapseTimer=window.setTimeout(function(){a._collapseNodeVisually()},b.collapseDelay)}else a._collapseNodeVisually()},_expandNodeVisually:function(){var b=this,d,c=b.options;if(b._tree.options.autoCollapse){d=b.element.siblings(":"+this.widgetBaseClass);a.each(d,function(c){var a=b._getNodeWidget(d[c]);a.options.expanded&&a._setExpanded(false)})}c.collapsedIconClass!==""&&c.expandedIconClass!==""&&b.$nodeImage.removeClass(c.collapsedIconClass).addClass(c.expandedIconClass);b._internalSetNodeClass(true);b._show()},_collapseNodeVisually:function(){var a=this;a.options.collapsedIconClass!==""&&a.options.expandedIconClass!==""&&a.$nodeImage.removeClass(a.options.expandedIconClass).addClass(a.options.collapsedIconClass);a._internalSetNodeClass(false);a._hide()},_internalSetNodeClass:function(a){this.$hitArea.removeClass("ui-icon ui-icon-triangle-1-se ui-icon-triangle-1-e").addClass("ui-icon "+(a?"ui-icon-triangle-1-se":"ui-icon-triangle-1-e"))},_show:function(){this._animation(true)},_hide:function(){this._animation(false)},_animation:function(d){var b=this,e=b.$nodes,h=d?"expandAnimation":"collapseAnimation",g=d?"nodeExpanded":"nodeCollapsed",f,c=b._tree.options[h];if(e)if(c){f=c.animated||c.effect;if(a.effects&&!!f)e[d?"show":"hide"](f,{},c.duration,function(){b._tree._trigger(g,null,b)});else e[d?"show":"hide"](c.duration,function(){b._tree._trigger(g,null,b)})}else{e[d?"show":"hide"]();b._tree._trigger(g,null,b)}},_getBounds:function(a){var b=a.height(),e=a.width(),d=a.offset().top,c=a.offset().left;return{h:b,w:e,t:d,l:c}},_isMouseInsideRect:function(b,a){return b.x<a.l||b.x>=a.l+a.w?false:b.y<=a.t+1||b.y>=a.t+a.h?false:true},_getNodeByMouseOn:function(b){a("li").each(function(){var c=this._getBounds(a(this));if(a.ui.isOver(b.y,b.x,c.t,c.l,c.h,c.w))return a(this)});return null},_drowTemplate:function(b,e,d){var c="unKnown",f=d.is(".wijmo-wijtree-node")?d:d.children(".wijmo-wijtree-node"),a=this._getBounds(f);e.width(f.width());if(b.y>a.t&&b.y<a.t+a.h/2){e.offset({left:a.l,top:a.t});c="before"}else if(b.y>a.t+a.h/2&&b.y<a.t+a.h){e.offset({left:a.l,top:a.t+a.h});c="after"}return c},_beginDrag:function(i){var b=this,h=b.element,e,g=b._tree.options,d=g.draggable,f={cursor:"point",cursorAt:{top:15,left:-25},helper:function(){return a("<div>"+b.$navigateUrl.html()+"</div>").addClass("ui-widget-header ui-corner-all")},distance:a.browser.msie?1:10,handle:b.$navigateUrl,scope:"tree"},c=a("<div>").addClass("wijmo-wijtree-insertion ui-state-default");if(typeof g.dropVisual==="string"){e=a(g.dropVisual);c=e.length?e:c}else if(a.isFunction(g.dropVisual)){e=a(g.dropVisual.call());c=e.length?e:c}c.hide();a.extend(f,d);f.start=function(e,f){b._tree._isDragging=true;b._tree.widgetDom.prepend(c);b._tree._trigger("nodeDragStarted",e,b);if(d&&a.isFunction(d.start))d.start.call(b.element,e,f);else h.hide()};f.drag=function(e,h){var j=e.srcElement||e.originalEvent.target,g=a(j),f,i={x:e.pageX,y:e.pageY};c&&c.hide();if(g){f=b._getNodeWidget(g);if(f){if(g.closest(".wijmo-wijtree-inner",b.element).length)b._insertPosition="end";else{c.show();b._insertPosition=b._drowTemplate(i,c,f.element)}b._dropTarget=f}}b._tree._trigger("nodeDragging",e,b);d&&a.isFunction(d.drag)&&d.drag.call(b.element,e,h)};f.stop=function(e,f){c.remove();b._dropTarget=null;b._insertPosition="unKnown";if(d&&a.isFunction(d.stop))d.stop.call(b.element,e,f);else{h.show();b._resetDrag()}};h.draggable(f).trigger(i);a.browser.mozilla&&b._setFocused(true)},_resetDrag:function(){var a=this,c,b;!a._tree.options.allowDrag&&a.element.data("draggable")&&a.element.draggable("destroy");c=a._getField("nodes");for(b=0;b<c.length;b++)c[b]._resetDrag()},_checkClick:function(){var a=this,b=a.options;if(!a._tree.options.disabled&&!a._isClosestDisabled()){if(b.checked&&a._checkState==="indeterminate"){a._checkState="checked";a._checkItem()}else{a._checkState=b.checked?"unChecked":"checked";a._setChecked(!b.checked)}a._tree._trigger("nodeCheckChanged",null,a)}},_checkItem:function(){var a=this,c=false,b=a._tree;if(b===null||!b.options.showCheckBoxes)return;if(b.options.autoCheckNodes&&a._checkState!=="indeterminate"){c=true;a._changeCheckState(a.options.checked)}b.options.allowTriState&&a._setParentCheckState();a[a.options.checked?"_checkNode":"_unCheckNode"](c)},_checkNode:function(e){var a=this,d=a.options,c=this._getField("nodes"),b;if(a._checkState==="checked"){a.$checkBox.wijtreecheck("option","checkState","check");d.checkState="checked"}else if(a._checkState==="indeterminate"){a.$checkBox.wijtreecheck("option","checkState","triState");d.checkState="indeterminate"}if(e)for(b=0;b<c.length;b++)c[b]._checkNode(true)},_unCheckNode:function(c){var b=this._getField("nodes"),d=this.options,a;this.$checkBox.wijtreecheck("option","checkState","unCheck");d.checkState="unChecked";if(c)for(a=0;a<b.length;a++)b[a]._unCheckNode(true)},_changeCheckState:function(b){var c=this._getField("nodes");a.each(c,function(c,a){a.options.checked=b;a.$nodeBody.attr("aria-checked",b);a._checkState=b?"checked":"unChecked";a._changeCheckState(b)})},_setParentCheckState:function(){var a=this._getOwner(),c,e=true,d=false,f=false,b,g=this;if(a.element.is(":"+g.options.treeClass))return;c=a._getField("nodes");for(b=0;b<c.length;b++){if(c[b]._checkState==="indeterminate")f=true;if(c[b].options.checked)d=true;else e=false;if(!e&&d)break}if(f){a._checkState="indeterminate";a._setChecked(true)}else if(d){if(e){a._checkState="checked";a._checkNode(false)}else a._checkState="indeterminate";a._setChecked(true)}else{a._checkState="unChecked";a._setChecked(false);a._unCheckNode(false)}a._setParentCheckState()},_onKeyDown:function(b){var d=a(b.target),c=this;d.closest(".wijmo-wijtree-inner",c.element).length>0&&c._keyAction(b)},_onClick:function(b){var d=a(b.target),c=this;if(d.closest(".wijmo-checkbox",c.element).length>0){c._checkClick(b);b.preventDefault();b.stopPropagation()}else if(c.$hitArea&&c.$hitArea[0]===d[0]){c._expandCollapseItem(b);b.preventDefault();b.stopPropagation()}else d.closest(".wijmo-wijtree-inner",c.element).length>0&&c._click(b)},_onMouseDown:function(b){var d=a(b.target),c=b.data;if(c._tree.options.allowDrag)d.closest(".wijmo-wijtree-node",c.element).length>0&&c._beginDrag(b)},_onMouseOver:function(c){var e=a(c.target),b=this,d=a(c.relatedTarget);if(e.closest(".wijmo-wijtree-inner",b.element).length>0&&(this._tree._overNode!==b||d.is(":"+this.widgetBaseClass))){b._mouseOver(c);this._tree._overNode=b}b._mouseOverHitArea(c)},_onMouseOut:function(b){var f=a(b.target),c=this,e=a(b.relatedTarget),d=this._getNodeWidget(e);if(f.closest(".wijmo-wijtree-inner",c.element).length>0&&(this._tree._overNode!==d||e.is(":"+this.widgetBaseClass))){c._mouseOut(b);if(!d)this._tree._overNode=null}c._mouseOutHitArea(b)},_onFocus:function(d){var c=a(d.target),b=this;if(c.closest(".wijmo-wijtree-inner",b.element).length>0&&!b._tree.options.disabled&&!b._isClosestDisabled()&&!(c.hasClass("ui-icon-triangle-1-se")||c.hasClass("ui-icon-triangle-1-e"))&&!c.closest(".wijmo-checkbox",b.element).length){b._tree._focusNode&&b._tree._focusNode.$navigateUrl.blur();b._focused=true;b._tree._focusNode=this;b.$inner.addClass("ui-state-focus")}},_onBlur:function(c){var d=a(c.target),b=c.data;if(!b._tree.options.disabled&&!b._isClosestDisabled()){b._focused=false;d.closest(".wijmo-wijtree-inner",b.element).length>0&&b.$inner.removeClass("ui-state-focus");b._tree._trigger("nodeBlur",c,b)}},_click:function(c){var a=this,d=a.options,b=a._tree;if(!b.options.disabled&&!a._isClosestDisabled()){if(!/^[#,\s]*$/.test(a._navigateUrl))return;a._isClick=true;b._ctrlKey=c.ctrlKey;if(d.selected&&b._ctrlKey)a._setSelected(false);else if(d.selected&&b.options.allowEdit&&!a._isTemplate)a._editNode();else a._setSelected(!d.selected);if(!a._isTemplate){c.preventDefault();c.stopPropagation()}}else a._setNavigateUrlHref("")},_selectNode:function(e,f){var b=this,d,c;if(!b._tree.options.disabled&&!b._isClosestDisabled()&&!b._tree._isDragging){d=b._tree._ctrlKey;if(d){c=a.inArray(b,b._tree._selectedNodes);if(c!==-1&&!e){b._tree._selectedNodes.splice(c,1);b.$inner.removeClass("ui-state-active")}}else{a.each(b._tree._selectedNodes,function(b,a){a.$inner.removeClass("ui-state-active");a.options.selected=false;a.$nodeBody.attr("aria-selected",false)});b._tree._selectedNodes=[]}if(e){c=a.inArray(b,b._tree._selectedNodes);c===-1&&this._tree._selectedNodes.push(b);b.$inner.addClass("ui-state-active")}else b.$inner.removeClass("ui-state-active");b._isClick&&b._tree._trigger("nodeClick",f,b);b._isClick=false;b._tree._ctrlKey=false;b._tree._trigger("selectedNodeChanged",f,b)}},_keyAction:function(c){var d=c.target,b=this;if(b._tree.options.disabled||b._isClosestDisabled())return;if(d){if(b._tree._editMode&&c.keyCode!==a.ui.keyCode.ENTER)return;switch(c.keyCode){case a.ui.keyCode.UP:b._moveUp();break;case a.ui.keyCode.DOWN:b._moveDown();break;case a.ui.keyCode.RIGHT:b._tree.options.showExpandCollapse&&b._moveRight();break;case a.ui.keyCode.LEFT:b._tree.options.showExpandCollapse&&b._moveLeft();break;case 83:!b._tree._editMode&&b._tree.options.allowSorting&&b.sortNodes();break;case 113:b._tree.options.allowEdit&&b._editNode();break;case 109:b._tree.options.showExpandCollapse&&this._expanded&&b._setExpanded(false);break;case 107:b._tree.options.showExpandCollapse&&!this._expanded&&b._setExpanded(true);break;case a.ui.keyCode.ENTER:if(b._tree._editMode){c.data=b;b._editionComplete(c)}break;case a.ui.keyCode.SPACE:if(b._tree.options.showCheckBoxes){b._checkState=b.options.checked?"unChecked":"checked";b._setChecked(!b.options.checked)}}b._customKeyDown(c.keyCode);if(!b._isTemplate){c.preventDefault();c.stopPropagation()}}},_customKeyDown:function(){},_prevNode:function(a){if(a.element.prev().length>0)return a.element.prev().data(this.widgetName)},_nextNode:function(a){if(a.element.next().length>0)return a.element.next().data(this.widgetName)},_getNextExpandedNode:function(c){var d=c,a=c._getField("nodes"),b;if(c._expanded&&a.length>0){b=a[a.length-1];if(b!==null)d=this._getNextExpandedNode(b)}return d},_getNextNode:function(b){var a=null,c=this;if(b.element.is(":"+c.options.treeClass))return null;a=c._nextNode(b);return a?a:c._getNextNode(b._getOwner())},_moveUp:function(){var b=this._getCurrentLevel(),a=this._prevNode(this);if(!a)b>0&&this._getOwner()._setFocused(true);else this._getNextExpandedNode(a)._setFocused(true)},_moveDown:function(){var c=this._getField("nodes"),b,d,a;if(this._expanded&&c.length>0)c[0]._setFocused(true);else{b=this._nextNode(this);if(b)b._setFocused(true);else{d=this._getOwner();a=this._getNextNode(d);a&&a._setFocused(true)}}},_moveLeft:function(){var a=this._getOwner();if(this._expanded)this._setExpanded(false);else a!==null&&!a.element.is(":"+this.options.treeClass)&&a._setFocused(true)},_moveRight:function(){if(this._hasChildren)if(!this._expanded)this._setExpanded(true);else{var a=this._getField("nodes")[0];a!==null&&a._setFocused(true)}},_mouseOver:function(c){var a=this,b=a._tree;if(!b.options.disabled&&!a._isClosestDisabled()&&!b._editMode){a._mouseOverNode();!b._isDragging&&b._trigger("nodeMouseOver",c,a)}},_mouseOut:function(c){var a=this,b=a._tree;if(!b.options.disabled&&!a._isClosestDisabled()&&!b._editMode){a._mouseOutNode();!b._isDragging&&b._trigger("nodeMouseOut",c,a)}},_mouseOverNode:function(){if(this.$inner!==null&&!this._isOverNode){this.$inner.addClass("ui-state-hover");this._isOverNode=true}},_mouseOutNode:function(){if(this.$inner!==null&&this._isOverNode){this.$inner.removeClass("ui-state-hover");this._isOverNode=false}},_mouseOverHitArea:function(c){var b,e,a=this,d=a._tree;if(!d.options.disabled&&!a._isClosestDisabled())if(d.options.expandCollapseHoverUsed)if(a._hasChildren&&!a._isOverHitArea){b=a._getBounds(a.element);e={x:c.pageX,y:c.pageY};if(a._isMouseInsideRect(e,b)){a._isOverHitArea=true;a._setExpanded(true)}}},_mouseOutHitArea:function(c){var e={x:c.pageX,y:c.pageY},b,a=this,d=a._tree;if(!d.options.disabled&&!a._isClosestDisabled())if(d.options.expandCollapseHoverUsed)if(a._hasChildren&&!!a._isOverHitArea){b=a._getBounds(a.element);if(!a._isMouseInsideRect(e,b)){a._isOverHitArea=false;a._setExpanded(false)}}else if(a._getOwner().element.is(":"+a.widgetBaseClass)){b=a._getBounds(a._getOwner().element);if(!a._isMouseInsideRect(e,b)){a._getOwner()._isOverHitArea=false;a._getOwner()._setExpanded(false)}}},destroy:function(){var b=this,c;b.element.data("draggable")&&b.element.draggable("destroy");b.$hitArea&&b.$hitArea.remove();b.$checkBox&&b.$checkBox.remove();b.$nodeImage&&b.$nodeImage.remove();b.$navigateUrl.unwrap().unwrap().removeClass("ui-state-default ui-state-active").unbind("mousedown").unbind("blur");c=this.element.find("ul:first").show();c.removeClass();c.children("li").each(function(){var c=b._getNodeWidget(a(this));c.destroy()});b.element.removeData("nodes").removeData("owner").removeData("widgetName").removeClass();a.Widget.prototype.destroy.apply(this)},add:function(c,f){var d=null,e,g,b=this,j,h,k="<li><a href='{0}'>{1}</a></li>",i;if(typeof c==="string"){e=a(k.replace(/\{0\}/,"#").replace(/\{1\}/,c));b._createNodeWidget(e);d=e.data(e.data("widgetName"))}else if(c.jquery){!c.data("widgetName")&&b._createNodeWidget(c);d=c.data(c.data("widgetName"))}else if(c.nodeType){e=a(c);b._createNodeWidget(e);d=e.data(e.data("widgetName"))}else if(a.isPlainObject(c)){e=a(k.replace(/\{0\}/,c.url?c.url:"#").replace(/\{1\}/,c.text));b._createNodeWidget(e,c);d=e.data(e.data("widgetName"))}if(d===null)return;g=b._getField("nodes");if(!f||f>g.length)if(f!==0)f=g.length;j=d._getField("nodes");d._tree=b._tree;for(h=0;h<j.length;h++)j[h]._tree=b._tree;d._setField("owner",b);i=g.length;if(!b.$nodes){b.$nodes=a("<ul></ul>").addClass("wijmo-wijtree-list ui-helper-reset wijmo-wijtree-child");b.element.append(b.$nodes)}if(i>0&&i!==f)d.element.get(0)!==g[f].element.get(0)&&d.element.insertBefore(g[f].element);else b.$nodes.append(d.element);b._changeCollection(f,d);b._collectionChanged("add");d._initNodeClass()},remove:function(b){var a=-1,c,e=this,d=this._getField("nodes");if(b.jquery)a=b.index();else if(typeof b==="number")a=b;if(a<0||a>=d.length)return;c=d[a];c.element.detach();e._changeCollection(a);e._collectionChanged("remove")},getNodes:function(){return this._getField("nodes")},_changeCollection:function(c,a){var b=this._getField("nodes");if(a)b.splice(c,0,a);else b.splice(c,1)},sortNodes:function(){var b=this._getField("nodes");this._sort();a.each(b,function(b,a){a._index=b;a._insertBefore(b)});this._refreshNodesClass()},check:function(a){this._setOption("checked",a)},select:function(a){this._setOption("selected",a)},getOwner:function(){var a=this._getOwner();return a&&a.element.is("li")?a:null},expand:function(){this._setOption("expanded",true)},collapse:function(){this._setOption("expanded",false)},_insertBefore:function(a){var b=this.element.parent().children("li");this.element.index()!==a&&this.element.insertBefore(b.eq(a))},_sort:function(){var a=this._getField("nodes");if(this._isSorted)if(!this._isDecsSort){a.sort(this._compare2NodeTextAcs);this._isDecsSort=true}else{a.sort(this._compare2NodeTextDesc);this._isDecsSort=false}else{a.sort(this._compare2NodeTextAcs);this._isSorted=true;this._isDecsSort=true}},_compare2NodeTextAcs:function(a,b){if(a!==null&&b!==null)return a._text.localeCompare(b._text)},_compare2NodeTextDesc:function(a,b){if(a!==null&&b!==null)return-1*a._text.localeCompare(b._text)},_collectionChanged:function(){this._hasChildren=this._getChildren();this._initNodeClass()},_refreshNodesClass:function(){for(var b=this._getField("nodes"),a=0;a<b.length;a++)b[a]._initNodeClass()},_setChecked:function(b){var a=this;if(a.options.checked===b&&a._checkState!=="indeterminate")return;a.options.checked=b;a.$nodeBody.attr("aria-checked",b);this._checkItem()},_isClosestDisabled:function(){var a=this;return a.element.closest(".wijmo-wijtree-disabled,.wijmo-wijtreenode-disabled",a._tree.element).length?true:false},_setExpanded:function(b){var a=this,c=a.options;if(a._expanded===b)return;(a._hasChildren||c.hasChildren)&&a._expandNode(b)},_setFocused:function(a){if(a){this.$navigateUrl.focus();this._setFocusNode()}else this.$navigateUrl.blur()},_setFocusNode:function(){this._tree._focusNode&&a.browser.webkit&&this._tree._focusNode.$navigateUrl.blur();this._focused=true;this._tree._focusNode=this;this.$inner.addClass("ui-state-focus")},_setToolTip:function(a){if(a.length)this.element.attr("title",a);else this.element.removeAttr("title")},_setText:function(a){if(this._text!==a&&a.length){this._text=a;this._changeText(a)}},_setSelected:function(a){var b=this,c=b.options;if(c.selected!==a){c.selected=a;b.$nodeBody.attr("aria-selected",a);b._selectNode(a);b._setFocused(a)}},_setCheckBoxes:function(c){var b=this;b.$checkBox&&b.$checkBox[c?"show":"hide"]();b.$nodes&&b.$nodes.children("li").each(function(){var d=b._getNodeWidget(a(this));d!==null&&d._setCheckBoxes(c)})},_setHitArea:function(c){var b=this;if(b._hasChildren)if(c){b._initNodeClass();b.$hitArea&&b.$hitArea.show()}else{b._expanded=true;b.options.expanded=true;b.$nodeBody.attr("aria-expanded",true);b.$nodes&&b.$nodes.show();b._initNodeClass();b.$hitArea&&b.$hitArea.hide()}b.$nodes&&b.$nodes.children("li").each(function(){var d=b._getNodeWidget(a(this));d!==null&&d._setHitArea(c)})},_getOwner:function(){return this._getField("owner")},_getTree:function(){var a=this._getOwner();return a?a.element.is(":"+this.options.treeClass)?a:a._getTree():null},_getInitElement:function(){var b=a("<li>"),d=this,e=a("<ul>"),c=d._getField("nodes");b.append(d.$navigateUrl.clone());if(c.length){b.append(e);a.each(c,function(c,b){var a=b._getInitElement();e.append(a)})}return b},_getChildren:function(){return this.element.find(">ul:first>li").length>0&&this.element.children("ul:first")},_getNodeWidget:function(c){var a=this._getNodeByDom(c),b;if(a.length>0){b=a.data(a.data("widgetName"));return b}return null},_createNodeWidget:function(c,b){if(a.fn.wijtreenode){c.data("owner",this);if(!!b&&a.isPlainObject(b)){a.extend(b,{treeClass:this.options.treeClass});c.wijtreenode(b)}else c.wijtreenode({treeClass:this.options.treeClass})}return c},_getNodeByDom:function(b){return a(b).closest(":"+this.widgetBaseClass)},_getCurrentLevel:function(){return this.element.parentsUntil(":"+this.options.treeClass).length-1},_getField:function(a){return this.element.data(a)},_setField:function(b,a){return this.element.data(b,a)}})})(jQuery);(function(a){var c="ui-icon ui-icon-check",b="ui-icon ui-icon-stop";a.widget("wijmo.wijtreecheck",{options:{checkState:"unCheck"},_create:function(){var b=this,c=this.options;if(b.element.is("div")){b.element.addClass("wijmo-checkbox ui-widget").attr("role","checkbox");b.$icon=a("<span>");b.$icon.addClass("wijmo-checkbox-icon");if(c.checkState==="check")b.$icon.addClass("ui-icon ui-icon-check");else c.checkState==="triState"&&b.$icon.addClass("ui-icon ui-icon-stop");b.$body=a("<div></div>").addClass("wijmo-checkbox-box ui-widget ui-corner-all ui-state-default").css({position:"relative"}).append(b.$icon);b.element.append(b.$body);b.element.bind("mouseover.wijtreecheck",function(){!b.options.disabled&&b.$body.removeClass("ui-state-default").addClass("ui-state-hover")}).bind("mouseout.wijtreecheck",function(){!b.options.disabled&&b.$body.removeClass("ui-state-hover").not(".ui-state-focus").addClass("ui-state-default")})}},_setOption:function(f,e){var d=this;if(f==="checkState")if(e==="unCheck"){d.$body.removeClass("ui-state-active");d.$icon.removeClass("ui-icon ui-icon-check ui-icon-stop ui-state-active")}else if(e==="check"){d.$body.addClass("ui-state-active");d.$icon.removeClass(b).addClass(c)}else if(e==="triState"){d.$body.addClass("ui-state-active");d.$icon.removeClass(c).addClass(b)}a.Widget.prototype._setOption.apply(d,arguments)},destory:function(){this.element.children().remove();this.element.removeClass("wijmo-checkbox ui-widget");a.Widget.prototype.destroy.apply(this)}})})(jQuery);
(function(a){"use strict";var r="wijmo-wijupload",j="wijmo-wijupload-fileRow",d="."+j,u="wijmo-wijupload-filesList",t="wijmo-wijupload-commandRow",i="wijmo-wijupload-uploadAll",h="wijmo-wijupload-cancelAll",s="wijmo-wijupload-buttonContainer",m="wijmo-wijupload-upload",e="."+m,l="wijmo-wijupload-cancel",n="."+l,v="wijmo-wijupload-file",f="wijmo-wijupload-progress",k="wijmo-wijupload-loading",w="ui-widget-content",o="ui-corner-all",x="ui-state-highlight",q,p,b=function(a){if(a.indexOf("\\")>-1)a=a.substring(a.lastIndexOf("\\")+1);return a},g=function(d){var e=d.files,c="";if(e){a.each(e,function(d,a){c+=b(a.name)+"; "});if(c.length)c=c.substring(0,c.lastIndexOf(";"))}else c=b(d.value);return c},c=function(d){var b=d.files,c=0;b&&b.length>0&&a.each(b,function(b,a){if(a.size)c+=a.size});return c};q=function(l,h,i){var f,d=a("input",h),k=function(a){if(a){a.abort();a=null}},j=function(a){if(a)a=null},e;e=function(){var e=this,l=d.get(0).files,m=[],f=0,n=0,p=function(j,i){var h=new XMLHttpRequest;h.open("POST",i,true);h.setRequestHeader("Wijmo-RequestType","XMLHttpRequest");h.setRequestHeader("Cache-Control","no-cache");h.setRequestHeader("Wijmo-FileName",j);h.setRequestHeader("Content-Type","application/octet-stream");h.upload.onprogress=function(h){if(h.lengthComputable){var f;if(a.isFunction(e.onProgress)){f={supportProgress:true,loaded:n+h.loaded,total:c(d[0]),fileName:b(e.currentFile.name),fileNameList:g(d[0]).split("; ")};e.onProgress(f)}}};h.onreadystatechange=function(d){if(this.readyState===4){var c=this.responseText,b;n+=l[f].size;f++;if(l.length>f)o(l[f]);else if(a.isFunction(e.onComplete)){b={e:d,response:c,supportProgress:true};e.onComplete(b)}}};m.push(h);return h},o=function(a){var c=b(a.name),d=p(c,i);e.currentFile=a;d.send(a)};e.fileRow=h;e.inputFile=d;e.upload=function(){o(l[f])};e.cancel=function(){a.each(m,function(b,a){k(a)});a.isFunction(e.onCancel)&&e.onCancel()};e.destroy=function(){a.each(m,function(b,a){j(a)})};e.updateAction=function(a){i=a};e.onCancel=null;e.onComplete=null;e.onProgress=null};f=new e;return f};p=function(n,j,l){var i,d=a("input",j),m=d.attr("id"),e="wijUploadForm_"+n,b=a("#"+e),g="wijUploadIfm_"+m,f=true,c=a('<iframe id="'+g+'" name="'+g+'">'),k=function(c,a){b.empty();b.attr("target",c.attr("name"));if(a){a.parent().append(a.clone());b.append(a)}b.submit()},p=function(a){a.attr("src","javascript".concat(":false;"))},o=function(a,c){if(c&&b){b.remove();b=null}if(a){a.remove();a=null}},h;if(b.length===0){b=a('<form method="post" enctype="multipart/form-data"></form>');b.attr("action",l).attr("id",e).attr("name",e).appendTo("body")}c.css("position","absolute").css("top","-1000px").css("left","-1000px");c.appendTo("body");h=function(){var e=this;e.fileRow=j;e.iframe=c;e.inputFile=d;e.upload=function(){var b;k(c,d);if(a.isFunction(e.onProgress)){b={supportProgress:false,loaded:1,total:1};e.onProgress(b)}};e.doPost=function(){k(c)};e.cancel=function(){p(c);a.isFunction(e.onCancel)&&e.onCancel()};e.updateAction=function(a){l=a;b.attr("action",a)};e.destroy=function(a){o(c,a)};e.onCancel=null;e.onComplete=null;e.onProgress=null;c.bind("load",function(i){if(!a.browser.safari)if(f){f=false;return}if(c.attr("src")==="javascript".concat(":false;"))return;var g=i.target,d,b,h;try{b=g.contentDocument?g.contentDocument:window.frames[0].document;if(b.XMLDocument)d=b.XMLDocument;else if(b.body)d=b.body.innerHTML;else d=b;if(a.isFunction(e.onComplete)){h={e:i,response:d,supportProgress:false};e.onComplete(h)}}catch(j){d=""}})};i=new h;return i};a.widget("wijmo.wijupload",{options:{action:"",autoSubmit:false,change:null,upload:null,totalUpload:null,progress:null,totalProgress:null,complete:null,totalComplete:null,maximumFiles:0,multiple:false,accept:""},_create:function(){var a=this,d=a.options,c=+new Date,b=a.supportXhr();a.filesLen=0;a.totalUploadFiles=0;a.useXhr=b;a.id=c;a._createContainers();a._createUploadButton();a._createFileInput();a._bindEvents();d.disabled&&a.disable()},_setOption:function(d,c){var b=this;a.Widget.prototype._setOption.apply(this,arguments);d==="disabled"&&b._handleDisabledOption(c,b.upload)},_handleDisabledOption:function(b,c){var a=this;if(b){if(!a.disabledDiv)a.disabledDiv=a._createDisabledDiv(c);a.disabledDiv.appendTo("body")}else if(a.disabledDiv){a.disabledDiv.remove();a.disabledDiv=null}},_createDisabledDiv:function(d){var g=this,b=d?d:g.upload,c=b.offset(),f=b.outerWidth(),e=b.outerHeight();return a("<div></div>").addClass("ui-disabled").css({"z-index":"99999",position:"absolute",width:f,height:e,left:c.left,top:c.top})},destroy:function(){var b=this;b.upload.removeClass(r);b.upload.undelegate(b.widgetName).undelegate("."+b.widgetName);b.input.remove();b.addBtn.remove();b.filesList.remove();b.commandRow.remove();b.isCreateByInput==true&&b.element.css({display:""}).unwrap();if(b.uploaders){a.each(b.uploaders,function(b,a){a.destroy&&a.destroy(true);a=null});b.uploaders=null}if(b.disabledDiv){b.disabledDiv.remove();b.disabledDiv=null}},widget:function(){return this.upload},supportXhr:function(){var a=false;if(typeof(new XMLHttpRequest).upload==="undefined")a=false;else a=true;return a},_createContainers:function(){var b=this,d,c,e;if(b.element.is(":input")&&b.element.attr("type")==="file"){b.isCreateByInput=true;b.maxDisplay=b.element.attr("multiple")?0:1;b.upload=b.element.css({display:"none"}).wrap("<div>").parent()}else if(b.element.is("div"))b.upload=b.element;else throw'The initial markup must be "DIV", "INPUT[type=file]"';b.upload.addClass(r);d=a("<ul>").addClass(u).appendTo(b.upload);c=a("<div>").addClass(t).appendTo(b.upload);b.filesList=d;c.hide();b.commandRow=c;b._createCommandRow(c)},_createCommandRow:function(d){var c=a("<a>").attr("href","#").text("uploadAll").addClass(i).button({icons:{primary:"ui-icon-circle-arrow-n"},label:"Upload All"}),b=a("<a>").attr("href","#").text("cancelAll").addClass(h).button({icons:{primary:"ui-icon-cancel"},label:"Cancel All"});d.append(c).append(b)},_createUploadButton:function(){var b=this,c=a("<a>").attr("href","#").button({label:"Upload files"});c.mousemove(function(a){if(b.input){var c=a.pageX,d=a.pageY;b.input.offset({left:c+10-b.input.width(),top:d+10-b.input.height()})}});b.addBtn=c;b.upload.prepend(c)},_createFileInput:function(){var b=this,d=b.addBtn,f=d.offset(),g=b.element.attr("accept")||b.options.accept,h="wijUpload_"+b.id+"_input"+b.filesLen,c=a("<input>").attr("type","file").prependTo(b.upload),i=b.options.maximumFiles||b.maxDisplay;i!==1&&c.attr("multiple","multiple");g&&c.attr("accept",g);b.filesLen++;c.attr("id",h).attr("name",h).css("position","absolute").offset({left:f.left+d.width()-c.width(),top:f.top}).css("z-index","9999").css("opacity",0).height(d.height()).css("cursor","pointer");b.input=c;c.bind("change",function(g){var f,d;if(b._trigger("change",g,a(this))===false)return false;b._createFileInput();f=b._createFileRow(a(this));b._setAddBtnState();if(b.options.autoSubmit){d=a(e,f);d&&d.click()}c.unbind("change")});b.uploadAll=false},_setAddBtnState:function(){var b=this,d=b.options.maximumFiles||b.maxDisplay,c=b.addBtn,e;if(!d)return;if(!c)return;if(!b.maskDiv)b.maskDiv=a("<div></div>").css("position","absolute").css("z-index","9999").width(c.outerWidth()).height(c.outerHeight()).offset(c.offset()).appendTo(b.element);e=a("li",b.filesList);if(e.length>=d){c.button({disabled:true});b.maskDiv.show();b.input&&b.input.css("left","-1000px")}else{c.button({disabled:false});b.maskDiv.hide()}},_createFileRow:function(e){var c=this,b=a("<li>"),r=e.val(),n,k,i,h=a("<span>").addClass(s),q=a("<a>").attr("href","#").text("upload").addClass(m).button({text:false,icons:{primary:"ui-icon-circle-arrow-n"},label:"upload"}),p=a("<a>").attr("href","#").text("cancel").addClass(l).button({text:false,icons:{primary:"ui-icon-cancel"},label:"cancel"});b.addClass(j).addClass(w).addClass(o);b.append(e);e.hide();n=a("<span>"+g(e[0])+"</span>").addClass(v).addClass(x).addClass(o);b.append(n);b.append(h);k=a("<span />").addClass(f);h.append(k);h.append(q).append(p);b.appendTo(c.filesList);i=a(d,c.upload);if(i.length){c.commandRow.show();c._createUploader(b);c._resetProgressAll()}return b},_createUploader:function(g){var d=this,i=a("input",g),h=d.options.action,e;if(d.useXhr)e=q(d.id,g,h);else e=p(d.id,g,h);e.onCancel=function(){var a=this;d._trigger("cancel",null,a.inputFile);d.totalUploadFiles--;d.totalUploadFiles===0&&d.uploadAll&&d._trigger("totalComplete")};if(d._wijUpload()){e.onProgress=function(b){var c=a("."+f,this.fileRow),e={sender:b.fileName,loaded:b.loaded,total:b.total},g=this.inputFile.attr("id");if(b.supportProgress){c.html(Math.round(1e3*b.loaded/b.total)/10+"%");if(b.fileNameList)e.fileNameList=b.fileNameList;d._trigger("progress",null,e);d._progressTotal(g,b.loaded)}else c.addClass(k)};e.onComplete=function(g){var e=this,i=e.inputFile.attr("id"),l=d.uploaders[i],m=b(e.inputFile.val()),j=c(e.inputFile[0]),h=a("."+f,e.fileRow),n=g.e.currentTarget;d._trigger("complete",g.e,e.inputFile);h.removeClass(k);h.html("100%");d._removeFileRow(e.fileRow,l,true);d._progressTotal(i,j);d.totalUploadFiles--;d.totalUploadFiles===0&&d.uploadAll&&d._trigger("totalComplete",g.e,g)}}if(typeof d.uploaders==="undefined")d.uploaders={};d.uploaders[i.attr("id")]=e},_progressTotal:function(f,e){var b=this,a=b.progressAll,c,d;if(!b.uploadAll)return;if(a&&a.loadedSize){a.loadedSize[f]=e;c=b._getLoadedSize(a.loadedSize);d=a.totalSize}b._trigger("totalProgress",null,{loaded:c,total:d})},_getLoadedSize:function(c){var b=0;a.each(c,function(c,a){b+=a});return b},_getTotalSize:function(){var d=this,b=0;d.uploaders&&a.each(d.uploaders,function(d,a){b+=c(a.inputFile[0])});return b},_resetProgressAll:function(){this.progressAll={totalSize:0,loadedSize:{}}},_wijUpload:function(){return true},_wijcancel:function(){},_upload:function(){},_bindEvents:function(){var b=this,f=b.progressAll;b.upload.delegate(n,"click."+b.widgetName,function(){var i=a(this),h=i.parents(d),e=a("input",h[0]),g=b.uploaders[e.attr("id")];b._wijcancel(e);b._wijUpload()&&g&&g.cancel();if(f){f.totalSize-=c(e[0]);if(f.loadedSize[e.val()])delete f.loadedSize[e.val()]}b._removeFileRow(h,g,false)});b.upload.delegate(e,"click."+b.widgetName,function(h){var g=a(this),f=g.parents(d),c=a("input",f[0]),e=b.uploaders[c.attr("id")];if(b._trigger("upload",h,c)===false)return false;b.totalUploadFiles++;b._upload(f);e&&b._wijUpload()&&e.upload()});b.upload.delegate("."+i,"click."+b.widgetName,function(c){b.uploadAll=true;!b.progressAll&&b._resetProgressAll();if(b._trigger("totalUpload",c,null)===false)return false;b.progressAll.totalSize=b._getTotalSize();b._wijuploadAll(a(e,b.filesList[0]));b._wijUpload()&&a(e,b.filesList[0]).each(function(c,b){a(b).click()})});b.upload.delegate("."+h,"click."+b.widgetName,function(){b._resetProgressAll();a(n,b.filesList[0]).each(function(c,b){a(b).click()})})},_wijuploadAll:function(){},_wijFileRowRemoved:function(){this._setAddBtnState()},_removeFileRow:function(f,b,h){var c=this,e,g;if(b)e=b.inputFile.attr("id");f.fadeOut(1500,function(){f.remove();c._wijFileRowRemoved(f,b.inputFile,h);if(c.uploaders[e])delete c.uploaders[e];g=a(d,c.upload);if(g.length){c.commandRow.show();b&&b.destroy&&b.destroy()}else{c.commandRow.hide();c._resetProgressAll();b&&b.destroy&&b.destroy(true)}})},_getFileName:function(a){return b(a)},_getFileNameByInput:function(a){return g(a)},_getFileSize:function(a){return c(a)}})})(jQuery);
(function(a){"use strict";a.widget("wijmo.wijwizard",{options:{navButtons:"auto",autoPlay:false,delay:3e3,loop:false,hideOption:{fade:true},showOption:{fade:true,duration:400},ajaxOptions:null,cache:false,cookie:null,stepHeaderTemplate:"",panelTemplate:"",spinner:"",add:null,remove:null,activeIndexChanged:null,show:null,load:null,validating:null},_defaults:{stepHeaderTemplate:"<li><h1>#{title}</h1>#{desc}</li>",panelTemplate:"<div></div>",spinner:"<em>Loading&#8230;</em>"},_create:function(){this._pageLize(true)},_init:function(){var a=this.options;if(a.disabled)this.disable();else a.autoPlay&&this.play()},_setOption:function(c,b){a.Widget.prototype._setOption.apply(this,arguments);switch(c){case"activeIndex":this.show(b);break;case"navButtons":this._createButtons();break;default:this._pageLize()}},play:function(){var b=this.options,a=this;if(!this.element.data("intId.wijwizard")){var c=window.setInterval(function(){var c=b.activeIndex+1;if(c>=a.panels.length)if(b.loop)c=0;else{a.stop();return}a.show(c)},b.delay);this.element.data("intId.wijwizard",c)}},stop:function(){var a=this.element.data("intId.wijwizard");if(a){window.clearInterval(a);this.element.removeData("intId.wijwizard")}},_normalizeBlindOption:function(a){if(a.blind===undefined)a.blind=false;if(a.fade===undefined)a.fade=false;if(a.duration===undefined)a.duration=200;if(typeof a.duration==="string")try{a.duration=parseInt(a.duration,10)}catch(b){a.duration=200}},_createButtons:function(){var d=this,e=this.options;this._removeButtons();if(e.navButtons==="none")return;if(!this.buttons){var f=e.navButtons;if(f==="auto")f=this.list?"common":"edge";this.buttons=a("<div/>");this.buttons.addClass("wijmo-wijwizard-buttons");var c=function(b,a){if(e.disabled)return;a.is(":not(.ui-state-disabled)")&&a.addClass("ui-state-"+b)},b=function(a,b){if(e.disabled)return;b.removeClass("ui-state-"+a)};if(f==="common"){this.backBtn=a("<a href='#'><span class='ui-button-text'>back</span></a>").addClass("ui-widget ui-button ui-button-text-only ui-state-default ui-corner-all").appendTo(this.buttons).bind({click:function(){d.back();return false},mouseover:function(){c("hover",a(this))},mouseout:function(){b("hover",a(this))},mousedown:function(){c("active",a(this))},mouseup:function(){b("active",a(this))}}).attr("role","button");this.nextBtn=a("<a href='#'><span class='ui-button-text'>next</span></a>").addClass("ui-widget ui-button ui-button-text-only ui-state-default ui-corner-all").appendTo(this.buttons).bind({click:function(){d.next();return false},mouseover:function(){c("hover",a(this))},mouseout:function(){b("hover",a(this))},mousedown:function(){c("active",a(this))},mouseup:function(){b("active",a(this))}}).attr("role","button")}else{this.backBtn=a("<a href='#'/>").addClass("wijmo-wijwizard-prev ui-state-default ui-corner-right").append("<span class='ui-icon ui-icon-triangle-1-w'></span>").appendTo(this.buttons).bind({click:function(){d.back();return false},mouseover:function(){c("hover",a(this))},mouseout:function(){b("hover",a(this))},mousedown:function(){c("active",a(this))},mouseup:function(){b("active",a(this))}}).attr("role","button");this.nextBtn=a("<a href='#'/>").addClass("wijmo-wijwizard-next ui-state-default ui-corner-left").append("<span class='ui-icon ui-icon-triangle-1-e'></span>").appendTo(this.buttons).bind({click:function(){d.next();return false},mouseover:function(){c("hover",a(this))},mouseout:function(){b("hover",a(this))},mousedown:function(){c("active",a(this))},mouseup:function(){b("active",a(this))}}).attr("role","button")}this.buttons.appendTo(this.element)}},_removeButtons:function(){if(this.buttons){this.buttons.remove();this.buttons=undefined}},_pageLize:function(d){var e=this,b=this.options;this.list=this.element.find("ol,ul").eq(0);if(this.list&&this.list.length===0)this.list=null;if(this.list)this.lis=a("li",this.list);if(d){this.panels=a("> div",this.element);var c=/^#.+/;this.panels.each(function(e,d){var b=a(d).attr("src");b&&!c.test(b)&&a.data(d,"load.wijwizard",b.replace(/#.*$/,""))});this.element.addClass("wijmo-wijwizard ui-widget ui-helper-clearfix");if(this.list){this.list.addClass("ui-widget ui-helper-reset wijmo-wijwizard-steps ui-helper-clearfix").attr("role","tablist");this.lis.addClass("ui-widget-header ui-corner-all").attr("role","tab")}this.container=a("<div/>");this.container.addClass("wijmo-wijwizard-content ui-widget ui-widget-content ui-corner-all");this.container.append(this.panels);this.container.appendTo(this.element);this.panels.addClass("wijmo-wijwizard-panel ui-widget-content").attr("role","tabpanel");if(b.activeIndex===undefined){if(typeof b.activeIndex!="number"&&b.cookie)b.activeIndex=parseInt(e._cookie(),10);if(typeof b.activeIndex!="number"&&this.panels.filter(".wijmo-wijwizard-actived").length)b.activeIndex=this.panels.index(this.panels.filter(".wijmo-wijwizard-actived"));b.activeIndex=b.activeIndex||(this.panels.length?0:-1)}else if(b.activeIndex===null)b.activeIndex=-1;b.activeIndex=b.activeIndex>=0&&this.panels[b.activeIndex]||b.activeIndex<0?b.activeIndex:0;this.panels.addClass("wijmo-wijwizard-hide").attr("aria-hidden",true);if(b.activeIndex>=0&&this.panels.length){this.panels.eq(b.activeIndex).removeClass("wijmo-wijwizard-hide").addClass("wijmo-wijwizard-actived").attr("aria-hidden",false);this.load(b.activeIndex)}this._createButtons()}else{this.panels=a("> div",this.container);b.activeIndex=this.panels.index(this.panels.filter(".wijmo-wijwizard-actived"))}this._refreshStep();this._initScroller();b.cookie&&this._cookie(b.activeIndex,b.cookie);b.cache===false&&this.panels.removeData("cache.wijwizard");if(b.showOption===undefined||b.showOption===null)b.showOption={};this._normalizeBlindOption(b.showOption);if(b.hideOption===undefined||b.hideOption===null)b.hideOption={};this._normalizeBlindOption(b.hideOption);this.panels.unbind(".wijwizard")},_initScroller:function(){if(!this.lis)return;var b=0;this.lis.each(function(){b+=a(this).outerWidth(true)});if(this.element.innerWidth()<b){if(this.scrollWrap===undefined){this.list.wrap("<div class='scrollWrap'></div>");this.scrollWrap=this.list.parent();a.effects.save(this.list,["width","height","overflow"])}this.list.width(b+8);this.scrollWrap.height(this.list.outerHeight(true));this.scrollWrap.wijsuperpanel({allowResize:false,hScroller:{scrollBarVisibility:"hidden"},vScroller:{scrollBarVisibility:"hidden"}})}else this._removeScroller()},_removeScroller:function(){if(this.scrollWrap){this.scrollWrap.wijsuperpanel("destroy").replaceWith(this.scrollWrap.contents());this.scrollWrap=undefined;a.effects.restore(this.list,["width","height","overflow"])}},_refreshStep:function(){var a=this.options;if(this.lis){this.lis.removeClass("ui-priority-primary").addClass("ui-priority-secondary").attr("aria-selected",false);if(a.activeIndex>=0&&a.activeIndex<=this.lis.length-1){this.lis&&this.lis.eq(a.activeIndex).removeClass("ui-priority-secondary").addClass("ui-priority-primary").attr("aria-selected",true);this.scrollWrap&&this.scrollWrap.wijsuperpanel("scrollChildIntoView",this.lis.eq(a.activeIndex))}}if(this.buttons&&!a.loop){this.backBtn[a.activeIndex<=0?"addClass":"removeClass"]("ui-state-disabled").attr("aria-disabled",a.activeIndex===0);this.nextBtn[a.activeIndex>=this.panels.length-1?"addClass":"removeClass"]("ui-state-disabled").attr("aria-disabled",a.activeIndex>=this.panels.length-1)}},_sanitizeSelector:function(a){return a.replace(/:/g,"\\:")},_cookie:function(){var b=this.cookie||(this.cookie=this.options.cookie.name);return a.cookie.apply(null,[b].concat(a.makeArray(arguments)))},_ui:function(a){return{panel:a,index:this.panels.index(a)}},_removeSpinner:function(){this.element.removeClass("ui-state-processing");var a=this.element.data("spinner.wijwizard");if(a){this.element.removeData("spinner.wijwizard");a.remove()}},_resetStyle:function(b){b.css({display:""});!a.support.opacity&&b[0].style.removeAttribute("filter")},destroy:function(){var b=this.options;this.abort();this.stop();this._removeScroller();this._removeButtons();this.element.unbind(".wijwizard").removeClass(["wijmo-wijwizard","ui-widget","ui-helper-clearfix"].join(" ")).removeData("wijwizard");this.list&&this.list.removeClass("ui-widget ui-helper-reset wijmo-wijwizard-steps ui-helper-clearfix").removeAttr("role");if(this.lis){this.lis.removeClass("ui-widget-header ui-corner-all ui-priority-primary ui-priority-secondary").removeAttr("role");this.lis.each(function(){if(a.data(this,"destroy.wijwizard"))a(this).remove();else a(this).removeAttr("aria-selected")})}this.panels.each(function(){var b=a(this).unbind(".wijwizard");a.each(["load","cache"],function(c,a){b.removeData(a+".wijwizard")});if(a.data(this,"destroy.wijwizard"))a(this).remove();else a(this).removeClass(["ui-state-default","wijmo-wijwizard-actived","ui-state-active","ui-state-hover","ui-state-focus","ui-state-disabled","wijmo-wijwizard-panel","ui-widget-content","wijmo-wijwizard-hide"].join(" ")).css({position:"",left:"",top:""}).removeAttr("aria-hidden")});this.container.replaceWith(this.container.contents());b.cookie&&this._cookie(null,b.cookie);return this},add:function(b,f,h){if(b===undefined)b=this.panels.length;if(f===undefined)f="Step "+b;var d=this,g=this.options,c=a(g.panelTemplate||d._defaults.panelTemplate).data("destroy.wijwizard",true),e;c.addClass("wijmo-wijwizard-panel ui-widget-content ui-corner-all wijmo-wijwizard-hide").attr("aria-hidden",true);if(b>=this.panels.length)if(this.panels.length>0)c.insertAfter(this.panels[this.panels.length-1]);else c.appendTo(this.container);else c.insertBefore(this.panels[b]);if(this.list&&this.lis){e=a((g.stepHeaderTemplate||d._defaults.stepHeaderTemplate).replace(/#\{title\}/g,f).replace(/#\{desc\}/g,h));e.addClass("ui-widget-header ui-corner-all ui-priority-secondary").data("destroy.wijwizard",true);if(b>=this.lis.length)e.appendTo(this.list);else e.insertBefore(this.lis[b])}this._pageLize();if(this.panels.length==1){g.activeIndex=0;e.addClass("ui-priority-primary");c.removeClass("wijmo-wijwizard-hide").addClass("wijmo-wijwizard-actived").attr("aria-hidden",false);this.element.queue("wijwizard",function(){d._trigger("show",null,d._ui(d.panels[0]))});this._refreshStep();this.load(0)}this._trigger("add",null,this._ui(this.panels[b]));return this},remove:function(a){var c=this.options,d=this.lis.eq(a).remove(),b=this.panels.eq(a).remove();if(a<c.activeIndex)c.activeIndex--;this._pageLize();b.hasClass("wijmo-wijwizard-actived")&&this.panels.length>=1&&this.show(a+(a<this.panels.length?0:-1));this._trigger("remove",null,this._ui(b[0]));return this},_showPanel:function(f){var b=this,d=this.options,c=a(f);c.addClass("wijmo-wijwizard-actived");if((d.showOption.blind||d.showOption.fade)&&d.showOption.duration>0){var e={duration:d.showOption.duration};if(d.showOption.blind)e.height="toggle";if(d.showOption.fade)e.opacity="toggle";c.hide().removeClass("wijmo-wijwizard-hide").animate(e,d.showOption.duration||"normal",function(){b._resetStyle(c);b._trigger("show",null,b._ui(c[0]));b._removeSpinner();c.attr("aria-hidden",false);b._trigger("activeIndexChanged",null,b._ui(c[0]))})}else{c.removeClass("wijmo-wijwizard-hide").attr("aria-hidden",false);b._trigger("show",null,b._ui(c[0]));b._removeSpinner();b._trigger("activeIndexChanged",null,b._ui(c[0]))}},_hidePanel:function(f){var e=this,b=this.options,c=a(f);c.removeClass("wijmo-wijwizard-actived");if((b.hideOption.blind||b.hideOption.fade)&&b.hideOption.duration>0){var d={duration:b.hideOption.duration};if(b.hideOption.blind)d.height="toggle";if(b.hideOption.fade)d.opacity="toggle";c.animate(d,b.hideOption.duration||"normal",function(){c.addClass("wijmo-wijwizard-hide").attr("aria-hidden",true);e._resetStyle(c);e.element.dequeue("wijwizard")})}else{c.addClass("wijmo-wijwizard-hide").attr("aria-hidden",true);this.element.dequeue("wijwizard")}},show:function(b){if(b<0||b>=this.panels.length)return this;if(this.element.queue("wijwizard").length>0)return this;var g=this,c=this.options,d=a.extend({},this._ui(this.panels[c.activeIndex]));d.nextIndex=b;d.nextPanel=this.panels[b];if(this._trigger("validating",null,d)===false)return this;var e=this.panels.filter(":not(.wijmo-wijwizard-hide)"),f=this.panels.eq(b);c.activeIndex=b;this.abort();c.cookie&&this._cookie(c.activeIndex,c.cookie);this._refreshStep();if(f.length){e.length&&this.element.queue("wijwizard",function(){g._hidePanel(e)});this.element.queue("wijwizard",function(){g._showPanel(f)});this.load(b)}else throw"jQuery UI wijwizard: Mismatching fragment identifier.";return this},next:function(){var b=this.options;if(b.disabled)return false;var a=b.activeIndex+1;if(b.loop)a=a%this.panels.length;if(a<this.panels.length){this.show(a);return true}return false},back:function(){var b=this.options;if(b.disabled)return false;var a=b.activeIndex-1;if(b.loop)a=a<0?this.panels.length-1:a;if(a>=0){this.show(a);return true}return false},load:function(f){var d=this,b=this.options,e=this.panels.eq(f)[0],g=a.data(e,"load.wijwizard");this.abort();if(!g||this.element.queue("wijwizard").length!==0&&a.data(e,"cache.wijwizard")){this.element.dequeue("wijwizard");return}this.element.addClass("ui-state-processing");if(b.spinner){var c=this.element.data("spinner.wijwizard");if(!c){c=a("<div/>");c.addClass("wijmo-wijwizard-spinner");c.html(b.spinner||d._defaults.spinner);c.appendTo(document.body);this.element.data("spinner.wijwizard",c);c.wijpopup({showEffect:"blind",hideEffect:"blind"})}c.wijpopup("show",{of:this.element,my:"center center",at:"center center"})}this.xhr=a.ajax(a.extend({},b.ajaxOptions,{url:g,dataType:"html",success:function(c,g){a(e).html(c);b.cache&&a.data(e,"cache.wijwizard",true);d._trigger("load",null,d._ui(d.panels[f]));try{b.ajaxOptions&&b.ajaxOptions.success&&b.ajaxOptions.success(c,g)}catch(h){}},error:function(a,c){d._trigger("load",null,d._ui(d.panels[f]));try{b.ajaxOptions&&b.ajaxOptions.error&&b.ajaxOptions.error(a,c,f,e)}catch(g){}}}));d.element.dequeue("wijwizard");return this},abort:function(){this.element.queue([]);this.panels.stop(false,true);this.element.queue("wijwizard",this.element.queue("wijwizard").splice(-2,2));if(this.xhr){this.xhr.abort();delete this.xhr}this._removeSpinner();return this},url:function(a,b){this.panels.eq(a).removeData("cache.wijwizard").data("load.wijwizard",b);return this},count:function(){return this.panels.length}})})(jQuery);
(function(a){"use strict";var b="wijmo-wijribbon",w=b+"-disabled",n=b+"-bigbutton",A=b+"-panel",q=b+"-groups",j=b+"-group",t=j+"-content",v=j+"-label",o=b+"-dropdown",g=b+"-dropdowngroup",p=b+"-abbrev",l=p+"group",B=b+"-text",r=b+"-icon",u=b+"-abbrevicon",y="ui-widget-content",i="ui-helper-reset",C="ui-tabs-nav",h="ui-helper-clearfix",f="ui-corner-all",c="ui-button-text",z="ui-state-default",e="ui-state-hover",d="ui-state-active",x="ui-state-disabled",s="ui-icon",m=s+"-triangle-1-s",k="ui-tabs-hide";a.widget("wijmo.wijribbon",{options:{click:null},_create:function(){var a=this;a._ribbonify();a.options.disabled&&a._setDisabled(true)},_setOption:function(c,b){a.Widget.prototype._setOption.apply(this,arguments);c==="disabled"&&this._setDisabled(b)},_setDisabled:function(e){var d=this,c=d.element,b=d.disabledModal;c.wijtabs("option","disabled",e);if(e){if(!b){b=a("<div></div>").addClass(x+" "+w).css({top:0,left:0,"z-index":"10000","background-color":"lightgray",position:"absolute"}).appendTo(c.parent()).bind("click mousedown mouseup mouseover mouseout focus keydown keypress",function(a){a.stopPropagation();a.preventDefault();return false});d.disabledModal=b}b.width(c.width()).height(c.height()).show()}else b&&b.hide()},_ribbonify:function(){var b=this;b.buttons={};b.listUis={};b._getButtonSets();b._createButtons();b._createGroup();b._createSplit();b._createDropdwon();b._hideShowedList();b._createTab();a("."+i+":not(."+q+", ."+C+")",b.element).hover(function(){a(this).addClass(e)},function(){a(this).removeClass(e)});a(".ui-button",b.element).bind("mouseenter",function(){a("."+c,this).addClass(e)}).bind("mouseleave",function(){a("."+c,this).removeClass(e)});a("button.ui-button").bind("mousedown",function(){b._addActiveClassToButtonText(this)}).bind("mouseup",function(){b._addActiveClassToButtonText(this)});a("label.ui-button").bind("click",function(){b._addActiveClassToLabelButtonText(this)})},_addActiveClassToButtonText:function(b){if(b)if(a(b).hasClass(d))a("."+c,b).addClass(d);else a("."+c,b).removeClass(d)},_addActiveClassToLabelButtonText:function(d){var c=this,b,f,e;if(d){f=a(d).attr("for");b=a("#"+f,c.element);if(b.is(":checkbox"))c._addActiveClassToButtonText(d);else if(b.is(":radio")){e=c.element.find("[name='"+b.attr("name")+"']");a.each(e,function(){c._updateGroupElementTextState(this)})}}},_updateGroupElementTextState:function(e){var f=this,b;if(!e)return;b=a("[for='"+a(e).attr("id")+"']",a(e).parent());if(b)if(b.hasClass(d))b.children("."+c).addClass(d);else b.children("."+c).removeClass(d)},_getButtonSets:function(){var b=this,c;b.groups=[];b.splits=[];b.dropdowns=[];a("span>button, span>:checkbox, span>:radio, div>button, div>:checkbox, div>:radio",b.element).each(function(e,d){c=a(d).parent();if(a(">ul",c).length===0)b.groups.push(c);else if(a(">button",c).length===2)b.splits.push(c);else a(">button",c).length===1&&b.dropdowns.push(c)});b.groups=b._unique(b.groups);b.splits=b._unique(b.splits)},_unique:function(c){var b=a.map(c,function(a){return a.get(0)});return a.map(a.unique(b),function(b){return a(b)})},_createButtons:function(){var b=this,c=b.element;a(":checkbox",c).each(function(){b._createButton(a(this),"checkbox")});a(":radio",c).each(function(){b._createButton(a(this),"radio")});a("button",c).each(function(){b._createButton(a(this),"button")})},_createButton:function(b,h){var g=this,e=g._buildButtonOption(b,h),f=b.data("commandName"),d;b.button(e);if(!e.text)if(h==="button")b.children("."+c).text(f);else{d=a("[for='"+b.attr("id")+"']",b.parent());d&&d.children("."+c).text(f)}g._triggerEvent(b)},_createGroup:function(){a.each(this.groups,function(b,a){a.buttonset()})},_createSplit:function(){var d=this;a.each(d.splits,function(p,g){var e=g.children("ul"),j=g.children("button:eq(0)"),l=j.data("commandName"),k=g.children("button:eq(1)"),n;e.children("li").addClass(f);g.addClass(b+"-"+l);k.button({icons:{primary:m},text:false}).data("list",e).unbind("click").bind("click",function(a){a.stopPropagation();a.preventDefault()}).bind("mouseup",function(b){e=a(this).data("list");if(e.is(":visible")){d.showList.hide().css("z-index","");d.showList=null}else{e.show().position({my:"left top",at:"left bottom",of:g}).css("z-index",9999);d.showList=e}b.stopPropagation();b.preventDefault()});k.children("."+c).text("foo");g.after(e);e.css("position","absolute").addClass(i+" "+h+" "+f+" "+o).hide();g.buttonset();n={ui:j,defaultValue:j.button("option","label"),buttons:[],type:"split",trigger:k,list:e};a("button, :checkbox, :radio",e).bind("click",function(a){e.hide().css("z-index","");d.showList=null;a.preventDefault()});e.find(">li>button,>li>:radio,>li>:checkbox").each(function(e,c){var b=a(c).data("commandName");if(b!==""&&d.buttons[b]){d.buttons[b].parent=j;d.buttons[b].type="split"}n.buttons.push(a(c))});if(l!=="")d.listUis[l]=n})},_createDropdwon:function(){var d=this;d.dropdownLabels={};a.each(d.dropdowns,function(n,j){var g=j.children("ul"),e=j.children("button:eq(0)"),k=e.data("commandName"),l;g.children("li").addClass(f);j.addClass(b+"-"+k);e.button({icons:{secondary:m}}).unbind("click").bind("click",function(a){a.stopPropagation();a.preventDefault()}).bind("mouseup",function(a){if(g.is(":visible")){d.showList.hide().css("z-index","");d.showList=null}else{if(d.showList){d.showList.hide();d.showList=null}g.show().position({my:"left top",at:"left bottom",of:e}).css("z-index",9999);d.showList=g;d.isShow=true}a.stopPropagation();a.preventDefault()});l={ui:e,defaultValue:e.button("option","label"),buttons:[],type:"dropdown",list:g};a("button, :checkbox, :radio",g).bind("click",function(i){var b=a(this).data("commandName"),f,h=e.children("."+c).width();if(!d.dropdownLabels[b])d.dropdownLabels[b]=d._getDropdownLabelSubstr(a(this).button("option","label"),e.children("."+c),h);f=d.dropdownLabels[b];e.button("option","label",f);e.attr("title",a(this).button("option","label"));g.hide().css("z-index","");d.showList=null;i.preventDefault()});g.css("position","absolute").addClass(i+" "+h+" "+f+" "+o).hide();j.buttonset();g.find(">li>button,>li>:radio,>li>:checkbox").each(function(f,c){var b=a(c).data("commandName");if(b!==""&&d.buttons[b]){d.buttons[b].parent=e;d.buttons[b].type="dropdown"}l.buttons.push(a(c))});if(k!=="")d.listUis[k]=l})},_createTab:function(){var d=this,c=d.element;c.addClass(b);d.tabEle=c;if(a(">ul",c).length>0){c.wijtabs();d._createRibbonGroups();return true}else c.addClass(b+"-simple").addClass(h);return false},updateRibbonSize:function(){var e=this,f,c,d;e.tabEle.children("div").each(function(o,n){var f=a(n),i=f.is(":visible"),m=f.find(">ul>li"),j=[],h;h=f.width();if(!i){f.removeClass(k);h=f.width()}m.each(function(k,i){var e=a(i),h=e.find(">div:last"),f=a.trim(h.text());c=e.children("."+g);d=e.children("."+l);if(c){e.addClass(b+"-"+f.toLowerCase()).prepend(c.children());c.remove();d&&d.remove()}j.push({width:e.outerWidth(true),text:f})});e._adjustRibbonGroupIfNeeded(m,j,h);!i&&f.addClass(k)})},_createRibbonGroups:function(){var c=this;c.tabEle.children("div").each(function(p,o){var d=a(o),l=d.is(":visible"),n=d.find(">ul>li"),g=[],m;!l&&d.removeClass(k);m=d.width();d.addClass(A);d.find(">ul").addClass(i+" "+h+" "+y+" "+f+" "+q);n.each(function(k,i){var c=a(i),d=c.find(">div:last"),h=z+" "+j,f=a.trim(d.text());if(d)h+=" "+b+"-"+f.toLowerCase();c.addClass(h);d.addClass(v).bind("click",function(){return false});c.wrapInner("<div class = '"+t+"'></div>");c.children().bind("mouseover",function(){a(this).addClass(e)}).bind("mouseout",function(){a(this).removeClass(e)});d.appendTo(c);g.push({width:c.outerWidth(true),text:f})});c._originalGroupInfo=g;c._adjustRibbonGroupIfNeeded(n,g,m);!l&&d.addClass(k)})},_adjustRibbonGroupIfNeeded:function(d,f,n){for(var o=this,c=d.length-1,h=0,k=0,j=0,e,i,m;c>=0;c--){j=0;for(h=0;h<c;h++)j+=f[h].width;if(j+k+f[c].width<=n){e=a(d[c]).children("."+g);i=a(d[c]).children("."+l);if(e){a(d[c]).addClass(b+"-"+f[c].text.toLowerCase()).prepend(e.children());e.remove();i&&i.remove()}}else{m=f[c];k+=o._createDropDownRibbonGroup(m.text,d[c])}}},_createDropDownRibbonGroup:function(f,k){var c=this,h=b+"-"+f.toLowerCase(),d=a(k).removeClass(h),i;d.wrapInner("<div class='"+g+" "+j+"'></div>").children().hide().addClass(h).bind("mouseup."+c.widget,function(){if(c.showDrpDwnGroup!==null){c.showDrpDwnGroup.hide().css("z-index","");c.showDrpDwnGroup=null}});i=a("<div class='"+l+"'><span class='"+p+f.toLowerCase()+" "+r+" "+u+"'></span><span class='"+B+"'>"+f+"</span><span class='"+s+" "+m+" "+r+"'></span></div>").appendTo(d).unbind(c.widget).bind("mouseover."+c.widget,function(){a(this).addClass(e)}).bind("mouseout."+c.widget,function(){a(this).removeClass(e)}).bind("click."+c.widget,function(d){var b=a(this).siblings("."+g);if(b.is(":visible")){b.hide().css("z-index","");c.showDrpDwnGroup=null}else{c.showDrpDwnGroup&&c.showDrpDwnGroup.hide().css("z-index","");b.show().position({my:"left top",at:"left bottom",of:this}).css("z-index","10000");c.showDrpDwnGroup=b;d.stopPropagation()}});return d.outerWidth(true)},_hideShowedList:function(){var b=this;a(document).bind("mouseup",function(d){var c=d.target;if(b.showList)if(a(c).is(document)||!a.contains(b.showList.get(0),c)){b.showList.hide().css("z-index","");b.showList=null}if(b.showDrpDwnGroup)if(a(c).is(document)||!a.contains(b.showDrpDwnGroup.get(0),c)){b.showDrpDwnGroup.hide().css("z-index","");b.showDrpDwnGroup=null}})},_buildButtonOption:function(b,j){var k=true,m=this,d=b.attr("class"),c,f,i,l,g,e,h;if(d&&d!==""&&d!==n){f=d.split(" ")[0];b.removeClass(f);g=a.trim(b.text());if(g==="")k=false}else{if(j==="checkbox"||j==="radio"){if(a.trim(b.attr("id"))==="")return;e=a("[for='"+b.attr("id")+"']",b.parent());if(!e.is("label"))return;d=e.attr("class");if(d&&d!==""&&d!==n){f=d.split(" ")[0];e.removeClass(f);g=a.trim(e.text());if(g==="")k=false}else c=e.children("span,div")}else if(j==="button")c=b.children("span,div");if(c)if(c.length===1){if(c.eq(0).attr("class")!==""){i=c.eq(0);f=i.attr("class");k=false}}else if(c.length===2){if(c.eq(0).attr("class")){i=c.eq(0);f=i.attr("class");if(i.is("span"))l="left";else if(i.is("div"))l="top";g=c.eq(1).text()}}else if(j==="button"&&a.trim(b.text())!=="")g=a.trim(b.text())}if(j==="button"){b.empty();h=a.trim(b.attr("name"));h!==""&&b.removeAttr("name")}else{h=a.trim(e.attr("name"));h!==""&&e.removeAttr("name")}if(h!==""){b.data("commandName",h);m.buttons[h]={button:b}}return{label:g,icons:{primary:f},position:l,text:k}},_triggerEvent:function(a){var b=this;a.bind("click",function(e){var f=a.data("commandName"),c=b.buttons[f],d={};if(c&&c.parent)d.name=c.parent.data("commandName");d.commandName=f;b._trigger("click",e,d);if(a.is("button")){e.preventDefault();e.stopPropagation()}})},_getDropdownLabelSubstr:function(i,l,h){var j=this,k=i.length,e=0,f=k,c=Math.floor((e+f)/2),d=a("<span></span>"),g=i.substr(0,c),b;d.appendTo(l.parent());b=j._calculateWidth(g,d);while(b!==h&&f>e){g=i.substr(0,c+1);b=j._calculateWidth(g,d);if(b>h)f=c-1;else if(b<h)e=c+1;c=Math.floor((e+f)/2)}d.remove();return g},_calculateWidth:function(b,a){a.text(b);return a.width()},hideDropdown:function(b){var c=this,a=c.listUis[b];a&&a.list&&a.list.hide()},getDropdownList:function(d){var e=this,c=e.listUis[d],b={};c&&a.each(c.buttons,function(c,a){b[a.data("commandName")]=a.button("option","label")});return b},setButtonDisabled:function(d,h){var f=this.buttons[d],g=false,b,e;if(f&&f.button){b=f.button;g=b.is("button");b.button("option","disabled",h);if(g)b.children("."+c).text(d);else a("[for='"+b.attr("id")+"']",b.parent()).children("."+c).text(d);e=this.listUis[d];if(e&&e.type==="split"){e.trigger.button("option","disabled",h);e.trigger.children("."+c).text(d)}}},setButtonsDisabled:function(b){var c=this;a.each(b,function(b,a){c.setButtonDisabled(b,a)})},setButtonsChecked:function(c){var b=this;a.each(c,function(d,c){if(a.isPlainObject(c))b.setButtonChecked(d,c.checked,c.name);else b.setButtonChecked(d,c)})},setButtonChecked:function(h,i,l){var f=this,j,b=f.buttons[h],e,g,k;if(b&&b.button){e=b.button;if(e.is("button"))if(i)e.addClass(d);else e.removeClass(d);else{e.attr("checked",i);e.button("refresh")}if(b.parent){if(b.type==="dropdown")if(i){if(!f.dropdownLabels[h])f.dropdownLabels[h]=f._getDropdownLabelSubstr(e.button("option","label"),b.parent.children("."+c),b.parent.children("."+c).width());k=f.dropdownLabels[h];b.parent.button("option","label",k);b.parent.attr("title",e.button("option","label"));j=a(":radio",b.button.closest("ul"));j&&a.each(j,function(){f._updateGroupElementTextState(this)})}}else f._addActiveClassToButtonText(e.button("widget"))}else if(l){g=f.listUis[l];if(g){g.ui.button("option","label",g.defaultValue);g.buttons&&a.each(g.buttons,function(b,a){a.attr("checked",false);a.button("refresh");f._addActiveClassToButtonText(a.button("widget"))})}}}})})(jQuery);
(function(a){"use strict";var d=alert,n=window,tc=document,f=parseInt,zd,vd,rd,c,I,wd=[],J=null,rc=true,U=true,k=0,A=[],j=null,Xb=null,B="wijeditor-",D="setButtonDisabled",Cb="setButtonsDisabled",u="setButtonChecked",Qc="setButtonsChecked",yd="form",Wc="imagebutton",jd="textarea",sd="button",pd="textbox",md="list",hd="passwordfield",Rc="dropdownlist",Vc="hiddenfield",ud="radio",fd="checkbox",Hb="insertcol",ac="insertrow",Tb="insertcell",cc="splitcell",M="mergecell",Ib="deletecol",bc="deleterow",Vb="deletecell",ab="justifyleft",V="justifycenter",W="justifyright",Z="justifyfull",ld="borders",S="insertorderedlist",R="insertunorderedlist",nd="outdent",td="indent",Yb="backcolor",Zb="fontcolor",mb="bold",gb="italic",jb="strikethrough",bb="underline",x="subscript",v="superscript",fc="template",Jb="removeformat",Xc="insertbreak",Gc="insertparagraph",Cc="insertprintpagebreak",gd="inserthorizontalrule",mc="tablebutton",Ob="inserttable",dd="edittable",Sb="wysiwyg",dc="split",Wb="code",N="wordwrap",Zc="fullscreen",E="undo",H="redo",od="preview",hc="cleanup",sc="cut",nc="copy",lc="paste",ed="selectall",kc="media",Pb="specialchar",xd="datetime",oc="find",ic="inspect",qc="save",id="spelling",Gb="imagebrowser",pc="link",db="xx-small",eb="x-small",lb="small",ib="medium",kb="large",hb="x-large",cb="xx-large",t="fontname",y="fontsize",Yc="blockquote",Ub="insertcode",b="wijmo-wijribbon",Ec=b+"-bigbutton",ob=b+"-dropdownbutton",ce=b+"-splitbutton",mf=b+"-list",of=b+"-save",Ye=b+"-save16",pf=b+"-undo",nf=b+"-redo",Qe=b+"-preview",Me=b+"-cleanup",xf=b+"-cut",hf=b+"-copy",df=b+"-paste",ve=b+"-selectall",Ke=b+"-bgcolor",bf=b+"-color",gf=b+"-bold",We=b+"-italic",ye=b+"-underline",Ze=b+"-strike",yf=b+"-sub",zf=b+"-sup",Fe=b+"-template",Rd=b+"-removeformat",ae=b+"-justifyleft",Kd=b+"-justifycenter",Qd=b+"-justifyright",Zd=b+"-justifyfull",Le=b+"-borders",ue=b+"-orderlist",de=b+"-unorderlist",Pe=b+"-outdent",Ve=b+"-indent",Ne=b+"-inspect",jf=b+"-find",Uc=b+"-table",zc=b+"-inserttable",Fc=b+"-edittable",re=b+"-insertcol",se=b+"-insertrow",je=b+"-insertcell",we=b+"-splitcell",te=b+"-mergecell",pe=b+"-deletecol",qe=b+"-deleterow",ge=b+"-deletecell",Yd=b+"-insertbreak",Ed=b+"-insertparagraph",Ad=b+"-insertprintpagebreak",De=b+"-inserthr",kf=b+"-form",Ge=b+"-textarea",Re=b+"-textbox",Ee=b+"-password",Wd=b+"-hiddenfield",Xd=b+"-imagebutton",Ue=b+"-button",Oe=b+"-listbox",Od=b+"-dropdownlist",ef=b+"-radio",Be=b+"-checkbox",lf=b+"-link",Xe=b+"-link16",Pd=b+"-imagebrowser",cf=b+"-media",be=b+"-specialchar",Ce=b+"-datetime",fe=b+"-blockquote",ke=b+"-insertcode",Tc=b+"-modes",he=b+"-designview",le=b+"-sourceview",xe=b+"-splitview",He=b+"-wordwrap",ie=b+"-fullscreen",e="wijmo-wijeditor",oe=e+"-container",Oc=e+"-header",Lc=e+"-content",Nc=e+"-footer",wc=e+"-pathselector",Ac=e+"-fullscreen",nb=e+"-dialog",Ef=nb+"-hr",G=nb+"-buttons",o=nb+"-button",h=nb+"-text",m=e+"-imagedlg",Ie=m+"-content",Se=m+"-fields",Kb=m+"-imagefield",ff=m+"-imagelist",Je=m+"-preview",Y=m+"-imagesrc",ad=m+"-imagealt",Lb=m+"-imagewidth",Db=m+"-imageheight",bd=m+"-css",ub=m+"-hideimagelist",g=e+"-templatedlg",Bf=g+"-toplabels",tf=g+"-topleftlabel",vf=g+"-toprightlabel",rf=g+"-content",Cf=g+"-templatelist",sf=g+"-preview",uf=g+"-templateinfo",Nb=g+"-nameinfo",Rb=g+"-descriptioninfo",Af=g+"-fields",L=g+"-name",T=g+"-description",qf=g+"-buttons",cd=g+"-delete",kd=g+"-save",z=e+"-linkdlg",K=z+"-address",Dc=z+"-linktype",Ab=z+"-anchor",Mb=z+"-text",Q=z+"-target",Qb=z+"-css",qd=e+"-codedlg",Kc=qd+"-source",Nd=qd+"-sourcelabel",s=e+"-taginsdlg",ne=s+"-caption",ee=s+"-taglabel",Bc=s+"-tagtext",Hd=s+"-filterempty",me=s+"-attribs",P=s+"-attriblist",tb=s+"-innerhtml",Fb=s+"-css",gc=e+"-colordlg",xb=gc+"-picker",C=gc+"-color",q=e+"-tabledlg",Eb=q+"-rows",vb=q+"-columns",Bb=q+"-width",zb=q+"-height",yb=q+"-border",rb=q+"-cellpadding",sb=q+"-cellspacing",wb=q+"-csstext",F=q+"-bgcolor",p=e+"-previewdlg",Vd=p+"-caption",pb=p+"-navigator",Jc=p+"-prev",Ic=p+"-next",xc=p+"-printall",yc=p+"-printone",Pc=p+"-ok",uc=p+"-printdocument",Dd=p+"-previewiframe",X=e+"-cleanupdlg",Ud=X+"-caption",Md=X+"-document",Td=X+"-actions",jc=e+"-finddlg",af=jc+"-find",Ae=jc+"-replace",O=e+"-mediadlg",Te=O+"-type",Sc=O+"-src",Mc=O+"-width",Hc=O+"-height",r=e+"-specialchardlg",Ld=r+"-chars",Fd=r+"-preview",vc=r+"-content",Sd=r+"-list",qb=r+"_label",Bd=r+"-punctuation",Gd=r+"-symbols",Cd=r+"-diacritics",w="wijmo-formatspan",i="."+G+" input:first",l="."+G+" input:last",wf=["Bold","Italic","UnderLine","StrikeThrough","SubScript","SuperScript","JustifyLeft","JustifyCenter","JustifyRight","JustifyFull","Border","NumberedList","BulletedList","Outdent","Indent"],Jd=["Bold","Italic","Link","BlockQuote","StrikeThrough","InsertDate","InsertImage","NumberedList","BulletedList","InsertCode"],Id=["Bold","Italic","StrikeThrough","UnderLine","ForeColor","FontSize","Link","InsertImage","NumberedList","BulletedList","BlockQuote"],ze={Form:{name:"form",tip:"Form",css:kf},Image:{name:"imagebutton",tip:"Image Button",css:Xd},TextArea:{name:"textarea",tip:"TextArea",css:Ge},Button:{name:"button",tip:"Button",css:Ue},TextBox:{name:"textbox",tip:"TextBox",css:Re},List:{name:"list",tip:"ListBox",css:Oe},PasswordField:{name:"passwordfield",tip:"Password Field",css:Ee},DropDownList:{name:"dropdownlist",tip:"DropDownList",css:Od},HiddenField:{name:"hiddenfield",tip:"Hidden Field",css:Wd},Radio:{name:"radio",tip:"RadioButton",css:ef},CheckBox:{name:"checkbox",tip:"CheckBox",css:Be},InsertColumn:{name:"insertcol",tip:"Insert Column",css:re},InsertRow:{name:"insertrow",tip:"Insert Row",css:se},InsertCell:{name:"insertcell",tip:"Insert Cell",css:je},SplitCell:{name:"splitcell",tip:"Split Cell",css:we},MergeCell:{name:"mergecell",tip:"Merge Cell",css:te},DeleteColumn:{name:"deletecol",tip:"Delete Column",css:pe},DeleteRow:{name:"deleterow",tip:"Delete Row",css:qe},DeleteCell:{name:"deletecell",tip:"Delete Cell",css:ge},JustifyLeft:{name:"justifyleft",tip:"Justify Left",css:ae,grpname:"alignment"},JustifyCenter:{name:"justifycenter",tip:"Justify Center",css:Kd,grpname:"alignment"},JustifyRight:{name:"justifyright",tip:"Justify Right",css:Qd,grpname:"alignment"},JustifyFull:{name:"justifyfull",tip:"Justify Full",css:Zd,grpname:"alignment"},Border:{name:"borders",tip:"Border",css:Le},NumberedList:{name:"insertorderedlist",tip:"Numbered List",css:ue,grpname:"list"},BulletedList:{name:"insertunorderedlist",tip:"Bulleted List",css:de,grpname:"list"},Outdent:{name:"outdent",tip:"Outdent",css:Pe,grpname:"block"},Indent:{name:"indent",tip:"Indent",css:Ve,grpname:"block"},BackColor:{name:"backcolor",tip:"Background Color",css:Ke},ForeColor:{name:"fontcolor",tip:"Font Color",css:bf},Bold:{name:"bold",tip:"Bold",css:gf},Italic:{name:"italic",tip:"Italic",css:We},StrikeThrough:{name:"strikethrough",tip:"Strikethrough",css:Ze},UnderLine:{name:"underline",tip:"Underline",css:ye},SubScript:{name:"subscript",tip:"Subscript",css:yf},SuperScript:{name:"superscript",tip:"Superscript",css:zf},Template:{name:"template",tip:"Template",css:Fe},RemoveFormate:{name:"removeformat",tip:"RemoveFormat",css:Rd},InsertBreak:{name:"insertbreak",tip:"Insert Break",css:Yd},InsertParagraph:{name:"insertparagraph",tip:"Insert Paragraph",css:Ed},InsertPrint:{name:"insertprintpagebreak",tip:"Insert Print Page Break",css:Ad},InsertHR:{name:"inserthorizontalrule",tip:"Insert Horizontal Line",css:De},Table:{name:"tablebutton",tip:"Table",css:Uc},InsertTable:{name:"inserttable",tip:"Insert Table",css:zc},EditTable:{name:"edittable",tip:"Edit Table",css:Fc},Wysiwyg:{name:"wysiwyg",tip:"Design View",css:he,grpname:"modes"},Split:{name:"split",tip:"Split View",css:xe,grpname:"modes"},Code:{name:"code",tip:"Source View",css:le,grpname:"modes"},Wordwrap:{name:"wordwrap",tip:"Wordwrap",css:He},FullScreen:{name:"fullscreen",tip:"Fullscreen",css:ie},Undo:{name:"undo",tip:"Undo",css:pf},Redo:{name:"redo",tip:"Redo",css:nf},Preview:{name:"preview",tip:"Preview",css:Qe},Cleanup:{name:"cleanup",tip:"Clean up",css:Me},Cut:{name:"cut",tip:"Cut",css:xf},Copy:{name:"copy",tip:"Copy",css:hf},Paste:{name:"paste",tip:"Paste",css:df},SelectAll:{name:"selectall",tip:"Select All",css:ve},Media:{name:"media",tip:"Media",css:cf},InsertSpecialChar:{name:"specialchar",tip:"Insert Special Character",css:be},InsertDate:{name:"datetime",tip:"Insert Date Time",css:Ce},Find:{name:"find",tip:"Find And Replace",css:jf,text:"Find"},Inspect:{name:"inspect",tip:"Tag Inspect",css:Ne,text:"Inspect"},Save:{name:"save",tip:"Form",css:of,text:"Save"},Spelling:{name:"spelling",tip:"Form",css:""},InsertImage:{name:"imagebrowser",tip:"Image Browser",css:Pd},Link:{name:"link",tip:"Link",css:lf,text:"Link"},FontName:{name:"fontname",tip:"Font Name",css:ob},FontSize:{name:"fontsize",tip:"Font Size",css:ob},BlockQuote:{name:"blockquote",tip:"Block Quote",css:fe},InsertCode:{name:"insertcode",tip:"Insert Code",css:ke}},ec=function(){var a=this,b=[];a.append=function(a){b.push(a)};a.toString=function(){return b.join("")};a.dispose=function(){b=null}},Df=function(a){this.text=a;this.render=function(){return this.text}},fb=function(f,c,d){var b=this,e={br:true,img:true,hr:true,input:true};b.tagName=f||"div";b.attributes=d||{};b.innerText=c||"";b.children=[];if(a.isPlainObject(c)){b.innerText="";b.attributes=c}b._isShortTag=false;if(e[b.tagName]===true)b._isShortTag=true;b.render=function(){var c=new ec,d="";c.append(b._renderBeginTag(b.tagName,b.attributes));b.innerText!==""&&c.append(b.innerText);b.children.length>0&&a.each(b.children,function(b,a){c.append(a.render())});c.append(b._renderEndTag(b.tagName));d=c.toString();c.dispose();return d};b.add=function(a){this.children.push(a)};b._renderBeginTag=function(e,d){var b=new ec,c="";b.append("<");b.append(e);a.each(d,function(c,a){b.append(" ");b.append(c);b.append("=");b.append('"');b.append(a.toString());b.append('"')});if(this._isShortTag)b.append(" ");else b.append(">");c=b.toString();b.dispose();return c};b._renderEndTag=function(c){var a=new ec,b="";if(this._isShortTag)a.append("/>");else{a.append("</");a.append(c);a.append(">")}b=a.toString();a.dispose();return b}};a.widget("wijmo.wijeditor",{options:{fullScreenContainerSelector:"",editorMode:"wysiwyg",fullScreenMode:false,showPathSelector:true,mode:"ribbon",commandButtonClick:null,simpleModeCommands:null,showFooter:true,customContextMenu:true},_create:function(){var a=this;if(a.element.is("input"))return;a._editorify();a._initElements();n.setTimeout(function(){a.options.disabled&&a._handleDisabledOption(true,a.editor)},40)},_createBigButton:function(f,e,c,d){var b=this,a=b._createElement("button",{title:f,name:c,"class":Ec});a.add(b._createDiv(e));a.add(b._createSpan("",d));return a},_createTextButton:function(c,a,b){return this._createElement("button",b,{title:c,name:a})},_createButton:function(f,e,c,d){var b=this,a;if(!d)return b._createElement("button",{title:f,name:c,"class":e});a=b._createElement("button",{title:f,name:c});a.add(b._createSpan(e));a.add(b._createSpan("",d));return a},_createTextRadioButton:function(g,c,b,e,f){var d=this,a=[];a.push(d._createElement("input",{id:c+b,type:"radio",name:e}));a.push(d._createElement("label",f,{"for":c+b,title:g,name:b}));return a},_createImageRadioButton:function(g,c,f,b,e){var d=this,a=[];a.push(d._createElement("input",{id:c+b,type:"radio",name:e}));a.push(d._createElement("label",{"for":c+b,title:g,name:b,"class":f}));return a},_createImageCheckButton:function(f,c,e,b){var d=this,a=[];a.push(d._createElement("input",{id:c+b,type:"checkbox"}));a.push(d._createElement("label",{"for":c+b,title:f,name:b,"class":e}));return a},_createRibbonList:function(){return this._createSpan(mf)},_createDropdownButton:function(f,e,i,h,g){var b=this,c=b._createElement("div",{title:f,"class":ob}),d=b._createElement("ul");c.add(b._createTextButton(f,e,i));c.add(d);a.each(h,function(i,c){var f=b._createElement("li"),h=b._createTextRadioButton(c.tip,g,c.name,e,c.text);a.each(h,function(b,a){f.add(a)});d.add(f)});return c},_createSplitButton:function(e,i,g,h,f){var b=this,c=b._createElement("div",{title:e,"class":ce}),d=b._createElement("ul");c.add(b._createBigButton(e,i,g,h));c.add(b._createElement("button",{"class":Ec}));c.add(d);a.each(f,function(e,a){var c=b._createElement("li");c.add(b._createButton(a.tip,a.css,a.name,a.text));d.add(c)});return c},_createButtonByCommand:function(e){var b=this,c,a=ze[e],d;if(!a)return;d=a.name;switch(d){case Yc:case yd:case Wc:case jd:case sd:case pd:case md:case hd:case Rc:case Vc:case ud:case fd:case Hb:case ac:case Tb:case cc:case M:case Ib:case bc:case Vb:case Jb:case Xc:case Gc:case Cc:case Zc:case E:case H:case sc:case nc:case lc:case xd:case N:case Yb:case Zb:case od:case hc:case kc:case Pb:case fc:case Gb:case Ub:case gd:case ed:c=b._createButton(a.tip,a.css,d);break;case oc:case ic:c=b._createButton(a.tip,a.css,d,a.text);break;case ld:case x:case v:case mb:case gb:case bb:case jb:c=b._createImageCheckButton(a.tip,B,a.css,d);break;case Sb:case dc:case Wb:case ab:case V:case W:case Z:case nd:case td:case S:case R:c=b._createImageRadioButton(a.tip,B,a.css,d,a.grpname);break;case mc:c=b._createSplitButton("Table",Uc,mc,"Table",[{tip:"Insert Table",css:zc,name:Ob,text:"Insert"},{tip:"Edit Table",css:Fc,name:dd,text:"Edit"}]);break;case qc:if(b.options.mode==="ribbon")c=b._createBigButton(a.tip,a.css,d,a.text);else c=b._createButton(a.tip,Ye,d);break;case pc:if(b.options.mode==="ribbon")c=b._createBigButton(a.tip,a.css,d,a.text);else c=b._createButton(a.tip,Xe,d);break;case t:c=b._createDropdownButton("Font Name",t,"Font Name",[{tip:"Arial",name:"fn1",text:"Arial"},{tip:"Courier New",name:"fn2",text:"Courier New"},{tip:"Garamond",name:"fn3",text:"Garamond"},{tip:"Tahoma",name:"fn4",text:"Tahoma"},{tip:"Times New Roman",name:"fn5",text:"Times New Roman"},{tip:"Verdana",name:"fn6",text:"Verdana"},{tip:"Wingdings",name:"fn7",text:"Wingdings"}],B);break;case y:c=b._createDropdownButton("Font Size",y,"Font Size",[{tip:"VerySmall",name:"xx-small",text:"VerySmall"},{tip:"Smaller",name:"x-small",text:"Smaller"},{tip:"Small",name:"small",text:"Small"},{tip:"Medium",name:"medium",text:"Medium"},{tip:"Large",name:"large",text:"Large"},{tip:"Larger",name:"x-large",text:"Larger"},{tip:"VeryLarge",name:"xx-large",text:"VeryLarge"}],B)}return c},_createActionGroup:function(){var a=this,c=a._createElement("li"),b=a._createRibbonList();c.add(a._createButtonByCommand("Save"));c.add(b);b.add(a._createButtonByCommand("Undo"));b.add(a._createButtonByCommand("Redo"));b=a._createRibbonList();c.add(b);b.add(a._createButtonByCommand("Preview"));b.add(a._createButtonByCommand("Cleanup"));b=a._createRibbonList();c.add(b);b.add(a._createButtonByCommand("Cut"));b.add(a._createButtonByCommand("Copy"));b.add(a._createButtonByCommand("Paste"));b.add(a._createButtonByCommand("SelectAll"));c.add(a._createElement("div","Actions"));return c},_createFontGroup:function(){var b=this,d=b._createElement("li"),c=b._createRibbonList();d.add(b._createButtonByCommand("FontName"));d.add(b._createButtonByCommand("FontSize"));d.add(c);c.add(b._createButtonByCommand("BackColor"));c.add(b._createButtonByCommand("ForeColor"));c=b._createRibbonList();d.add(c);a.each(b._createButtonByCommand("Bold"),function(b,a){c.add(a)});a.each(b._createButtonByCommand("Italic"),function(b,a){c.add(a)});a.each(b._createButtonByCommand("UnderLine"),function(b,a){c.add(a)});a.each(b._createButtonByCommand("StrikeThrough"),function(b,a){c.add(a)});a.each(b._createButtonByCommand("SubScript"),function(b,a){c.add(a)});a.each(b._createButtonByCommand("SuperScript"),function(b,a){c.add(a)});c=b._createRibbonList();d.add(c);c.add(b._createButtonByCommand("Template"));c=b._createRibbonList();d.add(c);c.add(b._createButtonByCommand("RemoveFormate"));d.add(b._createElement("div","Font"));return d},_createParaGroup:function(){var c=this,d=c._createElement("li"),b=c._createRibbonList();d.add(b);a.each(c._createButtonByCommand("JustifyLeft"),function(c,a){b.add(a)});a.each(c._createButtonByCommand("JustifyCenter"),function(c,a){b.add(a)});a.each(c._createButtonByCommand("JustifyRight"),function(c,a){b.add(a)});a.each(c._createButtonByCommand("JustifyFull"),function(c,a){b.add(a)});b=c._createRibbonList();d.add(b);a.each(c._createButtonByCommand("Border"),function(c,a){b.add(a)});b=c._createRibbonList();d.add(b);a.each(c._createButtonByCommand("NumberedList"),function(c,a){b.add(a)});a.each(c._createButtonByCommand("BulletedList"),function(c,a){b.add(a)});b=c._createRibbonList();d.add(b);a.each(c._createButtonByCommand("Outdent"),function(c,a){b.add(a)});a.each(c._createButtonByCommand("Indent"),function(c,a){b.add(a)});d.add(c._createElement("div","Paragraph"));return d},_createReviewGroup:function(){var b=this,a=b._createElement("li");a.add(b._createButtonByCommand("Inspect"));a.add(b._createButtonByCommand("Find"));a.add(b._createElement("div","Review"));return a},_createTablesGroup:function(){var a=this,c=a._createElement("li"),b=a._createRibbonList();c.add(a._createButtonByCommand("Table"));c.add(b);b.add(a._createButtonByCommand("InsertColumn"));b.add(a._createButtonByCommand("InsertRow"));b.add(a._createButtonByCommand("InsertCell"));b=a._createRibbonList();c.add(b);b.add(a._createButtonByCommand("SplitCell"));b.add(a._createButtonByCommand("MergeCell"));b=a._createRibbonList();c.add(b);b.add(a._createButtonByCommand("DeleteColumn"));b.add(a._createButtonByCommand("DeleteRow"));b.add(a._createButtonByCommand("DeleteCell"));c.add(a._createElement("div","Tables"));return c},_createBreaksGroup:function(){var b=this,a=b._createElement("li");a.add(b._createButtonByCommand("InsertBreak"));a.add(b._createButtonByCommand("InsertParagraph"));a.add(b._createButtonByCommand("InsertPrint"));a.add(b._createButtonByCommand("InsertHR"));a.add(b._createElement("div","Breaks"));return a},_createFormsGroup:function(){var b=this,c=b._createElement("li"),a=b._createRibbonList();c.add(a);a.add(b._createButtonByCommand("Form"));a=b._createRibbonList();c.add(a);a.add(b._createButtonByCommand("TextArea"));a.add(b._createButtonByCommand("TextBox"));a.add(b._createButtonByCommand("PasswordField"));a.add(b._createButtonByCommand("HiddenField"));a=b._createRibbonList();c.add(a);a.add(b._createButtonByCommand("Image"));a.add(b._createButtonByCommand("Button"));a=b._createRibbonList();c.add(a);a.add(b._createButtonByCommand("List"));a.add(b._createButtonByCommand("DropDownList"));a.add(b._createButtonByCommand("Radio"));a.add(b._createButtonByCommand("CheckBox"));c.add(b._createElement("div","Forms"));return c},_createSpecialGroup:function(){var b=this,a=b._createElement("li");a.add(b._createButtonByCommand("Link"));a.add(b._createButtonByCommand("InsertImage"));a.add(b._createButtonByCommand("Media"));a.add(b._createButtonByCommand("InsertSpecialChar"));a.add(b._createButtonByCommand("InsertDate"));a.add(b._createElement("div","Special"));return a},_getDefaultRibbonMarkup:function(){var a=this,d=a._createElement("div"),e=a._createElement("ul"),g=a._createElement("li"),i=a._createElement("li"),f=a._createElement("div",{id:B+"format"}),h=a._createElement("div",{id:B+"insert"}),b=a._createElement("ul"),c=a._createElement("ul");d.add(e);d.add(f);d.add(h);e.add(g);e.add(i);g.add(a._createElement("a","Format",{href:"#"+B+"format"}));i.add(a._createElement("a","Insert",{href:"#"+B+"insert"}));f.add(b);b.add(a._createActionGroup());b.add(a._createFontGroup());b.add(a._createParaGroup());b.add(a._createReviewGroup());h.add(c);c.add(a._createTablesGroup());c.add(a._createBreaksGroup());c.add(a._createFormsGroup());c.add(a._createSpecialGroup());return d.render()},_getRibbonModesMarkup:function(){var b=this,d=b._createDiv(Tc),c=b._createRibbonList();d.add(c);a.each(b._createButtonByCommand("Wysiwyg"),function(b,a){c.add(a)});a.each(b._createButtonByCommand("Code"),function(b,a){c.add(a)});a.each(b._createButtonByCommand("Split"),function(b,a){c.add(a)});d.add(b._createButtonByCommand("Wordwrap"));d.add(b._createButtonByCommand("FullScreen"));return d.render()},_getSimpleToolBar:function(e){var d=this,b,c=d._createDiv("");a.each(e,function(f,e){b=d._createButtonByCommand(e);if(b)if(a.inArray(e,wf)!==-1)a.each(b,function(b,a){c.add(a)});else c.add(b)});return c.render()},_editorify:function(){var b=this,d=b.element,p=d.width(),o=d.height(),f=b.options,m=f.mode,g,j,l,k,i,h,n;b._oriStyle=d.attr("style");b._oriContent=d.html();if(d.is("textarea")){if(m==="ribbon")c=a(b._getDefaultRibbonMarkup());else if(m==="bbcode")c=a(b._getSimpleToolBar(Id));else if(f.simpleModeCommands&&f.simpleModeCommands.length!==0){l=a.grep(f.simpleModeCommands,function(a){return a!=="Table"});c=a(b._getSimpleToolBar(l))}else c=a(b._getSimpleToolBar(Jd));b.sourceView=d;b.editor=d.wrap("<div></div>").parent();b.editor.width(p).height(o)}else{b.editor=d;c=d.children(":eq(0)");h=d.children(":eq(1)");if(h.is("textarea"))b.sourceView=h;else{n=h.html();h.remove();b.sourceView=a("<textarea></textarea>").val(n)}}g=a("<div class='"+oe+"'></div>");b.dialog=a("<div class ='"+e+"'></div>");b.subDialog=a("<div class ='"+e+"'></div>");b.editor.addClass(e).append(g).append(b.dialog).append(b.subDialog);b._createMenuMarkUp(b,f);c.wrap("<a href='#'></a>").parent().appendTo("<div class='"+Oc+" ui-widget-header ui-helper-clearfix ui-corner-top'></div>").parent().appendTo(g);j=a("<div class='"+Lc+"'></div>").appendTo(g);b.designView=a("<iframe frameborder='0'></iframe>");b.designView.wrap("<div></div>").parent().appendTo(j);b.sourceView.wrap("<div></div>").parent().appendTo(j);k=[c];I=a(b._getRibbonModesMarkup());if(f.showFooter){i=a("<div class='"+Nc+" ui-widget ui-widget-content ui-state-default'></div>");g.append(i);i.append("<div class='"+wc+"'></div>");I.appendTo(i);k.push(I)}a.each(k,function(c,a){a.wijribbon({click:function(c,a){b._ribbonCommand(a.commandName,a.name);b._trigger("commandButtonClick",c,a)}})})},_createMenuMarkUp:function(b,c){if(c.customContextMenu&&!a.browser.webkit){b.contextMenu=a("<ul><li _c1buttoncmd='cut'><a>Cut</a></li><li _c1buttoncmd='copy'><a>Copy</a></li><li _c1buttoncmd='paste'><a>Paste</a></li></ul>");a("<a href='#'></a>").append(b.contextMenu).appendTo(b.editor)}},_handleDisabledOption:function(b,c){var a=this;if(b){if(!a.disabledDiv)a.disabledDiv=a._createDisabledDiv(c);a.disabledDiv.appendTo("body")}else if(a.disabledDiv){a.disabledDiv.remove();a.disabledDiv=null}},_createDisabledDiv:function(d){var g=this,b=d?d:g.element,c=b.offset(),f=b.outerWidth(),e=b.outerHeight();return a("<div></div>").addClass("ui-state-disabled").css({"z-index":"99999",position:"absolute","background-color":"lightgray",width:f,height:e,left:c.left,top:c.top})},_initElements:function(){var a=this,b=a.options,e=a.element.height()-a._getHeader().outerHeight(true)-a._getFooter().outerHeight(true),d={};a._getContent().height(e).wijsplitter({showExpander:false,orientation:"horizontal",panel1:{scrollBars:"none",collapsed:false},panel2:{scrollBars:"none",collapsed:true}});a._addHandlerToDesignView();a._addDefaultFontStyleToDesignView();a._createWijMenu();(!b.showPathSelector||a.options.mode==="bbcode")&&a._getPathSelector().hide();a._ribbonCommand(b.editorMode);b.fullScreenMode&&a._setFullScreen(b.fullScreenMode);d[H]=true;d[E]=true;c.wijribbon(Cb,d)},_setOption:function(d,c){var b=this,e=b.options,f=e.customContextMenu;a.Widget.prototype._setOption.apply(b,arguments);if(d==="fullScreenMode"){e.fullScreenMode=c;b._setFullScreen(c)}else if(d==="showPathSelector"){e.showPathSelector=c;if(c)b._getPathSelector().show();else b._getPathSelector().hide()}else if(d==="editorMode"){e.editorMode=c;b._ribbonCommand(c)}else if(d==="fullScreenContainerSelector"){e.fullScreenContainerSelector=c;b.options.fullScreenMode&&b._setFullScreen(true)}else if(d==="disabled")b._handleDisabledOption(c,b.editor);else if(d==="commandButtonClick")e.commandButtonClick=c;else if(d==="customContextMenu"){if(f===c)return;if(c){!b.contextMenu&&b._createMenuMarkUp(b,e);b._createWijMenu()}else{b.contextMenu.wijmenu("destroy").remove();b.contextMenu=undefined}}},_getHeader:function(){return a("."+Oc,this.editor)},_getContent:function(){return a("."+Lc,this.editor)},_getFooter:function(){return a("."+Nc,this.editor)},_getPathSelector:function(){return a("."+wc,this.editor)},_getModes:function(){return a("."+Tc,this.editor)},_getDesignView:function(){return this.designView},_getDesignViewWindow:function(){var a=this.designView;return a&&a.length>0?a[0].contentWindow:null},_getDesignViewDocument:function(){var a=this._getDesignViewWindow();return a?a.document:null},_getDesignViewText:function(){var a=this._getDesignViewDocument();return a&&a.body&&a.body.innerHTML?a.body.innerHTML:""},_setDesignViewText:function(a){var c=this,b=this._getDesignViewDocument();if(this.options.mode==="bbcode")a=c._convertBBCodeToHtml(a);if(b&&b.body)b.body.innerHTML=a},_getDialog:function(){return this.dialog},_getSubDialog:function(){return this.subDialog},_initContentDocument:function(){var b=this,c=b.sourceView.val(),d=b._getDesignViewDocument();if(b.options.mode==="bbcode")c=b._convertBBCodeToHtml(a.trim(c));d.open();d.write('<html style="width:100%;height:100%;'+(b.options.enabled?"cursor:text;":"")+'"><head><title></title><style id="__wijStyle"  type="text/css" >table,td,tr{border: 1px #acacac dashed;}</style></head><body>'+c+"</body></html>");d.close();A=[];A.push(c);k=0},_addHandlerToDesignView:function(){var b=this,d=b._getDesignViewWindow(),c=d.document;b._initContentDocument();if(a.browser.mozilla)setTimeout(b._setDesignModeForFF,1e3,b);else b._setContentEditable(c,true);b.sourceView.bind("blur."+b.widgetName,function(){b._onSourceViewBlur()});b.sourceView.bind("keyup."+b.widgetName,function(){b._onSourceViewBlur()});if(!a.browser.mozilla)a(d).blur(function(){b._onDesignViewBlur()});else a(c).bind("blur."+b.widgetName,function(){b._onDesignViewBlur()});a(c).bind("mouseup."+b.widgetName,function(a){b._onDesignViewMouseUp(a)}).bind("keydown."+b.widgetName,function(a){b._onDesignViewKeyDown(a)}).bind("keyup."+b.widgetName,function(a){b._onDesignViewKeyUp(a);b._onDesignViewBlur()})},_addDefaultFontStyleToDesignView:function(){var e=this,f=e.options,g=e._getDesignViewDocument(),b=f.defaultFontName,d=f.defaultFontSize,h="",i="",c='<style type="text/css"> body {';if((b===""||b===null)&&(d===""||d===null))return;if(b!==""&&b!==null)c+="font-family: "+b+";";if(f.defaultFontSize!==""&&f.defaultFontSize!==null)c+=" font-size: "+d+";";c+="}</style>";window.setTimeout(function(){a(c).appendTo(a("head",g))},200);e._setFontStyleButtonState(b,t);e._setFontStyleButtonState(d,y)},_setFontStyleButtonState:function(b,e){var d="";if(!b||b===null)return;a.each(c.wijribbon("getDropdownList",e),function(c,a){if(a.toUpperCase()===b.toUpperCase()){d=c;return false}});c.wijribbon(u,d,true,e)},_setDesignModeForFF:function(a){a._getDesignViewDocument().designMode="on"},destroy:function(){var b=this;b.element.html(b._oriContent);b.element.removeAttr("tabindex");if(b._oriStyle===undefined)b.element.removeAttr("style");else b.element.attr("style",b._oriStyle);b.element.insertBefore(b.editor);b.element.unbind("."+b.widgetName);b.editor.remove();a.Widget.prototype.destroy.call(b)},showEditorDialog:function(a){switch(a){case Ob:case fc:case Gb:case ic:case oc:case Pb:case kc:case hc:case pc:case Yb:case Zb:case Ub:this._ribbonCommand(a);break;default:d("Cannot find the dialog with command name '"+a+"'!")}},executeEditorAction:function(b,a){this._ribbonCommand(b,a)},_isFontSizeCustomized:function(){if(J!==null)return J;var b=c.wijribbon("getDropdownList",y),d=[db,eb,lb,ib,kb,hb,cb];J=false;a.each(b,function(b){if(a.inArray(b,d)===-1){J=true;return false}});return J},_fontSizeCommand:function(e){var c=this,d=c._getDesignViewDocument(),b=4,f="font-size",g=[];switch(e){case db:b=1;break;case eb:b=2;break;case lb:b=3;break;case ib:b=4;break;case kb:b=5;break;case hb:b=6;break;case cb:b=7}if(!c._isFontSizeCustomized())d.execCommand("FontSize",false,b);else if(a.browser.msie)c._formatFontSpan(d,f,e);else{d.execCommand("FontSize",false,b);a.each(a("font[size]",d),function(d,b){g.push(c._replaceFontWithSpan(a(b),"size",f,e))});c._setSelection(g)}c.options.mode==="bbcode"&&!a.browser.msie&&c._convertFontStyleToStandTag();c._addtoUndoBuffer()},_fontNameCommand:function(g){var b=this,e=b._getDesignViewDocument(),f=c.wijribbon("getDropdownList",t),d;a.each(f,function(b,a){if(g===b){d=a;return false}});e.execCommand("FontName",false,d);b._isFontSizeCustomized()&&a.browser.msie&&b._formatFontSpan(e,"font-family",d);b._addtoUndoBuffer()},_formatFontSpan:function(h,b,f){var c=this,e=f,d="fontFamily",g=[];if(b!=="font-family"){e="c1-temp";d="fontSize"}h.execCommand("FontName",false,e);a.each(a("font[face='"+e+"']",h),function(k,j){var i=c._replaceFontWithSpan(a(j),"face",b,f),h,e;g.push(i);h=a("span."+w,i);for(e=h.length-1;e>=0;e--)c._removeSpecifiedStyleSpan(a(h[e]),d,b);a.each(i,function(f,e){a.each(a(e).parents("span."+w),function(h,g){var f=a(g);if(f.children().length>1)return false;f.text()===a(e).text()&&c._removeSpecifiedStyleSpan(f,d,b)})})});c._setSelection(g)},_setSelection:function(c,k,j){var i=this._getDesignViewWindow(),g=i.document,b,f,e,d,h=0;try{if(a.browser.msie){b=g.selection.createRange();if(c){a.each(c,function(b,a){h+=a.text().length});b.moveToElementText(c[0][0]);b.collapse(true);b.moveEnd("character",h)}else{b.moveStart("textedit",-1);b.collapse(true);b.moveStart("character",k);b.moveEnd("character",j)}b.select()}else{d=i.getSelection();b=g.createRange();f=c[0][0];e=c[c.length-1][0];b.setStart(f,0);b.setEnd(e,e.childNodes.length);d.removeAllRanges();d.addRange(b)}}catch(l){}},_replaceFontWithSpan:function(a,c,e,d){a.wrap("<span class = '"+w+"' style='"+e+":"+d+"'></span>");var b=a.parent();a.removeAttr(c);if(/<font\s*>/ig.test(b.html())){b.html(a.html());a.remove()}return b},_removeSpecifiedStyleSpan:function(b,f,e){var c,d=true;b[0].style[f]!==""&&b.css(e,"");c=b.attr("style");c&&a.each(c.split(";"),function(f,c){var b=a.trim(c).toLowerCase();if(b!==""&&b.indexOf(e)!==-1){d=false;return false}});d&&b.replaceWith(b.html())},_removeFormat:function(){var d=this,e=d._getDesignViewDocument(),b={};e.execCommand(Jb,false,null);d._isFontSizeCustomized()&&a.browser.msie&&d._removeFormatForIE(e);d._addtoUndoBuffer();b[mb]=false;b[gb]=false;b[jb]=false;b[bb]=false;b[x]=false;b[v]=false;b[S]=false;b[R]=false;b[ab]=false;b[V]=false;b[W]=false;b[Z]=false;c.wijribbon(Qc,b)},_removeFormatForIE:function(g){var i=g.selection.createRange(),k=i.htmlText,s=i.text,p=0,r=a(i.parentElement()),m=a(g.body),o="",l="",h="__c1temp",j="c1-temp",q="<span class='"+j+"'>"+h+"</span>",b,f,e,d,c,n;r.addClass("c1-app-parent");i.pasteHTML(q);p=m.text().indexOf(h);b=a("span."+j,g);f=b;b.parentsUntil("body").each(function(){if(a(this).is(".c1-app-parent"))return false;f=a(this)});b.html(k);e=a("span."+w,b);for(c=e.length-1;c>=0;c--){d=a(e[c]);d.replaceWith(d.html())}!f.is("."+j)&&f.after(b);a.each(f.parents("span."+w),function(c,b){o+="</span>";l="<span class='"+w+"' style = '"+a(b).attr("style")+"'>"+l});k=b.html();b.replaceWith(h);n=m.html().split(h);m.html(n[0]+o+k+l+n[1]);e=a("span."+w,g);for(c=e.length-1;c>=0;c--){d=a(e[c]);d.text()===""&&d.replaceWith(d.html())}a(".c1-app-parent",g).removeClass("c1-app-parent");this._setSelection(null,p,s.length)},_toggleFullScreen:function(){var b=this,a=b.options;a.fullScreenMode=!a.fullScreenMode;b._setFullScreen(a.fullScreenMode)},_setFullScreen:function(i){var b=this,j=1,m=b._getHeader(),l=b._getFooter(),k=b._getContent(),e=b.options.fullScreenContainerSelector,d=a(e),h,g,f;if(i){if(d.length===0){d=a(n);e="body";b._oriDocOverFlow=a(document.documentElement).css("overflow");a(document.documentElement).css({overflow:"hidden"});!a.browser.mozilla&&window.scrollTo(0,0);a(n).bind("resize.wijeditor",function(){b._fullscreenOnWindowResize()})}h=d.width();g=d.height()-2*j;zd=b.editor.width();vd=b.editor.height();if(!rd)rd=b.editor.parent();if(!b._replacedDiv)b._replacedDiv=a("<div />");b.editor.after(b._replacedDiv);a(e).append(b.editor);b.editor.css({width:h,height:g,position:""}).addClass(Ac);c.wijribbon("updateRibbonSize")}else{b._replacedDiv.after(b.editor).remove();b.editor.css({width:zd,height:vd,position:"static"}).removeClass(Ac);!b.options.fullScreenContainerSelector&&a(document.documentElement).css({overflow:b._oriDocOverFlow});a(n).unbind("resize.wijeditor");c.wijribbon("updateRibbonSize")}f=b.editor.height()-m.outerHeight(true)-l.outerHeight(true);k.height(f).wijsplitter("refresh");b._addHandlerToDesignView();b._addDefaultFontStyleToDesignView();b._createWijMenu()},_createWijMenu:function(){var b=this;b.contextMenu&&b.contextMenu.wijmenu({orientation:"vertical",trigger:b.designView,triggerEvent:"rtclick",showing:function(i,c){c.show();var d=b.designView.offset(),e=a(a(b.designView)[0].contentWindow).scrollLeft(),f=a(a(b.designView)[0].contentWindow).scrollTop(),g=d.left+2-e,h=d.top-f;c.position({my:"left top",at:"right top",of:i,offset:g+" "+h,collision:"none none"});c.hide()},animation:{animated:"fade"},select:function(c,a){b._contextMenuItemClick(c,a)}})},_fullscreenOnWindowResize:function(){var b=this,h=b._getHeader(),f=b._getFooter(),d=b._getContent(),c,g=a(window).width(),e=a(window).height();b.editor.css({width:g,height:e});c=b.editor.height()-h.height()-f.height();d.height(c).wijsplitter("refresh")},_saveText:function(){},_doSpellCheck:function(){},_ribbonCommand:function(h,k){var b=this,e=b._getDesignViewDocument(),i=b._getContent(),d,g,f;if(k===t){b._fontNameCommand(h);b._onDesignViewBlur();return}if(k===y){b._fontSizeCommand(h);b._onDesignViewBlur();return}b._setIEFocus();switch(h){case Yc:if(a.browser.msie){e.execCommand("FormatBlock",false,"<ADDRESS>");f=e.selection.createRange();f=a(f.parentElement()).closest("address");if(f.length){f.replaceWith("<blockquote>"+f.html()+"</blockquote>");e.body.innerHTML=e.body.innerHTML.replace(/<BLOCKQUOTE>\s*?<BLOCKQUOTE>/gi,"<BLOCKQUOTE>");e.body.innerHTML=e.body.innerHTML.replace(/<\/BLOCKQUOTE>\s*?<\/BLOCKQUOTE>/gi,"</BLOCKQUOTE>");e.body.innerHTML=e.body.innerHTML.replace(/<BLOCKQUOTE>\s*?<\/BLOCKQUOTE>/gi,"")}}else e.execCommand("FormatBlock",false,"<BLOCKQUOTE>");break;case yd:d=b._generateUniqueName("form");b.insertHTML('<form id="'+d+'" name="'+d+'" method="post">'+d+"</form>");break;case Wc:d=b._generateUniqueName("image");b.insertHTML('<input id="'+d+'" name="'+d+'" type="image" value="'+d+'"/>');break;case jd:d=b._generateUniqueName("textarea");b.insertHTML('<textarea id="'+d+'" name="'+d+'" rows="4" cols="48"></textarea>');break;case sd:d=b._generateUniqueName("button");b.insertHTML('<input id="'+d+'" name="'+d+'" type="button" value="'+d+'"/>');break;case pd:d=b._generateUniqueName("textbox");b.insertHTML('<input id="'+d+'" name="'+d+'" type="text" value="'+d+'"/>');break;case md:d=b._generateUniqueName("list");b.insertHTML('<select id="'+d+'" name="'+d+'" style="width: 120px" size="8"></select>');break;case hd:d=b._generateUniqueName("password");b.insertHTML('<input id="'+d+'" name="'+d+'" type="password" value="'+d+'"/>');break;case Rc:d=b._generateUniqueName("dropdown");b.insertHTML('<select id="'+d+'" name="'+d+'"></select>');break;case Vc:d=b._generateUniqueName("hidden");b.insertHTML('<input id="'+d+'" name="'+d+'" type="hidden" value="'+d+'" />');break;case ud:d=b._generateUniqueName("radiobox");b.insertHTML('<input id="'+d+'" name="'+d+'" type="radio" value="'+d+'"><label for="'+d+'">'+d+"</label></input>");break;case fd:d=b._generateUniqueName("checkbox");b.insertHTML('<input id="'+d+'" name="'+d+'" type="checkbox" value="'+d+'"><label for="'+d+'">'+d+"</label></input>");break;case Hb:case ac:case Tb:case cc:case M:case Ib:case bc:case Vb:b._tableAction(h);break;case ld:b._toggleTableBorders();break;case x:try{if(e.queryCommandState(v)){e.execCommand(v,false,null);c.wijribbon(u,v,false)}}catch(m){}e.execCommand(x,false,null);b._addtoUndoBuffer();break;case v:try{if(e.queryCommandState(x)){e.execCommand(x,false,null);c.wijribbon(u,x,false)}}catch(l){}e.execCommand(v,false,null);b._addtoUndoBuffer();break;case Jb:b._removeFormat();break;case Xc:b.insertHTML("<br/>");break;case Gc:g=b._getSelectedContent();if(!g||g==="")g="&nbsp;";b.insertHTML("<p>"+g+"</p>");break;case Cc:b.insertHTML('<div title="Print Page Break" style="font-size:1px;page-break-before:always;vertical-align:middle;height:1px;background-color:#c0c0c0">&nbsp;</div>');break;case Zc:b._toggleFullScreen();break;case E:b._undoAction();break;case H:b._redoAction();break;case sc:b._execCut();break;case nc:b._execCopy();break;case lc:b._execPaste();break;case xd:b.insertDateAndTime();break;case Sb:I.wijribbon(D,N,true).wijribbon(u,Sb,true);c.wijribbon("option","disabled",false);i.wijsplitter("option","panel2",{collapsed:true});break;case dc:I.wijribbon(D,N,true).wijribbon(u,dc,true);c.wijribbon("option","disabled",false);i.wijsplitter("option",{panel1:{collapsed:false},panel2:{collapsed:false}});break;case Wb:I.wijribbon(D,N,false).wijribbon(u,Wb,true);c.wijribbon("option","disabled",true);i.wijsplitter("option","panel1",{collapsed:true});break;case N:i.wijsplitter("option","panel1").collapsed&&b._toggleWordWrap();break;case Yb:if(a.browser.msie)j=e.selection.createRange();b._createDialog("Set BackColor",b._getDialogRes_BackColor(),b.initBackColorDialog);break;case Zb:if(a.browser.msie)j=e.selection.createRange();b._createDialog("Set ForeColor",b._getDialogRes_ForeColor(),b.initForeColorDialog);break;case Ob:if(a.browser.msie)j=e.selection.createRange();b._createDialog("Insert Table",b._getDialogRes_Table(false),b.initInsertTableDialog);break;case dd:b._getEditableTable()&&b._createDialog("Edit Table",b._getDialogRes_Table(true),b.initEditTableDialog);break;case od:b._createDialog("Preview",b._getDialogRes_Preview(),b.initPreviewDialog);break;case hc:b._createDialog("Clean up source HTML document",b._getDialogRes_CleanUp(),b.initCleanUpDialog);break;case kc:if(a.browser.msie)j=e.selection.createRange();b._createDialog("Insert media",b._getDialogRes_Media(),b.initMediaDialog);break;case Pb:if(a.browser.msie)j=e.selection.createRange();b._createDialog("Insert special character",b._getDialogRes_SpecialCharacter(),b.initSpecialCharacterDialog);break;case oc:b._createDialog("Find and replace",b._getDialogRes_FindAndReplace(),b.initFindDialog);break;case ic:Xb=b._getSelectedElement();b._createDialog("Tag Inspector",b._getDialogRes_TagInspector(),b.initTagInspectorDialog);break;case fc:if(a.browser.msie)j=e.selection.createRange();b._createDialog("Apply Template",b._getDialogRes_Template(),b.initTemplateDialog);break;case Gb:if(a.browser.msie)j=e.selection.createRange();b._createDialog("Image Browser",b._getDialogRes_ImageBrowser(),b.initImageBrowserDialog);break;case pc:if(a.browser.msie)j=e.selection.createRange();b._createDialog("Insert hyperLink",b._getDialogRes_Link(),b.initHyperLinkDialog);break;case Ub:if(a.browser.msie)j=e.selection.createRange();b._createDialog("Insert Code",b._getDialogRes_Code(),b.initInsertCodeDialog);break;case ab:case V:case W:case Z:case nd:case td:case mb:case gb:case bb:case S:case R:case jb:case gd:case ed:e.execCommand(h,false,null);b.options.mode==="bbcode"&&!a.browser.msie&&b._convertStyleToStandTag();b._addtoUndoBuffer();break;case qc:b._saveText();break;case id:b._doSpellCheck()}b._onDesignViewBlur()},_createDialog:function(d,e,c){var b=this,a=b.dialog;a.html("").undelegate(b.widgetName).undelegate("."+b.widgetName).append(e);if(!a.data("wijdialog"))a.wijdialog({width:"auto",height:"auto",modal:true,title:d,position:"center",resizable:false,captionButtons:{pin:{visible:false},refresh:{visible:false},toggle:{visible:false},minimize:{visible:false},maximize:{visible:false}}});else{a.wijdialog("reset");a.wijdialog("option",{width:"auto",height:"auto",title:d})}b._adjustDialogLayoutForIE7();c&&c.call(b);a.wijdialog("open")},_adjustDialogLayoutForIE7:function(){var b=this.dialog;a.browser.msie&&/^7\.[0-9]+/.test(a.browser.version)&&b.wijdialog("option","width",b.parent().width())},_contextMenuItemClick:function(e,b){var a=this,c=b.item.attr("_c1buttoncmd");switch(c){case sc:a._execCut();break;case nc:a._execCopy();break;case lc:a.focus();a._execPaste()}},_execCut:function(){var b=this,c=b._getDesignViewDocument();if(a.browser.safari)d("This function is not supported in current browser. Plesse use (Ctrl + X).");else if(a.browser.msie){c.execCommand("Cut",false,null);b._addtoUndoBuffer()}else{b._execCopy();b._deleteSelectionContent();b._addtoUndoBuffer()}},_execCopy:function(){var b=this,c=b._getDesignViewDocument();if(a.browser.safari)d("This function is not supported in current browser. Plesse use (Ctrl + C).");else if(a.browser.msie){c.execCommand("Copy",false,null);b._addtoUndoBuffer()}else b._copyToClipboard(b._getSelectedContent())},_execPaste:function(){var c=this,b,e=c._getDesignViewDocument();if(a.browser.safari)d("This function is not supported in current browser. Plesse use (Ctrl + V).");else if(a.browser.msie){e.execCommand("Paste",false,null);c._addtoUndoBuffer()}else try{b=c._copyFromClipboard();b&&b!==""&&c.insertHTML(b)}catch(f){}},_getFontSizeCollection:function(){return{"10px":db,"13px":eb,"16px":lb,"18px":ib,"24px":kb,"32px":hb,"48px":cb,1:db,2:eb,3:lb,4:ib,5:kb,6:hb,7:cb}},_updateButtonStates:function(l){var e=this,k=e._getDesignViewDocument(),d,b,h={},j=[mb,gb,jb,bb,x,v,S,R,ab,V,W,Z],g,i=l.target,f=a(i);a.each(j,function(b,a){h[a]=k.queryCommandState(a)});c.wijribbon(Qc,h);d=e._queryCommandValue(t)||"";a.each(c.wijribbon("getDropdownList",t),function(c,a){if(a.toUpperCase()===d.toUpperCase()){b=c;return false}});c.wijribbon(u,b,true,t);if(e._isFontSizeCustomized()){if(f.is("span"))b=i.style.fontSize;else b="";if(b===""){g=f.parents("span."+w);a.each(g,function(c,a){b=a.style.fontSize;if(b&&b!=="")return false})}if(b==="")b=f.css("font-size")}else{d=e._queryCommandValue(y)||"";if(d==="")d=f.css("font-size");a.each(e._getFontSizeCollection(),function(c,a){if(c.toString()===d.toString()){b=a;return false}})}c.wijribbon(u,b,true,y)},_queryCommandValue:function(a){var b=this._getDesignViewDocument();try{if(!b.queryCommandEnabled(a))return null}catch(c){return null}try{return b.queryCommandValue(a)}catch(d){}return null},_escActionAssociated:function(){var b=this,a=b._getDesignViewWindow();a.document.selection!==undefined&&a.document.selection.empty();a.getSelection!==undefined&&a.getSelection().removeAllRanges();b._hideAllDropdownsMenus()},_hideAllDropdownsMenus:function(){var a=this;a.contextMenu&&a.contextMenu.wijmenu("hideAllMenus");c.wijribbon("hideDropdown",t).wijribbon("hideDropdown",y).wijribbon("hideDropdown",mc)},_onDesignViewKeyDown:function(b){var a=this,c;a._setSaveBtnEnabled();try{if(b.ctrlKey)c=String.fromCharCode(b.keyCode).toLowerCase();else switch(b.keyCode){case 27:a._escActionAssociated();break;case 13:case 46:a._addtoUndoBuffer()}}catch(d){}},_onDesignViewKeyUp:function(a){var b=this,c;(a.keyCode===37||a.keyCode===38||a.keyCode===39||a.keyCode===40||a.keyCode===33||a.keyCode===34||a.keyCode===35||a.keyCode===36)&&b._updateButtonStates(a);if(a.ctrlKey){c=String.fromCharCode(a.keyCode).toLowerCase();switch(c){case"y":b._redoAction();a.preventDefault();a.stopPropagation();break;case"z":b._undoAction();a.preventDefault();a.stopPropagation();break;case"x":case"v":b._addtoUndoBuffer()}}},_onDesignViewMouseUp:function(c){var d=this,b;if(c.button===2)return;d._updateButtonStates(c);d._refreshPathSelector();d._hideAllDropdownsMenus();a(document).mouseup();if(a.browser.msie){b=a(c.target).closest("a");if(c.ctrlKey&&b.length>0)try{b.focus();n.open(b[0].href,"_blank")}catch(e){}}},_onDesignViewBlur:function(){var c=this,d=c.options,b;b=c._getDesignViewText();if(d.mode==="bbcode")b=c._convertHtmlToBBCode(a.trim(b));c.sourceView.val(b)},_onSourceViewBlur:function(){var b=this,a;a=b.sourceView.val();b._setDesignViewText(a)},_convertBBCodeToHtml:function(a){a=a.replace(/</g,"&lt;");a=a.replace(/>/g,"&gt;");a=a.replace(/(?:\r\n|\n|\r)/g,"<br>");a=a.replace(/\[EMAIL\]([\s\S]*?)\[\/EMAIL\]/gim,'<a href="mailto:$1">$1</a>');a=a.replace(/\[EMAIL\=([^\]]+)]([\s\S]*?)\[\/EMAIL\]/gim,'<a href="mailto:$1">$2</a>');a=a.replace(/\[URL\]([\s\S]*?)\[\/URL\]/gim,'<a href="$1">$1</a>');a=a.replace(/\[URL\=([^\]]+)]([\s\S]*?)\[\/URL\]/gim,'<a href="$1">$2</a>');a=a.replace(/\[B\]/gim,"<b>");a=a.replace(/\[\/B\]/gim,"</b>");a=a.replace(/\[I\]/gim,"<i>");a=a.replace(/\[\/I\]/gim,"</i>");a=a.replace(/\[S\]/gim,"<strike>");a=a.replace(/\[\/S\]/gim,"</strike>");a=a.replace(/\[U\]/gim,"<u>");a=a.replace(/\[\/U\]/gim,"</u>");a=a.replace(/\[IMG height=(.*?) width=(.*?)](.+?)\[\/IMG\]/gim,'<img height="$1" width = "$2" src="$3"/>');a=a.replace(/\[BLOCK\]/gim,"<blockquote>");a=a.replace(/\[\/BLOCK\]/gim,"</blockquote>");a=a.replace(/\[LIST\=1\]\[\*\]([\s\S]*?)\[\/LIST\]/gim,"<ol><li>$1</li></ol>");a=a.replace(/\[LIST\]\[\*\]([\s\S]*?)\[\/LIST\]/gim,"<ul><li>$1</li></ul>");a=a.replace(/\[\*\]/gim,"</li><li>");a=a.replace(/\[size=([^\]]*?)\]/gi,'<font size="$1">');a=a.replace(/\[\/size\]/gim,"</font>");a=a.replace(/\[color=([^\]]*?)\]/gi,'<font color="$1">');a=a.replace(/\[\/color\]/gim,"</font>");return a},_replaceComplexHtml:function(g){var f,c,d,b,e=a("<div/>").html(g);f=a("img",e);a.each(f,function(){d="[IMG height="+a(this).height()+" width="+a(this).width()+"]"+a(this).attr("src").toString()+"[/IMG]";a(this).replaceWith(d)});c=a("font",e);for(b=c.length-1;b>=0;b--){if(a(c[b]).attr("color")&&a(a(c[b])).attr("size"))d="[Color="+a(a(c[b])).attr("color")+"][Size="+a(a(c[b])).attr("size")+"]"+a(a(c[b])).html()+"[/Size][/Color]";else if(a(a(c[b])).attr("color")&&!a(a(c[b])).attr("size"))d="[Color="+a(a(c[b])).attr("color")+"] "+a(a(c[b])).html()+"[/Color]";else if(a(a(c[b])).attr("size")&&!a(a(c[b])).attr("color"))d="[Size="+a(a(c[b])).attr("size")+"]"+a(a(c[b])).html()+"[/Size]";a(a(c[b])).replaceWith(d)}return e.html()},_convertHtmlToBBCode:function(a){var b=this;if(a==="")return;a=b._replaceComplexHtml(a);a=a.replace(/<br(?=[ \/>]).*?>/gim,"\r\n");a=a.replace(/<a .*?href=(["'])(.+?)\1.*?>(.+?)<\/a>/gi,"[URL=$2]$3[/URL]");a=a.replace(/<a .*?href=(["'])mailto:(.+?)\1.*?>(.+?)<\/a>/gi,"[EMAIL=$2]$3[/EMAIL]");a=a.replace(/<(?:b|strong)>/gim,"[B]");a=a.replace(/<\/(?:b|strong)>/gim,"[/B]");a=a.replace(/<(?:i|em)>/gim,"[I]");a=a.replace(/<\/(?:i|em)>/gim,"[/I]");a=a.replace(/<(?:strike|s)>/gim,"[S]");a=a.replace(/<\/(?:strike|s)>/gim,"[/S]");a=a.replace(/<u>/gim,"[U]");a=a.replace(/<\/u>/gim,"[/U]");a=a.replace(/<blockquote.*?\>/gim,"[BLOCK]");a=a.replace(/\s{0,}<\/blockquote>/gim,"[/BLOCK]");a=a.replace(/(?:\r\n|\r|\n){0,1}<(?:ol)>[\s]*/gim,"[LIST=1]");a=a.replace(/<\/(?:ol)>/gim,"[/LIST]");a=a.replace(/(?:\r\n|\r|\n){0,1}\<(?:ul)>[\s]*/gim,"[LIST]");a=a.replace(/<\/(?:ul)>/gim,"[/LIST]");a=a.replace(/\s{0,}<li\s{0,1}.*?>([\s\S]*?)\n{0,}\s{0,}<\/li>/gim,"[*]$1");a=a.replace(/&nbsp;/gi," ");a=a.replace(/(<[^>]+>)/gm,"");return a},_convertFontStyleToStandTag:function(){var e=this,g=e._getDesignViewDocument(),f=a(g.body),b,c,d=a("[style*='color: ']",f);if(d.length!==0){b=d;c="<font color='"+e._getWebColorFromRgb(d.css("color"))+"'></font>"}b&&a.each(b,function(){if(a(this).is("span"))a(this).replaceWith(a(c).html(a(this).html()));else a(this).is("font")&&a(this).attr("size")&&a(this).removeAttr("style").html(a(c).html(a(this).html()))})},_convertStyleToStandTag:function(){var j=this,k=j._getDesignViewDocument(),d=a(k.body),b,c,e,i=a("[style*='font-weight: bold;']",d),g=a("[style*='font-style: italic;']",d),h=a("[style*='text-decoration: line-through;']",d),f=a("[style*='text-decoration: underline;']",d);if(i.length!==0){b=i;c="<b></b>";e="font-weight"}else if(g.length!==0){b=g;c="<i></i>";e="font-style"}else if(h.length!==0){b=h;c="<strike></strikes>";e="text-decoration"}else if(f.length!==0){b=f;c="<u></u>";e="text-decoration"}b&&a.each(b,function(){if(a(this).is("span")&&this.style.fontSize==="")a(this).replaceWith(a(c).html(a(this).html()));else a(this).removeAttr("style").html(a(c).html(a(this).html()))})},_getWebColorFromRgb:function(a){var c=this,b;if(a.indexOf("rgb(")===0){b=a.substring(4,a.length-1).split(",");a=c._convertToWebColor(f(b[0]),f(b[1]),f(b[2]))}return a},_updateList:function(d,c){var b;a("option",c).remove();for(b in d)d[b]&&c.append("<option>"+b+"</option>")},_triggerEvent:function(c,d){var b=this,a=b.options[c];return a&&typeof a==="function"?a.call(b,d):a},_closeDialog:function(){this.dialog.wijdialog("close")},_onTemplateList:function(a){return this._triggerEvent("templateList",a)},updateTemplateList:function(c,e){var b=this,d=e||a("select",b.dialog);b._updateList(c,d);b._templateList=c},initTemplateDialog:function(){var b=this,d=b.dialog,e=a("select",d),c=b._onTemplateList();d.delegate("select","change."+b.widgetName,function(){b.templateListOnChanged()}).delegate("."+cd,"click."+b.widgetName,function(){b.deleteTemplate()}).delegate("."+kd,"click."+b.widgetName,function(){b.saveTemplate()}).delegate(i,"click."+b.widgetName,function(){b.applyTemplate()}).delegate(l,"click."+b.widgetName,function(){b._closeDialog()});if(!c){c=b._templateList;if(!c)return}b.updateTemplateList(c,e)},templateListOnChanged:function(){var g=this,c=g.dialog,d=a("select",c).val(),e=a("iframe",c),f=g._templateList,b;if(!f)return;b=f[d];b.src&&e.attr("src",b.src+"?d="+(new Date).getMilliseconds().toString());b.text&&e.length>0&&e[0].contentWindow.document.write(b.text);if(d){a("."+Nb,c).html(d);a("."+L,c).val(d)}if(b.desc){a("."+Rb,c).html(b.desc);a("."+T,c).val(b.desc)}},_onSaveTemplate:function(a){this._triggerEvent("saveTemplate",a)},saveTemplate:function(){var c=this,f=c.dialog,b=a("."+L,f).val(),g=a("."+T,f).val(),e=c._templateList,h=this._getDesignViewText();if(a.trim(b)===""){d("Please input a template name!");return}if(!e){c._templateList=[];e=c._templateList}!e[b]&&a("select",f).append("<option>"+b+"</option>");e[b]={desc:g,text:h};c._onSaveTemplate({name:b,desc:g,text:h})},_onDeleteTemplate:function(a){this._triggerEvent("deleteTemplate",a)},deleteTemplate:function(){var e=this,b=e.dialog,f=a("select",b),c=f.val(),g=e._templateList;if(a.trim(c)===""){d("Please select a template file.");return}a("option:selected",f).remove();a("iframe",b).attr("src","about:blank");a("."+Nb,b).empty();a("."+L,b).val("");a("."+Rb,b).empty();a("."+T,b).val("");delete g[c];e._onDeleteTemplate(c)},applyTemplate:function(){var b=this,c=b.dialog,g=a("select",c),e=g.val(),f=a("iframe",c)[0],i=a("."+L,c).val(),h=f.contentWindow.document.body.innerHTML;if(a.trim(i)===""||a.trim(e)===""){d("Please select a valid template file.");return}b._setDesignViewText(h);b._addtoUndoBuffer();b._setSaveBtnEnabled();b._closeDialog()},_onImageList:function(){var b=this,a=b.options.imageList;return a&&typeof a==="function"?a.call(b):a},updateImageList:function(b,g){var c=this,e=c.dialog,f=g||a("select",e),d=a("."+Kb,e);c._updateList(b,f);c._imgList=b;if(!b){d.addClass(ub);return}d.removeClass(ub)},initImageBrowserDialog:function(){var b=this,d=b.dialog,c=b._onImageList();a("img",d).hide();d.delegate("select","change."+b.widgetName,function(){b.imageListOnChanged(this)}).delegate("."+Y+" input","change."+b.widgetName,function(){b.imageUrlChanged(this)}).delegate(i,"click."+b.widgetName,function(){b.submitInsertImageDialog();b._onDesignViewBlur()}).delegate(l,"click."+b.widgetName,function(){b._closeDialog()});if(!c){c=b._imgList;if(!c){a("."+Kb,d).addClass(ub);return}}b.updateImageList(c,a("select",d))},imageUrlChanged:function(b){a("img",this.dialog).attr("src",a(b).val()).show()},imageListOnChanged:function(){var e=this,b=e.dialog,f=a("select",b).val(),d=e._imgList,c;if(!d)return;c=d[f];a("img",b).attr("src",c).show();a("."+Y+" input",b).attr("value",c);n.setTimeout(function(){a("."+Lb+" input",b).val(a("img",b).width());a("."+Db+" input",b).val(a("img",b).height())},200)},submitInsertImageDialog:function(){var b=this,e,c=b.dialog,g=a("."+Y+" input",c).val(),i=a("."+ad+" input",c).val(),h=a("."+Lb+" input",c).val(),f=a("."+Db+" input",c).val(),j=a("."+bd+" input",c).val();if(a.trim(g)===""){d("Please select a image.");return}if(!b._isNumeric(h)){d("Please input a number for 'Image width' textbox.");return}if(!b._isNumeric(f)){d("Please input a number for 'Image height' textbox.");return}b.focus();e='<img src="'+g+'" alt="'+i+'" width="'+h+'" height="'+f;if(b.options.mode!=="bbcode")e+='" style="'+j;e+='"/>';b.insertHTML(e);b._closeDialog()},initHyperLinkDialog:function(){var b=this,c=b.dialog,d=b.getLinkHrefField(),e=a("."+K+" input",c);c.delegate(i,"click."+b.widgetName,function(){b.submitHyperLinkDialog();b._onDesignViewBlur()}).delegate(l,"click."+b.widgetName,function(){b._closeDialog()}).delegate("."+Ab,"change."+b.widgetName,function(){b.anchorListOnChanged(this)}).delegate("."+Dc+">div","click."+b.widgetName,function(){b.radioListOnChanged()});try{e.val(d);a("."+Mb+" input",c).val(b._getLinkInnerHTML());a("."+Qb+" input",c).val(b._getLinkCssField());a("."+Q+" select",c).val(b._getLinkTarget())}catch(f){}if(d.length>4&&d.substring(0,4)==="http")a("#radUrl",c).attr("checked","checked");else if(d.length>6&&d.substring(0,6)==="mailto")a("#radMail",c).attr("checked","checked");else a("#radAnchor",c).attr("checked","checked")},_getLinkInnerHTML:function(){var b=this,a;b.focus();a=b._getInspectElement();return a&&a.tagName==="A"?a.innerHTML||"":b.getSelectionHTMLContent()||""},getLinkHrefField:function(){var b=this,a;b.focus();a=b._getInspectElement();return a&&a.tagName==="A"?b.fixAbsoluteUrlsIfNeeded(a.href||""):""},_getLinkTarget:function(){var b=this,a;b.focus();a=b._getInspectElement();return a&&a.tagName==="A"?a.target||"":""},_getLinkCssField:function(){var b=this,a;b.focus();a=b._getInspectElement();return a&&a.tagName==="A"?a.style.cssText||"":""},submitHyperLinkDialog:function(){var c=this,b=c.dialog,h=a("#radMail",b),g=a("."+K+" input",b),k=a("."+Mb+" input",b),l=a("."+Qb+" input",b),i=a("."+Q+" select",b),e=g.val(),f=k.val(),j=i.val(),m=l.val();if(e===""){d("Please input address!");return}if(f===""){d("Please input display text!");return}if(h.attr("checked")&&!c._isEmail(e)){d("Please input correct email!");return}c._editLink(f,e,m,j);c._closeDialog()},_editLink:function(g,f,d,e){var b=this,a,c="";b.focus();a=b._getInspectElement();if(a&&a.tagName==="A"){a.innerHTML=g;a.href=f;a.target=e;if(d!==a.style.cssText)a.style.cssText=d;b._addtoUndoBuffer();b._setSaveBtnEnabled();return}c='<a href="'+f+'" target="'+e+'"';if(d!=="")c+=' style="'+d+'"';c+=">"+g+"</a>";b._setIESelection();b.insertHTML(c)},anchorListOnChanged:function(d){var e=this,b=e.dialog,c=a(d).val();if(c!==""){a("."+K+" input",b).val(c);a("#radAnchor",b).attr("checked","checked")}},radioListOnChanged:function(){var e=this,b=e.dialog,c=a("."+Ab,b),d=a("."+K+" input",b);d.val("");if(a("#radUrl",b).is(":checked"))c.hide();else if(a("#radAnchor",b).is(":checked"))c.show();else if(a("#radMail",b).is(":checked")){c.hide();d.val("mailto:")}},_getDialogRes_Code:function(){var b=this,a=b._createDiv(z);a.add(b._createElement("div","Enter source code",{"class":Nd}));a.add(b._createElement("textarea","",{"class":Kc}));a.add(b._createSeparator());a.add(b._createOKCancelButtons());return a.render()},initInsertCodeDialog:function(){var a=this,b=a.dialog;b.delegate(i,"click."+a.widgetName,function(){a.submitCodeDialog();a._onDesignViewBlur()}).delegate(l,"click."+a.widgetName,function(){a._closeDialog()})},submitCodeDialog:function(){var c=this,e=c.dialog,d=a("."+Kc,e),b=d.val();if(b==="")return;b=b.replace(/</g,"&lt;");b=b.replace(/>/g,"&gt;");b="<pre>"+b+"</pre>";c._setIESelection();c.insertHTML(b);c._closeDialog()},initTagInspectorDialog:function(){var b=this,c=b.dialog,d=a("."+tb);c.delegate(i,"click."+b.widgetName,function(){b.submitTagInspectorDialog();b._onDesignViewBlur()}).delegate(l,"click."+b.widgetName,function(){b._closeDialog()}).delegate("#displayNoEmpty","click."+b.widgetName,function(){b.tagInspectorDialogSwitchAttList(this)});b._laySelectedElementAttributes(a("."+P,c),a("."+Bc,c));a("."+Fb+" input",c).val(b._getSelectedElementStyle());if(b._selectedElementCanHaveChildren()){d.show();a("textarea",d).val(b._getSelectedElementInnerHTML())}else d.hide()},submitTagInspectorDialog:function(){var b=this,g=b.dialog,c=b._getInspectElement(),e=a("."+P,g),d=a("."+Fb+" input").val(),f=a("."+tb+" textarea").val();try{a.each(a("input:checkbox",e),function(g,f){var b,e,d=a(f);if(d.is(":checked")){b=d.siblings("span").text();b=b.substring(0,b.length-1);e=d.siblings("input:text").val();a(c).attr(b,e)}});if(a.trim(d)!=="")c.style.cssText=d;b._selectedElementCanHaveChildren()&&a(c).html(f)}catch(h){}b._closeDialog();b._addtoUndoBuffer();b._setSaveBtnEnabled()},tagInspectorDialogSwitchAttList:function(c){var b=a("."+P,this.dialog),d=!c.checked;a.each(a("input:text",b),function(c,b){a(b).val()===""&&a(b).parent("li")[d?"show":"hide"]()})},_laySelectedElementAttributes:function(i,j){var f=this,c=f._getInspectElement(),g,d,e,b="";if(!c)return;j.html(c.tagName);g=f._getDictionaryDeclare();d=c.tagName.toLowerCase();e=g[d];switch(d){case"ul":case"u":case"textarea":case"tbody":case"tr":case"th":case"td":case"table":case"select":case"strong":case"span":case"p":case"option":case"ol":case"li":case"label":case"input":case"img":case"i":case"hr":case"form":case"font":case"em":case"div":case"code":case"button":case"body":case"b":case"a":b+="<ul class='ui-helper-reset'>";a.each(e,function(d,a){var e=c.getAttribute(a)||"";b+="<li><span class='"+h+"'>";b+=a+":</span>";b+="<input type='text' value='"+e+"'/>";b+="<input type='checkbox' id='save"+d+"'/>";b+="<label for='save"+d+"'>Save</label></li>"})}i.html(b)},_getSelectedElementStyle:function(){var a=this._getInspectElement();return a&&a.style?a.style.cssText||"":""},_getSelectedElementInnerHTML:function(){var a=this._getInspectElement();return a?a.innerHTML:""},_selectedElementCanHaveChildren:function(){return!a(this._getInspectElement()).is("input,hr,br,img")},initBackColorDialog:function(){this._initColorDialog("BackColor")},initForeColorDialog:function(){this._initColorDialog("ForeColor")},_initColorDialog:function(h){var c=this,g=c.dialog,k=c._getDesignViewDocument(),j=k.queryCommandValue(h),e,d,b;g.delegate(i,"click."+c.widgetName,function(){c.submitColorDialog(h);c._onDesignViewBlur()}).delegate(l,"click."+c.widgetName,function(){c._closeDialog()});if(j){b=j.toString();if(a.browser.msie){e=f(b);b="rgb("+(e&255)+", "+((e&65280)>>8)+", "+((e&16711680)>>16)+")"}if(b.indexOf("rgb(")===0){d=b.substring(4,b.length-1).split(",");b=c._convertToWebColor(f(d[0]),f(d[1]),f(d[2]))}else if(b.indexOf("rgba(")===0){d=b.substring(5,b.length-1).split(",");b=c._convertToWebColor(f(d[0]),f(d[1]),f(d[2]))}a("."+C+" input",g).attr("value",b)}a("."+xb,g).wijeditorcolorcanvas("."+C+" input",b)},submitColorDialog:function(c){var b=this,d=a("."+C+" input",b.dialog);b.setColor(c,d.val());b._closeDialog()},setColor:function(d,e){var b=this,f=b._getDesignViewDocument(),g=b._getDesignViewWindow(),c;b._setIESelection();if(a.browser.mozilla&&d==="BackColor"){c=g.getSelection();b.insertHTML('<span style="background-color:'+e+';">'+c+"</span>")}else{f.execCommand(d,false,e);b.options.mode==="bbcode"&&!a.browser.msie&&b._convertFontStyleToStandTag()}b._addtoUndoBuffer();b._setSaveBtnEnabled()},initInsertTableDialog:function(){var a=this,b=a.dialog;b.delegate(i,"click."+a.widgetName,function(){a.submitInsertTableDialog();a._onDesignViewBlur()}).delegate(l,"click."+a.widgetName,function(){a._closeDialog()}).delegate("."+F+" input:button","click."+a.widgetName,function(){a.showTableColorDialog(this)})},submitInsertTableDialog:function(){var a=this,b=a._getValuesFromTableDialog();if(!b)return;a._insertTable(b);a._closeDialog()},_insertTable:function(a){var e=this,b="",c,d;if(!a)return false;e._setIEFocus();b+='<table width="'+a.width+'" height="'+a.height+'" cellspacing="'+a.cspacing+'" cellpadding="'+a.cpadding+'" border="'+a.border+'" bgcolor="'+a.bgcolor+'" style="'+a.css+'">';for(c=0;c<a.rows;c++){b+="<tr>";for(d=0;d<a.cols;d++)b+="<td>Cell "+(c+1)+"-"+(d+1)+"</td>";b+="</tr>"}b+="</table>";e.insertHTML(b)},initEditTableDialog:function(){var c=this,b=c.dialog,d=c._getInspectElement(),e,f;b.delegate(i,"click."+c.widgetName,function(){c.submitEditTableDialog();c._onDesignViewBlur()}).delegate(l,"click."+c.widgetName,function(){c._closeDialog()}).delegate("."+F+" input:button","click."+c.widgetName,function(){c.showTableColorDialog(this)});if(!d)return;try{e=d.rows;if(e.length>0)f=e[0].cells.length;else f=0;e=e.length}catch(g){}a("."+Eb+" input",b).val(e);a("."+vb+" input",b).val(f);a("."+Bb+" input",b).val(d.getAttribute("width"));a("."+zb+" input",b).val(d.getAttribute("height"));a("."+yb+" input",b).val(d.getAttribute("border"));a("."+rb+" input",b).val(d.getAttribute("cellPadding"));a("."+sb+" input",b).val(d.getAttribute("cellSpacing"));a("."+F+" input",b).val(d.getAttribute("bgcolor")||"#ffffff");a("."+wb+" input",b).val(d.style.cssText)},submitEditTableDialog:function(){var j=this,c=j._getInspectElement(),d=a(c),b=j._getValuesFromTableDialog(),h=b&&f(b.rows),e=b&&f(b.cols),i,g;if(!b)return;if(c){d.attr("width",b.width);d.attr("height",b.height);d.attr("bgcolor",b.bgcolor);d.attr("border",b.border);d.attr("cellSpacing",b.cspacing);d.attr("cellPadding",b.cpadding);c.style.cssText=b.css;if(!h||isNaN(h))return;if(!e||isNaN(e))return;while(c.rows.length>h)c.deleteRow(0);while(c.rows.length<h){i=c.insertRow(0);while(i.cells.length<e){g=i.insertCell(0);g.innerHTML="&nbsp;"}}a.each(c.rows,function(b,a){while(a.cells.length>e)a.deleteCell(0);while(a.cells.length<e){g=a.insertCell(0);g.innerHTML="&nbsp;"}})}j._closeDialog()},_getValuesFromTableDialog:function(){var c=this,b=c.dialog,l=a("."+Eb+" input",b).val(),k=a("."+vb+" input",b).val(),j=a("."+Bb+" input",b).val(),i=a("."+zb+" input",b).val(),h=a("."+yb+" input",b).val(),e=a("."+rb+" input",b).val(),g=a("."+sb+" input",b).val(),n=a("."+wb+" input",b).val(),m=a("."+F+" input",b).val();if(!c._isNumeric(l)){d("Please input a number for 'Rows' textbox.");return false}if(!c._isNumeric(k)){d("Please input a number for 'Columns' textbox.");return false}if(!c._isNumeric(j)){d("Please input a number for 'Table Width ' textbox.");return false}if(!c._isNumeric(i)){d("Please input a number for 'Table Height' textbox.");return false}if(!c._isNumeric(h)){d("Please input a number for 'Border thickness' textbox.");return false}if(!c._isNumeric(e)){d("Please input a number for 'Cell Padding' textbox.");return false}if(!c._isNumeric(g)){d("Please input a number for 'Cell Spacing' textbox.");return false}return{rows:l,cols:k,width:f(j),height:f(i),border:h,cpadding:e,cspacing:g,css:n,bgcolor:m}},showTableColorDialog:function(f){var b=this,c=b.subDialog,d=a(f).prev().val(),e=b._getDialogRes_Color();c.empty().append(e).wijdialog({width:"auto",height:"auto",modal:true,title:"Set Background Color",position:"center",resizable:false,captionButtons:{pin:{visible:false},refresh:{visible:false},toggle:{visible:false},minimize:{visible:false},maximize:{visible:false}}});c.delegate(i,"click."+b.widgetName,function(){b.submitTableColorDialog()}).delegate(l,"click."+b.widgetName,function(){b.closeSubDialog()});d!==""&&a("."+C+" input",c).val(d);a("."+xb,c).wijeditorcolorcanvas("."+C+" input",d);c.wijdialog("open")},submitTableColorDialog:function(){var b=this,c=b.subDialog,e=b.dialog,d=a("."+C+" input",c).val();a("."+F+" input:text",e).val(d);b.closeSubDialog()},closeSubDialog:function(){this.subDialog.wijdialog("close")},_getEditableTable:function(){var e=this,b,c;b=e._getSelectedElement();if(!b){d("Please select a table!");return false}c=a(b);if(c.is("td,tr,tbody"))b=c.parents("table:first")[0];else{d("Please select a table!");return false}Xb=b;return true},initPreviewDialog:function(){var a=this,b=a.dialog;a._setPreviewContent(0);b.delegate("#rad640_480","click."+a.widgetName,function(){a._setPreviewDialogSize(640,480)}).delegate("#rad800_600","click."+a.widgetName,function(){a._setPreviewDialogSize(800,600)}).delegate("#rad1024_768","click."+a.widgetName,function(){a._setPreviewDialogSize(1024,768)}).delegate("#chkSplit","click."+a.widgetName,function(){a._splitPreviewPages(this.checked)}).delegate("."+xc,"click."+a.widgetName,function(){a._printPreviewPage(true)}).delegate("."+yc,"click."+a.widgetName,function(){a._printPreviewPage(false)}).delegate("."+Pc,"click."+a.widgetName,function(){a._closeDialog()}).delegate("."+Jc,"click."+a.widgetName,function(){a._navigatePreviewPage(false)}).delegate("."+Ic,"click."+a.widgetName,function(){a._navigatePreviewPage(true)})},_setPreviewContent:function(d){var b=this,f=b.dialog,g=a("iframe",f),e=a("."+pb+" span",f),c=g[0].contentWindow.document;c.open();if(d===-1){c.write(b._getPreviewAllPageContent());e.html("1 / 1")}else{c.write(b._getPreviewPageContent(d));e.html(d+1+" / "+b._getPreviewPageCount())}c.close()},_setPreviewDialogSize:function(g,f){var h=this,b=h.dialog,c=a("iframe",b),e=b.wijdialog("option","width"),d=b.wijdialog("option","height");if(e==="auto")e=b.parent(".wijmo-wijdialog").width()-c.width();else e=e-c.width();if(d==="auto")d=b.parent(".wijmo-wijdialog").height()-c.height();else d=d-c.height();c.css("width",g).css("height",f);b.wijdialog("option",{width:g+e,height:f+d})},_getPreviewPageCount:function(){return this._getPreviewPages().length},_getPreviewPageContent:function(a){var b=this._getPreviewPages();return b.length>a?b[a]:null},_getPreviewAllPageContent:function(){return this._getDesignViewText()},_getPreviewPages:function(){var b=this._getPreviewAllPageContent(),c=new RegExp("<(DIV|div)[^>]*(page-break-before|PAGE-BREAK-BEFORE)[ ]*:[ ]*always[^>]*>(.*?)<\\/(DIV|div)>","g"),a=b.replace(c,"!-~U^n#i@q,P|.a=g~e+br!");return a.split("!-~U^n#i@q,P|.a=g~e+br!")},_curPageIdx:0,_splitPreviewPages:function(f){var b=this,e=b.dialog,c=a("."+uc,e),d=a("."+pb,e);if(f){b._setPreviewContent(0);d.show();c.hide()}else{b._setPreviewContent(-1);d.hide();c.show()}b._curPageIdx=0},_navigatePreviewPage:function(f){var c=this,e=a("#chkSplit",c.dialog),b=c._curPageIdx,d=c._getPreviewPageCount();if(e.is(":checked")){if(f){b++;if(b<d)c._setPreviewContent(b);else b=d-1}else{b--;if(b>=0)c._setPreviewContent(b);else b=0}c._curPageIdx=b}},_printPreviewPage:function(f){var c=this,b=c.dialog,e=a("#chkSplit",b),d=a("iframe",b)[0].contentWindow;if(f){e.removeAttr("checked");c._setPreviewContent(-1)}d.focus();d.print()},initCleanUpDialog:function(){var b=this,c=b.dialog;a("textarea",c).val(b.sourceView.val());c.delegate(i,"click."+b.widgetName,function(){b.submitCleanUpDialog();b._onDesignViewBlur()}).delegate(l,"click."+b.widgetName,function(){b._closeDialog()})},submitCleanUpDialog:function(){var e=this,d=e.dialog,f=e.sourceView,b=f.val(),c;if(a("#replaceSpans",d).is(":checked")){c=new RegExp("<\\/?SPAN[^>]*>","g");b=b.replace(c,"")}if(a("#replaceClass",d).is(":checked")){c=new RegExp("<(\\w[^>]*) class=([^ |>]*)([^>]*)","g");b=b.replace(c,"<$1$3")}if(a("#replaceStyle",d).is(":checked")){c=new RegExp('<(\\w[^>]*) style="([^"]*)"([^>]*)',"g");b=b.replace(c,"<$1$3");c=new RegExp("<(\\w[^>]*) lang=([^ |>]*)([^>]*)","g");b=b.replace(c,"<$1$3");c=new RegExp("<\\\\?\\?xml[^>]*>","g");b=b.replace(c,"");c=new RegExp("<\\/?\\w+:[^>]*>","g");b=b.replace(c,"")}if(a("#replaceNbsp",d).is(":checked")){c=new RegExp("&nbsp;","g");b=b.replace(c," ")}if(a("#transformPtoDiv",d).is(":checked")){c=new RegExp("(<P)([^>]*>.*?)(<\\/P>)","g");b=b.replace(c,"<div$2</div>")}f.val(b);e._setDesignViewText(b);e._addtoUndoBuffer();e._closeDialog()},initFindDialog:function(){var a=this,b=a.dialog;b.delegate(i,"click."+a.widgetName,function(){a.submitFindAction()}).delegate(l,"click."+a.widgetName,function(){a.submitReplaceAction();a._onDesignViewBlur()})},submitFindAction:function(){var b=this,c=a("textarea:first",b.dialog).val();if(a.trim(c)==="")return;b._findAndReplaceString(c)},submitReplaceAction:function(){var f=this,e=f.dialog,b=a("textarea:first",e).val(),c=a("textarea:last",e).val();if(a.trim(b)==="")return;if(a.trim(c)===""){d("please input replace string");return}f._findAndReplaceString(b,c)},tRange:null,txtFoundInIE:false,txtFoundInNoneIE:false,_findAndReplaceString:function(e,f){var b=this,h=b._getDesignViewWindow(),c=0,g=false,i=f&&f!==e;if(!f)f=e;if(a.browser.msie){if(b.tRange)if(b.txtFoundInIE&&i){b.tRange.pasteHTML(f);b.tRange=null;g=true;b.txtFoundInIE=false}else{b.tRange.collapse(false);c=b.tRange.findText(e);c&&b.tRange.select()}if(!g&&(!b.tRange||!c)){b.tRange=h.document.body.createTextRange();c=b.tRange.findText(e);if(c){b.tRange.select();if(i){b.tRange.pasteHTML(f);b.tRange=null;g=true}}}}else{if(b.txtFoundInNoneIE&&i){b._replaceSelectionForNoneIE(f);g=true;b.txtFoundInNoneIE=false}else{c=h.find(e);if(!c){c=h.find(e,0,1);while(h.find(e,0,1))continue}}b.txtFoundInNoneIE=b.txtFoundInNoneIE||c;if(b.txtFoundInNoneIE&&i){b._replaceSelectionForNoneIE(f);g=true;b.txtFoundInNoneIE=false}}if(!c&&!g){d('"'+e+'" String Not Found');b.tRange=null;b.txtFoundInNoneIE=false;b.txtFoundInIE=false}else b.txtFoundInIE=true},_replaceSelectionForNoneIE:function(d){var a=this._getDesignViewDocument(),b="insert_html_"+Math.round(Math.random()*1e8),c=new RegExp("<[^<]*"+b+"[^>]*>");a.execCommand("insertimage",false,b);a.body.innerHTML=a.body.innerHTML.replace(c,d)},initMediaDialog:function(){var a=this,b=a.dialog;b.delegate(i,"click."+a.widgetName,function(){a.submitMediaDialog();a._onDesignViewBlur()}).delegate(l,"click."+a.widgetName,function(){a._closeDialog()})},submitMediaDialog:function(){var b=this,c=b.dialog,h=a("select",c).val(),e=a("."+Sc+" input",c).val(),g=a("."+Mc+" input",c).val(),f=a("."+Hc+" input",c).val();if(e===""){d("URL is empty!");return}if(!b._isUrl(e)){d("please input correct URL!");return}if(!b._isNumeric(g)){d("please input width of the media!");return}if(!b._isNumeric(f)){d("please input height of the media!");return}b._insertMedia(h,e,g,f);b._closeDialog()},_insertMedia:function(f,d,c,b){var e=this,a="";e._setIESelection();switch(f){case"video":a+='<embed src="'+d+'" width="'+c+'" height="'+b+'" type=audio/x-pn-realaudio-plugin console="Clip1" controls="IMAGEWINDOW,ControlPanel,StatusBar" autostart="true"></embed>';break;case"flash":a+='<object classid="clsid:D27CDB6E-AE6D-11cf-96B8-444553540000" codebase="http://download.macromedia.com/pub/shockwave/cabs/flash/swflash.cab#version=6,0,29,0" width="'+c+'" height="'+b+'">';a+='<param name="movie" value="'+d+'">';a+='<param name="quality" value="high">';a+='<embed src="'+d+'" quality="high" pluginspage="http://www.macromedia.com/go/getflashplayer" type="application/x-shockwave-flash" width="'+c+'" height="'+b+'"></embed>';a+="</object>";break;case"applet":a+='<applet code="'+d+'" width="'+c+'" height="'+b+'"></applet>';break;case"other":a+='<embed src="'+d+'" width="'+c+'" height="'+b+'"></embed>'}e.insertHTML(a)},initSpecialCharacterDialog:function(){var b=this,d=b.dialog,c=a("."+vc+" span",d);d.delegate("label","click."+b.widgetName,function(){b.submitSpecialCharacterDialog(this);b._onDesignViewBlur()}).delegate(i,"click."+b.widgetName,function(){b._closeDialog()}).delegate("label","mouseover."+b.widgetName,function(){c.html(a(this).html())}).delegate("label","mouseout."+b.widgetName,function(){c.empty()})},submitSpecialCharacterDialog:function(c){var b=this;b._setIESelection();b.insertHTML(a(c).html());b._closeDialog()},_setSaveBtnEnabled:function(){c.wijribbon(D,qc,false)},_undoAction:function(){var b=this._getDesignViewDocument().body,a={};k--;if(k<=0)k=0;b.innerHTML=A[k];if(!k){a[E]=true;a[H]=false;c.wijribbon(Cb,a)}else c.wijribbon(D,H,false)},_redoAction:function(){var d=this._getDesignViewDocument().body,b=A.length,a={};k++;if(k>=b-1)k=b-1;d.innerHTML=A[k];if(k===b-1){a[E]=false;a[H]=true;c.wijribbon(Cb,a)}else c.wijribbon(D,E,false)},_addtoUndoBuffer:function(){for(var b=A.length-1-k,a=0;a<b;a++)A.pop();k++;A.push(this._getDesignViewText());c.wijribbon(D,E,false)},_deleteSelectionContent:function(){var e=this._getDesignViewWindow(),b,c,d,f="rangeCount";if(a.browser.msie){b=e.document.selection;b.type.toLowerCase()!=="none"&&b.clear()}else{b=e.getSelection();for(c=0;c<b[f];c++){d=b.getRangeAt(c);d.deleteContents()}}},_refreshPathSelector:function(){var e=this,d=e._getParentElement(e._getDesignViewWindow()),c=e._getPathSelector(),f=a(d).parents(),h=f.length,g="wijmo-wijeditor-label ui-state-default ui-corner-all",b;if(!d)return;c.empty();for(b=h-1;b>=0;b--)c.append("<label class='"+g+"'>&lt;"+f[b].tagName.toLowerCase()+"&gt;</label>");c.append("<label class='"+g+" wijmo-wijeditor-selectlabel ui-state-highlight ui-corner-all'>&lt;"+d.tagName.toLowerCase()+"&gt;</label>")},_toggleTableBorders:function(){var c=this._getDesignViewDocument(),b=a("#__wijStyle",c);U=!U;if(a.browser.safari)if(U)b.html("table,td,tr{border: 1px #acacac dashed;}");else b.empty();else b.attr("disabled",!U)},_tableAction:function(j){var b=this,o=b._getParentElement(b._getDesignViewWindow()),k=a(o).closest("td"),l,n,q,f,c,h,g,i,m,p,e=0;b._setSaveBtnEnabled();if(k.length===0&&j!==M)return false;else if(j!==M){l=k.parent();n=l.closest("table");q=k[0];f=l[0];c=n[0];h=f.rowIndex;g=q.cellIndex}try{switch(j){case ac:i=f.cells.length;p=c.insertRow(h);for(e=0;e<i;e++)b._insertCell(p,e);break;case bc:c.deleteRow(h);break;case Hb:m=c.rows.length;for(e=0;e<m;e++)b._insertCell(c.rows[e],g);break;case Ib:b._removeColumn(c,g);break;case Tb:b._insertCell(f,g+1);break;case Vb:i=f.cells.length;if(i===1)c.deleteRow(h);else f.deleteCell(g);break;case cc:b._splitCell(c,f,h,g);break;case M:b._mergeCell(b._getSelectedCells(o))}this._addtoUndoBuffer()}catch(r){d(r.message);return false}return true},_removeColumn:function(e,h){var i=e.rows.length,f=0,g,c,a,b,d;while(f<i){g=e.rows[f];c=g.cells;a=c.length;b=h>a-1?a-1:h;d=c[b].colSpan;if(d>1&&a>1)if(b+1<a)c[b+1].colSpan+=d-1;else c[b-1].colSpan+=d+1;if(a===1){e.deleteRow(f);i=e.rows.length}else{g.deleteCell(b);f++}}},_splitCell:function(j,h,l,e){var k=j.rows.length,a=0,i=0,f,d,b,g,c;while(a<=e){if(h.cells[a].colSpan>1)i+=h.cells[a].colSpan-1;a++}this._insertCell(h,e+1);for(b=0;b<k;b++){f=j.rows[b];if(b!==l){g=e;a=0;d=0;while(a<=g){if(f.cells[a].colSpan>1){d+=f.cells[a].colSpan-1;g-=d}a++}c=e+i-d;if(c<0)c=0;f.cells[c].colSpan++}}},_mergeCell:function(b){var e=b.length,c,a,f,d;if(e<2||b[0].parentNode!==b[e-1].parentNode)return false;c=b[0].parentNode;a=b[0].cellIndex;f=a+e;for(d=a+1;d<f;d++){c.cells[a].innerHTML+=c.cells[a+1].innerHTML;c.cells[a].colSpan++;c.deleteCell(a+1)}},_getSelectedCells:function(k){var j=this._getDesignViewWindow(),m=j.document,e=[],b,d,h,c,f,g,i,l;if(a.browser.msie){b=m.selection.createRange();d=a(k).closest("tr")[0];d&&a.each(d.cells,function(f,d){var a=m.selection.createRange(),c="compareEndPoints";a.moveToElementText(d);(b.inRange(a)||b[c]("StartToStart",a)>=0&&b[c]("StartToEnd",a)<=0||b[c]("EndToStart",a)>=0&&b[c]("EndToEnd",a)<=0)&&e.push(d)})}else if(a.browser.mozilla){h=j.getSelection();f=h.rangeCount;for(c=0;c<f;c++){b=h.getRangeAt(c);g=b.startContainer;i=g.nodeName.toLowerCase();if(i==="td"||i==="th")e.push(g);else if(i==="tr"){l=b.startOffset;e.push(g.cells[l])}}}else{h=j.getSelection();d=a(k).closest("tr")[0];f=d.cells.length;if(d)for(c=0;c<f;c++)e.push(d.cells[c])}return e},insertDateAndTime:function(){this.insertHTML((new Date).toDateString()+" "+(new Date).toTimeString())},_toggleWordWrap:function(){var d=this,b=d.sourceView,e="wrap",c;rc=!rc;c=rc?"soft":"off";b.attr(e,c);b[0].focus();if(a.browser.mozilla){b.hide();n.setTimeout(function(){b.show()},40)}},insertHTML:function(d){var c=this,e=c._getDesignViewDocument(),b;try{if(a.browser.msie){b=e.selection.createRange();b.pasteHTML(d);b.collapse(false);b.select()}else e.execCommand("insertHTML",false,d)}catch(f){}c._addtoUndoBuffer();c._setSaveBtnEnabled()},_getSelectedContent:function(){var g=this._getDesignViewWindow(),f=g.document,c="",d="cloneContents",a,e,b;if(!f.selection){a=g.getSelection().getRangeAt(0);if(a)if(a[d]){e=a[d]();b=document.createElement("div");b.appendChild(e);c=b.innerHTML;b=null}}else{a=f.selection.createRange();return a.htmlText}return c||""},_setIESelection:function(){a.browser.msie&&j&&j.select()},_setIEFocus:function(){var b=this._getDesignViewDocument();if(a.browser.msie)try{b.body.focus()}catch(c){}},focus:function(){var b=this._getDesignViewWindow(),c=b.document;if(a.browser.msie)if(!j)c.body.focus();else j.select();else b.focus()},_getInspectElement:function(){return Xb||this._getSelectedElement()},_getSelectedElement:function(){return this._getParentElement(this._getDesignViewWindow())},_createElement:function(c,a,b){return new fb(c,a,b)},_createDiv:function(a){return this._createElement("div",{"class":a})},_createSpan:function(a,b){var c=this;return!b?c._createElement("span",{"class":a}):a.length===0?c._createElement("span",b):this._createElement("span",b,{"class":a})},_createTextBox:function(c,b){var a={"class":c,type:"text"};if(b)a.value=b;return this._createElement("input",a)},_createLabel:function(b,a){return a?new fb("label",b,{"for":a}):new fb("label",b)},_createRadio:function(d,c,b){var a={name:c,id:d,value:b,type:"radio"};return this._createElement("input",a)},_createCheckbox:function(b){var a={type:"checkbox",id:b};return this._createElement("input","",a)},_createSelect:function(d,e){var c=this,f={"class":d},b=c._createElement("select",f);if(d==="")b=c._createElement("select");a.each(e,function(e,d){if(a.isPlainObject(d)&&d.selected)b.add(c._createElement("option",d.text,{selected:"selected"}));else b.add(c._createElement("option",d))});return b},_createInputButton:function(c,b){var a={"class":c,type:"button"};if(b)a.value=b;return this._createElement("input",a)},_createTextField:function(g,f,e,c){var b=this,a=b._createDiv(f),d={type:"text"};if(c)d.value=c;a.add(b._createSpan(h,g));a.add(b._createElement("input",d));e&&a.add(new Df(e));return a},_createSeparator:function(){var b=this,a=b._createDiv(Ef);a.add(b._createElement("hr"));return a},_createOKCancelButtons:function(){var b=this,a=b._createDiv(G);a.add(b._createElement("input",{type:"button","class":o,value:"OK"}));a.add(b._createElement("input",{type:"button","class":o,value:"Cancel"}));return a},_getDialogRes_Template:function(){var a=this,b=a._createDiv(g),e=a._createDiv(Bf),f=a._createDiv(rf),m=a._createDiv(Cf),l=a._createDiv(sf),i=a._createDiv(uf),j=a._createElement("div","Name :"),k=a._createElement("div","Description :"),c=a._createDiv(Af),d=a._createDiv(qf);e.add(a._createElement("div","Select Template:",{"class":tf}));e.add(a._createElement("div","Template Preview:",{"class":vf}));b.add(e);m.add(a._createElement("select",{size:8}));l.add(a._createElement("iframe",{frameborder:0}));f.add(m);f.add(l);b.add(f);j.add(a._createSpan(Nb));k.add(a._createSpan(Rb));i.add(j);i.add(k);b.add(i);c.add(a._createSpan(h,"Name :"));c.add(a._createTextBox(L));c.add(a._createSpan(h,"Description :"));c.add(a._createTextBox(T));b.add(c);d.add(a._createInputButton(o+" "+cd,"Delete selected"));d.add(a._createInputButton(o+" "+kd,"Save current page as template"));b.add(d);b.add(a._createSeparator());b.add(a._createOKCancelButtons());return b.render()},_getDialogRes_ImageBrowser:function(){var a=this,g=a._createDiv(m),c=a._createDiv(Ie),b=a._createDiv(Se),d=a._createDiv(Kb),f=a._createDiv(ff),e=a._createDiv(Je);b.add(a._createTextField("Image src:",Y));b.add(a._createTextField("Image alt text:",ad));b.add(a._createTextField("Image width:",Lb,"px"));b.add(a._createTextField("Image height:",Db,"px"));b.add(a._createTextField("Css text:",bd));c.add(b);d.add(f);f.add(a._createElement("select",{size:8}));d.add(e);e.add(a._createElement("img",{src:"",alt:""}));c.add(d);c.add(a._createSeparator());c.add(a._createOKCancelButtons());g.add(c);return g.render()},_getDialogRes_Link:function(){var b=this,c=b._createDiv(z),n=b._createTextField("Address :",K),f=b._createDiv(Dc),e=b._createElement("div"),m=[{id:"radUrl",value:"url"},{id:"radAnchor",value:"anchor",checked:true},{id:"radMail",value:"email"}],i=[],o=b._createTextField("Text to display :",Mb),g=b._createDiv(Q),l=b._createSpan(h,"Target :"),j=[{text:"_blank",selected:true},"_parent","_self","_top"],k=b._createSelect(Q,j),p=b._createTextField("Css :",Qb),d;c.add(n);c.add(f);f.add(e);a.each(m,function(c,a){e.add(b._createRadio(a.id,"radioList",a.value));e.add(b._createLabel(a.value,a.id))});for(d=1;d<8;d++)i.push("#anchor"+d.toString());f.add(b._createSelect(Ab,i));c.add(b._createSeparator());c.add(o);c.add(g);g.add(l);g.add(k);c.add(p);c.add(b._createSeparator());c.add(b._createOKCancelButtons());return c.render()},_getDialogRes_TagInspector:function(){var a=this,b=a._createDiv(s),f=a._createDiv(ne),c=a._createDiv(Hd),e=a._createDiv(me),d=a._createDiv(tb);b.add(f);f.add(a._createSpan(ee,"Selected tag:"));f.add(a._createSpan(Bc,""));b.add(c);c.add(a._createCheckbox("displayNoEmpty"));c.add(a._createLabel("Display not empty attributes only","displayNoEmpty"));b.add(e);e.add(a._createSpan(h,"Attributes:"));e.add(a._createDiv(P));b.add(d);d.add(a._createSpan(h,"Inner HTML:"));d.add(a._createElement("textarea"));b.add(a._createTextField("Css Text:",Fb));b.add(a._createSeparator());b.add(a._createOKCancelButtons());return b.render()},_getDialogRes_Color:function(){return this._getDialogRes_CommonColor("#FFFFFF")},_getDialogRes_ForeColor:function(){return this._getDialogRes_CommonColor("#000000")},_getDialogRes_BackColor:function(){return this._getDialogRes_CommonColor("#FFFFFF")},_getDialogRes_CommonColor:function(d){var a=this,b=a._createDiv(gc),c=a._createDiv(C);b.add(a._createDiv(xb));b.add(c);c.add(a._createSpan(h,"Selected Color:"));c.add(a._createElement("input",{type:"text",value:d}));b.add(a._createSeparator());b.add(a._createOKCancelButtons());return b.render()},_getDialogRes_Table:function(){var a=this,b=a._createDiv(q),c=a._createDiv(F);b.add(a._createTextField("Rows :",Eb,"",3));b.add(a._createTextField("Columns :",vb,"",3));b.add(a._createTextField("Table Width :",Bb,"&nbsp;pixels",200));b.add(a._createTextField("Table Height :",zb,"&nbsp;pixels",200));b.add(a._createTextField("Border thickness :",yb));b.add(a._createTextField("Cell Padding :",rb));b.add(a._createTextField("Cell Spacing :",sb));b.add(a._createTextField("Css Text :",wb));b.add(c);c.add(a._createSpan(h,"Background Color :"));c.add(a._createElement("input",{type:"text"}));c.add(a._createElement("input",{type:"button",value:"..."}));b.add(a._createSeparator());b.add(a._createOKCancelButtons());return b.render()},_getDialogRes_Preview:function(){var a=this,c=a._createDiv(p),b=a._createDiv(Vd),e=a._createDiv(G),d=a._createDiv(pb),f=a._createDiv(Dd);c.add(b);b.add(a._createSpan(h,"Preview Size:"));b.add(a._createElement("input",{id:"rad640_480",name:"preview",type:"radio",checked:"checked"}));b.add(a._createLabel("640x480","rad640_480"));b.add(a._createElement("input",{id:"rad800_600",name:"preview",type:"radio"}));b.add(a._createLabel("800x600","rad800_600"));b.add(a._createElement("input",{id:"rad1024_768",name:"preview",type:"radio"}));b.add(a._createLabel("1024x768","rad1024_768"));b.add(a._createElement("input",{id:"chkSplit",type:"checkbox",checked:"checked"}));b.add(a._createLabel("Split pages","chkSplit"));c.add(a._createSeparator());c.add(e);e.add(a._createInputButton(o+" "+xc,"Print All"));e.add(a._createInputButton(o+" "+yc,"Print Page"));e.add(a._createInputButton(o+" "+Pc,"OK"));c.add(a._createSeparator());c.add(d);d.add(a._createElement("a","Prev page",{"class":Jc,href:"#"}));d.add(a._createElement("span","1 / 1"));d.add(a._createElement("a","Next page",{"class":Ic,href:"#"}));c.add(a._createDiv(uc));c.add(f);f.add(a._createElement("iframe",{src:"about:blank"}));return c.render()},_getDialogRes_CleanUp:function(){var b=this,c=b._createDiv(X),e=b._createDiv(Ud),f=b._createDiv(Md),d=b._createDiv(Td),g=[{id:"replaceSpans",label:"Strip SPAN tag"},{id:"replaceClass",label:"Strip CLASS tag"},{id:"replaceStyle",label:"Strip STYLE attribute"},{id:"replaceNbsp",label:"Replace &amp;nbsp; symbol"},{id:"transformPtoDiv",label:"Transform Paragraph to DIV"}];c.add(e);e.add(b._createSpan(h,"Document source :"));c.add(f);f.add(b._createElement("textarea",{readonly:"readonly"}));c.add(d);a.each(g,function(c,a){d.add(b._createCheckbox(a.id));d.add(b._createLabel(a.label,a.id))});c.add(b._createSeparator());c.add(b._createOKCancelButtons());return c.render()},_getDialogRes_FindAndReplace:function(){var a=this,b=a._createDiv(jc),e=a._createDiv(af),d=a._createDiv(Ae),c=a._createDiv(G);b.add(e);e.add(a._createSpan(h,"Find:"));e.add(a._createElement("textarea","text"));b.add(d);d.add(a._createSpan(h,"Replace:"));d.add(a._createElement("textarea"));b.add(a._createSeparator());b.add(c);c.add(a._createInputButton(o,"Find"));c.add(a._createInputButton(o,"Replace"));return b.render()},_getDialogRes_Media:function(){var a=this,b=a._createDiv(O),c=a._createDiv(Te);b.add(c);c.add(a._createSpan(h,"Media Type :"));c.add(a._createSelect("",["flash","video","applet","other"]));b.add(a._createTextField("Media Url :",Sc));b.add(a._createTextField("Width :",Mc,"px",200));b.add(a._createTextField("Height :",Hc,"px",200));b.add(a._createSeparator());b.add(a._createOKCancelButtons());return b.render()},_getDialogRes_SpecialCharacter:function(){var b=this,c=b._createDiv(r),e=b._createDiv(Ld),m=b._createDiv(Fd),l=b._createDiv(vc),d=b._createDiv(Sd),f=b._createDiv(qb,"Punctuation"),i=b._createDiv(Bd),p=["&#8211;","&#8212;","&iexcl;","&iquest;","&quot;","&laquo;","&raquo;","&nbsp;"],h=b._createDiv(qb,"Symbols"),n=b._createDiv(Gd),s=["&amp;","&cent;","&copy;","&divide;","&gt;","&lt;","&micro;","&#8226;","&para;","&plusmn;","&#8364;","&pound;","&reg;","&sect;","&yen;"],g=b._createDiv(qb,"Diacritics"),j=b._createDiv(Cd),q=["&aacute;","&Aacute;","&agrave;","&Agrave;","&acirc;","&Acirc;","&aring;","&Aring;","&atilde;","&Atilde;","&auml;","&Auml;","&aelig;","&AElig;","&ccedil;","&Ccedil;","&eacute;","&Eacute;","&egrave;","&Egrave;","&ecirc;","&Ecirc;","&euml;","&Euml;","&iacute;","&Iacute;","&igrave;","&Igrave;","&icirc;","&Icirc;","&iuml;","&Iuml;","&ntilde;","&Ntilde;","&oacute;","&Oacute;","&ograve;","&Ograve;","&ocirc;","&Ocirc;","&oslash;","&Oslash;","&otilde;","&Otilde;","&ouml;","&Ouml;","&uacute;","&Uacute;","&ugrave;","&Ugrave;","&ucirc;","&Ucirc;","&uuml;","&Uuml;","&szlig;","&yuml;","&#8216;","&#8217;"],k=b._createDiv(G);c.add(e);e.add(m);m.add(l);l.add(new fb("span"));e.add(d);d.add(f);f.add(i);a.each(p,function(c,a){i.add(b._createLabel(a))});d.add(h);h.add(n);a.each(s,function(c,a){n.add(b._createLabel(a))});d.add(g);g.add(j);a.each(q,function(c,a){j.add(b._createLabel(a))});c.add(b._createSeparator());k.add(b._createInputButton(o,"Cancel"));c.add(k);return c.render()},_copyFromClipboard:function(){var d,c,b={},e={};if(n.clipboardData)return n.clipboardData.getData("Text");else if(a.browser.mozilla){try{netscape.security.PrivilegeManager.enablePrivilege&&netscape.security.PrivilegeManager.enablePrivilege("UniversalXPConnect")}catch(f){}d=Components.classes["@mozilla.org/widget/clipboard;1"].getService(Components.interfaces.nsIClipboard);if(!d)return false;c=Components.classes["@mozilla.org/widget/transferable;1"].createInstance(Components.interfaces.nsITransferable);if(!c)return false;c.addDataFlavor("text/unicode");d.getData(c,d.kGlobalClipboard);c.getTransferData("text/unicode",b,e);if(b)b=b.value.QueryInterface(Components.interfaces.nsISupportsString);return b?b.data.substring(0,e.value/2):""}},_copyToClipboard:function(e){var f,c,g,b={},h={};if(n.clipboardData&&e)n.clipboardData.setData("Text",e);else if(a.browser.mozilla)try{netscape.security.PrivilegeManager.enablePrivilege&&netscape.security.PrivilegeManager.enablePrivilege("UniversalXPConnect");f=Components.classes["@mozilla.org/widget/clipboard;1"].createInstance(Components.interfaces.nsIClipboard);if(!f)return;c=Components.classes["@mozilla.org/widget/transferable;1"].createInstance(Components.interfaces.nsITransferable);if(!c)return;c.addDataFlavor("text/unicode");b={};h={};b=Components.classes["@mozilla.org/supports-string;1"].createInstance(Components.interfaces.nsISupportsString);b.data=e;c.setTransferData("text/unicode",b,e.length*2);g=Components.interfaces.nsIClipboard;if(!f)return false;f.setData(c,null,g.kGlobalClipboard)}catch(i){b="Copy text to Clipboard \n";b+="If you are using firefox please do the following :\n ";b+="1. Write in your url box : 'about:config'\n";b+="2. Change signed.applets.codebase_principal_support = true\n";d(b)}},fixAbsoluteUrlsIfNeeded:function(o){for(var g=this,n=tc.URL,b=tc.URL,f=tc.URL,i=false,p=b.length,a=o,d,j,k,c,l,m,h,e=p-1;e>0;e--){d=b.charAt(e);j=b.charAt(e-1);if(d==="/"||d==="\\"){if(d===j)break;f=b.substring(0,e)+d;if(!i){b=f;i=true}}}k=g._prepareLiteralRegexText(n+"?");c=new RegExp(k,"g");a=a.replace(c,"?");l=g._prepareLiteralRegexText(b);c=new RegExp(l,"g");a=a.replace(c,"");m=g._prepareLiteralRegexText(f);c=new RegExp(m,"g");a=a.replace(c,"/");h=a.indexOf("#");if(h>-1)a=a.substr(h);return a},_insertCell:function(c,b){var a=c.insertCell(b);a.innerHTML="&nbsp;";return a},_getDictionaryDeclare:function(){var a={};a.a=["accesskey","charset","class","coords","dir","href","hreflang","id","lang","name","rel","rev","shape","tabindex","target","title"];a.b=["class","dir","id","lang","title"];a.body=["alink","background","bgColor","bgproperties","bottommargin","class","dir","id","lang","leftmargin","link","marginheight","marginwidth","rightmargin","text","title","topmargin","vlink"];a.button=["accesskey","class","dir","disabled","id","lang","name","tabindex","title","type","value"];a.code=["class","dir","id","lang","title"];a.div=["align","class","dir","id","lang","title"];a.em=["class","dir","id","lang","title"];a.font=["class","color","dir","face","id","lang","pointsize","size","title"];a.form=["action","class","dir","enctype","id","lang","method","name","runat","target","title"];a.hr=["align","class","color","id","noshade","size","title","width"];a.i=["class","dir","id","lang","title"];a.img=["align","alt","border","class","controls","dir","dynsrc","height","hspace","id","ismap","lang","longdesc","loop","lowsrc","name","src","start","title","usemap","vspace","width"];a.input=["accept","accesskey","align","alt","border","checked","class","dir","disabled","height","hspace","id","lang","maxlength","name","readonly","size","src","tabindex","title","type","usemap","value","vspace","width"];a.label=["accesskey","class","dir","for","id","lang","title"];a.li=["class","dir","id","lang","title","type","value"];a.ol=["class","compact","dir","id","lang","start","title","type"];a.option=["class","dir","disabled","id","label","lang","selected","title","value"];a.p=["align","class","dir","id","lang","title"];a.span=["class","dir","id","lang","title"];a.strong=["class","dir","id","lang","title"];a.select=["accesskey","class","dir","disabled","id","lang","multiple","name","size","tabindex","title"];a.table=["align","background","bgColor","border","bordercolor","bordercolordark","bordercolorlight","cellpadding","cellspacing","class","cols","datapagesize","dir","frame","height","hspace","id","lang","rules","summary","title","vspace","width"];a.td=["abbr","align","axis","background","bgColor","bordercolor","bordercolordark","bordercolorlight","class","colspan","dir","headers","height","id","lang","nowrap","rowspan","scope","title","valign","width"];a.th=["abbr","align","axis","background","bgColor","bordercolor","bordercolordark","bordercolorlight","class","colspan","dir","headers","height","id","lang","nowrap","rowspan","scope","title","valign","width"];a.tr=["align","bgColor","bordercolor","bordercolordark","bordercolorlight","class","dir","height","id","lang","nowrap","title","valign"];a.tbody=["align","bgColor","class","dir","id","lang","title","valign"];a.textarea=["accesskey","class","cols","dir","disabled","id","label","lang","name","readonly","rows","tabindex","title","wrap"];a.u=["class","id","xml:lang"];a.ul=["class","compact","dir","id","lang","title","type"];return a},_getParentElement:function(e){var h=this,a=h._getRange(e),b,f,g,c,d;if(!a)return null;if(a.commonAncestorContainer){b=e.getSelection();f=a.startContainer||b.baseNode;g=a.endContainer||b.extentNode;c=a.startOffset;if(c===null)c=b.baseOffset;d=a.endOffset;if(d===null)d=b.extentOffset;return f===g&&d-c===1?b.anchorNode.childNodes[b.anchorOffset]:!a.commonAncestorContainer.tagName?e.document===a.commonAncestorContainer&&b.baseNode?b.baseNode.parentNode:a.commonAncestorContainer.parentNode:a.commonAncestorContainer}return a.length?a.item(0):a.parentElement?a.parentElement():null},_getRange:function(a){var b,c;if(a.document.selection&&!n.opera)return a.document.selection.createRange();if(a.getSelection){b=a.getSelection();if(!b||b.rangeCount<1)return null;if(b.getRangeAt)c=b.getRangeAt(0);else c=a.document.createRange();return c}},_generateUniqueName:function(b){var a=wd[b];if(!a)a=0;wd[b]=++a;return b+a},_setContentEditable:function(b,d){var c="designMode",e="contentEditable";try{if(b.body[e])b.body[e]=d.toString();if(b[c])if(!d&&b[c]!=="off")b[c]="off";else if(d&&b[c]!=="on")b[c]="on";d&&!a.browser.msie&&b.execCommand("useCSS",false,true)}catch(f){}},_formatString:function(a,d){for(var c=a.length,b=0;b<d-c;b++)a="0"+a;return a},_convertToWebColor:function(c,b,a){var d=this,i,h,g,e;if(isNaN(c)||255-c<0)c=0;if(isNaN(b)||255-b<0)b=0;if(isNaN(a)||255-a<0)a=0;i=d._formatString(f(c).toString(16),2);h=d._formatString(f(b).toString(16),2);g=d._formatString(f(a).toString(16),2);e="#"+i+h+g;return e},_prepareLiteralRegexText:function(b){var a=b;a=a.replace("\\","\\\\");a=a.replace(".","\\.");a=a.replace("?","\\?");return a},_isNumeric:function(a){return new RegExp("^\\d+$").test(a)},_isEmail:function(a){return new RegExp("mailto:(\\S)+[@]{1}(\\S)+[.]{1}(\\w)+").test(a)},_isUrl:function(a){return new RegExp("[a-zA-z]+://[^s]+").test(a)},refresh:function(){var a=this,d=a.element,g=a._getHeader(),f=a._getFooter(),i=d.width(),h=d.height(),e=a._getContent(),b;a.editor.width(i).height(h);c.wijribbon("updateRibbonSize");b=a.editor.height()-g.outerHeight(true)-f.outerHeight(true);e.height(b).wijsplitter("refresh")},getText:function(){var a=this;return a._getDesignViewText()},setText:function(a){var b=this;a&&b._setDesignViewText(a)}})})(jQuery);(function(a){"use strict";var d=document,b=parseInt,c="wijmo-wijeditor",e=c+"-colorcanvas",g=c+"-color",h=c+"-wheel",i=c+"-overlay",f=c+"-marker";a.fn.wijeditorcolorcanvas=function(c,b){a.wijeditorcolorcanvas(this,c,b);return this};a.wijeditorcolorcanvas=function(c,e,d){var b=a(c).get(0);return b.wijeditorcolorcanvas||(b.wijeditorcolorcanvas=new a._wijeditorcolorcanvas(b,e,d))};a._wijeditorcolorcanvas=function(l,n,o){var c=this,j="",k,m;m="progid:DXImageTransform.Microsoft.AlphaImageLoader(enabled=true, sizingMethod=crop, ";j+="<div class='"+e+"'>";j+="<div class='"+g+"'></div>";j+="<div class='"+h+"'></div>";j+="<div class='"+i+"'></div>";j+="<div class='h-marker "+f+"'></div>";j+="<div class='sl-marker "+f+"'></div></div>";a(l).html(j);k=a("."+e,l);c.wheel=a("."+h,l).get(0);c.radius=84;c.square=100;c.width=194;a.browser.msie&&a.browser.version<7&&a("*",k).each(function(){var c=this,b=c.currentStyle.backgroundImage;if(b!=="none"){b=b.substring(5,b.length-2);a(c).css({backgroundImage:"none",filter:m+"src='"+b+"')"})}});c.linkTo=function(b){typeof c.callback==="object"&&a(c.callback).unbind("keyup",c.updateValue);c.color=null;if(typeof b==="function")c.callback=b;else if(typeof b==="object"||typeof b==="string"){c.callback=a(b);c.callback.bind("keyup",c.updateValue);c.callback.get(0).value&&c.setColor(c.callback.get(0).value)}return this};c.updateValue=function(){var a=this;a.value&&a.value!==c.color&&c.setColor(a.value)};c.setColor=function(a){var b=c.unpack(a);if(c.color!==a&&b){c.color=a;c.rgb=b;c.hsl=c.RGBToHSL(c.rgb);c.updateDisplay()}return this};c.setHSL=function(a){c.hsl=a;c.rgb=c.HSLToRGB(a);c.color=c.pack(c.rgb);c.updateDisplay();return this};c.widgetCoords=function(b){var f,g,h,e,d;h=b.target||b.srcElement;e=c.wheel;d=c.absolutePosition(e);f=(b.pageX||0*(b.clientX+a("html").get(0).scrollLeft))-d.x;g=(b.pageY||0*(b.clientY+a("html").get(0).scrollTop))-d.y;return{x:f-c.width/2,y:g-c.width/2}};c.mousedown=function(b){if(!d.dragging){a(d).bind("mousemove",c.mousemove).bind("mouseup",c.mouseup);d.dragging=true}var e=c.widgetCoords(b);c.circleDrag=Math.max(Math.abs(e.x),Math.abs(e.y))*2>c.square;c.mousemove(b);return false};c.mousemove=function(f){var b=c.widgetCoords(f),a,e,d;if(c.circleDrag){a=Math.atan2(b.x,-b.y)/6.28;if(a<0)a+=1;c.setHSL([a,c.hsl[1],c.hsl[2]])}else{e=Math.max(0,Math.min(1,-(b.x/c.square)+.5));d=Math.max(0,Math.min(1,-(b.y/c.square)+.5));c.setHSL([c.hsl[0],e,d])}return false};c.mouseup=function(){a(d).unbind("mousemove",c.mousemove).unbind("mouseup",c.mouseup);d.dragging=false};c.updateDisplay=function(){var d=c.hsl[0]*6.28,b;a(".h-marker",k).css({left:Math.round(Math.sin(d)*c.radius+c.width/2)+"px",top:Math.round(-Math.cos(d)*c.radius+c.width/2)+"px"});a(".sl-marker",k).css({left:Math.round(c.square*(.5-c.hsl[1])+c.width/2)+"px",top:Math.round(c.square*(.5-c.hsl[2])+c.width/2)+"px"});a("."+g,k).css("backgroundColor",c.pack(c.HSLToRGB([c.hsl[0],1,.5])));if(typeof c.callback==="object"){a(c.callback).css({backgroundColor:c.color,color:c.hsl[2]>.5?"#000":"#fff"});a(c.callback).each(function(){b=this;if(b.value&&b.value!==c.color)b.value=c.color})}else typeof c.callback==="function"&&c.callback.call(c,c.color)};c.absolutePosition=function(a){var d={x:a.offsetLeft,y:a.offsetTop},b;if(a.offsetParent){b=c.absolutePosition(a.offsetParent);d.x+=b.x;d.y+=b.y}return d};c.pack=function(a){var d=Math.round(a[0]*255),c,b;c=Math.round(a[1]*255);b=Math.round(a[2]*255);return"#"+(d<16?"0":"")+d.toString(16)+(c<16?"0":"")+c.toString(16)+(b<16?"0":"")+b.toString(16)};c.unpack=function(a){return a.length===7?[b("0x"+a.substring(1,3))/255,b("0x"+a.substring(3,5))/255,b("0x"+a.substring(5,7))/255]:a.length===4?[b("0x"+a.substring(1,2))/15,b("0x"+a.substring(2,3))/15,b("0x"+a.substring(3,4))/15]:void 0};c.HSLToRGB=function(g){var c,b,d,e,a,f=this;d=g[0];e=g[1];a=g[2];b=a<=.5?a*(e+1):a+e-a*e;c=a*2-b;return[f.hueToRGB(c,b,d+.33333),f.hueToRGB(c,b,d),f.hueToRGB(c,b,d-.33333)]};c.hueToRGB=function(b,c,a){a=a<0?a+1:a>1?a-1:a;return a*6<1?b+(c-b)*a*6:a*2<1?c:a*3<2?b+(c-b)*(.66666-a)*6:b};c.RGBToHSL=function(i){var h,a,f,g,j,d,e,c,b;e=i[0];c=i[1];b=i[2];h=Math.min(e,Math.min(c,b));a=Math.max(e,Math.max(c,b));f=a-h;d=(h+a)/2;j=0;if(d>0&&d<1)j=f/(d<.5?2*d:2-2*d);g=0;if(f>0){if(a===e&&a!==c)g+=(c-b)/f;if(a===c&&a!==b)g+=2+(b-e)/f;if(a===b&&a!==e)g+=4+(e-c)/f;g/=6}return[g,j,d]};a("*",k).mousedown(c.mousedown);c.setColor(o||"#000000");n&&c.linkTo(n)}})(jQuery);
(function(a){"use strict";var j="wijmo-wijrating",h="wijmo-wijrating-starcontainer",c="wijmo-wijrating-reset",l="ui-corner-all",k="ui-state-default",i="ui-state-hover",g="wijmo-wijrating-resethover",m="wijmo-wijrating-star",b="wijmo-wijrating-normal",d="wijmo-wijrating-hover",e="wijmo-wijrating-rated",f="wijmo-wijrating-vertical";a.widget("wijmo.wijrating",{options:{disabled:false,count:5,split:1,totalValue:5,value:0,min:null,max:null,resetButton:{disabled:false,hint:"cancel this rating!",position:"leftOrTop",customizedClass:"",customizedHoverClass:""},hint:{disabled:false,content:null},orientation:"horizontal",direction:"normal",ratingMode:"continuous",icons:{iconsClass:null,hoverIconsClass:null,ratedIconsClass:null},iconWidth:16,iconHeight:16,animation:null,rating:null,rated:null,reset:null,hover:null},_setOption:function(g,e){var i=this,d=i.options,j=a("."+c,i.ratingElement[0]),k=a("."+h,i.ratingElement[0]),l=a("."+b,i.ratingElement[0]);if(a.isPlainObject(d[g])){switch(g){case"resetButton":if(typeof e.disabled!=="undefined")if(e.disabled!==d[g].disabled)if(e.disabled){j.hide();j.attr("aria-hidden",true)}else if(!d.disabled){j.show();j.attr("aria-hidden",false)}if(typeof e.hint!=="undefined")if(e.hint!==d[g].hint)if(e.hint===null)j.attr("title","");else j.attr("title",e.hint);if(e.position&&e.position.length)if(e.position!==d[g].position)if(e.position==="rightOrBottom")j.parent().append(j);else j.parent().prepend(j);if(typeof e.customizedClass!=="undefined")if(e.customizedClass!==d[g].customizedClass){d[g].customizedClass.length&&j.removeClass(d[g].customizedClass);e.customizedClass.length&&j.addClass(e.customizedClass)}break;case"hint":if(typeof e.disabled!=="undefined")if(e.disabled!==d[g].disabled)if(e.disabled)l.removeAttr("title");else i._resetHint(d.hint.content);if(typeof e.content!=="undefined")if(e.content!==d[g].content)!d[g].disabled&&i._resetHint(e.content);break;case"icons":if(typeof e.iconsClass!=="undefined"){d[g].iconsClass&&d[g].iconsClass.length&&i._removeCustomizedIconsClass(d[g].iconsClass);i._addCustomizedIconsClass(e.iconsClass,d.split)}if(typeof e.hoverIconsClass!=="undefined")d[g].hoverIconsClass&&d[g].hoverIconsClass.length&&i._removeCustomizedIconsClass(d[g].hoverIconsClass);if(typeof e.ratedIconsClass!=="undefined"){d[g].ratedIconsClass&&d[g].ratedIconsClass.length&&i._removeCustomizedIconsClass(d[g].ratedIconsClass);i._resetValue(d.value,d.ratingMode,e.ratedIconsClass)}}a.extend(true,d[g],e)}else{if(e===d[g])return;switch(g){case"disabled":if(e){i._unbindLiveEvents();j.hide();j.attr("aria-hidden",true)}else{i._bindLiveEvents();if(!d.resetButton.disabled){j.show();j.attr("aria-hidden",false)}}break;case"count":i._createStars(d.split,e,k);break;case"split":i._createStars(e,d.count,k);break;case"totalValue":i._resetTotalValue(e);break;case"orientation":if(e==="vertical")i.ratingElement.addClass(f);else i.ratingElement.removeClass(f);if(d.split>1){d[g]=e;i._createStars(d.split,d.count,k)}break;case"direction":d[g]=e;i._createStars(d.split,d.count,k);break;case"ratingMode":i._resetValue(d.value,e,d.icons.ratedIconsClass);break;case"value":if(d.min&&e<d.min)return;if(d.max&&e>d.max)return;i._resetValue(e,d.ratingMode,d.icons.ratedIconsClass);break;case"iconWidth":d[g]=e;i._createStars(d.split,d.count,k);break;case"iconHeight":d[g]=e;i._createStars(d.split,d.count,k)}a.Widget.prototype._setOption.apply(i,arguments)}},_create:function(){var b=this,d=b.options,c;if(b.element.is("select")){b._parseSelect();b.element.hide();c=a("<div></div>");b.element.after(c)}else if(b.element.is("div"))if(b.element.children("input:[type='radio']").length>0){b._parseRadio();b.element.hide();c=a("<div></div>");b.element.after(c)}else c=b.element;else return;b.ratingElement=c;b._createRating();!d.disabled&&b._bindLiveEvents()},destroy:function(){var b=this;b._unbindLiveEvents();if(b.element!==b.ratingElement){b.ratingElement.remove();b.element.show()}else{b.element.removeClass("ui-widget");b.element.removeClass(j);b.element.removeClass(f);b.element.empty()}a.Widget.prototype.destroy.apply(b,arguments)},_unbindLiveEvents:function(){a("."+b,this.ratingElement[0]).die("wijrating").die(".wijrating");a("."+c,this.ratingElement[0]).die("wijrating").die(".wijrating")},_bindLiveEvents:function(){var f=this,e=f.options,j="."+b,m="."+c,h,l={element:f.ratingElement,mouseover:function(c){var b=a(c.target),g=a(j,f.ratingElement[0]);if(b.is(j)){g.removeClass(d);b.addClass(d);if(e.ratingMode==="continuous")if(e.direction==="reversed")b.parent().nextAll().children().addClass(d);else b.parent().prevAll().children().addClass(d);f._addCustomizedHoverIconsClass(e.icons.hoverIconsClass,e.split,b);h={value:parseFloat(b.html()),target:b};f._trigger("hover",c,h)}},mouseout:function(g){var c=a(g.target),b=a(j,f.ratingElement[0]);if(c.is(j)){b.removeClass(d);f._removeCustomizedIconsClass(e.icons.hoverIconsClass)}},click:function(c){var k=a(c.target),b=parseFloat(k.html()),g=a(j,f.ratingElement[0]),m=a.extend({duration:500,easing:null,delay:250},e.animation),l=a.wijmo.wijrating.animations,i=m.animated;if(!k.is(j))return;if(e.max&&b>e.max)return;if(e.min&&b<e.min)return;h={oldValue:e.value,newValue:b,target:k};if(f._trigger("rating",c,h)===false)return false;e.value=b;f._resetValue(b,e.ratingMode,e.icons.ratedIconsClass);g.removeClass(d);f._removeCustomizedIconsClass(e.icons.hoverIconsClass);h={value:b,target:k};if(i)if(l&&l[i])l[i](e,g,function(){f._trigger("rated",c,h)});else if(a.effects&&a.effects[i])f._playJqueryAnimation(m,g,function(){a.browser.msie&&a.browser.version<9&&g.css("filter","");f._trigger("rated",c,h)});else f._trigger("rated",c,h);else f._trigger("rated",c,h)}},k={element:f.ratingElement,mouseover:function(d){var b=a(d.target);b=b.closest("."+c);b.addClass(g);b.addClass(i);e.resetButton.customizedHoverClass&&e.resetButton.customizedHoverClass.length&&b.addClass(e.resetButton.customizedHoverClass)},mouseout:function(d){var b=a(d.target);b=b.closest("."+c);b.removeClass(g);b.removeClass(i);e.resetButton.customizedHoverClass&&e.resetButton.customizedHoverClass.length&&b.removeClass(e.resetButton.customizedHoverClass)},click:function(b){var c=a(b.target);f._setOption("value",0);h={target:c};f._trigger("reset",b,h)}};a(j,this.ratingElement[0]).live("mouseover.wijrating",a.proxy(l.mouseover,l)).live("mouseout.wijrating",a.proxy(l.mouseout,l)).live("click.wijrating",a.proxy(l.click,l));a(m,this.ratingElement[0]).live("mouseover.wijrating",a.proxy(k.mouseover,k)).live("mouseout.wijrating",a.proxy(k.mouseout,k)).live("click.wijrating",a.proxy(k.click,k))},_clearIntentTimer:function(){var b=this;b.intentTimers&&b.intentTimers.length&&a.each(b.intentTimers,function(b,a){if(a){window.clearTimeout(a);a=null}});b.intentTimers=[]},_playJqueryAnimation:function(b,c,e){var d=this,h=d.options,f={easing:b.easing},g=b.animated;d._clearIntentTimer();c.each(function(j,l){var k=Math.floor(j/h.split)*b.delay,i;i=window.setTimeout(function(){a(l).hide(g,f,b.duration,function(){if(j!==c.length-1)return;c.each(function(j,l){var k=Math.floor(j/h.split)*b.delay,i;i=window.setTimeout(function(){a(l).show(g,f,b.duration,function(){if(j===c.length-1)e&&a.isFunction(e)&&e.call(this)})},k);d.intentTimers.push(i)})})},k);d.intentTimers.push(i)})},_addCustomizedIconsClass:function(c,g){var h=this,f,e=0,d=0;if(c&&c.length){f=a("."+b,h.ratingElement[0]);f.each(function(f,b){if(e===g){e=0;d++}if(typeof c==="string")a(b).addClass(c);else if(a.isArray(c))d<c.length&&a(b).addClass(c[d]);e++})}},_addCustomizedHoverIconsClass:function(c,j,g){var l=this,m=l.options,i=m.direction,k=m.ratingMode,f=a("."+b,l.ratingElement[0]),h=f.index(g),e=0,d;if(c&&c.length)if(typeof c==="string"){g.addClass(c);if(k!=="single")if(i==="reversed")g.parent().nextAll().children().addClass(c);else g.parent().prevAll().children().addClass(c)}else if(a.isArray(c))if(k==="single"){if(i==="reversed")d=f.length-1-h;else d=h;e=Math.floor(d/j);c.length>e&&g.addClass(c[e])}else if(i==="reversed")for(d=f.length-1;d>=h;d--){e=Math.floor((f.length-1-d)/j);c.length>e&&a(f[d]).addClass(c[e])}else for(d=0;d<=h;d++){e=Math.floor(d/j);c.length>e&&a(f[d]).addClass(c[e])}},_removeCustomizedIconsClass:function(c){var e=this,d=a("."+b,e.ratingElement[0]);if(c&&c.length)if(typeof c==="string")d.removeClass(c);else a.isArray(c)&&a.each(c,function(b,a){d.removeClass(a)})},_resetValue:function(j,l,c){var k=this,g=k.options,i=a("."+b,k.ratingElement[0]),m=l||g.ratingMode,h=c&&c.length,f=0,d;i.each(function(k,n){var b=a(n),l=parseFloat(b.html());b.removeClass(e);b.parent().attr("aria-checked",false);if(h)if(typeof c==="string"){b.removeClass(c);d=c}else if(a.isArray(c)){a.each(c,function(c,a){b.removeClass(a)});if(g.direction==="reversed")f=Math.floor((i.length-1-k)/g.split);else f=Math.floor(k/g.split);if(c.length>f)d=c[f]}if(l===j){b.addClass(e);h&&b.addClass(d);b.parent().attr("aria-checked",true)}else if(m==="continuous")if(l<j){b.addClass(e);h&&b.addClass(d)}})},_resetTotalValue:function(l){var j=this,g=j.options,d=g.hint,i=a("."+b,j.ratingElement[0]),h=i.length,e,k,f,c=0;for(c;c<h;c++){f=Math.round((c+1)*l*100/h)/100;e=a(i[c]);k=parseFloat(e.html());if(k===g.value)g.value=f;e.html(f);if(d&&d.length&&d.length>=c&&d[c]&&d[c].length)e.attr("title",d[c]);else e.attr("title",f)}},_resetHint:function(d){var h=this,f=a("."+b,h.ratingElement[0]),e,g,c=0;for(c;c<f.length;c++){e=a(f[c]);g=parseFloat(e.html());if(d&&d.length&&d.length>=c&&d[c]&&d[c].length)e.attr("title",d[c]);else e.attr("title",g)}},_createRating:function(){var m=this,g=m.ratingElement,d=m.options,b,i,e;g.addClass(j+" ui-widget");d.orientation==="vertical"&&g.addClass(f);b=a("<div></div>");b.addClass(c);b.addClass(l);b.addClass(k);d.resetButton.customizedClass&&d.resetButton.customizedClass.length&&b.addClass(d.resetButton.customizedClass);b.appendTo(g);b.attr("role","button");b.attr("aria-label","reset");b.attr("aria-hidden",false);d.resetButton.hint&&d.resetButton.hint.length&&b.attr("title",d.resetButton.hint);if(d.resetButton.disabled||d.disabled){b.hide();b.attr("aria-hidden",true)}i=a("<span></span>");i.addClass("ui-icon ui-icon-close");b.append(i);e=a("<div></div>");e.attr("role","radiogroup");e.addClass(h);if(d.resetButton.position==="leftOrTop")e.appendTo(g);else e.prependTo(g);m._createStars(d.split,d.count,e)},_createStars:function(g,s,q){var u=this,c=u.options,k=c.hint,d,f,l,i=0,h=0,t=Math.ceil(c.iconWidth/g),r=Math.ceil(c.iconHeight/g),j=c.icons.ratedIconsClass,o,n,p=j&&j.length;q.empty();for(i;i<s*g;i++,h++){l=Math.round((i+1)*c.totalValue*100/s/g)/100;if(h===g)h=0;f=a("<div></div>");f.attr("role","radio");f.attr("aria-checked",false);if(c.orientation==="vertical"){f.width(c.iconWidth);f.height(r)}else{f.width(t);f.height(c.iconHeight)}f.addClass(m);d=a("<div>"+l+"</div>");d.addClass(b);d.width(c.iconWidth);d.height(c.iconHeight);f.attr("aria-label",l);if(h>0&&c.direction==="normal")if(c.orientation==="vertical")d.css({"margin-top":"-"+h*r+"px"});else d.css({"margin-left":"-"+h*t+"px"});else if(h<g-1&&c.direction==="reversed")if(c.orientation==="vertical")d.css({"margin-top":"-"+(g-1-h)*r+"px"});else d.css({"margin-left":"-"+(g-1-h)*t+"px"});if(!k.disabled)if(k.content&&k.content.length){if(i<=k.content.length){d.attr("title",k.content[i]);f.attr("aria-label",k.content[i])}}else d.attr("title",l);if(p)if(typeof j==="string")n=j;else if(a.isArray(j)){if(c.direction==="reversed")o=Math.floor((s*g-1-i)/g);else o=Math.floor(i/g);if(j.length>o)n=j[o]}if(l===c.value){d.addClass(e);p&&d.addClass(n);f.attr("aria-checked",true)}else if(l<c.value&&c.ratingMode==="continuous"){d.addClass(e);p&&d.addClass(n)}d.appendTo(f);if(c.direction==="reversed")f.prependTo(q);else f.appendTo(q)}u._addCustomizedIconsClass(c.icons.iconsClass,g)},_parseRadio:function(){var e=this,d=e.options,b=[],c=a("input:[type='radio']",e.element);if(c.length){d.count=c.length;d.totalValue=c.length;c.each(function(i,h){var g=a(h),c=g.attr("id"),f;if(c&&c.length>0){f=a("label:[for='"+c+"']",e.element);if(f.length)b.push(f.html());else b.push("")}else b.push("");if(g.is(":checked"))d.value=i+1});d.hint.content=b}},_parseSelect:function(){var e=this,c=e.options,d=[],b=a("option",e.element);if(b.length){c.count=b.length;c.totalValue=b.length;b.each(function(e,f){var b=a(f);d.push(b.html());if(b.is(":selected"))c.value=e+1});c.hint.content=d}}});a.extend(a.wijmo.wijrating,{animations:{scroll:function(i,c,b){var e=i,d=b,g=250,j=500,f=250,h=jQuery.makeArray(c);h.reverse();a.each(h,function(i,m){var l=Math.floor(i/e.split)*f,k={width:0},b,h;b=window.setTimeout(function(){a(m).animate(k,g,function(){window.clearTimeout(b);if(i!==c.length-1)return;h=window.setTimeout(function(){c.each(function(h,k){var j=Math.floor(h/e.split)*f,i={width:e.iconWidth},b;b=window.setTimeout(function(){a(k).animate(i,g,function(){window.clearTimeout(b);if(h===c.length-1)d&&a.isFunction(d)&&d.call(this)})},j)});window.clearTimeout(h)},j)})},l)});b&&a.isFunction(b)&&b.call(this)}}})})(jQuery);
(function(a){"use strict";if(!window.Raphael)return;a.widget("wijmo.wijscatterchart",a.wijmo.wijchartcore,{options:{animation:{enabled:true,duration:2e3,easing:">"},seriesTransition:{enabled:true,duration:2e3,easing:">"},zoomOnHover:true,mouseDown:null,mouseUp:null,mouseOver:null,mouseOut:null,mouseMove:null,click:null},_create:function(){var b=this;a.wijmo.wijchartcore.prototype._create.apply(b,arguments);b.chartElement.addClass("wijmo-wijscatterchart")},destroy:function(){var b=this;b.chartElement.removeClass("wijmo-wijscatterchart");a.wijmo.wijchartcore.prototype.destroy.apply(b,arguments)},getScatter:function(e,d){var h=this,f=h.chartElement.data("fields"),g,c,a,b;if(f&&f.chartElements){a=f.chartElements.scatters;if(a&&a.length){c=a.length;if(e<0||e>=c)return g;b=a[e];if(typeof d==="undefined")return b;c=b.length;if(b&&c)return d<0||d>=c?g:b[d]}return g}},_paintLegend:function(){var b=this,c=b.options,d=[].concat(c.seriesList),e=c.seriesStyles,f=0;a.extend(true,c,{legend:{size:{width:20,height:10}}});a.wijmo.wijchartcore.prototype._paintLegend.apply(b,arguments);if(c.legend.visible){b.legends.length&&b.legendIcons.length&&a.each(b.legendIcons,function(b,a){a.hide()});c.legend.reversed&&d.reverse();a.each(d,function(m,j){var k=j.markerType,l,h,n,o,p=c.legend.reversed?e[d.length-1-m]:e[m],g=a.extend(true,{},p),i;if(g.stroke&&!g.fill)g.fill=g.stroke;if(j.legendEntry&&j.display!=="exclude"){l=b.legendIcons[f];h=l.wijGetBBox();n=h.x+h.width/2;o=h.y+h.height/2;if(!k)k="circle";i=b.canvas.paintMarker(k,n,o,3);a.wijraphael.addClass(a(i.node),"wijchart-legend-dot wijchart-canvas-object wijchart-legend");i.attr(g);b.legendDots.push(i);b.legendEles.push(i);f++}})}},_showSerieEles:function(b){a.each(b,function(b,a){a.show()})},_hideSerieEles:function(b){a.each(b,function(b,a){a.hide()})},_paintTooltip:function(){var c=this,d=c.chartElement,b=d.data("fields");a.wijmo.wijchartcore.prototype._paintTooltip.apply(this,arguments);if(c.tooltip)if(b&&b.chartElements&&b.chartElements.tooltipTars){c.tooltip.setTargets(b.chartElements.tooltipTars);c.tooltip.setOptions({mouseTrailing:false})}},_getTooltipText:function(d,c){var b=a(c).data("wijchartDataObj"),e={data:b,label:b.label,x:b.x,y:b.y,type:b.markerType,target:c,fmt:d};return a.proxy(d,e)()},_onBeforeTooltipShowing:function(c){var e=this,d=c.options,b=c.target;if(b){d.style.stroke=b.getAttribute("stroke")||b.getAttribute("fill")||"#ffffff";b.attrs={stroke:d.style.stroke}}a.wijmo.wijchartcore.prototype._onBeforeTooltipShowing.apply(e,arguments)},_clearChartElement:function(){var b=this,c=b.chartElement.data("fields");if(b.headerEles.length){a.each(b.headerEles,function(b,a){a.wijRemove();a=null});b.headerEles=[]}if(b.footerEles.length){a.each(b.footerEles,function(b,a){a.wijRemove();a=null});b.footerEles=[]}if(b.legendEles.length){a.each(b.legendEles,function(b,a){a.wijRemove();a=null});b.legendEles=[]}if(b.legends.length){a.each(b.legends,function(b,a){a.wijRemove();a=null});b.legends=[]}if(b.legendIcons.length){a.each(b.legendIcons,function(b,a){a.wijRemove();a=null});b.legendIcons=[]}if(b.legendDots.length){a.each(b.legendDots,function(b,a){a=null});b.legendDots=[]}if(b.axisEles.length){a.each(b.axisEles,function(b,a){a.wijRemove();a=null});b.axisEles=[]}if(b.chartLabelEles.length){a.each(b.chartLabelEles,function(b,a){a.wijRemove();a=null});b.chartLabelEles=[]}if(c&&c.chartElements){a.each(c.chartElements,function(c,b){b.length&&a.each(b,function(b,a){if(a[0]!==null){a.remove&&a.remove();a=null}});b=[]});c.chartElements=[]}b.canvas.clear();b.innerState={}},_paintPlotArea:function(){var b=this,c=b.options;b.chartElement.wijscatter({bounds:b.canvasBounds,widgetName:b.widgetName,canvas:b.canvas,tooltip:b.tooltip,axis:c.axis,animation:c.animation,seriesTransition:c.seriesTransition,seriesList:c.seriesList,seriesStyles:c.seriesStyles,seriesHoverStyles:c.seriesHoverStyles,hint:c.hint,isXTime:b.axisInfo.x.isTime,isYTime:b.axisInfo.y[0].isTime,zoomOnHover:c.zoomOnHover,mouseDown:a.proxy(b._mouseDown,b),mouseUp:a.proxy(b._mouseUp,b),mouseOver:a.proxy(b._mouseOver,b),mouseOut:a.proxy(b._mouseOut,b),mouseMove:a.proxy(b._mouseMove,b),click:a.proxy(b._click,b)})}})})(jQuery);(function(a){"use strict";if(!window.Raphael)return;a.fn.extend({wijscatter:function(c){var b=this,f=c.bounds,z=f.endX-f.startX,x=f.endY-f.startY,C=c.axis.x.min,D=c.axis.y.min,A=c.axis.x.max,B=c.axis.y.max,i={minX:C,minY:D,maxX:A,maxY:B,width:z,height:x,kx:z/(A-C),ky:x/(B-D)},e=c.widgetName,M=c.canvas,j=c.animation,L=c.seriesTransition,I=c.seriesList,k=c.seriesStyles,J=c.isXTime,K=c.isYTime,m=c.zoomOnHover,p=c.mouseDown,w=c.mouseUp,r=c.mouseOver,s=c.mouseOut,q=c.mouseMove,y=c.click,H=M.set(),t=[],l=[],o,g=b.data("fields")||{},v=b.css("background-color"),n=[],u=a.toOADate,h,d,E;if(b.find("svg").length>0)h=new a.chartRender(b.find("svg").get(0),b.width(),b.height());else h=new a.chartRender(b.children(":first").addClass("vmlcontainer").get(0),b.width(),b.height());d=h.clipRect(0,0,0,b.height());E=h.g().clip(d).add();function G(){var c=a.isFunction;a(".wijscatterchart",b[0]).live("mousedown."+e,function(e){if(c(p)){var d=a(e.target).data("wijchartDataObj");if(!d)d=a(e.target.parentNode).data("wijchartDataObj");p.call(b,e,d)}}).live("mouseup."+e,function(e){if(c(w)){var d=a(e.target).data("wijchartDataObj");if(!d)d=a(e.target.parentNode).data("wijchartDataObj");w.call(b,e,d)}}).live("mouseover."+e,function(f){var d=a(f.target).data("wijchartDataObj"),g,h,e;if(!d)d=a(f.target.parentNode).data("wijchartDataObj");e=d.dot;if(m){g=d.seriesIndex;e.attr&&e.attr(h);if(document.createElementNS)e.scale(1.5,1.5);else e.attr("stroke-width",5)}c(r)&&r.call(b,f,d)}).live("mouseout."+e,function(f){var d=a(f.target).data("wijchartDataObj"),g,e;if(!d)d=a(f.target.parentNode).data("wijchartDataObj");e=d.dot;if(m){g=d.seriesIndex;e.attr&&e.attr(k[g])}document.createElementNS&&e.scale(1,1);c(s)&&s.call(b,f,d)}).live("mousemove."+e,function(e){if(c(q)){var d=a(e.target).data("wijchartDataObj");if(!d)d=a(e.target.parentNode).data("wijchartDataObj");q.call(b,e,d)}}).live("click."+e,function(e){if(c(y)){var d=a(e.target).data("wijchartDataObj");if(!d)d=a(e.target.parentNode).data("wijchartDataObj");y.call(b,e,d)}})}function F(){a(".wijscatterchart",b).die(e).die("."+e)}a.each(I,function(p,c){var o=c.data,d,q=c.markerWidth||5,b=k[p],j=o.x,m=o.y,g=[],e=[];c=a.extend(true,{visible:true,markerType:"circle"},c);d=c.markerType;if(c.display==="exclude")return true;if(!b.fill&&b.stroke)b.fill=b.stroke;a.each(m,function(r,s){var o=j[r],v=0,w=0,t,n,k={};if(J)o=u(o);if(K)s=u(s);if(typeof o==="undefined")return false;if(isNaN(o)||typeof o==="string")t=r;else t=o;v=f.startX+(t-i.minX)*i.kx;w=f.endY-(s-i.minY)*i.ky;if(b.opacity){b["fill-opacity"]=b.opacity;b["stroke-opacity"]=b.opacity;delete b.opacity}if(d==="cross"&&b["stroke-width"]!==undefined&&b["stroke-width"]===0)b["stroke-width"]=1;n=h.symbol(d,v,w,q).attr(b).add(E);n.attr({"class":"wijchart-canvas-object wijscatterchart"});k.dot=n;k.x=j[r];k.y=m[r];k.seriesIndex=p;k.index=r;k.markerType=d;k.label=c.label;k.series=c;k.data=c.data;k.type="scatter";a(n.element).data("wijchartDataObj",k);g.push(n);l.push(a.extend({},n,{node:n.element}));e.push(n)});t.push(g);n.push(e)});if(j.enabled||L.enabled){if(v==="transparent")v="white";if(d.getCSS)a(d.members[0].element).animate({width:b.width()},{duration:j.duration,step:function(c){d.width=c;var b=d.getCSS();a(this).css(b)}});else a(d.element).animate({width:b.width()},{duration:j.duration,step:function(a){d.attr("width",a)}})}else if(d.getCSS){a(d.members[0].element).css({width:b.width()});d.width=b.width();a(d.members[0].element).css(d.getCSS())}else{a(d.element).css({width:b.width()});d.attr("width",b.width())}F();G();o={animationSet:H,tooltipTars:l,scatters:t};if(!g.chartElements)g.chartElements={};g.seriesEles=n;a.extend(true,g.chartElements,o);b.data("fields",g)}})})(jQuery);(function(a){var c=document,z=a.each,t=a.browser.msie,g=c.documentMode===8,s="http://www.w3.org/2000/svg",y=!!c.createElementNS&&!!c.createElementNS(s,"svg").createSVGRect,B=0,f="div",w="absolute",m="hidden",n="scatterchart-",r="visible",p="visibility",v="px",u="none",e="M",b="L",k,o,q;function h(a){return typeof a==="string"}function x(a){return typeof a==="number"}function d(a){return a!==undefined&&a!==null}function i(c,b,f){var e="setAttribute",g;if(h(b)){if(d(f))c[e](b,f);else if(c&&c.getAttribute)g=c.getAttribute(b)}else d(b)&&a.isPlainObject(b)&&a.each(b,function(a,b){c[e](a,b)});return g}function j(c,b){if(t)if(b&&b.opacity!==undefined)b.filter="alpha(opacity="+b.opacity*100+")";a.extend(c.style,b)}function A(f,d,e){var b=c.createElement(f);d&&a.extend(b,d);e&&j(b,e);return b}function l(){}l.prototype={init:function(b,a){this.element=c.createElementNS(s,a);this.renderer=b},attr:function(c,l){var e,b,g=this.element,j=g.nodeName,k,f=this;if(c===undefined)return;if(h(c)&&d(l)){e=c;c={};c[e]=l}if(h(c)){e=c;if(j==="circle")e=({x:"cx",y:"cy"})[e]||e;f=i(g,e)||this[e]||0;if(e!=="d"&&e!==p)f=parseFloat(f)}else c&&a.each(c,function(a){k=false;b=c[a];if(a==="d"){if(b&&b.join)b=b.join(" ");if(/(NaN| {2}|^$)/.test(b))b="M 0 0";this.d=b}else if(j==="circle"&&(a==="x"||a==="y"))a=({x:"cx",y:"cy"})[a]||a;if(jQuery.browser.safari&&a==="stroke-width"&&b===0)b=1e-6;!k&&i(g,a,b)});return f},scale:function(e,f){var b=this,a=b.getBBox(),c=-(a.x+a.width/2)/2,d=-(a.y+a.height/2)/2;if(e===1)c=0;if(f===1)d=0;b.attr("transform","matrix("+e+",0,0, "+f+","+c+","+d+")")},symbolAttr:function(b){var a=this;z(["x","y","r","start","end","width","height","innerR"],function(d,c){if(b[c])a[c]=b[c];else a[c]=a[c]});a.attr({d:a.renderer.symbols[a.symbolName](Math.round(a.x*2)/2,Math.round(a.y*2)/2,a.r,{start:a.start,end:a.end,width:a.width,height:a.height,innerR:a.innerR})})},clip:function(a){return this.attr("clip-path","url("+this.renderer.url+"#"+a.id+")")},crisp:function(e,i,j,h,g){var b=this,c,f={},a={},d;e=e||b.strokeWidth||0;d=e%2/2;a.x=Math.floor(i||b.x||0)+d;a.y=Math.floor(j||b.y||0)+d;a.width=Math.floor((h||b.width||0)-2*d);a.height=Math.floor((g||b.height||0)-2*d);a.strokeWidth=e;for(c in a)if(b[c]!==a[c])b[c]=f[c]=a[c];return f},css:function(b){var c=this,g=c.element,f=b&&b.width&&g.nodeName==="text",d="",e=function(b,a){return"-"+a.toLowerCase()};if(b&&b.color)b.fill=b.color;b=a.extend(c.styles,b);c.styles=b;if(t&&!y){if(f)delete b.width;j(c.element,b)}else{a.each(b,function(c,a){d+=a.replace(/([A-Z])/g,e)+":"+b[a]+";"});c.attr({style:d})}return c},getBBox:function(){var b,e,d,f=this.rotation,c=f*Math.PI/180;try{b=a.extend({},this.element.getBBox())}catch(g){b={width:0,height:0}}e=b.width;d=b.height;if(f){b.width=Math.abs(d*Math.sin(c))+Math.abs(e*Math.cos(c));b.height=Math.abs(d*Math.cos(c))+Math.abs(e*Math.sin(c))}return b},show:function(){return this.attr({visibility:r})},hide:function(){return this.attr({visibility:m})},add:function(b){var a=this,m=a.renderer,h=b||m,k=h.element||m.box,l=k.childNodes,f=a.element,c=i(f,"zIndex"),e,j,g;if(b&&a.htmlNode){if(!b.htmlNode)b.htmlNode=[];b.htmlNode.push(a)}if(c){h.handleZ=true;c=parseInt(c,10)}if(h.handleZ)for(g=0;g<l.length;g++){e=l[g];j=i(e,"zIndex");if(e!==f&&(parseInt(j,10)>c||!d(c)&&d(j))){k.insertBefore(f,e);return a}}k.appendChild(f);a.added=true;return a},empty:function(){var b=this.element,a=b.childNodes,c=a.length;while(c--)b.removeChild(a[c])},remove:function(){var a=this.element,b=a.parentNode;b.removeChild(a)}};k=function(){this.init.apply(this,arguments)};k.prototype={Element:l,init:function(e,g,f){var b=this,h=c.location,d;if(a(e).is("svg")){b.box=e;d=new b.Element;d.element=e;d.render=b;b.defs=a("defs",e).get(0)}else{d=b.createElement("svg").attr({xmlns:s,version:"1.1"});e.appendChild(d.element);b.box=d.element;b.boxWrapper=d;b.defs=this.createElement("defs").add();b.setSize(g,f)}b.url=t?"":h.href.replace(/#.*?$/,"")},destroy:function(){var a=this;a.box=null;a.boxWrapper=a.boxWrapper.destroy();return null},createElement:function(b){var a=new this.Element;a.init(this,b);return a},path:function(a){return this.createElement("path").attr({d:a,fill:u})},circle:function(b,e,d){var c=a.isPlainObject(b)?b:{x:b,y:e,r:d};return this.createElement("circle").attr(c)},rect:function(b,h,g,f,c,d){if(a.isPlainObject(b)){h=b.y;g=b.width;f=b.height;c=b.r;d=b.strokeWidth;b=b.x}var e=this.createElement("rect").attr({rx:c,ry:c,fill:u});return e.attr(e.crisp(d,b,h,Math.max(g,0),Math.max(f,0)))},setSize:function(c,b){var a=this;a.width=c;a.height=b;a.boxWrapper.attr({width:c,height:b})},g:function(b){var a=this.createElement("g");return d(b)?a.attr({"class":n+b}):a},symbol:function(i,f,g,d,c){var b,e=this,h=e.symbols[i],j=h&&h(Math.round(f),Math.round(g),d,c);if(j){b=e.path(j);a.extend(b,{symbolName:i,x:f,y:g,r:d});c&&a.extend(b,c)}else b=e.circle(f,g,d);return b},symbols:{box:function(c,d,f){var a=.707*f;return[e,c-a,d-a,b,c+a,d-a,c+a,d+a,c-a,d+a,"Z"]},tri:function(c,d,a){return[e,c,d-1.33*a,b,c+a,d+.67*a,c-a,d+.67*a,"Z"]},invertedTri:function(c,d,a){return[e,c,d+1.33*a,b,c-a,d-.67*a,c+a,d-.67*a,"Z"]},diamond:function(c,d,a){return[e,c,d-a,b,c+a,d,c,d+a,c-a,d,"Z"]},cross:function(c,d,f){var a=.707*f;return[e,c-a,d-a,b,c+a,d+a,e,c-a,d+a,b,c+a,d-a]},arc:function(f,g,c,d){var h=d.start,n=d.end-1e-6,a=d.innerR,i=Math.cos(h),j=Math.sin(h),l=Math.cos(n),m=Math.sin(n),k=d.end-h<Math.PI?0:1;return[e,f+c*i,g+c*j,"A",c,c,0,k,1,f+c*l,g+c*m,b,f+a*l,g+a*m,"A",a,a,0,k,0,f+a*i,g+a*j,"Z"]}},clipRect:function(g,h,f,e){var b,d=n+B++,c=this.createElement("clipPath").attr({id:d});a(this.defs).append(c.element);b=this.rect(g,h,f,e,0).add(c);b.id=d;b.clipPath=c;return b}};a.chartRender=k;if(!y){q=function(){};q.prototype=a.extend(true,{},l.prototype,{init:function(d,a){var b=["<",a,' filled="f" stroked="f"'],c=["position: ",w,";"];(a==="shape"||a===f)&&c.push("left:0;top:0;width:10px;height:10px;");g&&c.push("visibility: ",a===f?m:r);b.push(' style="',c.join(""),'"/>');if(a){b=a===f||a==="span"||a==="img"?b.join(""):d.prepVML(b);this.element=A(b)}this.renderer=d},add:function(a){var b=this,e=b.renderer,d=b.element,h=e.box,f=a&&a.inverted,c=a?a.element||a:h;f&&e.invertChild(d,c);g&&c.gVis===m&&j(d,{visibility:m});c.appendChild(d);b.added=true;return b},attr:function(k,A){var m,b,c,l=this,e=l.element||{},y=e.style,z=e.nodeName,B=l.symbolName,s,w,t=l.shadows,o,n,q=l;if(k===undefined)return q;if(h(k)&&d(A)){m=k;k={};k[m]=A}if(h(k)){m=k;if(m==="strokeWidth"||m==="stroke-width")q=l.strokeweight;else q=l[m]}else k&&a.each(k,function(a,d){b=d;o=false;if(B&&/^(x|y|r|start|end|width|height|innerR)/.test(a)){if(!w){l.symbolAttr(k);w=true}o=true}else if(a==="d"){b=b||[];l.d=b.join(" ");c=b.length;n=[];while(c--)if(x(b[c]))n[c]=Math.round(b[c]*10)-5;else if(b[c]==="Z")n[c]="x";else n[c]=b[c];b=n.join(" ")||"x";e.path=b;if(t){c=t.length;while(c--)t[c].path=b}o=true}else if(a==="zIndex"||a===p){if(g&&a===p&&z===f){e.gVis=b;s=e.childNodes;c=s.length;while(c--)j(s[c],{visibility:b});if(b===r)b=null}if(b)y[a]=b;o=true}else if(a==="class")e.className=b;else if(a==="stroke")a="strokecolor";else if(a==="stroke-width"||a==="strokeWidth"){e.stroked=b?true:false;a="strokeweight";l[a]=b;if(x(b))b+=v}else if(a==="fill")if(z==="SPAN")y.color=b;else{e.filled=b!==u?true:false;a="fillcolor"}if(!o)if(g)e[a]=b;else i(e,a,b)});return q},scale:function(c,d){var a=this,b=a.attr("stroke-width")||0;a.css({filter:"progid:DXImageTransform.Microsoft.Matrix(M11="+c+",, M12=0, M21=0, M22="+d+", Dx=0, Dy=0, sizingmethod='auto expand')"}).attr("stroke-width",b)},clip:function(b){var a=this,c=b.members;c.push(a);return a.css(b.getCSS(a.inverted))},css:function(c){var b=this,e=b.element,d=c&&e.tagName==="SPAN"&&c.width;if(d){delete c.width;b.textWidth=d}b.styles=a.extend(b.styles,c);j(b.element,c);return b},destroy:function(){var a=this;a.destroyClip&&a.destroyClip();return l.prototype.destroy.apply(a)},empty:function(){var d=this.element,b=d.childNodes,c=b.length,a;while(c--){a=b[c];a.parentNode.removeChild(a)}},getBBox:function(){var c=this,a=c.element,b=c.bBox;if(!b){if(a.nodeName==="text")a.style.position=w;b=c.bBox={x:a.offsetLeft,y:a.offsetTop,width:a.offsetWidth,height:a.offsetHeight}}return b}});o=function(){this.init.apply(this,arguments)};o.prototype=a.extend(true,{},k.prototype,{Element:q,isIE8:a.browser.msie&&a.browser.version===8,init:function(e,h,g){var d=this,b;if(a(e).hasClass("vmlcontainer")){d.box=e;b=new this.Element;b.element=e;b.render=this;d.boxWrapper=b}else{b=d.createElement(f);e.appendChild(b.element);d.box=b.element;d.boxWrapper=b;d.setSize(h,g)}if(!c.namespaces.v){c.namespaces.add("v","urn:schemas-microsoft-com:vml");c.createStyleSheet().cssText="v\\:fill, v\\:path, v\\:shape, v\\:stroke{ behavior:url(#default#VML); display: inline-block; } "}},clipRect:function(e,f,d,c){var b=this.createElement();return a.extend(b,{members:[],left:e,top:f,width:d,height:c,getCSS:function(b){var c=this,h=c.top,f=c.left,e=f+c.width,d=h+c.height,i={clip:"rect("+Math.round(b?f:h)+"px,"+Math.round(b?d:e)+"px,"+Math.round(b?e:d)+"px,"+Math.round(b?h:f)+"px)"};!b&&g&&a.extend(i,{width:e+v,height:d+v});return i},updateClipping:function(){z(b.members,function(c,a){a.css(b.getCSS(a.inverted))})}})},prepVML:function(a){var b="display:inline-block;behavior:url(#default#VML);",c=this.isIE8;a=a.join("");if(c){a=a.replace("/>",' xmlns="urn:schemas-microsoft-com:vml" />');if(a.indexOf('style="')===-1)a=a.replace("/>",' style="'+b+'" />');else a=a.replace('style="','style="'+b)}else a=a.replace("<","<v:");return a},path:function(a){return this.createElement("shape").attr({coordsize:"100 100",d:a})},g:function(a){var c,b;if(a)b={className:n+a,"class":n+a};c=this.createElement(f).attr(b);return c},symbols:{arc:function(c,d,b,h){var e=h.start,f=h.end,k=Math.cos(e),l=Math.sin(e),g=Math.cos(f),m=Math.sin(f),a=h.innerR,i=.07/b,j=a&&.1/a||0;if(f-e===0)return["x"];else if(2*Math.PI-f+e<i)g=-i;else if(f-e<j)g=Math.cos(e+j);return["wa",c-b,d-b,c+b,d+b,c+b*k,d+b*l,c+b*g,d+b*m,"at",c-a,d-a,c+a,d+a,c+a*g,d+a*m,c+a*k,d+a*l,"x","e"]},circle:function(b,c,a){return["wa",b-a,c-a,b+a,c+a,b+a,c,b+a,c,"e"]},rect:function(c,f,a,i){if(!d(i))return[];var k=i.width,j=i.height,h=c+k,g=f+j;a=Math.min(a,k,j);return[e,c+a,f,b,h-a,f,"wa",h-2*a,f,h,f+2*a,h-a,f,h,f+a,b,h,g-a,"wa",h-2*a,g-2*a,h,g,h,g-a,h-a,g,b,c+a,g,"wa",c,g-2*a,c+2*a,g,c+a,g,c,g-a,b,c,f+a,"wa",c,f,c+2*a,f+2*a,c,f+a,c+a,f,"x","e"]}}});a.chartRender=o}})(jQuery);
(function(a){"use strict";var d=1e4,e=0,c=0,b=0;a.widget("wijmo.wijbubblechart",a.wijmo.wijchartcore,{options:{minimumSize:5,maximumSize:20,sizingMethod:"diameter",animation:{enabled:true,duration:1e3,easing:">"},seriesTransition:{enabled:true,duration:400,easing:">"},seriesList:[],seriesHoverStyles:[{opacity:1,"stroke-width":5},{opacity:1,"stroke-width":5},{opacity:1,"stroke-width":5},{opacity:1,"stroke-width":5},{opacity:1,"stroke-width":5},{opacity:1,"stroke-width":5},{opacity:1,"stroke-width":5},{opacity:1,"stroke-width":5},{opacity:1,"stroke-width":5},{opacity:1,"stroke-width":5},{opacity:1,"stroke-width":5},{opacity:1,"stroke-width":5}],chartLabel:{position:"inside",compass:"north",visible:true,style:{},chartLabelFormatString:""},mouseDown:null,mouseUp:null,mouseOver:null,mouseOut:null,mouseMove:null,click:null},_setOption:function(e,b){var c=this,f=c.options;if(e==="minimumSize"||e==="minimumSize"){if(isNaN(b)||b<0)b=0;else if(b>d)b=d;f[e]=b;c.redraw()}else if(e==="chartLabel"){a.extend(f.chartLabel,b);c.redraw()}else a.wijmo.wijchartcore.prototype._setOption.apply(c,arguments);if(e==="seriesList"){c.indexs=null;c.bubbleRadius=null}},_create:function(){var b=this,d=b.options,c=b._getDefFill();a.each(d.seriesStyles,function(b,a){if(!a.fill)a.fill=c[b]});b._setLabelOption();a.wijmo.wijchartcore.prototype._create.apply(b,arguments);b.chartElement.addClass("wijmo-wijbubblechart")},_setLabelOption:function(){var b=this.options;if(b.showChartLabels!==true&&b.chartLabel.visible===true)b.chartLabel.visible=false;if(!a.isPlainObject(b.chartLabel.style)&&a.isPlainObject(b.chartLabelStyle))b.chartLabel.style=b.chartLabelStyle},destroy:function(){var b=this;b.chartElement.removeClass("wijmo-wijbubblechart ui-helper-reset");b._destroyEles();a.wijmo.wijchartcore.prototype.destroy.apply(b,arguments)},_destroyEles:function(){var b=this,d=b.element,c=d.data("fields");c.bubbleInfos&&a.each(c.bubbleInfos,function(c,a){b._removeEle(a.bubble);b._removeEle(a.dcl);b._removeEle(a.symbol);a=null});d.removeData("fields");b.bubbleRadius=[]},_removeEle:function(b){if(b){b.node&&a(b.node).removeData();b.wijRemove();b=null}},_paintPlotArea:function(){var b=this,f=this.element,c=b.options,e=c.seriesList,d=e.length,i=[].concat(c.seriesStyles.slice(0,d)),g=[].concat(c.seriesHoverStyles.slice(0,d)),h=b.canvasBounds,j=b.axisInfo.x,k=b.axisInfo.y[0];if(d===0)return;b._prepBubbleData();f.wijbubble({seriesList:e,seriesStyles:i,seriesHoverStyles:g,canvas:b.canvas,bounds:h,xAxisInfo:j,yAxisInfo:k,chartLabel:c.chartLabel,textStyle:c.textStyle,chartLabelStyle:c.chartLabelStyle,chartLabelFormatString:c.chartLabelFormatString,bubbleRadius:b.bubbleRadius,animation:c.animation,seriesTransition:c.seriesTransition,sizingMethod:c.sizingMethod,minimumSize:c.minimumSize,maximumSize:c.maximumSize,mouseDown:a.proxy(b._mouseDown,b),mouseUp:a.proxy(b._mouseUp,b),mouseOver:a.proxy(b._mouseOver,b),mouseOut:a.proxy(b._mouseOut,b),mouseMove:a.proxy(b._mouseMove,b),click:a.proxy(b._click,b),disabled:c.disabled});b.tooltipbubbles=[];a.each(f.data("fields").bubbleInfos,function(c,a){b.tooltipbubbles.push(a.bubble);a.dcl&&b.tooltipbubbles.push(a.dcl);a.symbol&&b.tooltipbubbles.push(a.symbol)});b.tooltip&&b.tooltip.setTargets(b.tooltipbubbles)},_paintLegend:function(){var c=this,l=c.options,b=0,m=0,q=0,f=null,k=l.seriesList,p=l.seriesStyles,d=null,j=null,e=null,n=0,o=0,h=null,i=null,g=null;a.extend(true,l,{legend:{size:{width:30,height:3}}});a.wijmo.wijchartcore.prototype._paintLegend.apply(c,arguments);if(l.legend.visible){if(c.legends.length&&c.legendIcons.length)for(b=0,m=c.legendIcons.length;b<m;b++){f=c.legendIcons[b];f.attr({fill:f.attr("stroke")})}if(!l.legend.reversed)for(b=0,m=k.length;b<m;b++){d=k[b];j=p[b];if(d.legendEntry){if(d.markers)i=d.markers.type;f=c.legendIcons[b];e=f.wijGetBBox();n=e.x+e.width/2;o=e.y+e.height/2;h=d.markerStyle;h=a.extend({fill:j.stroke,stroke:j.stroke,opacity:1},h);if(!i)i="circle";g=c.canvas.paintMarker(i,n,o,7);a.wijraphael.addClass(a(g.node),"chart-legend-dot wijchart-canvas-object wijchart-legend");g.attr(h);a(g.node).data("index",b);f.remove();c.legendIcons[b]=g;q++}}else for(b=k.length-1;b>=0;b--){d=k[b];j=p[k.length-1-b];if(d.legendEntry){if(d.markers)i=d.markers.type;f=c.legendIcons[b];e=f.wijGetBBox();n=e.x+e.width/2;o=e.y+e.height/2;h=d.markerStyle;h=a.extend({fill:j.stroke,stroke:j.stroke,opacity:1},h);if(!i)i="circle";g=c.canvas.paintMarker(i,n,o,7);a.wijraphael.addClass(a(g.node),"chart-legend-dot");g.attr(h);f.remove();c.legendIcons[b]=g;q++}}}},_getbubbleIndexs:function(m,l){var d=this,e=d.options,o=e.axis.x.max,p=e.axis.x.min,t=e.axis.y.min,s=e.axis.y.max,q=[],u=[],n=[],r=[],f=[],g=[],i=-1,k=-1,h=-1,j=-1;d.bubbleRadius=[];d._prepBubbleData();a.each(e.seriesList,function(v,i){var h=i.data,k=i.markers||{},j=k.type||"circle";a.each(h.y1,function(k,x){var w=a.wijbubble.transform(x,e.maximumSize,e.minimumSize,d.canvasBounds,c,b,e.sizingMethod,j),v,i;if(d._isDate(h.x[k]))v=a.toOADate(h.x[k]);else if(isNaN(h.x[k]))v=k;else v=h.x[k];i=h.y[k];if(d._isDate(i))i=a.toOADate(i);q.push(v-w*(o-p)/m);u.push(i-w*(s-t)/l);n.push(v+w*(o-p)/m);r.push(i+w*(s-t)/l);f.push(v);g.push(i);d.bubbleRadius.push(w)})});i=d._getMinIndex(q);k=d._getMinIndex(u);h=d._getMaxIndex(n);j=d._getMaxIndex(r);d.indexs={xMin:{x:f[i],y:g[i],r:d.bubbleRadius[i]},xMax:{x:f[h],y:g[h],r:d.bubbleRadius[h]},yMin:{x:f[k],y:g[k],r:d.bubbleRadius[k]},yMax:{x:f[j],y:g[j],r:d.bubbleRadius[j]}}},_calculateParameters:function(c,b){a.wijmo.wijchartcore.prototype._calculateParameters.apply(this,arguments);var d=this;if(!b.autoMax&&!b.autoMin)return;d._adjust(b,c)},_adjust:function(e,b){var g=e.unitMinor,a=this,l=e.autoMin,k=e.autoMax,f=a.canvasBounds,j={x:f.startX,y:f.startY},i=f.endX-j.x,h=f.endY-j.y,c=b.max,d=b.min;!a.indexs&&a._getbubbleIndexs(i,h);if(b.id==="x"){if(l)d=a._getMinTick(a.indexs.xMin.x,a.indexs.xMin.r,d,c,i,g);if(k)c=a._getMaxTick(a.indexs.xMax.x,a.indexs.xMax.r,d,c,i,g)}else{if(l)d=a._getMinTick(a.indexs.yMin.y,a.indexs.yMin.r,d,c,h,g);if(k)c=a._getMaxTick(a.indexs.yMax.y,a.indexs.yMax.r,d,c,h,g)}if(c!==b.max||d!==b.min){b.min=d;b.max=c;this._calculateMajorMinor(e,b);a._adjust(e,b)}},_getMinTick:function(e,f,a,d,c,b){return(e-a)*c/(d-a)<f?a-b:a},_getMaxTick:function(e,f,c,a,b,d){return(e-c)*b/(a-c)+f>b?a+d:a},_getMinIndex:function(d){var c=-1,b=0;a.each(d,function(c,a){if(c===0)b=a;else if(a<b)b=a});a.each(d,function(a,d){if(d===b){c=a;return false}});return c},_getMaxIndex:function(d){var c=-1,b=0;a.each(d,function(c,a){if(c===0)b=a;else if(a>b)b=a});a.each(d,function(a,d){if(d===b){c=a;return false}});return c},_showSerieEles:function(b){a.each(b,function(b,a){if(a.bubble){a.bubble.show();a.bubble.tracker&&a.bubble.tracker.show()}a.dcl&&a.dcl.show();a.symbol&&a.symbol.show()})},_hideSerieEles:function(b){a.each(b,function(b,a){if(a.bubble){a.bubble.hide();a.bubble.tracker&&a.bubble.tracker.hide()}a.dcl&&a.dcl.hide();a.symbol&&a.symbol.hide()})},_parseTable:function(){if(!this.element.is("table"))return;var e=this,f=e.element,b=e.options,c=a("caption",f),m=a("thead th",f),g=[],n=a("tbody tr",f),l=null,k=null,i=[],j=[],h=[],d=function(b){var c=a.trim(b);if(!isNaN(b))c=parseFloat(b);return c};if(c.length){b.header=a.extend({visible:true,text:a.trim(a(c[0]).text())},b.header);if(c.length>1)b.footer=a.extend({visibel:true,text:a.trim(a(c[1]).text())},b.footer)}b.legend=a.extend({visible:true},b.legend);l=a.trim(m.eq(1).text());n.each(function(e,c){var b=a("td",c);if(b.length>=3){i.push(d(b.eq(0).text()));j.push(d(b.eq(1).text()));h.push(d(b.eq(2).text()))}});k={label:l,legendEntry:true,data:{x:i,y:j,y1:h}};g.push(k);e.options.seriesList=g},_unbindLiveEvents:function(){var b=this;a(".wijbubblechart-bubble",b.chartElement[0]).die(".wijbubblechart").die("wijbubblechart");if(b.tooltip){b.tooltip.destroy();b.tooltip=null}},_paintTooltip:function(){var c=this,b=c.element.data("fields");a.wijmo.wijchartcore.prototype._paintTooltip.apply(this,arguments);if(c.tooltip)if(b&&b.trackers&&b.trackers.length){c.tooltip.setTargets(b.trackers);c.tooltip.setOptions({relatedElement:b.trackers[0]})}},_getTooltipText:function(e,d){var c=a(d.node),b,f;if(c.data("owner"))c=c.data("owner");b=c.data("wijchartDataObj");f={data:b,value:b.value,label:b.label,total:b.total,target:d,fmt:e,x:b.x,y:b.y,y1:b.y1};return a.proxy(e,f)()},_prepBubbleData:function(){var i=this,h=i.options.seriesList,f=-999999999999,g=9999999999999,d;a.each(h,function(c,b){d=b.data;d&&d.y1&&a.each(d.y1,function(b,a){f=Math.max(f,a);g=Math.min(g,a)})});e=f;c=g;b=f-g},getBubble:function(a){return this.element.data("fields").bubbles[a]}});a.fn.extend({wijbubble:function(e){var l=this,d=e,f=l.data("fields")||{},n=0,g=d.bounds,h=d.canvas,C=d.seriesList,y=d.seriesStyles,t=d.seriesHoverStyles,H=d.xAxisInfo,I=d.yAxisInfo,j={x:g.startX,y:g.startY},O=g.endX-j.x,M=g.endY-j.y,i=d.chartLabel,p=[],q=[],E=d.mouseDown,L=d.mouseUp,G=d.mouseOver,K=d.mouseOut,F=d.mouseMove,N=d.click,o=[],J=d.disabled,k=h.set();function m(d,b){var a=d.bubble,e=d.symbol,c;if(a.type==="circle")a.attr({r:.0001,cx:b.startX,cy:b.endY});else{a.transform("s0.01");c=a.wijGetBBox();a.transform("t"+(b.startX-c.x)+","+(b.endY-c.y)+"s0.001")}e&&e.hide()}function w(){var b=d.animation,k=d.bounds,h=f.bubblesAnimationInfos,i=[],j=f.bubbleInfos,c=d.seriesTransition,e,g,l;if(b&&b.enabled){e=b.duration||400;g=b.easing;a.each(j,function(n,f){var a=f.bubble,j,b,d=a.wijGetBBox();if(a.type==="circle")j={r:a.attr("r"),cx:a.attr("cx"),cy:a.attr("cy")};else j={transform:"S1T0,0","stroke-width":a.attr("stroke-width"),width:d.width,x:d.x,y:d.y};if(h&&c.enabled){b=h[n];if(b){if(a.type==="circle")a.attr({cx:b.cx,cy:b.cy,r:b.r});else{d=a.wijGetBBox();l=b.width/d.width;a.transform("s"+l);d=a.wijGetBBox();a.transform("t"+(b.x-d.x)+","+(b.y-d.y)+"")}e=c.duration;g=c.easing}else m(f,k)}else m(f,k);i.push(j);a.wijAnimate(j,e,g,function(){f.dcl&&f.dcl.attr("opacity",1);f.symbol&&f.symbol.show()})});f.bubblesAnimationInfos=i}else a.each(j,function(b,a){a.dcl&&a.dcl.attr("opacity",1)})}function D(c,d){var b;a.each(c,function(a,c){if(a===d){b=c;return false}});return b}function u(c,d){var b=true;a.each(c,function(a){if(d===a){b=false;return false}});return b}function B(b,d,e,c){var a;if(h[b])a=h[b](d,e,c);return a}function z(d){var b=h.text(0,0,d),a=b.wijGetBBox(),c;c={width:a.width,height:a.height};b.remove();return c}function s(a,f){var d=e.chartLabel.compass||"north",b=z(f),c=a.r;switch(d){case"north":a.y-=c+b.height/2;break;case"south":a.y+=c+b.height/2;break;case"east":a.x+=c+b.width/2;break;case"west":a.x-=c+b.width/2}}function r(f,j){var g=a.extend(true,{},e.textStyle,e.chartLabelStyle,i.style),c=a.round(j,2),b=i.chartLabelFormatString===""?e.chartLabelFormatString:i.chartLabelFormatString,d;if(b&&b.length)c=Globalize.format(c,b);d=h.text(f.x,f.y,c).attr(g);return d}function A(j,x,v,l,m,G,F){var t=j.data,E=l.min,I=m.min,H=l.max,C=m.max,J=G/(H-E),K=F/(C-I),z=[],w=e.bubbleRadius,d,A,y;a.each(t.y1,function(I,Q){var L=t.x[I],R=t.y[I],V=j.markers||{},U=V.type||"circle",W=V.symbol,X=j.invisibleMarkLabels||[],T,S,H,p,O,P,G,N,F,M;if(w){F=w[n];n++}else F=a.wijbubble.transform(Q,e.maximumSize,e.minimumSize,e.bounds,c,b,e.sizingMethod,U);if(l.isTime)L=a.toOADate(L);else if(isNaN(L))L=I;if(m.isTime)R=a.toOADate(R);O=g.startX+(L-E)*J;P=g.startY+(C-R)*K;if(W)G=D(W,I);p=B(U,O,P,F);p.attr(x);if(G){A=G.width||F*2;y=G.height||F*2;N=h.image(G.url,O-F,P-F,A,y)}a.wijraphael.addClass(a(p.node),"wijchart-canvas-object wijbubblechart-bubble");G&&p.attr("opacity",.1);H=a.extend(true,{index:I,bubble:p,style:x,y1:Q,x:L,y:R,type:"bubble",hoverStyle:v},j);if(G){H.symbol=true;H.hoverStyle=a.extend({},v,{opacity:.1});a(N.node).data("wijchartDataObj",H);a.wijraphael.addClass(a(N.node),"wijbubblechart-symbol")}a(p.node).data("wijchartDataObj",H);M=p.clone().attr({opacity:.01,fill:"white","fill-opacity":.01});a(M.node).data("owner",a(p.node));a.wijraphael.addClass(a(M.node),"wijchart-canvas-object wijbubblechart-bubble bubbletracker");p.tracker=M;k.push(M);q.push(p);f.bubbles=q;T={x:O,y:P,r:F};if(i.visible&&u(X,I)){i.position==="outside"&&s(T,Q);d=r(T,Q);d.attr("opacity",0);a(d.node).data("wijchartDataObj",H);a.wijraphael.addClass(a(d.node),"wijbubblechart-label")}S={bubble:p,dcl:d,symbol:N};o.push(S);z.push(S)});f.bubbleInfos=o;p.push(z)}function x(){a.each(C,function(a,d){var c=y[a],b=t[a];A(d,c,b,H,I,O,M,j)})}function v(b,d,i,f,g,e,j,c){var h={mousedown:function(g){if(c)return;var e=a(g.target),f;if(e.data("owner"))e=e.data("owner");f=e.data("wijchartDataObj");d.call(b,g,f)},mouseup:function(f){if(c)return;var d=a(f.target),e;if(d.data("owner"))d=d.data("owner");e=d.data("wijchartDataObj");i.call(b,f,e)},mouseover:function(g){if(c)return;var d=a(g.target),e;if(d.data("owner"))d=d.data("owner");e=d.data("wijchartDataObj");f.call(b,g,e)},mouseout:function(h){if(c)return;var f=a(h.target),d,e;if(f.data("owner"))f=f.data("owner");d=f.data("wijchartDataObj");e=d.bubble;if(d.symbol)return;if(!d.hoverStyle)e&&e.attr({opacity:"1"});else{e.attr(d.style);d.style.opacity&&e.attr("opacity",d.style.opacity)}g.call(b,h,d)},mousemove:function(h){if(c)return;var g=a(h.target),d,f;if(g.data("owner"))g=g.data("owner");d=g.data("wijchartDataObj");f=d.bubble;if(!d.hoverStyle)f&&f.attr({opacity:"0.8"});else f.attr(d.hoverStyle);e.call(b,h,d)},click:function(f){if(c)return;var d=a(f.target),e;if(d.data("owner"))d=d.data("owner");e=d.data("wijchartDataObj");j.call(b,f,e)}};a.each(["click","mouseover","mouseout","mousemove","mousedown","mouseup"],function(d,c){a(".bubbletracker",b).bind(c+".wijbubblechart",h[c])})}x();f.seriesEles=p;w();k.toFront();f.trackers=k;v(l,E,L,G,K,F,N,J);l.data("fields",f)}});a.wijbubble={transform:function(n,j,e,c,k,d,g,i){var f,b=n,h=j-e,m=c.endX-c.startX,l=c.endY-c.startY;b-=k;if(d===0)b=1;else b/=d;b=a.wijbubble.transformByArea(b,g,i);b*=h;b+=e;f=Math.min(m,l);b*=f/200;return b},transformByArea:function(d,b,c){var a=d;if(b==="area")switch(c){case"circle":a=Math.sqrt(a/Math.PI);break;case"tri":case"invertedTri":a=Math.sqrt(a/(3*Math.sin(Math.PI/6)*Math.cos(Math.PI/6)));break;case"box":a=Math.sqrt(a/2);break;case"diamond":case"cross":a=Math.sqrt(a/2);break;default:a=Math.sqrt(4*a/Math.PI)}return a}}})(jQuery);
(function(a){"use strict";var n="ui-helper-clearfix",y="ui-widget-content",l="ui-corner-",k=l+"all",c="ui-state-disabled",d="ui-state-hover",b="wijmo-wijcarousel-",B="wijmo-wijcarousel",w=B+" ui-widget ",F=b+"list",q=b+"item ",D=b+"clip",g=b+"current",t=b+"horizontal-multi",v=b+"horizontal",r=b+"button",u=b+"vertical-multi",x=b+"vertical",o=b+"button-next",p=b+"button-previous",z=b+"preview",e="ui-icon-triangle-1-",G=e+"n",H=e+"s",E=e+"e",I=e+"w",h="ui-icon-play",j="ui-icon-pause",C='<a class="ui-state-default"><span class="ui-icon"></span></a>',f=".wijmo-wijpager,."+r+",."+o+",."+p,m='<div class="ui-helper-clearfix"></div>',A='<li class="ui-state-default wijmo-wijcarousel-page"><a></a></li>',s="li.wijmo-wijcarousel-page",i=1;a.widget("wijmo.wijcarousel",{options:{data:[],auto:false,interval:5e3,showTimer:false,buttonPosition:"inside",showPager:false,prevBtnClass:{defaultClass:"",hoverClass:"",disableClass:""},nextBtnClass:{defaultClass:"",hoverClass:"",disableClass:""},pagerType:"numbers",thumbnails:{mouseover:null,mouseout:null,mousedown:null,mouseup:null,click:null,imageWidth:58,imageHeight:74,images:[]},pagerPosition:{},orientation:"horizontal",loop:true,animation:{queue:true,disable:false,duration:1e3,easing:"easeOutCubic"},start:0,display:1,preview:false,step:1,showControls:false,control:"",controlPosition:{},showCaption:true,showControlsOnHover:false,itemClick:null,beforeScroll:null,afterScroll:null,loadCallback:null},_handleDisabledOption:function(d){var b=this;if(b.pager&&!b.pager.is(":hidden"))b.disabledEles=b.disabledEles.add(b.pager);if(d){b.element.addClass(c);!b.disabledDiv.length&&b._createDisabledDiv();b.disabledDiv.appendTo("body")}else if(b.disabledDiv){b.element.removeClass(c);b.disabledDiv.remove();b.disabledDiv=a()}},_createDisabledDiv:function(){var b=this;b.disabledEles.each(function(){var d=a(this),e=d.offset(),g=d.outerWidth(),f=d.outerHeight(),c=a("<div></div>").addClass("ui-state-disabled").css({"z-index":"99999",position:"absolute",width:g,height:f,left:e.left,top:e.top});if(a.browser.msie){c.css("background-color","white");a.browser.version==="9.0"&&c.css("opacity","0.1")}b.disabledDiv=b.disabledDiv.add(c)})},_initStates:function(d,c){var b=this;b.count=0;b.currentIdx=d.start;b.timeout=null;b.isHorizontal=d.orientation==="horizontal";b.width=c.width()||640;b.height=c.height()||480;b.offset=0;b.disabledEles=c;b.disabledDiv=a()},_create:function(){var b=this,c=b.options,d=b.element;b._initStates(c,d);b._createDom(b.isHorizontal);b.list.bind("click."+b.widgetName,a.proxy(b._itemClick,b));if(c.showContorlsOnHover){b.container.bind("mouseenter."+b.widgetName,function(){b._showControls()}).bind("mouseleave."+b.widgetName,function(){b._hideControls()});b.container.find(f).hide()}c.loadCallback&&a.isFunction(c.loadCallback)&&b._trigger("loadCallback",null,b);if(c.disabled)b.disable();else c.auto&&b.play()},_showControls:function(){this.container.find(f).stop(true,true).fadeIn(600,function(){a(this).css("opacity","")})},_hideControls:function(){this.container.find(f).stop(true,true).fadeOut(600)},_applyContainerStyle:function(d){var a=this,g=a.options,f={},b=a.list,h=0,e,k=0,l=d?"left":"top",c=0,j=d?"width":"height";e=a.itemBound[d?"w":"h"];a.count=a.list.children("li").length;h=a.count*e;a.list[j](h);a.clip[j](g.display*e);a.clip[d?"height":"width"](a.itemBound[d?"h":"w"]);if(!g.loop){f[l]=-e*a.currentIdx;b.css(f)}else{for(c;c<a.currentIdx;c++)b.find("li:first").appendTo(b);if(g.preview){for(c=0;c<i;c++)b.find("li:last").prependTo(b);k=-e*i}f[l]=k;b.css(f)}},_applyListStyle:function(){var a=this,f=a.options,b=f.orientation==="horizontal",c=0,d,e=b?"width":"height";a.itemBound=a._getItemBound();d=a.itemBound[b?"w":"h"];c=a.count*d;a.list[e](c)},_createButtons:function(g,f){var b=this,h=b.options,e,d=c;a.each(["prevBtn","nextBtn"],function(n,i){var c=h[i+"Class"],j=i==="nextBtn",m=j?"next":"previous",l=j?o:p,k=j?f:g;if(c&&c.defaultClass){d=c.disableClass||d;e=c.hoverClass;b[i]=a('<a class="ui-state-default"></a>').addClass(c.defaultClass).mouseover(function(){!a(this).hasClass(d)&&a(this).addClass(e)}).mouseout(function(){!a(this).hasClass(d)&&a(this).removeClass(e)})}else b[i]=a(b._createBtn(l,k));b[i].bind("click."+b.widgetName,a.proxy(b[m],b)).appendTo(b.container)})},_applyBtnClass:function(){var e=this,g=e.options,b=c,f=d;a.each(["prevBtn","nextBtn"],function(i,d){var c=g[d+"Class"],h,a=e[d];if(c){b=c.disableClass||b;f=c.hoverClass||f}h=d==="prevBtn"?e.currentIdx<=0:e.currentIdx+g.display>=e.count;if(h&&!g.loop)a.removeClass(f).addClass(b);else a.hasClass(b)&&a.removeClass(b)})},_applyBtnStyle:function(b){var c=this,i=0,d,k={collision:"none",of:c.container,my:b?"right center":"center bottom",at:b?"right center":"center bottom"},m={collision:"none",of:c.container,my:b?"left center":"center top",at:b?"left center":"center top"},g=c.options.buttonPosition==="inside",e,f,j=["bottom","top","right","left"],h=function(e,f,g,c,d){e.removeClass(f).addClass(g);!isNaN(c)&&c!==0&&a.extend(d,{offset:b?c+" 0":"0 "+c});e.position(d)};i=b?c.prevBtn.width():c.prevBtn.height();d=g?0:i;e=l+j[b*2+g];f=l+j[b*2+!g];h(c.nextBtn,f,e,d,k);h(c.prevBtn,e,f,-d,m);c._applyBtnClass()},_createDom:function(d){var b=this,c=b.options,e=b.element,f,g,h,i;if(e.is("div")){b.list=e.children("ul:eq(0)");b.container=b.element;if(!b.list.length)b.list=a("<ul></ul>").appendTo(b.container)}else if(e.is("ul")){b.list=e;b.container=e.parent()}else return;b.itemBound=b._getItemBound();if(d){f=c.display>1&&!c.preview?t:v;g=E;h=I}else{f=c.display>1&&!c.preview?u:x;g=H;h=G}b.list.addClass(F).addClass(n);i=w+" "+f+" "+(c.preview?z+" ":"")+(c.display>1?y+" "+k:"");b.container.addClass(i);b._createItems(d);b._createClip(d);b._applyContainerStyle(d);b._createButtons(h,g);b._applyBtnStyle(d);c.preview&&b._createPreview();c.showTimer&&b._createTimer();c.showPager&&b._createPager();c.showControls&&b._createControls()},_createPreview:function(){var a=this,g=a.options,b,d,c=g.orientation==="horizontal",e=c?"left":"top",h=c?"right":"bottom",f;d=a.itemBound[c?"w":"h"];b=a.offset=Math.round(d/4);f=g.display*d+b*2;a.clip[c?"width":"height"](f);a.list.css(e,function(c,a){return parseFloat(a)+b});a.clip.css(e,function(){return-b});a.container.css("margin-"+e,b+"px").css("margin-"+h,b+"px")},_createItemsFromData:function(b){var c=this;if(!a.isArray(b)||!b.length||!a.isPlainObject(b[0])||a.isEmptyObject(b[0]))return;c.list.empty();a.each(b,function(e,b){var d;if(!a.isPlainObject(b))return true;d=c._generateMarkup(b);c.list.append(d)})},_generateMarkup:function(b){var c,d;if(!a.isPlainObject(b))return;c=a("<li></li>");if(typeof b.linkUrl==="string"&&b.linkUrl){d=a("<a>").attr("src",b.linkUrl);d.appendTo(c)}typeof b.imageUrl==="string"&&b.imageUrl&&a("<img>").attr("src",b.imageUrl).appendTo(d||c);typeof b.caption==="string"&&b.caption&&a("<span>").html(b.caption).appendTo(c);return c},_createItems:function(){var b=this,c,f,e=b.options,h,d;if(b.list){b._createItemsFromData(e.data);b.list.children("li").each(function(d){var c=a(this);b._createItem(c,d)});h=b.list.children("li").eq(b.currentIdx).addClass(g);if(e.preview&&e.display>1){c=d=h;for(f=0;f<e.display-1;f++){d=d.next();c=c.add(d)}c.find("div.wijmo-wijcarousel-mask").css({opacity:0})}}},_createItem:function(b,h){var c=this,i=c.options,g,f,e=c.itemBound.w,d=c.itemBound.h;g=b.addClass(q).addClass(n).find("img:eq(0)").attr("role","img").addClass("wijmo-wijcarousel-image");if(!c.itemWidth||!c.itemHeight){b.width(e).height(d);c.itemWidth=e-(b.outerWidth(true)-e);c.itemHeight=d-(b.outerHeight(true)-d)}b.width(c.itemWidth).height(c.itemHeight);f=b.children("span:eq(0)").hide();c._createCaption(b,g,f);i.preview&&a('<div class="wijmo-wijcarousel-mask">').appendTo(b);b.data("itemIndex",h);return b},_createCaption:function(g,j,i){var e=this,k=e.options,b,h,c,f,d;if(k.showCaption){b=i.html()||j.attr("title");if(b&&b.length){c=a("<span></span>").html(b);f=a(m).addClass("wijmo-wijcarousel-caption").width(e.itemWidth).appendTo(g);h=a(m).addClass("ui-widget-content wijmo-wijcarousel-text").append(c).width(e.itemWidth).appendTo(g);d=c.outerHeight(true);h.height(d);f.height(d)}}},_showCaption:function(b,c){var e=this,d=e._getItemByIndex(b),f=d.find(".wijmo-wijcarousel-text"),a=d.find(".wijmo-wijcarousel-caption");f.length&&f.fadeIn(300,function(){b<c&&e._showCaption(b+1,c)});if(a.length){a.show();a.animate({opacity:.5},300)}},_hideCaption:function(){this.element.find(".wijmo-wijcarousel-text,.wijmo-wijcarousel-caption").hide()},_createClip:function(){this.clip=this.list.wrap("<div></div>").parent().addClass(D)},_createBtn:function(f,e){var b=a(C);b.addClass(f).attr("role","button").mouseover(function(){!a(this).hasClass(c)&&a(this).addClass(d)}).mouseout(function(){!a(this).hasClass(c)&&a(this).removeClass(d)}).children("span:eq(0)").addClass(e);return b},_createControls:function(){var b=this,c=b.options,d={collision:"none",of:b.container,my:"center bottom",at:"center bottom"};if(c.control){b.controls=a(c.control).css({position:"absolute"}).appendTo(b.container);a.extend(d,c.controlPosition);b.controls.position(d)}},_createTimer:function(){var b=this;b._createPausePlay();b.progressBar=a("<div></div>").addClass("wijmo-wijcarousel-timerbar-inner "+k).css({width:"0%"}).attr("role","progressbar");b.timer=a("<div></div>").addClass("wijmo-wijcarousel-timerbar "+k).appendTo(b.container).append(b.progressBar).append(b.playPauseBtn)},_createPausePlay:function(){var b=this,c=b.options;b.playPauseBtn=a(b._createBtn(r,c.auto?j:h)).bind("click."+b.widgetName,function(){var c=a(this).children("span:eq(0)");b[c.hasClass(h)?"play":"pause"]()})},_createPagingItem:function(g,b,h,d){var c=a(A).attr({role:"tab","aria-label":d,title:d}),f,e;if(g)c.addClass("wijmo-wijcarousel-dot");else if(b&&b.images&&b.images[d]){f=b.imageWidth;e=b.imageHeight;f&&e&&c.width(f).height(e);c.children("a").append(a("<img>").attr("src",b.images[d]))}else return;h.append(c)},_createPaging:function(i){var b=this,j=b.options,f,h,g,c=j.thumbnails,e=i==="dots";b.container.append(b.pager=a('<div><ul class="wijmo-list ui-corner-all ui-helper-clearfix" role="tablist"></ul></div>'));!e&&b.pager.addClass("wijmo-wijcarousel-thumbnails");h=b.pager.children("ul.wijmo-list");for(f=0;f<b.count;f++)b._createPagingItem(e,c,h,f);g=b.pager.find("li").eq(b.currentIdx);g.length&&b._activePagerItem(g);b.pager.bind("mouseover."+b.widgetName,function(a){b._pageingEvents(a,"mouseover",c,e,function(a){a.addClass(d)})}).bind("mouseout."+b.widgetName,function(a){b._pageingEvents(a,"mouseout",c,e,function(a){a.removeClass(d)})}).bind("click."+b.widgetName,function(a){b._pageingEvents(a,"click",c,e,function(a){b.scrollTo(a.index());b._activePagerItem(a)})});!e&&a.each(["mousedown","mouseup"],function(e,d){a.isFunction(c[d])&&b.pager.bind(d,function(b){var e=a(b.target).closest(s);e.length&&c[d].call(e,b)})})},_pageingEvents:function(b,f,d,g,e){var c=a(b.target).closest(s);if(c.length){a.isFunction(e)&&e.call(b,c);!g&&a.isFunction(d[f])&&d[f].call(c,b)}},_activePagerItem:function(a){a.addClass("ui-state-active").attr("aria-selected","true").siblings("li").removeClass("ui-state-active").removeAttr("aria-selected")},_createWijSlider:function(){var b=this,c={orientation:"horizontal",range:false,min:0,max:b.count-1,step:1,value:b.currentIdx,buttonClick:function(d,c){var a=c.value;b.scrollTo(a)},slide:function(d,c){var a=c.value;b.scrollTo(a)}},d=a("<div></div>").css({"margin-bottom":"10px",width:"200px"}).appendTo(b.container);b.pager=d.wijslider(c).parent().wrap("<div>").parent().addClass("wijmo-wijcarousel-slider-wrapper")},_createWijPager:function(){var b=this,c={pageCount:b.count,pageIndex:b.currentIdx,pageButtonCount:b.count,mode:"numeric",pageIndexChanged:function(d,c){var a=c.newPageIndex;b.scrollTo(a)}},d=a("<div></div>").appendTo(b.container);b.pager=d.wijpager(c).css({position:"absolute"})},_createPager:function(){var b=this,c=b.options,d={collision:"none",of:b.container,my:"right top",at:"right bottom"};if(c.pagerType==="numbers")b._createWijPager();else if(c.pagerType==="dots"||c.pagerType==="thumbnails"){b._createPaging(c.pagerType);b.pager.css({position:"absolute"})}else if(a.wijmo.wijslider&&c.pagerType==="slider")b._createWijSlider();else return;b.pager.width(b.pager.width()+1);a.extend(d,c.pagerPosition);b.pager.addClass("wijmo-wijcarousel-pager").position(d)},_setOption:function(c,d){var b=this,g=b.options,e,i,f,h=g.orientation==="horizontal";if(c==="pagerPosition"||c==="animation"||c==="controlPosition")a.extend(true,g[c],d);else{f=g[c];a.Widget.prototype._setOption.apply(b,arguments);switch(c){case"showControls":case"showPager":case"showTimer":if(d===f)break;e=c.replace(/show/i,"").toLowerCase();i=c.replace(/show/i,"_create");if(d===true)if(!b[e])b[i]();else b[e].jquery&&b[e].show();else b[e].remove();break;case"loop":case"orientation":case"display":if(d!==f){b.destroy();b._create()}break;case"data":b._createItems(h);b._applyContainerStyle(h);b._applyBtnClass();g.showPager&&b._createPager();break;case"buttonPosition":b._applyBtnStyle(h);break;case"pagerType":if(d!==f){if(b.pager&&b.pager.jquery){b.pager.remove();b.pager=null}b._createPager()}break;case"disabled":b._handleDisabledOption(d,b.element)}}},_getItemBound:function(){var b={},a=this,c=a.options;if(c.orientation==="horizontal")b={w:Math.round(a.width/c.display),h:a.height};else b={w:a.width,h:Math.round(a.height/c.display)};return b},_stopAnimation:function(){var a=this;a.isPlaying&&a.progressBar&&a.progressBar.stop().css({width:"0%"});a.list.stop(true,true)},_itemClick:function(g){var i=a(g.target),b=this,j=b.options,e=b.currentIdx,c=i.closest("li."+q,i),d=c.data("itemIndex"),h,f;if(c.length>0){if(j.preview&&d<e||d>e+j.display-1){h=b._getItemByIndex(e).index();f=c.index()>h?"next":"previous";b[f]()}b._trigger("itemClick",g,{index:d,el:c})}},destroy:function(){var b=this;b.container.removeClass("wijmo-wijcarousel ui-widget").removeClass("wijmo-wijcarousel-horizontal").removeClass("wijmo-wijcarousel-vertical");b.list.unwrap().removeClass("wijmo-wijcarousel-list ui-helper-clearfix").unbind("."+b.widgetName).removeAttr("style").children("li").each(function(){var b=a(this);b.removeClass("wijmo-wijcarousel-item ui-helper-clearfix").removeClass(g);b.children("img").removeClass("wijmo-wijcarousel-image");b.children(".wijmo-wijcarousel-caption,.wijmo-wijcarousel-text").remove();b.css({width:"",height:""});b.removeData("itemIndex")});b.element.find(f+",.wijmo-wijcarousel-timerbar").remove();b.pager&&b.pager.wijpager("destroy").remove();b.element.find("li>span").css("display","");if(b.disabledDiv.length){b.disabledDiv.remove();b.disabledDiv=a()}a.Widget.prototype.destroy.apply(this)},play:function(){var a=this,b=a.options;if(a.isPlaying)return;if(b.interval===0)return a.pause();if(b.showTimer&&a.progressBar){a.progressBar.css({width:"0%"});a.playPauseBtn.children("span:eq(0)").removeClass(h).addClass(j);a.progressBar.animate({width:"100%"},b.interval,function(){a._scroll("next",b.step)})}else{if(a.timeout)return;a.timeout=window.setTimeout(function(){a.next()},b.interval)}a.isPlaying=true},pause:function(){var a=this,b=a.options;if(b.showTimer&&a.progressBar){a.progressBar.stop().css({width:"0%"});a.playPauseBtn.children("span:eq(0)").removeClass(j).addClass(h)}else{if(a.timeout===null)return;window.clearTimeout(a.timeout);a.timeout=null}a.isPlaying=false},next:function(){var a=this,b=a.options.step;if(typeof b!=="number"||b<1)return;a._stopAnimation();a._scroll("next",b)},previous:function(){var a=this,b=a.options.step;if(typeof b!=="number"||b<1)return;a._stopAnimation();a._scroll("previous",b)},scrollTo:function(b){var a=this,c,d;a._stopAnimation();c=b>a.currentIdx?"next":"previous";d=Math.abs(b-a.currentIdx);b!==a.currentIdx&&a._scroll(c,d)},_scroll:function(m,k){var b=this,d=b.options,p=b.list,c=0,n,h,t,r=d.orientation==="horizontal",j={},e=b.itemBound[r?"w":"h"],l=r?"left":"top",f=k,s={},q=0,o=b.currentIdx*e;if(!d.loop){if(m==="next"){if(b.currentIdx+d.display+k<=b.count)c=-o-e*f;else if(b.currentIdx+d.display<b.count){f=b.count-b.currentIdx-d.display;c=-o-e*f}}else if(b.currentIdx-k>=0)c=-o+e*f;else if(b.currentIdx>0){f=b.currentIdx;c=0}if(c!==undefined){j[l]=c+b.offset;b._doAnimation(m,j,f)}}else{if(d.preview)c=q=-e*i+b.offset;if(m==="next"){c+=-e*f;j[l]=c}else{for(h=0;h<k;h++){c-=e;p.find("li:last").prependTo(p)}s[l]=c;j[l]=q;p.css(s)}b._doAnimation(m,j,k,l,e)}if(d.preview){n=a();for(h=0;h<d.display;h++)n=n.add(b._getItemByIndex(b.currentIdx+h).find("div.wijmo-wijcarousel-mask:eq(0)"));n.stop(true).animate({opacity:.6},d.animation.duration/2,function(){b._getItemByIndex(b.currentIdx).removeClass(g)})}},_doAnimation:function(k,o,h,n,p){var b=this,e=b.list,d=b.options,l,j,g={},f,m={},c;if(k==="next")c=b.currentIdx+h;else c=b.currentIdx-h;if(!d.loop)f=function(){b.currentIdx=c;b._setCurrentState(b.currentIdx)};else{c=c%b.count+(c<0?b.count:0);f=function(){var a=0;if(d.preview)a=b.offset-i*p;if(k==="next"){for(j=0;j<h;j++)e.find("li:first").appendTo(e);if(n){m[n]=a;e.css(m)}}b.currentIdx=c;b._setCurrentState(b.currentIdx)}}g.complete=f;l={index:b.currentIdx,to:c,el:b._getItemByIndex(b.currentIdx)};if(!b._trigger("beforeScroll",null,l))return;if(d.animation&&d.animation.complete)d.animation.complete=undefined;a.extend(g,d.animation);b._hideCaption();e.animate(o,g)},_setCurrentState:function(c){var b=this,d=b.options,i,l,k,h=c+d.display-1,j,e,f;if(!d.loop){k=c+d.display<b.count;if(b.isPlaying&&k){b.timeout=null;b.isPlaying=false;b.play()}else b.progressBar&&b.pause();b._applyBtnClass()}else if(b.isPlaying){b.timeout=null;b.isPlaying=false;b.play()}if(d.preview){e=a();j=b._getItemByIndex(c);for(f=0;f<d.display;f++)e=e.add(b._getItemByIndex(c+f).find("div.wijmo-wijcarousel-mask:eq(0)"));e.animate({opacity:0},d.animation.duration/2,function(){j.addClass(g);b._showCaption(c,h)})}else b._showCaption(c,h);if(b.pager)if(a.wijmo.wijslider&&b.pager.find(":wijmo-wijslider").length)b.pager.find(":wijmo-wijslider:eq(0)").wijslider("value",c);else if(a.wijmo.wijpager&&b.pager.is(":wijmo-wijpager"))b.pager.wijpager("option","pageIndex",c);else if(b.pager.jquery){i=b.pager.find(">ul:eq(0)>li").eq(c);i.length&&b._activePagerItem(i)}l={firstIndex:c,lastIndex:h};b._trigger("afterScroll",null,l)},_getItemByIndex:function(f){var b=this,e=b.list,d,c=f%b.count;if(!b.options.loop)return e.children("li").eq(c);e.children("li").each(function(){var b=a(this);if(b.data("itemIndex")===c){d=b;return false}});return d},widget:function(){return this.container},_collectionChanged:function(b){var a=this;a.count=a.count+(b==="add"?1:-1);a._applyListStyle();if(a.pager&&a.pager.jquery){a.pager.remove();a.pager=null;a._createPager()}a._applyBtnClass()},add:function(e,d){var b=this,c,f;if(typeof e==="string")c=a(e);else if(e.jquery)c=e;else if(a.isPlainObject(e))c=b._generateMarkup(e);else return;if(!c.is("li"))c=c.wrap("<li></li>").parent();f=c;if(typeof d==="number"&&d>=0&&d<b.count){f.insertBefore(b._getItemByIndex(d));b.list.children("li").each(function(){var b=a(this);b.data("itemIndex")>=d&&b.data("itemIndex",b.data("itemIndex")+1)})}else f.insertAfter(b._getItemByIndex(b.count-1));b._createItem(c,d!==undefined?d:b.count);b._collectionChanged("add")},remove:function(c){var b=this,d;if(typeof c==="number"&&c>=0&&c<b.count){d=b._getItemByIndex(c);b.list.children("li").each(function(){var b=a(this);b.data("itemIndex")>c&&b.data("itemIndex",b.data("itemIndex")-1)})}else d=b._getItemByIndex(b.count-1);d&&d.remove();b._collectionChanged("remove")}})})(jQuery);
(function(a){"use strict";var h="ui-helper-clearfix",m="ui-widget-content",i="ui-corner-all",b="ui-state-disabled",c="ui-state-hover",n="ui-state-default",j="wijmo-wijgallery-",k=j+"button-",v=j+"button",s="ui-icon-triangle-1-e",u="ui-icon-triangle-1-w",d="ui-icon-play",e="ui-icon-pause",o="ui-widget-content ui-state-default wijmo-wijgallery-thumbs-pointer-{0}",f="wijmo-wijgallery-flashwrapper",q='<div class="wijmo-wijgallery-frame  ui-widget-content '+h+'"><div class="wijmo-wijgallery-content"></div></div>',p='<div class="wijmo-wijgallery-thumbs"></div>',r='<a class="ui-state-default"><span class="ui-icon"></span></a>',t='<div class="wijmo-wijgallery-frame-{0}"><a href="#" class="wijmo-wijgallery-frame-link"></a></div>',g='<div class="ui-widget-content '+h+'"></div>',l="li.wijmo-wijcarousel-item";a.widget("wijmo.wijgallery",{options:{autoPlay:false,scrollWithSelection:false,showTimer:true,interval:5e3,showCaption:true,data:[],showControls:false,control:"",controlPosition:{},captionOrientation:"horizontal",showCounter:true,counter:"[i] of [n]",showPager:false,pagingPosition:{},thumbnails:true,thumbnailOrientation:"horizontal",thumbnailDirection:"after",transitions:{animated:"slide",duration:1e3,easing:null},showControlsOnHover:true,thumbsDisplay:5,thumbsLength:100,beforeTransition:null,afterTransition:null,loadCallback:null,showMovieControls:false,autoPlayMovies:true,flashParams:{bgcolor:"#000000",allowfullscreen:true,wmode:"transparent"},flashVars:{},flashVersion:"9.0.115",flvPlayer:"player\\player.swf",flashInstall:"player\\expressInstall.swf",mode:"img"},_setOption:function(c,d){var b=this,h=b.options,e,f,g;if(c==="framePosition"||c==="thumbnailPosition"||c==="transitions"||c==="pagingPosition")a.extend(true,h[c],d);else{g=h[c];a.Widget.prototype._setOption.apply(b,arguments);switch(c){case"disabled":b._handleDisabledOption(d,b.element);break;case"thumbnailOrientation":b.thumbs.wijgallery({orientation:d});break;case"autoPlay":b.play();break;case"showPager":case"showCounter":case"showTimer":case"showControls":e=c.replace(/show/i,"").toLowerCase();f=c.replace(/show/i,"_create");if(d!==g)if(d===true)if(!b[e])b[f]();else b[e].jquery&&b[e].show();else b[e].remove()}}},thumbWidgetName:"wijcarousel",_handleDisabledOption:function(c){var b=this;if(b.pager&&!b.pager.is(":hidden"))b.disabledEles=b.disabledEles.add(b.pager);if(c){!b.disabledDiv.length&&b._createDisabledDiv();b.disabledDiv.appendTo("body")}else if(b.disabledDiv){b.disabledDiv.remove();b.disabledDiv=a()}},_createDisabledDiv:function(){var b=this;b.disabledEles.each(function(){var d=a(this),e=d.offset(),g=d.outerWidth(),f=d.outerHeight(),c=a("<div></div>").addClass("ui-state-disabled").css({"z-index":"99999",position:"absolute",width:g,height:f,left:e.left,top:e.top});if(a.browser.msie){c.css("background-color","white");a.browser.version==="9.0"&&c.css("opacity","0.1")}b.disabledDiv=b.disabledDiv.add(c)})},_initLi:function(e){var d=e.children("a:eq(0)"),c=e.find("img:eq(0)"),f=e.find("span:eq(0)"),b={title:c.attr("alt"),caption:null};if(d.length&&d.attr("href")){b.url=d.attr("href");if(!b.title)b.title=d.attr("title")}else if(c.length)b.url=c.attr("src");if(f.length)b.caption=f;else if(c.attr("title"))b.caption=a("<span>").html(c.attr("title"));b.thumbUrl=c.attr("src");return b},_initStatus:function(){var b=this,c;b.images=[];b.ul=b.element.children("ul");c=b.ul.children("li");b.count=c.length;c.each(function(){var c=b._initLi(a(this));b.images.push(c)})},_createMarkupFromData:function(){var b=this,f=b.options,d=f.data,e=b.element,c=e.children("ul:eq(0)");b.images=d;if(c.length)c.empty();else c=a("<ul>").appendTo(e);b.ul=c;a.each(d,function(g,b){var e=a("<a>"),f=a("<li>"),d=a("<img>");b.url&&e.attr("href",b.url);b.thumbUrl&&d.attr("src",b.thumbUrl);b.title&&d.attr("alt");e.append(d).appendTo(f);f.appendTo(c)});b.count=d.length},_create:function(){var b=this,c=b.options;b.container=b.element;b.container.addClass("wijmo-wijgallery ui-widget");b.currentThumbIdx=0;b.currentIdx=-1;b.disabledEles=b.element;b.disabledDiv=a();if(c.showPager){c.pagingPosition=true;c.thumbnails=false}if(c.data&&c.data.length)b._createMarkupFromData();else b._initStatus();c.loadCallback&&a.isFunction(c.loadCallback)&&b._trigger("loadCallback",null,b);b._createDom();c.autoPlay&&b.play();if(c.showControlsOnHover){b.frame.find(".wijmo-wijpager,.wijmo-wijgallery-button-next,.wijmo-wijgallery-counter,.wijmo-wijgallery-button-previous").hide();!b.isPlaying&&b.timer&&b.timer.hide()}c.disabled&&b.disable()},_createDom:function(){var a=this,b=a.options;if(b.thumbnails)a._createThumbnails();else a.ul.hide();a._createFrame();b.control&&a._createControls();b.showCounter&&a._createCounter();b.showTimer&&a._createTimer();b.showPager&&a._createPager()},_getFrameSize:function(){var a=this,d=a.options.thumbnailOrientation==="horizontal",b=a.element.height()-(d?a.thumbs?a.thumbs.outerHeight(true):0:0),c=a.element.width()-(d?0:a.thumbs?a.thumbs.outerWidth(true):0);return{w:c<0||!c?750:c,h:b<0||!b?300:b}},_createFrame:function(){var b=this,d=b.options,f,e,c=b._getFrameSize(),g=d.thumbnailDirection==="after";b.frame=a(q)[g?"prependTo":"appendTo"](b.container).setOutWidth(c.w-1).setOutHeight(c.h).wrap('<div class="wijmo-wijgallery-framewrapper">');b.size=c;f=b.frame.width();e=b.frame.height();b.frameWrapper=b.frame.parent();d.thumbnailOrientation==="vertical"&&b.frameWrapper.addClass("wijmo-wijgallery-framewrapper-vertical");d.showControlsOnHover&&b.frame.bind("mouseenter."+b.widgetName,function(){b._showControls("controls")}).bind("mouseleave."+b.widgetName,function(){b._hideControls("controls")});b.content=b.frame.children("div.wijmo-wijgallery-content");d.mode==="img"&&b._createFrameMask();b._createPrevNextBtn();b._createCaption(c);b._createLoading();b.last=a('<div class="ui-widget-overlay wijmo-wijgallery-last"></div>').appendTo(b.content).width(f).height(e).css({"line-height":c.h+"px"});b.current=a('<div class="ui-widget-overlay wijmo-wijgallery-current"></div>').appendTo(b.content).width(f).height(e).css({"line-height":c.h+"px"});b._show(0)},_createControls:function(){var b=this,c=b.options,d={collision:"none",of:b.container,my:"center bottom",at:"center bottom"};if(c.control){b.controls=a(c.control).css({position:"absolute"}).appendTo(b.container);a.extend(d,c.controlPosition);b.controls.position(d)}},_createLoading:function(){var b=this;b.loading=a("<div></div>").addClass("wijmo-wijgallery-loading").appendTo(b.content);b.loading.css({left:(b.content.width()-b.loading.width())/2,top:(b.content.height()-b.loading.height())/2});b.loading.hide()},_createFrameMask:function(){var b=this,c=b.options;a.each(["previous","next"],function(g,d){var e=a(t.replace(/\{0\}/,d)).appendTo(b.frame),f=e.children("a");c.showControlsOnHover&&e.bind("mouseenter."+b.widgetName,function(){b._showControls(d)}).bind("mouseleave."+b.widgetName,function(){b._hideControls(d)});f.bind("click."+b.widgetName,function(a){b[d]();a.preventDefault()})})},_createCounter:function(){var b=this,c=b.options;if(!c.showCounter){if(b.counter){b.counter.remove();b.counter=undefined}return}if(!b.counter)b.counter=a("<div></div>").addClass("wijmo-wijgallery-counter ui-state-default ui-corner-tl").appendTo(b.frame);b._refreshCounter()},_refreshCounter:function(){var b=this,d=b.options,c;if(!b.counter)return;b.counter.empty();if(d.counter){c=d.counter.replace(/\[i\]/,b.currentIdx+1);c=c.replace(/\[n\]/,b.count);a("<span></span>").text(c).appendTo(b.counter)}},_createPrevNextBtn:function(){var b=this;a.each(["next","previous"],function(f,c){var e=c==="next"?s:u,d;d=b.frame.find(".wijmo-wijgallery-frame-"+c);if(!d.length||b.options.mode!=="img")d=b.frame;b[c+"Btn"]=a(b._createBtn(k+c,e)).bind("click."+b.widgetName,a.proxy(b[c],b)).appendTo(d);b._applyBtnStyle(c)})},_applyBtnStyle:function(e){var a=this,f=e==="next",d=a[e+"Btn"],g=f?"right center":"left center",k=g,j="ui-corner-"+(f?"left":"right"),i=e==="next"?a.currentIdx>=a.count:a.currentIdx<=0,h={collision:"none",of:a.frame,my:k,at:g};d.addClass(j).position(h);if(i)d.removeClass(c).addClass(b);else d.hasClass(b)&&d.removeClass(b)},_createCaption:function(c){var b=this,d=b.options;if(d.showCaption){b.overlay=a(g).addClass("wijmo-wijgallery-caption").width(c.w).appendTo(b.content);b.caption=a(g).addClass("wijmo-wijgallery-text").width(c.w).appendTo(b.content)}},_loadCaption:function(g){var f=this,c=g.caption,e,b=a("<span></span>"),d=f.element.find(".wijmo-wijgallery-text,.wijmo-wijgallery-caption");if(c){d.show();c.jquery&&c.show();b.html(c);f.caption.empty().append(b);e=b.outerHeight(true);d.height(e);a.browser.msie&&d.height(b.css("display","block").outerHeight(true))}d.hide()},_showCaption:function(b){var a=this;if(b&&b.caption){a.caption.length&&a.caption.fadeIn(500);a.overlay.length&&a.overlay.show().animate({opacity:.5},500)}},_createTooltip:function(c){var b=this,d=c||"bottom";b.pointer=a("<div>").addClass(o.replace(/\{0\}/,d));b.pointer.appendTo(b.thumbsWrapper).hide()},_createThumbnails:function(){var b=this,d=b.options,h=d.thumbnailDirection==="after",g="wijmo-wijgallery-thumbs-{0}",e=d.thumbnailOrientation==="horizontal",f=h?e?"bottom":"right":e?"top":"left";b.thumbPosition=f;b.thumbs=a(p).appendTo(b.container).addClass(m).addClass(e?"wijmo-wijcarousel-horizontal-multi":"wijmo-wijcarousel-vertical-multi");if(e)b.thumbs.css({height:d.thumbsLength+"px"}).setOutWidth(b.element.width());else b.thumbs.css({width:d.thumbsLength+"px"}).setOutHeight(b.element.height());b.ul.appendTo(b.thumbs);b.ul.children("li").each(function(f){var c=a(this).children("a"),d=b.images[f],e=d.thumbUrl;if(!c.length){c=a(this).wrapInner("<a>").children("a");c.attr("href",e)}});if(a[b.namespace][b.thumbWidgetName]){b.thumbs.addClass(g.replace(/\{0\}/,f)).find("li").addClass(n).hover(function(){a(this).addClass(c)},function(){a(this).removeClass(c)});b.thumbsWrapper=b.thumbs[b.thumbWidgetName]({display:d.thumbsDisplay,step:d.thumbsDisplay-1,itemPadding:"0 10px",showCaption:false,orientation:d.thumbnailOrientation,loop:false,itemClick:function(a,d){var c=d.index;b.show(c);a.preventDefault()},afterScroll:function(c,a){b.currentThumbIdx=a.firstIndex;b.activeLi&&b.activeLi.is("li")&&b.activeLi.index()>=a.firstIndex&&b.activeLi.index()<=a.lastIndex&&b._highlightThumb(b.activeLi);b.isScrolling=false},beforeScroll:function(){b.isScrolling=true;if(d.mode==="swf"||d.mode==="flv")b.pointer.hide();else b.pointer.fadeOut(100)}}).wrap('<div class="wijmo-wijgallery-thumbswrapper">').parent();!e&&b.thumbsWrapper.addClass("wijmo-wijgallery-thumbswrapper-vertical");b._createTooltip(f)}},_calculatePosition:function(a,g,f,e,d,b){var c=this;if(c.thumbPosition==="bottom"){a.left=a.left+(e-g)/2+b;a.top=a.top-f}else if(c.thumbPosition==="top"){a.left=a.left+(e-g)/2+b;a.top=a.top+d+2*b}else if(c.thumbPosition==="left"){a.left=a.left+e+2*b;a.top=a.top+(d-f)/2+b}else if(c.thumbPosition==="right"){a.left=a.left-g;a.top=a.top+(d-f)/2+b}},_highlightThumb:function(a){var b=this,h,g,e,d,c,f;if(a&&a.length){a.siblings("li.wijmo-wijgallery-selected").removeClass("wijmo-wijgallery-selected ui-state-active");a.addClass("wijmo-wijgallery-selected ui-state-active");h=b.pointer.outerWidth(true);g=b.pointer.outerHeight(true);e=a.width();d=a.height();c=a.offset();f=5;b._calculatePosition(c,h,g,e,d,f);b.pointer.fadeIn(100);b.pointer.offset(c)}},_getSelector:function(b,e){var a,c=".wijmo-wijgallery-button-",d=".wijmo-wijpager,.wijmo-wijgallery-counter";if(e)d+=",.wijmo-wijgallery-timerbar";if(b==="next"||b==="previous")a=c+b;else if(b==="controls")a=d;else a=d+","+c+"next,"+c+"previous";return a},_showControls:function(d){var b=this,c;c=b._getSelector(d,!b.isPlaying&&b.timer);b.frame.find(c).stop(true,true).fadeIn(400,function(){a(this).css("opacity","")})},_hideControls:function(c){var a=this,b;b=a._getSelector(c,!a.isPlaying&&a.timer);this.frame.find(b).stop(true,true).fadeOut(600)},_createPager:function(){var b=this,f=b.options,d,c=f.thumbsDisplay,e=1,h=b.currentIdx,g=b.currentIdx,i={collision:"none",of:b.container,my:"right top",at:"right bottom"};if(f.thumbnails){d=a("<div></div>").appendTo(b.thumbs);if(c!==0){e=Math.ceil(b.count/c);h=Math.ceil(b.currentIdx/c)}b.pager=d.wijpager({pageCount:e,pageIndex:h,pageButtonCount:e,mode:"numeric",pageIndexChanged:function(d,e){var a=e.newPageIndex;(g<a*c||g>=(a+1)*c)&&b.thumbs[b.thumbWidgetName]("scrollTo",a*c);d.preventDefault()}}).css({position:"absolute"})}else{d=a("<div></div>").appendTo(b.container);b.pager=d.wijpager({pageCount:b.count,pageIndex:b.currentIdx,pageButtonCount:b.count,mode:"numeric",pageIndexChanged:function(d,c){var a=c.newPageIndex;b._show(a)}}).css({position:"absolute"});a.extend(i,f.pagingPosition);b.pager.addClass("wijmo-wijgallery-pager").position(i)}},_createBtn:function(f,e){var d=a(r);d.addClass(f).attr("role","button").bind("mouseover"+this.widgetName,function(){if(a(this).hasClass(b))return;a(this).addClass(c)}).bind("mouseout"+this.widgetName,function(){if(a(this).hasClass(b))return;a(this).removeClass(c)});d.children("span:eq(0)").addClass(e);return d},_createTimer:function(){var b=this;b._createPausePlay();b.progressBar=a("<div></div>").addClass("wijmo-wijgallery-timerbar-inner "+i).css({width:"0%"}).attr("role","progressbar");b.timer=a("<div></div>").addClass("wijmo-wijgallery-timerbar "+i).appendTo(b.frame).append(b.progressBar).append(b.playPauseBtn)},_createPausePlay:function(){var c=this,f=c.options;c.playPauseBtn=a(c._createBtn(v,f.autoPlay?e:d)).bind("click."+c.widgetName,function(){if(!a(this).hasClass(b)){var e=a(this).children("span:eq(0)");c[e.hasClass(d)?"play":"pause"]()}})},_show:function(c){var b=this,d=b.images[c],g,h,i,j=b._getFrameSize(),k=b.options,e=k.mode;if(b.currentIdx===c)return;if(d&&a.isPlainObject(d)){b.loading.delay(500).fadeIn(100);i=b.last.children("img,div."+f);i.length&&i.remove();if(e==="swf"||e==="flv"){b.last.hide();b.current.empty();b._wrapFlash(b.current,e,d.url);b.picture=b.current.children("div."+f);b._setCurrentStates(c);b.loading.stop().hide();b._thumbsScroll(c)}else if(e==="img"){b.picture&&b.picture.length&&b.last.append(b.picture.unbind("load"));b.current.hide();b.last.show();b.picture=a("<img>").attr({src:d.url,alt:d.title}).appendTo(b.current).data("itemIndex",c);if(b.picture[0].complete&&a.browser.msie)b._imageLoaded(b,j);else b.picture.bind("load",function(){b._imageLoaded(b,j)})}else if(e==="iframe"){if(b.current.is(":hidden")){g=b.current;h=b.last}else{g=b.last;h=b.current}b.picture=a("<iframe></iframe>").addClass("wijmo-wijgallery-iframe").attr({frameborder:"0",marginwidth:"0",marginheight:"0",scrolling:"auto",allowtransparency:"true",src:d.url}).hide().appendTo(g).data("itemIndex",c).bind("load",function(){var d=a(this),c=d.data("itemIndex");b.loading.stop().hide();b.pointer&&b.pointer.fadeOut(100);b._setCurrentStates(c);if(c!==undefined){d.show();h.fadeOut(function(){h.empty()});g.fadeIn()}})}}},_imageLoaded:function(a,c){var b=a.picture.attr("role","img"),d=b.data("itemIndex"),f=b[0].naturalWidth||b.width(),e=b[0].naturalHeight||b.height(),g=a.images[d];a.loading.stop().hide();a.pointer&&a.pointer.fadeOut(100);if(f>c.w||e>c.h)if(f/e>c.w/c.h)b.css({width:"100%"});else b.css({height:"100%"});else f<c.w&&e<c.h&&b.addClass("ui-state-default wijmo-wijgallery-small-image");if(d!==undefined){a.options.showCaption&&a.caption&&a._loadCaption(g);a._animate(d)}},_animate:function(d){var b=this,n=b.options,l=n.transitions,f=n.thumbnailOrientation==="horizontal",h,g,j,k,m,e,o,c=l.animated,i=l.duration;if(!b.last.children().length){b._setCurrentStates(d);b.last.hide();b.current.show();return}m={index:b.currentIdx,to:d,toImg:b.images[d]};if(!b._trigger("beforeTransition",null,m))return;if(c)if(c==="slide"){h=b.size.w;g=b.size.h;b.current.show();e=b.currentIdx>d?true:false;j=a.effects.createWrapper(b.last).css({overflow:"hidden",width:f?h*2:h,height:f?g:g*2,left:f?e?-h:0:0,top:f?0:e?-g:0});j[e?"prepend":"append"](b.current);j.animate({left:f?e?0:-h:0,top:f?0:e?0:-g},i,function(){b.last.parent().is(".ui-effects-wrapper")&&b.last.unwrap();b.last.hide();b._setCurrentStates(d)})}else if(c==="explode"||c==="scale"||c==="blind"||c==="fold"){b.current.css({position:"absolute"});b.current.stop(true,true).show(c,i,function(){b.last.hide();b._setCurrentStates(d)})}else if(c==="size"){b.last.hide();b.current.stop(true,true).show(c,i,function(){b.last.hide();b._setCurrentStates(d)})}else{k=i/2;b.last.hide(c,k,function(){b.last.hide();b.current.stop(true,true).show(c,k,function(){b._setCurrentStates(d)})})}else{b.last.hide();b.current.show();b._setCurrentStates(d)}b._thumbsScroll(d)},_thumbsScroll:function(b){var d,a=this,c=a.options;if(a.thumbs&&a.thumbs[a.thumbWidgetName])if(c.scrollWithSelection){d=b-Math.ceil(c.thumbsDisplay/2)+1;a.thumbs[a.thumbWidgetName]("scrollTo",d)}else if(b>c.thumbsDisplay+a.currentThumbIdx-1)a.thumbs[a.thumbWidgetName]("scrollTo",b-c.thumbsDisplay+1);else b<a.currentThumbIdx&&a.thumbs[a.thumbWidgetName]("scrollTo",b)},_setCurrentStates:function(d){var a=this,h=a.options,e,f,g;g=a.currentIdx;a.currentIdx=d;e=d+1<a.count;if(a.isPlaying&&e){a.timeout=null;a.isPlaying=false;a.play()}else a.progressBar&&a.pause();if(d+1>=a.count)a.nextBtn.add(a.playPauseBtn).removeClass(c).addClass(b);else a.nextBtn.add(a.playPauseBtn).removeClass(b);if(d<=0)a.previousBtn.removeClass(c).addClass(b);else a.previousBtn.removeClass(b);h.showCaption&&a._showCaption(a.images[d]);if(a.thumbs&&a.thumbs[a.thumbWidgetName]){a.activeLi=a.thumbs.find(l).eq(d);!a.isScrolling&&a._highlightThumb(a.activeLi)}else if(a.pager)a.pager.is(":wijmo-wijpager")&&a.pager.wijpager("option","pageIndex",d);a._refreshCounter();a._clearCss();f={last:g,index:a.currentIdx,toImg:a.images[a.currentIdx]};a._trigger("afterTransition",null,f)},_clearCss:function(){this.current.css({position:"",visibility:""})},_resetState:function(){var a=this;a._stopAnimation();if(a.isPlaying&&a.progressBar){a.progressBar.stop();a.progressBar.css({width:"0%"})}},_stopAnimation:function(){var b=this,a;a=b.content.find(".ui-effects-wrapper");a.length&&a.stop(true,true);b.current.stop(true,true);b.last.stop(true,true)},widget:function(){return this.element},count:function(){return this.count},destroy:function(){var b=this;b.frame.unwrap().remove();if(b.options.thumbnails){if(a[b.namespace][b.thumbWidgetName]){b.thumbs[b.thumbWidgetName]("destroy");b.element.find("li").unbind().removeClass("ui-state-active").filter(".wijmo-wijgallery-selected").removeClass("wijmo-wijgallery-selected");b.thumbs.children("ul").unwrap().unwrap()}}else{b.pager&&b.pager.length&&b.pager.remove();b.element.find("ul").css({display:""})}b.pointer&&b.pointer.remove();b.element.removeClass("wijmo-wijgallery ui-widget ui-widget-content ui-corner-all");if(b.disabledDiv){b.disabledDiv.remove();b.disabledDiv=null}a.Widget.prototype.destroy.apply(this)},show:function(b){var a=this;a._resetState();a._show(b)},next:function(){var a=this,b;a._resetState();b=a.currentIdx+1;b<a.count&&a._show(b)},previous:function(){var a=this,b;a._resetState();b=a.currentIdx-1;b>=0&&a._show(b)},play:function(){var a=this,b=a.options;if(a.isPlaying)return;if(b.interval===0)return a.pause();if(b.showTimer&&a.progressBar){a.progressBar.css({width:"0%"});a.playPauseBtn.children("span:eq(0)").removeClass(d).addClass(e);a.progressBar.animate({width:"100%"},b.interval,function(){a._show(a.currentIdx+1)})}else{if(a.timeout)return;a.timeout=window.setTimeout(function(){a.next()},b.interval)}a.isPlaying=true},pause:function(){var a=this,b=a.options;if(b.showTimer&&a.progressBar){a.progressBar.stop();a.progressBar.css({width:"0%"});a.playPauseBtn.children("span:eq(0)").removeClass(e).addClass(d)}else{if(a.timeout===null)return;window.clearTimeout(a.timeout);a.timeout=null}a.isPlaying=false},add:function(c,d){var b=this,e,g,f;if(typeof c==="string"){e=a(c);f=b._initLi(e)}else if(c.jquery){e=c;f=b._initLi(e)}else if(a.isPlainObject(c))f=c;else return;if(!d||d>b.count)g=b.count;else if(d<0)g=0;else g=d;b.images.splice(g,0,f);b.count++;b.thumbs&&b.thumbs[b.thumbWidgetName]&&b.thumbs[b.thumbWidgetName]("add",e,d)},remove:function(b){var a=this,c;if(!b||b>a.count)c=a.count;else if(b<0)c=0;else c=b;a.images.splice(c,1);a.count--;a.thumbs&&a.thumbs[a.thumbWidgetName]&&a.thumbs[a.thumbWidgetName]("remove",b)},_getExt:function(a){var c,b,e=/[0-9a-z]+$/i,d=a.indexOf("?");if(d>-1)a=a.substring(0,d);b=a.match(e);if(b)c=b[0].toLowerCase();return c},_getPlayerName:function(c){if(c.indexOf("#")===0||c.indexOf("#")>0&&c.indexOf(document.location.href)===0)return"inline";var e=["bmp","gif","jpg","jpeg","png"],f=["swf"],d=["flv","m4v"],h=["dv","mov","moov","movie","mp4","avi","mpg","mpeg"],g=["asf","avi","mpg","mpeg","wm","wmv"],b=this._getExt(c);if(b){if(a.inArray(b,e)>=0)return"img";if(a.inArray(b,f)>=0)return"swf";if(a.inArray(b,d)>=0)return"flv";if(a.inArray(b,g)>=0)return"wmp";if(a.inArray(b,h)>=0)return"qt"}return"unknown"},_wrapFlash:function(m,p,k){var i=this,b=i.options,j=k,d,h="100%",e="100%",n=b.flashInstall,o=b.flashVersion,c=b.flashVars,g=b.flashParams,l=i._newId();if(p==="flv"){j=b.flvPlayer;c=a.extend({file:k,width:h,height:e,autostart:b.autoPlayMovies?"true":"false",controlbar:b.showMovieControls?"bottom":"none",backcolor:"0x000000",frontcolor:"0xCCCCCC",lightcolor:"0x557722"},b.flashVars);g=a.extend({autostart:b.autoPlayMovies?"true":"false",allowscriptaccess:"always"},b.flashParams)}d=a("<div/>").addClass(f).appendTo(m);a("<div/>").css({width:"100%",height:"100%",overflow:"hidden"}).attr("id",l).appendTo(d);S.flash.embedSWF(j,l,h,e,o,n,c,g)},_newId:function(){var d="a|b|c|d|e|f|g|h|i|j|k|l|m|n|o|p|q|r|s|t|u|v|w|x|y|z",a=[],b="";a=d.split("|");for(var c=0;c<16;c++)b+=a[Math.round(Math.random()*25)];return b}})})(jQuery);
(function(a){"use strict";if(!window.Raphael)return;Raphael.fn.isoTri=function(a,b,d,c,l){var f=a,i=b+c/2,g=a+d,j=b,h=a+d,k=b+c,e;if(l==="north"){f=a;i=b;g=a-d/2;j=b+c;h=a+d/2;k=b+c}e=["M",f,i,"L",g,j,"L",h,k,"z"];return this.path(e.concat(" "))};a.wijgauge={math:{mod360:function(b){var a=b%360;if(b<0)a+=360;return a},getAngle:function(e,d,f){var a=this,b=a.distance(d,f),c=a.distance(d,e),g=a.distance(f,e),i=b*b,j=c*c,k=g*g,h=Math.acos((k-j-i)/(-2*c*b));return Math.round(180/Math.PI*h)},distance:function(a,b){return Math.sqrt(Math.pow(b.x-a.x,2)+Math.pow(b.y-a.y,2))},log:function(b,a){return b<=0?NaN:a===1||a<0?NaN:Math.log(b)/Math.log(a)}},decoratorUtils:{generateValues:function(b,f,a){var d=[],e,c;if(f>b&&a>0){e=parseInt((f-b)/a+1,10);for(c=0;c<e;c++)d.push(b+c*a)}else a===0&&d.push(b);return d},isInRange:function(a,c,b){return a>=c&&a<=b||a<=c&&a>=b}},paintMarker:function(b,c,e,f,a,d){return c==="rect"?b.rect(e-a/2,f-d/2,a,d):b.paintMarker(c,e,f,a)},formatString:function(c,b){return a.isFunction(b)?b.call(this,c):b!==""?b.replace(/\{0\}/g,c):c}}})(jQuery);(function(a){"use strict";a.widget("wijmo.wijgauge",{options:{value:0,max:100,min:0,width:600,height:400,tickMajor:{position:"inside",style:{fill:"#1E395B",stroke:"none"},factor:2,visible:true,marker:"rect",offset:0,interval:10},tickMinor:{position:"inside",style:{fill:"#1E395B",stroke:"none"},factor:1,visible:false,marker:"rect",offset:0,interval:5},pointer:{length:1,style:{fill:"#1E395B",stroke:"#1E395B"},width:8,offset:0,shape:"tri",visible:true,template:null},islogarithmic:false,logarithmicBase:10,labels:{format:"",style:{fill:"#1E395B","font-size":12,"font-weight":"800"},visible:true,offset:0},animation:{enabled:true,duration:2e3,easing:">"},face:{style:{fill:"270-#FFFFFF-#D9E3F0",stroke:"#7BA0CC","stroke-width":4},template:null},marginTop:0,marginRight:0,marginBottom:0,marginLeft:0,ranges:[],beforeValueChanged:null,valueChanged:null,painted:null},_create:function(){var a=this,b=a.options;isNaN(b.width)&&a._setDefaultWidth();isNaN(b.height)&&a._setDefaultHeight();a._setDefaultWidthHeight();b.disabled&&a.disable();a.element.addClass("ui-widget").toggleClass("ui-state-disabled",b.disabled);a.canvas=new Raphael(a.element[0],b.width,b.height);a._autoCalculate();a._draw()},_autoCalculate:function(){},_setDefaultWidth:function(){},_setDefaultHeight:function(){},_setDefaultWidthHeight:function(){var c=this,a=c.element,d=c.options,b=a.get(0).style,f=b.width,e=b.height;if(f!=="")d.width=a.width();if(e!=="")d.height=a.height()},_setOption:function(d,c){var b=this,f=b.options,e=f[d];if(d==="disabled")b._handleDisabledOption(c,b.element);else if(d==="value"){if(f.disabled)return;if(b._trigger("beforeValueChanged",null,{newValue:c,oldValue:e})){a.Widget.prototype._setOption.apply(b,arguments);b._set_value(c,e)}b._trigger("valueChanged",null,{newValue:c,oldValue:e})}else{if(f.disabled)return;a.Widget.prototype._setOption.apply(b,arguments);if(a.isPlainObject(c))f[d]=a.extend({},e,c);if(f.radius==="auto"){b._autoCalculate();b.redraw();return}b["_set_"+d]&&b["_set_"+d](c,e)}},_set_value:function(){this._setPointer()},_set_max:function(){this._redrawMarksAndLabels();this._setPointer()},_set_min:function(){this._redrawMarksAndLabels();this._setPointer()},_set_width:function(){this.redraw()},_set_height:function(){this.redraw()},_set_tickMajor:function(){this._redrawMarksAndLabels()},_set_tickMinor:function(){this._redrawMarksAndLabels()},_set_pointer:function(){var a=this;a.pointer&&a.pointer.remove();a._paintPointer();a._setPointer()},_set_islogarithmic:function(){var a=this;a._redrawMarksAndLabels();a._setPointer()},_set_logarithmicBase:function(){var a=this;a._redrawMarksAndLabels();a._setPointer()},_set_labels:function(){this._redrawMarksAndLabels()},_set_margin:function(b,a){b!==a&&this.redraw()},_set_marginTop:function(b,a){this._set_margin(b,a)},_set_marginBottom:function(b,a){this._set_margin(b,a)},_set_marginLeft:function(b,a){this._set_margin(b,a)},_set_marginRight:function(b,a){this._set_margin(b,a)},_redrawMarksAndLabels:function(){var a=this;a._removeMarksAndLabels();a._drawMarksAndLabels()},_removeMarksAndLabels:function(){var b=this;a.each(b.labels,function(b,a){a.remove()});a.each(b.majorMarks,function(b,a){a.remove()});a.each(b.minorMarks,function(b,a){a.remove()})},_drawMarksAndLabels:function(){var a=this;a.labels=[];a.majorMarks=[];a.minorMarks=[];a._paintMarks()},_triggerPainted:function(){return this._trigger("painted")},_draw:function(){var a=this,b=a.options;a.pointer=null;a._innerBbox={width:b.width-b.marginLeft-b.marginRight,height:b.height-b.marginTop-b.marginBottom,left:b.marginLeft,top:b.marginTop};a._paintFace();a.ranges&&a._removeRanges();a._paintRanges();a._drawMarksAndLabels();a._paintPointer();if(a.pointer){a._setOffPointerValue();a._setPointer()}a._triggerPainted()},redraw:function(){var a=this,b=a.options;a.element.empty();a.canvas=new Raphael(a.element[0],b.width,b.height);a._draw()},destroy:function(){var b=this;b._unbindEvents(b.majorMarks);b._unbindEvents(b.minorMarks);b._unbindEvents(b.labels);b.element.removeClass("ui-widget").empty();if(b.disabledDiv){b.disabledDiv.remove();b.disabledDiv=null}a.Widget.prototype.destroy.apply(b,arguments)},getCanvas:function(){return this.canvas},_percentage:function(){var e=this,b=e.options,d=b.max,a=b.min,c=b.value;return isNaN(c)?0:d===a?1:(c-a)/(d-a)},_valueToLogical:function(e){var i=this,b=i.options,f=b.min,g=b.max,h=b.logarithmicBase,c,d;if(e<f)return 0;if(g<e)return 1;c=(e-f)/(g-f);if(!b.islogarithmic)d=c;else d=a.wijgauge.math.log(1+(h-1)*c,b.logarithmicBase);return d},_logicalToValue:function(b){var f=this,a=f.options,e=a.max,d=a.min,c;if(b<0)return d;if(1<=b)return e;if(!a.islogarithmic)c=b;else{if(a.logarithmicBase<=1)return a.min;c=(Math.pow(a.logarithmicBase,b)-1)/(a.logarithmicBase-1)}return d+(e-d)*c},_paintFace:function(){},_paintRanges:function(){var b=this,d=b.options,c=d.ranges||[];b.ranges=[];a.each(c,function(c,a){b._paintRange(a)})},_removeRanges:function(){a.each(this.ranges,function(b,a){a.remove()})},_paintMarks:function(){var b=this,c=b.options,d=a.wijgauge.decoratorUtils.generateValues,e=d(c.min,c.max,c.tickMajor.interval),g=d(c.min,c.max,c.tickMinor.interval),f=c.labels,h=f.visible;c.tickMajor.visible&&a.each(e,function(d,a){b.majorMarks.push(b._paintMark(a,c.tickMajor,true));h&&b.labels.push(b._paintLabel(a,f))});c.tickMinor.visible&&a.each(g,function(g,f){var d=false;a.each(e,function(b,a){if(f===a){d=true;return false}});!d&&b.minorMarks.push(b._paintMark(f,c.tickMinor,false))});b._bindClickEvents(b.majorMarks);b._bindClickEvents(b.minorMarks);b._bindClickEvents(b.labels)},_bindClickEvents:function(c){var b=this;a.each(c,function(d,c){a(c.node).bind("click."+b.widgetName,function(a){b._trigger("click",a,{ele:c})})})},_unbindEvents:function(b){var c=this;a.each(b,function(d,b){a(b.node).unbind("."+c.widgetName)})},_paintLabel:function(){},_paintMark:function(){},_paintPointer:function(){},_setPointer:function(){},_setOffPointerValue:function(){},_handleDisabledOption:function(b,c){var a=this;if(b){if(!a.disabledDiv)a.disabledDiv=a._createDisabledDiv(c);a.disabledDiv.appendTo("body")}else if(a.disabledDiv){a.disabledDiv.remove();a.disabledDiv=null}},_createDisabledDiv:function(h){var d=this,e=d.options,b=h||d.element,c=b.offset(),g=e.width||b.outerWidth(),f=e.height||b.outerHeight();return a("<div></div>").addClass("ui-disabled").css({"z-index":"99999",position:"absolute",width:g,height:f,left:c.left,top:c.top})}})})(jQuery);
(function(a){"use strict";a.widget("wijmo.wijlineargauge",a.wijmo.wijgauge,{options:{orientation:"horizontal",xAxisLocation:.1,xAxisLength:.8,yAxisLocation:.5,width:"auto",height:"auto",pointer:{length:.5,width:4,offset:0,visible:true,template:null},marginLeft:5,marginTop:5,marginRight:5,marginBottom:5},_setDefaultWidth:function(){var a=this.options;a.width=a.orientation==="horizontal"?310:70},_setDefaultHeight:function(){var a=this.options;a.height=a.orientation==="horizontal"?70:310},_set_orientation:function(){var a=this;a._setDefaultWidth();a._setDefaultHeight();a.markBbox=null;a.redraw()},_set_xAxisLocation:function(){this.redraw()},_set_xAxisLength:function(){this.redraw()},_set_yAxisLocation:function(){this.redraw()},_create:function(){a.wijmo.wijgauge.prototype._create.apply(this,arguments);this.element.addClass("wijmo-wijlineargauge")},_paintLabel:function(g,i){var d=this,n=d.options,k=i.format,m=i.style,h=g,l=d.options.tickMajor,j=l.position||"inside",c,f,b,e;if(k!=="")h=a.wijgauge.formatString(g,k);b=d._getMarkerBbox();e=d._getLabelBBox(h);c=d._valueToPoint(g,0);if(n.orientation==="horizontal")if(j==="inside")c.y=b.y-e.height;else c.y=b.y+b.width;else if(j==="inside")c.x=b.x-e.width/2;else c.x=b.x+b.width+e.width/2;f=d.canvas.text(c.x,c.y,h);f.attr(m);a.wijraphael.addClass(a(f.node),"wijmo-wijlineargauge-label");return f},_getLabelBBox:function(d){var c=this,e=c.options,a,b;a=c.canvas.text(0,0,d);a.attr(e.gaugeLableStyle);b=a.wijGetBBox();a.remove();return b},_getMarkerBbox:function(){var a=this,d=a.options,c=d.tickMajor,b;if(!a.markBbox){b=a._paintMark(0,c);a.markBbox=b.wijGetBBox();b.remove()}return a.markBbox},_paintMark:function(h,f,m){var b=this,j=b.options,d=f.marker||"rect",k=d==="rect"?5:2,e=b._valueToPoint(h,0),l=f.position||"inside",n=f.offset||0,i=m?2:1,g,c;g=k*f.factor;if(a.isFunction(d))return d.call(b,b.canvas,e,j);else if(j.orientation==="horizontal")c=a.wijgauge.paintMarker(b.canvas,d,e.x,e.y,i,g);else c=a.wijgauge.paintMarker(b.canvas,d,e.x,e.y,g,i);c.attr(f.style);a.wijraphael.addClass(a(c.node),"wijmo-wijlineargauge-mark");b._applyPosition(c,l,n,h);return c},_applyPosition:function(f,g,a){var c=0,d=0,h=this,e=h.options.orientation==="horizontal",b=f.wijGetBBox();switch(g){case"inside":if(e)d-=b.width/2+a;else c-=b.width/2+a;break;case"outside":if(e)d+=b.width/2+a;else c+=b.width/2+a;break;case"center":if(e)d-=a;else c-=a}f.attr("transform","t"+c+","+d)},_paintFace:function(){var b=this,d,c=b.options,f=b._innerBbox.width,e=b._innerBbox.height,g=b._innerBbox.left,h=b._innerBbox.top,i={width:f,height:e,x:g,y:h,canvas:b.canvas};if(c.face&&c.face.template&&a.isFunction(c.face.template))return c.face.template.call(b,i);d=b.canvas.rect(g,h,f,e,5);c.face&&c.face.style&&d.attr(c.face.style);a.wijraphael.addClass(a(d.node),"wijmo-wijlineargauge-face");return d},_paintPointer:function(){var c=this,h=c.options,g=c._valueToPoint(0,0),j=c._innerBbox.width,i=c._innerBbox.height,l=c._innerBbox.left,m=c._innerBbox.top,b=h.pointer,e,d,f,k;if(!b.visible)return;k=h.orientation==="horizontal"?i:j;f=k*b.offset;d=k*b.length;if(b.template&&a.isFunction(b.template))e=b.template.call(c.canvas,g,a.extend({},h.pointer,{offset:f,length:d}));else{if(h.orientation==="horizontal")if(b.shape==="rect")e=c.canvas.rect(g.x-b.width/2,i-d-f+m,b.width,d);else e=c.canvas.isoTri(g.x-b.width/2,i-d-f+m,b.width,d,"north");else if(b.shape==="rect")e=c.canvas.rect(j-d-f+l,g.y-b.width/2,d,b.width);else e=c.canvas.isoTri(j-d-f+l,g.y-b.width/2,d,b.width);e.attr(b.style)}a.wijraphael.addClass(a(e.node),"wijmo-wijlineargauge-pointer");c.pointer=e},_setPointer:function(){var a=this,c=a.options,b=c.orientation,d=b==="horizontal"?a._minScreenPoint(0).x:a._minScreenPoint(0).y,e=b==="horizontal"?a._maxScreenPoint(0).x:a._maxScreenPoint(0).y;if(!a.pointer)return;a._setLinearPointer(d,e,c.value)},_setLinearPointer:function(h,i,g){var b=this,f=b.options,e=b._valueToPoint(g,0),c=b.pointer.wijGetBBox(),d=f.animation,a={x:0,y:0};if(f.orientation==="horizontal")a.x=e.x-c.x-c.width/2;else a.y=e.y-c.y-c.height/2;if(d.enabled)b.pointer.wijAnimate({transform:"...t"+a.x+","+a.y},d.duration,d.easing);else b.pointer.attr("transform","...t"+a.x+","+a.y)},_minScreenPoint:function(h){var a=this,b=a.options,e=a._innerBbox.width,d=a._innerBbox.height,f=a._innerBbox.left,g=a._innerBbox.top,c=b.yAxisLocation+h;return b.orientation==="horizontal"?{x:e*b.xAxisLocation+f,y:d*c+g}:{x:e*c+f,y:d*(1-b.xAxisLocation)+g}},_maxScreenPoint:function(i){var a=this,b=a.options,e=a._innerBbox.width,d=a._innerBbox.height,f=a._innerBbox.left,h=a._innerBbox.top,c=b.yAxisLocation+i,g=b.xAxisLocation+b.xAxisLength;return b.orientation==="horizontal"?{x:e*g+f,y:d*c+h}:{x:e*c+f,y:d*(1-g)+h}},_paintRange:function(a){var g=this,d=g.options,b=isNaN(a.startValue)?0:a.startValue,c=isNaN(a.endValue)?0:a.endValue,h=isNaN(a.startWidth)?isNaN(a.width)?0:a.width:a.startWidth,i=isNaN(a.endWidth)?isNaN(a.width)?0:a.width:a.endWidth,j=a.startDistance||0,k=a.endDistance||0,e,f;if(b!==c){if(c>b){e=Math.max(b,d.min);f=Math.min(d.max,c)}else{e=Math.max(d.min,c);f=Math.min(d.max,b)}g._drawRange(e,f,j,k,h,i,a)}},_drawRange:function(s,u,e,f,n,o,v){var b=this,w=b.options,t=w.orientation,k=b._innerBbox.width,j=b._innerBbox.height,q=b._innerBbox.left,r=b._innerBbox.top,c=b._valueToPoint(s,0),d=b._valueToPoint(u,0),l,m,p,i,g,h;if(t==="horizontal"){g=n*j;h=o*j;if(e!==0)c.y=e*j+r;if(f!==0)d.y=f*j+r;l={x:c.x,y:c.y-g};m={x:d.x,y:d.y-h}}else{g=n*k;h=o*k;if(e!==0)c.x=e*k+q;if(f!==0)d.x=f*k+q;l={x:c.x-g,y:c.y};m={x:d.x-h,y:d.y}}p=["M",c.x,c.y,"L",d.x,d.y,"L",m.x,m.y,"L",l.x,l.y,"Z"];i=b.canvas.path(p.concat(" "));i.attr(v.style);a.wijraphael.addClass(a(i.node),"wijmo-wijlineargauge-range");b.ranges.push(i)},_valueToPoint:function(g,e){var b=this,f=b.options,a,d,c;if(f.max===f.min)return{x:0,y:0};a=b._valueToLogical(g);d=b._minScreenPoint(e);c=b._maxScreenPoint(e);return{x:d.x*(1-a)+c.x*a,y:d.y*(1-a)+c.y*a}}})})(jQuery);
(function(a){"use strict";var c=180,b=9,d=5;a.widget("wijmo.wijradialgauge",a.wijmo.wijgauge,{options:{radius:"auto",startAngle:0,sweepAngle:180,pointer:{length:.8,style:{fill:"#1E395B",stroke:"#1E395B"},width:8,offset:.15},origin:{x:.5,y:.5},labels:{style:{fill:"#1E395B","font-size":12,"font-weight":"800"},offset:30},tickMinor:{position:"inside",offset:30,style:{fill:"#1E395B"},visible:true},tickMajor:{position:"inside",offset:27,style:{fill:"#1E395B",stroke:"#1E395B","stroke-width":1},visible:true},cap:{radius:15,style:{fill:"#1E395B",stroke:"#1E395B"},behindPointer:false,visible:true,template:null},face:{style:{fill:"r(0.9, 0.60)#FFFFFF-#D9E3F0",stroke:"#7BA0CC","stroke-width":4}}},_create:function(){var b=this;a.wijmo.wijgauge.prototype._create.apply(b,arguments);b.element.addClass("wijmo-wijradialgauge")},_init:function(){var b=this,c=b.options;a.wijmo.wijgauge.prototype._init.apply(b,arguments)},_set_radius:function(){var a=this;a._redrawMarksAndLabels();a.pointer.remove();a._paintPointer();a._setPointer()},_set_startAngle:function(){var a=this;a._redrawMarksAndLabels();a._setPointer()},_set_sweepAngle:function(b){var a=this;if(b>360)a.options.endAngle=360;a._redrawMarksAndLabels();a._setPointer()},_set_ranges:function(){var a=this;a._removeRanges();a._paintRanges()},_set_width:function(){var b=this;b._autoCalculate();a.wijmo.wijgauge.prototype._set_width.apply(b,arguments)},_set_height:function(){var b=this;b._autoCalculate();a.wijmo.wijgauge.prototype._set_width.apply(b,arguments)},_set_origin:function(){var b=this;b._autoCalculate();a.wijmo.wijgauge.prototype._set_width.apply(b,arguments)},_set_cap:function(){var a=this;a.pointer.remove();a._paintPointer();a._setPointer()},_valueToAngleIncludeOffset:function(b){return a.wijgauge.math.mod360(this._valueToAngle(b)+c)},_valueToAngle:function(c){var a=this,b=a._valueToLogical(c);return a._logicalToAngle(b)},_angleToValue:function(c){var a=this,b=a._angleToLogical(c);return a._logicalToValue(b)},_logicalToAngle:function(b){var e=this,c=e.options,a=c.startAngle,d=c.sweepAngle;return a*(1-b)+(a+d)*b},_angleToLogical:function(h){var i=this,f=i.options,g=f.startAngle,c=a.wijgauge.math.mod360(h-g),b=f.sweepAngle,d,e;if(b===0||c===0)return 0;if(b<0){c=360-c;b=-b}d=c-b;if(d>0){e=360-c;return d<e?1:0}return c/b},_generatePoints:function(a,g,f,n){for(var l=this,m=parseInt(b+b*(Math.abs(parseInt(g-a,10))/(b*d)),10),i=[],c,h,k,j,e=0;e<m;e++){c=e/(m-1);h=f+(n-f)*c;j=a+(g-a)*c;k=l._angleToValue(j);i.push(l._valueToPoint(k,h))}return i},_valueToPoint:function(d,c){var e=this,b=e._valueToAngleIncludeOffset(d)*Math.PI/180,a=c;return{x:a*Math.cos(b),y:a*Math.sin(b)}},_pointToValue:function(b){var c=a.wijgauge.math.mod360(Math.atan2(b.x,-b.y)*180/Math.PI);return this._angleToValue(c)},_radiusScreen:function(a){var b=this,c=b.options;return Math.max(c.radius*a,0)},_autoCalculate:function(){var c=this,b=c.options,m=b.width,l=b.height,e,f,g,k=a.wijgauge.formatString(b.max,b.labels.format),d=0,i,h=l-b.marginTop-b.marginBottom,j=m-b.marginLeft-b.marginRight;c.centerPoint={x:b.marginLeft+j*b.origin.x,y:b.marginTop+h*b.origin.y};c.radius=b.radius;if(b.radius==="auto"){c.faceRadius=Math.min(j,h)/2;i=c._getFaceBorder();c.faceRadius-=i;if(b.tickMajor.position==="inside")c.faceRadius-=c._getMaxRangeWidth();e=c._getMarkerbbox(b.tickMajor).width;f=c._getMarkerbbox(b.tickMinor).width;g=c._getLabelBBox(k).width;if(b.tickMajor.position==="center"){d-=e/2;d-=g}else if(b.tickMajor.position==="outside"){d-=e;d-=g}if(b.tickMinor.position==="center")d=Math.min(d,-f/2);else if(b.tickMinor.position==="outside")d=Math.min(d,-f);c.radius=c.faceRadius+d}},_getMaxRangeWidth:function(){var c=this,d=c.options,b=0;a.each(d.ranges,function(c,a){b=Math.max(b,a.width||0);b=Math.max(b,a.startWidth||0);b=Math.max(b,a.endWidth||0)});return b},_getMarkerbbox:function(d){var c=this,b=c._paintMarkEle(d),a=b.wijGetBBox();b.remove();return{width:a.width,height:a.height}},_getFaceBorder:function(){var c=this,a=c._paintFace(),b=a.attr("stroke-width")||1;if(a.type==="set")b=a[0].attr("stroke-width")||1;a.remove();return b},_paintMarks:function(){var b=this;b.markBbox=null;a.wijmo.wijgauge.prototype._paintMarks.apply(b,arguments)},_paintMark:function(e,c){var d=this,b,f=c.position||"inside",g=c.offset||0;b=d._paintMarkEle(c);b.attr(c.style);a.wijraphael.addClass(a(b.node),"wijmo-wijradialgauge-mark");a(b.node).data("value",e);d._applyAlignment(b,f,g);d._setMarkValue(e,b);return b},_applyAlignment:function(b,e,d){if(!b)return;var f=b.wijGetBBox(),c=f.width/2,a=0;switch(e){case"outside":a-=c+d;break;case"inside":a+=c+d}b.transform("t"+a+",0")},_paintMarkEle:function(f){var b=this,i=b.options,d={x:b.centerPoint.x-b.radius,y:b.centerPoint.y},c=f.marker||"circle",g=c==="rect"?5:2,h=2,e;e=g*f.factor;return a.isFunction(c)?c.call(b,b.canvas,d,i):a.wijgauge.paintMarker(b.canvas,c,d.x,d.y,e,h)},_setMarkValue:function(c,d){var a=this,b=a._valueToAngle(c);d.transform(Raphael.format("r{0},{1},{2}...",b,a.centerPoint.x,a.centerPoint.y))},_paintLabel:function(i,g){var b=this,o=b._valueToAngle(i),k=g.format,p=g.style,n=g.offset,j=i,l=b.options.tickMajor,m=l.position||"inside",h,f,d,c,e;if(k!=="")j=a.wijgauge.formatString(i,k);d=b._getMarkerBbox();e=b._getLabelBBox(j);switch(m){case"inside":c=d.x+d.width+e.width/2;break;case"outside":c=d.x-e.width/2;break;default:c=d.x-e.width/2}c=b.centerPoint.x-c+n;h=a.wijmo.wijradialgauge.utility.getPositionByAngle(b.centerPoint.x,b.centerPoint.y,c,o);f=b.canvas.text(h.x,h.y,j);f.attr(p);a.wijraphael.addClass(a(f.node),"wijmo-wijradialgauge-label");return f},_getLabelBBox:function(d){var c=this,e=c.options,a,b;a=c.canvas.text(0,0,d);a.attr(e.gaugeLableStyle);b=a.wijGetBBox();a.remove();return b},_getMarkerBbox:function(){var a=this,d=a.options,c=d.tickMajor,b;if(!a.markBbox){b=a._paintMarkEle(c,true);a._applyAlignment(b,c.position,c.offset||0);a.markBbox=b.wijGetBBox();b.remove()}return a.markBbox},_paintFace:function(){var b=this,c=b.options,e=Math.min(c.width,c.height)/2,d,f;if(b.faceRadius)e=b.faceRadius;if(c.face&&c.face.template&&a.isFunction(c.face.template)){f={canvas:b.canvas,r:e,origin:{x:b.centerPoint.x,y:b.centerPoint.y}};return c.face.template.call(b,f)}d=b.canvas.circle(b.centerPoint.x,b.centerPoint.y,e);c.face&&c.face.style&&d.attr(c.face.style);a.wijraphael.addClass(a(d.node),"wijmo-wijradialgauge-face");return d},_paintPointer:function(){var c=this,d=c.options,b=d.pointer,g=c.radius*b.length,f={x:c.centerPoint.x-g+b.offset*c.radius,y:c.centerPoint.y-b.width/2},e;if(!b.visible)return;d.cap&&d.cap.behindPointer&&d.cap.visible&&c._paintCap();if(b.template&&a.isFunction(b.template))e=b.template.call(c.canvas,f,a.extend({},b,{length:g}));else{if(b.shape==="rect")e=c.canvas.rect(f.x-b.width/2,f.y,g,b.width);else e=c.canvas.isoTri(f.x-b.width/2,f.y,g,b.width);e.attr(b.style)}c.pointer=e;a.wijraphael.addClass(a(e.node),"wijmo-wijradialgauge-pointer");(!d.cap||!d.cap.behindPointer)&&d.cap.visible&&c._paintCap()},_paintCap:function(){var b=this,e=b.options,c=e.cap,d;if(c&&c.template&&a.isFunction(c.template)){d={canvas:b.canvas,origin:{x:b.centerPoint.x,y:b.centerPoint.y}};b.cap=c.template.call(b,d);return b.cap}b.cap=b.canvas.circle(b.centerPoint.x,b.centerPoint.y,c.radius);c&&c.style&&b.cap.attr(c.style);a.wijraphael.addClass(a(b.cap.node),"wijmo-wijradialgauge-cap");return b.cap},_paintRange:function(a){var d=this,e=d.options,b=isNaN(a.startValue)?0:a.startValue,c=isNaN(a.endValue)?0:a.endValue,j=isNaN(a.startWidth)?isNaN(a.width)?0:a.width:a.startWidth,k=isNaN(a.endWidth)?isNaN(a.width)?0:a.width:a.endWidth,f=a.startDistance||1,h=a.endDistance||1,g,i;if(b!==c){if(c>b){g=Math.max(b,e.min);i=Math.min(e.max,c)}else{g=Math.max(e.min,c);i=Math.min(e.max,b)}f=f*d.radius;h=h*d.radius;d._drawRange(g,i,f,h,j,k,a)}},_drawRange:function(o,p,g,h,l,m,n){var b=this,i=b._valueToAngle(o),j=b._valueToAngle(p),k=b._generatePoints(i,j,l+g,m+h),f=b._generatePoints(i,j,g,h),d,e,c="";a.each(k,function(d,a){if(d===0)c+="M"+(a.x+b.centerPoint.x)+" "+(a.y+b.centerPoint.y);else c+="L"+(a.x+b.centerPoint.x)+" "+(a.y+b.centerPoint.y)});for(d=f.length-1;d>=0;d--)c+="L"+(f[d].x+b.centerPoint.x)+" "+(f[d].y+b.centerPoint.y);c+="Z";e=b.canvas.path(c);e.attr(n.style);b.ranges.push(e);a.wijraphael.addClass(a(e.node),"wijmo-wijradialgauge-range")},_setOffPointerValue:function(){var a=this,b=a._valueToAngle(0);a.pointer.transform(Raphael.format("r{0},{1},{2}",b,a.centerPoint.x,a.centerPoint.y))},_setPointer:function(){var a=this,d=a.options,c=a._valueToAngle(d.value),b=d.animation;if(!a.pointer)return;if(b.enabled)a.pointer.wijAnimate({transform:"r"+c+","+a.centerPoint.x+","+a.centerPoint.y},b.duration,b.easing);else a.pointer.transform(Raphael.format("r{0},{1},{2}",c,a.centerPoint.x,a.centerPoint.y))}});a.wijmo.wijradialgauge.utility={pointers:{donut:function(k,c,d,b,h,f,g){var e=a.wijmo.wijradialgauge.utility.getPositionByAngle,i=e(c,d,b,f),n=e(c,d,b,g),m=e(c,d,h,f),l=e(c,d,h,g),j=g-f>180,o;if((g-f)%360!==0){o=["M",i.x,i.y,"A",b,b,0,+j,1,n.x,n.y,"L",l.x,l.y,"A",h,h,0,+j,1,m.x,m.y,"L",i.x,i.y,"z"];k.path(o)}else k.circle(c,d,b)}},getPositionByAngle:function(e,f,c,d){var a={},b=Raphael.rad(d);a.x=e-c*Math.cos(b);a.y=f-c*Math.sin(b);return a}}})(jQuery);
(function(a){"use strict";a.widget("wijmo.wijlightbox",{options:{textPosition:"overlay",width:600,height:400,autoSize:true,player:"",groupItems:[],rootUrl:"",ctrlButtons:"",dialogButtons:"close",counterType:"default",counterFormat:"[i] of [n]",counterLimit:10,showCounter:true,showNavButtons:true,showTimer:false,controlsPosition:"inside",showControlsOnHover:true,clickPause:false,keyNav:false,modal:false,position:{my:"center",at:"center",of:window,collision:"fit",using:function(c){var b=a(this).css(c).offset().top;b<0&&a(this).css("top",c.top-b)}},zIndex:1e3,closeOnEscape:true,closeOnOuterClick:true,autoPlay:false,delay:2e3,loop:true,cookie:null,transAnimation:{animated:"fade",duration:400,easing:"easeInQuad"},slideDirection:"horizontal",resizeAnimation:{animated:"sync",duration:400},textShowOption:{duration:300,easing:"easeInQuad"},textHideOption:{duration:300,easing:"easeInQuad"},showMovieControls:true,autoPlayMovies:true,flashParams:{bgcolor:"#000000",allowfullscreen:true},flashVars:{},flashVersion:"9.0.115",flvPlayer:"player\\player.swf",flashInstall:"player\\expressInstall.swf",beforeShow:null,show:null,open:null,beforeClose:null,close:null},_keyDownHandler:function(b){var d=this.options,c=this;if(b.keyCode&&b.keyCode===a.ui.keyCode.ESCAPE){if(c._isFullSize())c._toggleFullSize();else d.closeOnEscape&&c._close();b.preventDefault();return}if(d.keyNav)if(b.keyCode)switch(b.keyCode){case a.ui.keyCode.LEFT:case a.ui.keyCode.DOWN:c.back();b.preventDefault();break;case a.ui.keyCode.RIGHT:case a.ui.keyCode.UP:c.next();b.preventDefault();break;case a.ui.keyCode.HOME:d.groupItems.length>0&&c.show(0);b.preventDefault();break;case a.ui.keyCode.END:d.groupItems.length>0&&c.show(d.groupItems.length-1);b.preventDefault()}},_create:function(){var b=this.options,c=this;this._defaults={transAnimation:{animated:"fade",duration:400,easing:"easeInQuad"},resizeAnimation:{animated:"sync",duration:400},textShowOption:{duration:300,easing:"easeInQuad"},textHideOption:{duration:300,easing:"easeInQuad"}};this._parse();this.container=a("<div/>").addClass("wijmo-wijlightbox ui-widget wijmo-wijlightbox-controls-"+b.controlsPosition).css("z-index",b.zIndex).attr({tabIndex:-1,role:"dialog"}).bind("keydown.wijlightbox",a.proxy(c,"_keyDownHandler")).appendTo(document.body).hide();this.frame=a("<div></div>").addClass("wijmo-wijlightbox-frame ui-widget-content ui-corner-all ui-helper-clearfix").appendTo(this.container);this.content=a("<div></div>").addClass("wijmo-wijlightbox-content").appendTo(this.frame);if(b.clickPause)this._groupMode()&&(b.autoPlay||this.ctrlButtons&&this.ctrlButtons.indexOf("play")>=0)&&this.content.click(function(){c[!c.isPlaying()?"play":"stop"]()});else this._groupMode()&&this.content.click(function(d){var b=a.extend({},a(this).offset(),{width:a(this).outerWidth(true),height:a(this).outerHeight(true)});if(d.pageX>=b.left&&d.pageX<b.left+b.width/2)c.back();else c.next()});if(b.activeIndex===undefined){if(typeof b.activeIndex!=="number"&&b.cookie)b.activeIndex=parseInt(c._cookie(),10);b.activeIndex=b.activeIndex||(b.groupItems.length?0:-1)}else if(b.activeIndex===null)b.activeIndex=-1;b.activeIndex=b.activeIndex>=0&&b.groupItems[b.activeIndex]||b.activeIndex<0?b.activeIndex:0;this._createTimerBar();this._createDialogButtons();this._createCtrlButtons();this._createText();this._createCounter();this._refreshCounter();this.toolBox&&this.toolBox.find(".wijmo-wijlightbox-toolbox-button").bind({mouseover:function(){c._addState("hover",a(this))},mouseout:function(){c._removeState("hover",a(this))},mousedown:function(){c._addState("active",a(this))},mouseup:function(){c._removeState("active",a(this))}});this._groupMode()&&this._createNavButtons();b.showControlsOnHover&&this.frame.bind({mouseenter:function(){if(c.container.data("moving.wijlightbox"))return false;c._showAccessories(true)},mouseleave:function(){if(c.container.data("moving.wijlightbox"))return false;c._hideAccessories(true)},mousemove:function(){c.container.data("moving.wijlightbox")===false&&c.container.data("accessvisible.wijlightbox")===false&&c.frame.trigger("mouseenter")}});this.container.width(this.frame.outerWidth())},destroy:function(){var c=this.options,b=this;this._hideWaiting();this._hideOverlay();c.cookie&&this._cookie(null,c.cookie);this.container.remove();a.Widget.prototype.destroy.apply(b,arguments);return b},_setOption:function(c,b){a.Widget.prototype._setOption.apply(this,arguments);switch(c){case"groupItems":if(this.options.activeIndex>=b.length)this.show(b.length-1);else if(this.options.activeIndex<0&&b.length)this.show(0);else this.show(this.options.activeIndex);break;case"activeIndex":this.show(b);break;case"textPosition":this._resetText()}},_getPlugins:function(){var c=this.container.data("plugins.wijlightbox");if(!c){c={};if(window.navigator.plugins&&window.navigator.plugins.length){var b=[];a.each(window.navigator.plugins,function(c,a){b.push(a.name)});b=b.join(",");var e=b.indexOf("Flip4Mac")>-1;c={fla:b.indexOf("Shockwave Flash")>-1,qt:b.indexOf("QuickTime")>-1,wmp:!e&&b.indexOf("Windows Media")>-1,f4m:e}}else{var d=function(b){var a;try{a=new ActiveXObject(b)}catch(c){}return!!a};c={fla:d("ShockwaveFlash.ShockwaveFlash"),qt:d("QuickTime.QuickTime"),wmp:d("wmplayer.ocx"),f4m:false}}this.container.data("plugins.wijlightbox",c)}return c},_sanitizeSelector:function(a){return a.replace(/:/g,"\\:")},_getFragmentId:function(d){var f=/^#.+/,b=a(d).attr("href")||"",c=b.split("#")[0],e=a("base")[0];if(c&&(c===window.location.toString().split("#")[0]||e&&c===e.href)){b=d.hash;d.href=b}return f.test(b)?this._sanitizeSelector(b):""},_parseLink:function(j){var e=this,g=this.options,d=a(j);if(d.length>0&&d[0].tagName.toLowerCase()==="a"){var f=d.attr("rel"),b={},k=["href","player","title","alt","height","width","gallery"];a.each(k,function(c,a){b[a]=d.attr(a)||""});if(!b.href)return;if(!b.player)b.player=g.player||e._getPlayerName(b.href);var c=d.find("img");if(c&&c.length===0)c=d;if(c&&c.length>=1){a.each(["title","alt"],function(d,a){b[a]=c.attr(a)||b[a]});b.img=c}if(f){var h=f.match(/\[(.*?)\]/);if(h)b.gallery=h[1]||b.gallery;a.each(f.split(";"),function(d,c){var a=c.match(/\s*([a-z_]*?)\s*=\s*(.+)\s*/);if(a)b[a[1]]=a[2]})}if(b.player==="inline")b.href=e._getFragmentId(j);if(!b.gallery)d.bind({click:function(){e._open(c,b);return false}});else{var i=g.groupItems.length;g.groupItems[i]=b;d.bind({click:function(){e._open(c,i);return false}})}}},_parse:function(){var a=this,b=this.options;this._parseLink(this.element);this.element.find('a[rel^="wijlightbox"], a[rel^="lightbox"]').each(function(){a._parseLink(this)})},_showAccessories:function(a){this.container.data("accessvisible.wijlightbox",true);this._showNavButtons(a);this._showToolboxButtons(a);this._showCounter(a)},_hideAccessories:function(a){this.container.data("accessvisible.wijlightbox",false);this._hideNavButtons(a);this._hideToolboxButtons(a);this._hideCounter(a)},_groupMode:function(){var b=this,a=this.options;return a.groupItems&&a.groupItems.length>0},_resetText:function(){this._removeText();this._createText()},_createText:function(h){var g=this,c=this.options;if(c.textPosition==="none")return;if(this.container.find(".wijmo-wijlightbox-text").length)return;var e=c.textPosition.toLowerCase(),b=a("<div></div>").addClass("wijmo-wijlightbox-text wijmo-wijlightbox-text-"+e+" ui-widget-content ui-helper-clearfix"),f=a("<h3></h3>").addClass("wijmo-wijlightbox-title wijmo-wijlightbox-title-"+e+" ui-helper-clearfix").appendTo(b),i=a("<p></p>").addClass("wijmo-wijlightbox-detail wijmo-wijlightbox-detail-"+e+" ui-helper-clearfix").appendTo(b);if(c.textPosition==="inside")b.addClass("ui-widget-content ui-helper-clearfix").width(this.frame.width()).appendTo(this.frame);else if(c.textPosition==="outside")b.addClass("ui-widget-content ui-corner-all ui-helper-clearfix").width(this.frame.width()).appendTo(this.container);else if(c.textPosition==="overlay"||c.textPosition==="titleOverlay"){var d=a("<div></div>").addClass("wijmo-wijlightbox-mask wijmo-wijlightbox-mask-"+e+" ui-helper-clearfix").width(this.frame.width()).appendTo(this.frame);b.width(this.frame.width()).appendTo(this.frame);c.textPosition==="titleOverlay"&&b.bind({mouseenter:function(){d.stop();b.stop();var e=f.outerHeight(true)+i.outerHeight(true),h=a.extend({},g._defaults.textShowOption,c.textShowOption,{queue:false});d.animate({height:e},h);b.animate({height:e},h)},mouseleave:function(){d.stop();b.stop();var e=f.height(),h=a.extend({},g._defaults.textHideOption,c.textHideOption,{queue:false});d.animate({height:e},h);b.animate({height:e},h)}})}this._refreshText(h)},_removeText:function(){var b=this.container.find(".wijmo-wijlightbox-text"),a=this.container.find(".wijmo-wijlightbox-mask");b&&b.remove();a&&a.remove()},_getActiveItem:function(){var b=this,a=this.options;return a.groupItems&&a.groupItems.length&&a.activeIndex>=0&&a.activeIndex<a.groupItems.length?a.groupItems[a.activeIndex]:null},_refreshText:function(l){var m=this,c=this.options;if(c.textPosition==="none")return;var h=this.container.data("item.wijlightbox")||this._getActiveItem();if(!h)return;var b=this.container.find(".wijmo-wijlightbox-text"),k=this.container.find(".wijmo-wijlightbox-title"),j=this.container.find(".wijmo-wijlightbox-detail"),g=this.container.find(".wijmo-wijlightbox-mask");g.stop();b.stop();k.html(h.title);j.html(h.alt);c.textPosition==="outside"&&b.width(this.frame.width());var d=k.outerHeight(true),e=j.outerHeight(true),n=c.textPosition==="titleOverlay"?d:b.height(),f=a.extend({},m._defaults.textShowOption,c.textShowOption,{queue:false});if(c.textPosition==="overlay"||c.textPosition==="titleOverlay"){var i=d+(c.textPosition==="overlay"?e:0);b.height(0);g.height(0);b.animate({height:i},f);g.animate({height:i},f)}else if(!!l)b.height(d+e);else{b.height(0);b.animate({height:d+e},f)}},_addState:function(b,a){a.is(":not(.ui-state-disabled)")&&a.addClass("ui-state-"+b)},_removeState:function(a,b){b.removeClass("ui-state-"+a)},_createNavButtons:function(){var b=this,c=this.options;if(!c.showNavButtons||!this._groupMode()){this._removeNavButtons();return}if(!this.backBtn)this.backBtn=a("<a href='#'/>").addClass("wijmo-wijlightbox-button wijmo-wijlightbox-button-prev ui-state-default"+(c.controlsPosition==="inside"?" ui-corner-right":" ui-corner-left")).append("<span class='ui-icon ui-icon-triangle-1-w'></span>").hide().appendTo(this.frame).bind({click:function(){!a(this).hasClass("ui-state-disabled")&&b.back();return false},mouseover:function(){b._addState("hover",a(this))},mouseout:function(){b._removeState("hover",a(this))},mousedown:function(){b._addState("active",a(this))},mouseup:function(){b._removeState("active",a(this))}});if(!this.nextBtn)this.nextBtn=a("<a href='#'/>").addClass("wijmo-wijlightbox-button wijmo-wijlightbox-button-next ui-state-default"+(c.controlsPosition==="inside"?" ui-corner-left":" ui-corner-right")).append("<span class='ui-icon ui-icon-triangle-1-e'></span>").hide().appendTo(this.frame).bind({click:function(){!a(this).hasClass("ui-state-disabled")&&b.next();return false},mouseover:function(){b._addState("hover",a(this))},mouseout:function(){b._removeState("hover",a(this))},mousedown:function(){b._addState("active",a(this))},mouseup:function(){b._removeState("active",a(this))}})},_removeNavButtons:function(){if(this.backBtn){this.backBtn.remove();this.backBtn=undefined}if(this.nextBtn){this.nextBtn.remove();this.nextBtn=undefined}},_refreshNavButtons:function(){var a=this.options;this.backBtn&&this.backBtn[a.activeIndex===0?"addClass":"removeClass"]("ui-state-disabled");this.nextBtn&&this.nextBtn[a.activeIndex>=a.groupItems.length-1?"addClass":"removeClass"]("ui-state-disabled")},_showNavButtons:function(b){if(this.isPlaying())return;this.container.find(".wijmo-wijlightbox-button").stop(true,true).fadeIn(b?600:0,function(){a(this).css("opacity","")})},_hideNavButtons:function(a){this.container.find(".wijmo-wijlightbox-button").stop(true,true).fadeOut(a?600:0)},_createToolbox:function(){if(!this.toolBox)this.toolBox=a("<div></div>").addClass("wijmo-wijlightbox-toolbox").appendTo(this.frame)},_showToolboxButtons:function(b){this.container.find(".wijmo-wijlightbox-toolbox-button").stop(true,true).fadeIn(b?600:0,function(){a(this).css("opacity","")})},_hideToolboxButtons:function(a){this.container.find(".wijmo-wijlightbox-toolbox-button").stop(true,true).fadeOut(a?600:0)},_createCtrlButtons:function(){var b=this,c=this.options;if(!c.ctrlButtons||c.ctrlButtons.length===0||!this._groupMode()){this._removeCtrlButtons();return}this._createToolbox();var d=c.ctrlButtons.split("|");if(d.length===1&&d[0]===c.ctrlButtons)d=c.ctrlButtons.split(",");a.each(d,function(e,d){d=a.trim(d);if(d==="play"&&!this.playBtn)b.playBtn=a("<a href='#'/>").addClass("wijmo-wijlightbox-toolbox-button wijmo-wijlightbox-toolbox-button-play ui-state-default ui-corner-all").append("<span class='ui-icon ui-icon-play'></span>").hide().click(function(){if(b.isPlaying())b.stop();else{c.activeIndex>=c.groupItems.length-1&&b.show(0);b.play()}return false});else if(d==="stop"&&!this.stopBtn)b.stopBtn=a("<a href='#'/>").addClass("wijmo-wijlightbox-toolbox-button wijmo-wijlightbox-toolbox-button-stop ui-state-default ui-state-disabled ui-corner-all").append("<span class='ui-icon ui-icon-stop'></span>").hide().click(function(){if(b.isPlaying()){b.stop();b.show(0)}return false})});this.stopBtn&&this.stopBtn.appendTo(this.toolBox);this.playBtn&&this.playBtn.appendTo(this.toolBox)},_removeCtrlButtons:function(){if(this.playBtn){this.playBtn.remove();this.playBtn=undefined}if(this.stopBtn){this.stopBtn.remove();this.stopBtn=undefined}},_refreshCtrlButtons:function(){if(this.playBtn){var a=this.playBtn.find(".ui-icon");if(a){a.removeClass("ui-icon-play ui-icon-pause");a.addClass(this.isPlaying()?"ui-icon-pause":"ui-icon-play")}}this.stopBtn&&this.stopBtn[!this.isPlaying()?"addClass":"removeClass"]("ui-state-disabled")},_createDialogButtons:function(){var d=this,b=this.options;if(!b.dialogButtons||b.dialogButtons.length===0){this._removeDialogButtons();return}this._createToolbox();var c=b.dialogButtons.split("|");if(c.length===1&&c[0]===b.dialogButtons)c=b.dialogButtons.split(",");a.each(c,function(c,b){b=a.trim(b);if(b==="close"&&!this.closeBtn)d.closeBtn=a("<a href='#'/>").addClass("wijmo-wijlightbox-toolbox-button wijmo-wijlightbox-toolbox-button-close ui-state-default ui-corner-all").append("<span class='ui-icon ui-icon-close'></span>").hide().click(function(){d._close();return false});else if(b==="fullSize"&&!this.fullBtn)d.fullBtn=a("<a href='#'/>").addClass("wijmo-wijlightbox-toolbox-button wijmo-wijlightbox-toolbox-button-fullsize ui-state-default ui-corner-all").append("<span class='ui-icon ui-icon-arrow-4-diag'></span>").hide().click(function(){d._toggleFullSize();return false})});this.closeBtn&&this.closeBtn.appendTo(this.toolBox);this.fullBtn&&this.fullBtn.appendTo(this.toolBox);if(!this.btnSep)this.btnSep=a("<a href='#'/>").addClass("wijmo-wijlightbox-toolbox-separator").appendTo(this.toolBox)},_removeDialogButtons:function(){if(this.closeBtn){this.closeBtn.remove();this.closeBtn=undefined}if(this.fullBtn){this.fullBtn.remove();this.fullBtn=undefined}},_refreshDialogButtons:function(){if(this.fullBtn){var a=this.fullBtn.find(".ui-icon");if(a){a.removeClass("ui-icon-arrow-4-diag ui-icon-newwin");a.addClass(this._isFullSize()?"ui-icon-newwin":"ui-icon-arrow-4-diag")}}},_createTimerBar:function(){var c=this,b=this.options;if(!b.showTimer||!this._groupMode()){this._removeTimerBar();return}this._createToolbox();if(!this.timerBar){this.timerBar=a("<div></div>").addClass("wijmo-wijlightbox-timerbar ui-widget-content ui-priority-secondary ui-corner-all").appendTo(this.toolBox);this.timerMeter=a("<div></div>").addClass("wijmo-wijlightbox-timermeter ui-progressbar-value ui-widget-content ui-corner-all").appendTo(this.toolBox)}},_removeTimerBar:function(){if(this.timerMeter){this.timerMeter.remove();this.timerMeter=undefined}if(this.timerBar){this.timerBar.remove();this.timerBar=undefined}},_createCounter:function(){var c=this,b=this.options;if(!b.showCounter||!this._groupMode()){this._removeCounter();return}if(!this.counter)this.counter=a("<div></div>").addClass("wijmo-wijlightbox-counter ui-state-default"+(b.controlsPosition==="inside"?"  ui-corner-tl":" ui-corner-all")).hide().appendTo(this.frame)},_removeCounter:function(){if(this.counter){this.counter.remove();this.counter=undefined}},_refreshCounter:function(d){var i=this,b=this.options,f="";if(!this.counter||!this._groupMode())return;this.counter.empty();if(b.showCounter&&b.groupItems.length>1&&this.counter){if(d===undefined)d=b.activeIndex;var h=b.groupItems.length;if(b.counterType==="sequence"){var c=0,g=h,e=parseInt(b.counterLimit,10)||0;if(e>=2&&e<h){var k=Math.floor(e/2);c=Math.min(g-e,Math.max(c,d-k));g=Math.min(g,c+e)}while(c!==g)a("<a></a>").addClass("wijmo-wijlightbox-counter-item ui-corner-all ui-state-default"+(c===d?" wijmo-wijlightbox-counter-active ui-state-active":"")).text(++c).appendTo(this.counter);this.counter.find("a").click(function(){if(a(this).hasClass("wijmo-wijlightbox-counter-active"))return false;i.show(parseInt(a(this).text(),10)-1)})}else{var j=b.counterFormat||"[i] of [n]";f=j.replace("[i]",d+1);f=f.replace("[n]",h);a("<span></span>").text(f).appendTo(this.counter)}}},_showCounter:function(b){this.container.find(".wijmo-wijlightbox-counter").stop(true,true).fadeIn(b?600:0,function(){a(this).css("opacity","")})},_hideCounter:function(a){this.container.find(".wijmo-wijlightbox-counter").stop(true,true).fadeOut(a?600:0)},_cookie:function(){var b=this.cookie||(this.cookie=this.options.cookie.name);return a.cookie.apply(null,[b].concat(a.makeArray(arguments)))},_showOverlay:function(){if(this.container.data("overlay.wijlightbox"))return;this.container.data("overlay.wijlightbox",new a.wijmo.wijlightbox.overlay(this))},_hideOverlay:function(){var a=this.container.data("overlay.wijlightbox");if(!a)return;a.close();this.container.removeData("overlay.wijlightbox")},_hasOverlay:function(){return this.container.hasData("overlay.wijlightbox")},_showWaiting:function(){if(this.container.data("waiting.wijlightbox"))return;this.container.data("waiting.wijlightbox",new a.wijmo.wijlightbox.overlay(this,true))},_hideWaiting:function(){var a=this.container.data("waiting.wijlightbox");if(!a)return;a.close();this.container.removeData("waiting.wijlightbox")},_hasWaiting:function(){return this.container.hasData("waiting.wijlightbox")},_getUrl:function(c){var d=this.options,b=c.href,a=d.rootUrl;if(a&&a.length>0){if(a.indexOf("//")===-1)a=window.location.protocol+"//"+window.location.host+(a.startsWith("/")?"":"/")+a;if(a.substr(a.length-1,1)!=="/")a+="/";b=a+(b.substr(0,1)==="/"?b.substr(1):b)}return b},_preload:function(){for(var a=this.options,b=Math.max(0,a.activeIndex);b<Math.min(a.activeIndex+5,a.groupItems.length);b++)if(!a.groupItems[b].image){a.groupItems[b].image=new Image;a.groupItems[b].image.src=this._getUrl(a.groupItems[b])}},_slideTo:function(o,l,k,d,j){var n=this.options,i=this,b=o.getElement(),c,g;if(b.parent().is(".wijmo-wijlightbox-aniwrapper"))c=b.parent();else{c=a.effects.createWrapper(b).css({overflow:"hidden"});c.removeClass("ui-effects-wrapper");c.addClass("wijmo-wijlightbox-aniwrapper")}if(c.parent().is(".wijmo-wijlightbox-aniwrapper"))g=c.parent();else{g=a.effects.createWrapper(c).css({overflow:"hidden"});g.removeClass("ui-effects-wrapper");g.addClass("wijmo-wijlightbox-aniwrapper")}var h=n.slideDirection||"horizontal",e=b.outerWidth(),f=b.outerHeight();if(h==="horizontal"){b.width(e).css("float",d?"left":"right");c.width(2*e).css({left:d?0:-1*e,position:"absolute"})}else{b.height(f);c.width(e).css({top:d?0:-1*f,position:"absolute"}).height(2*f)}l.appendTo(c);var m=l.getElement();if(h==="horizontal")m.width(e).css("float",d?"left":"right");else m.height(f);this.container.data("animating.wijlightbox",true);c.effect("slide",{mode:"hide",direction:h==="horizontal"?d?"left":"right":d?"up":"down",easing:k.easing,distance:h==="horizontal"?e:f,duration:k.duration},function(){b=c.children(":last");while(b.parent().is(".wijmo-wijlightbox-aniwrapper"))b.parent().replaceWith(b);b.css({"float":"",width:"",height:""});if(n.autoSize&&!i._isFullSize())i._resize(j);else{a.isFunction(j)&&j.apply(i);i._refreshText()}})},_moveFrom:function(e,c,d){var b=this,g=this.options;if(a.isFunction(c)){d=c;c=a.extend({},b._defaults.resizeAnimation,g.resizeAnimation)}else c=a.extend({},b._defaults.resizeAnimation,g.resizeAnimation,c);b._removeText();if(c.animated==="none"||c.duration<=0){b._createText();a.isFunction(d)&&d.apply(b);this.container.data("moving.wijlightbox",false);return}var f=a.extend({width:b.frame.width(),height:b.frame.height()},b.container.offset());b.frame.width(e.width).height(e.height);b.container.css({left:e.left,top:e.top,width:b.frame.outerWidth(),position:"absolute",opacity:""});b._moveTo(f,c,function(){b.frame.width(f.width);b.container.width(b.frame.outerWidth());b._createText();b.container.data("moving.wijlightbox",false);a.isFunction(d)&&d.apply(b)})},_moveTo:function(d,b,f){var c=this,i=this.options;if(a.isFunction(b)){f=b;b=a.extend({},c._defaults.resizeAnimation,i.resizeAnimation)}else b=a.extend({},c._defaults.resizeAnimation,i.resizeAnimation,b);var g=b.duration/2,e=b.animated,h=c._isOpen(),l=e==="wh"?{left:d.left}:{top:d.top},m=e==="wh"?{top:d.top}:{left:d.left},j=e==="wh"?{width:d.width}:{height:d.height},k=e==="wh"?{height:d.height}:{width:d.width};if(e==="wh"||e==="hw"){h&&c.container.animate(l,{duration:g,easing:b.easing,queue:true});c.frame.animate(j,{duration:g,easing:b.easing,complete:function(){h&&c.container.animate(m,{duration:g,easing:b.easing,queue:true});c.frame.animate(k,{duration:g,easing:b.easing,complete:function(){c.container.data("moving.wijlightbox",false);a.isFunction(f)&&f.apply(c)}})}});return}h&&c.container.animate({left:d.left,top:d.top},{duration:b.duration,easing:b.easing,queue:true});c.frame.animate({width:d.width,height:d.height,opacity:1},{duration:b.duration,easing:b.easing,complete:function(){c.container.data("moving.wijlightbox",false);a.isFunction(f)&&f.apply(c)}})},show:function(a){this._show(a);return this},_resize:function(c){var b=this,e=this.options,d=a.extend({},b.container.offset(),{width:b.frame.width(),height:b.frame.height()});b._size();b._isOpen()&&b._position();b._moveFrom(d,c)},_onAfterShow:function(){var a=this,b=this.options;a._refreshNavButtons();a.container.data("animating.wijlightbox",false);!b.modal&&a._hideOverlay();var c={index:b.activeIndex,item:b.groupItems[b.activeIndex]};a._trigger("show",null,c);a._startTimer()},_show:function(f,g,i){var b=this,c=this.options;if(this.container.data("showing.wijlightbox")){var m=[function(){b._show(f,g,i)}];this.container.queue("showqueue",m);return this}var d=c.activeIndex;if(!a.isPlainObject(f)){d=f;if(d<0||d>=c.groupItems.length)return this;f=c.groupItems[d]}f&&this.container.data("item.wijlightbox",f);this._groupMode()&&this._preload();if(a.isFunction(g)){i=g;g=undefined}if(!i)i=b._onAfterShow;var l={index:d,item:f};if(b._trigger("beforeShow",null,l)===false)return this;this.container.data("showing.wijlightbox",true);var j=function(){a.isFunction(i)&&i.apply(b);b.container.data("showing.wijlightbox",false);b.container.dequeue("showqueue");b.container.clearQueue("showqueue")};b._refreshCounter(d);var h=this.container.data("player.wijlightbox"),e,k=function(){b.container.data("playerwidth.wijlightbox",e.width);b.container.data("playerheight.wijlightbox",e.height);var f=a.extend({},b._defaults.transAnimation,c.transAnimation);if(c.activeIndex===d||f.animated==="none"||f.duration<=0||!b._isOpen()){c.activeIndex=d;h&&h.remove();e.appendTo(b.content);j();return}c.cookie&&b._cookie(c.activeIndex,c.cookie);if(f.animated==="slide"){g=g===undefined?d>c.activeIndex:g;b._slideTo(h,e,f,g,j);c.activeIndex=d}else{c.activeIndex=d;var k=function(){if(e){e.appendTo(b.content,true);e.fadeIn(f.duration,j)}};a.browser.msie&&b.frame.trigger("mouseleave");var i=function(){h&&h.remove();if(c.autoSize&&!b._isFullSize())b._resize(k);else{k();b._refreshText()}};if(h)h.fadeOut(f.duration*.4,i);else i()}};e=this._createPlayer(f,k);return this},next:function(){var b=this.options;if(!this._groupMode())return false;var a=b.activeIndex+1;if(b.loop)a=a%b.groupItems.length;if(a<b.groupItems.length){this._show(a,true);return true}return false},back:function(){var b=this.options;if(!this._groupMode())return false;var a=b.activeIndex-1;if(b.loop)a=a<0?b.groupItems.length-1:a;if(a>=0){this._show(a,false);return true}return false},isPlaying:function(){return!!this.container.data("playing.wijlightbox")},_startTimer:function(){if(!this.isPlaying()||!this._groupMode())return;var b=this.options,a=this;if(b.showTimer===true){!this.timerMeter&&this._createTimerBar();var c=this.timerBar.width();a.timerMeter.width("0");a.timerMeter.animate({width:c},b.delay,function(){a.isPlaying()&&!a.next()&&a.stop()})}else window.setTimeout(function(){a.isPlaying()&&!a.next()&&a.stop()},b.delay)},play:function(){if(!this._groupMode())return false;!this.container.data("playing.wijlightbox")&&this.container.data("playing.wijlightbox",true);this._refreshCtrlButtons();this._hideNavButtons();this._startTimer()},stop:function(){this.container.removeData("playing.wijlightbox");this._refreshCtrlButtons();this._removeTimerBar()},_size:function(d,h){var g=this.options,k=this,c=g.width,b=g.height,f=g.autoSize?this.container.data("playerwidth.wijlightbox")||c:c,e=g.autoSize?this.container.data("playerheight.wijlightbox")||b:b,j=e/f;if(typeof d==="boolean")h=d;else if(a.isPlainObject(d)&&"width"in d&&"height"in d){c=d.width;b=d.height}else{var i=this.container.data("player.wijlightbox");if(g.autoSize&&i&&i.name==="img"){if(f>c){f=c;e=Math.round(c*j)}if(e>b){e=b;f=Math.round(b/j)}}c=f;b=e;if(h)return{width:c,height:b}}this.frame.width(c).height(b);this.container.width(this.frame.outerWidth(true))},_position:function(){var f=this.options,g=this,c=[],e=[0,0],d,b=f.position;if(b){if(typeof b==="string"||typeof b==="object"&&"0"in b){c=b.split?b.split(" "):[b[0],b[1]];if(c.length===1)c[1]=c[0];a.each(["left","top"],function(a,b){if(+c[a]===c[a]){e[a]=c[a];c[a]=b}});b={my:c.join(" "),at:c.join(" "),offset:e.join(" ")}}b=a.extend({},f.position,b)}d=this.container.is(":visible");!d&&this.container.show();this.container.css({top:0,left:0}).position(b);!d&&this.container.hide()},_getRelRect:function(b){var c;if(b){if(a.isPlainObject(b)&&"left"in b&&"top"in b&&"width"in b&&"height"in b)c=a.merge({},b);else b=a(b);if(b.jquery&&b.length)c=a.extend({},b.offset(),{width:b.width(),height:b.height()})}return c},_close:function(c){var g=this.options,b=this;if(!this._isOpen())return;var f={rel:c};if(false===this._trigger("beforeClose",null,f))return;c=f.rel;if(!c&&this._groupMode())c=g.groupItems[g.activeIndex].img;this.container.data("moving.wijlightbox",true);this._hideAccessories(false);this._hideWaiting();this._hideOverlay();this.stop();var e=function(){b._removePlayer();b.container.hide();b._trigger("close");b.container.unbind("keypress.wijlightbox");b.container.removeData("open.wijlightbox").removeData("rect.wijlightbox").removeData("moving.wijlightbox").removeData("fullsize.wijlightbox");a(document).unbind("keydown.wijlightbox").unbind("click.wijlightbox")},d=this._getRelRect(c);if(!d)if(this.container.data("rect.wijlightbox"))d=this.container.data("rect.wijlightbox");this._removeText();if(d){this._moveTo(d,{animated:"sync",duration:200},e);return}e.call();return this},_isOpen:function(){return!!this.container.data("open.wijlightbox")},_open:function(d,f){if(this._isOpen())return;var c=this.options,b=this;if(this.toolBox)if(this._isFullSize())this.toolBox.css({top:"2px",right:"4px"});else this.toolBox.css({top:"",right:""});var e=function(){c.modal&&b._showOverlay();if(c.showControlsOnHover)this._hideAccessories(false);else this._showAccessories(false);var e=b._getRelRect(d);b.container.css("opacity",0);b.container.show();b._size();b._createText(true);b._refreshText(true);b._position();b.container.data("open.wijlightbox",true);if(d&&e){b.container.data("rect.wijlightbox",e);b._moveFrom(e,{animated:"sync"})}else{var f=a.extend({},b._defaults.transAnimation,c.transAnimation);if(f.animated==="fade"){b.container.hide();b.container.fadeIn(f.duration,function(){b._createText()})}else b._createText();this.container.data("moving.wijlightbox",false)}a(document).bind("keydown.wijlightbox",a.proxy(b,"_keyDownHandler")).bind("click.wijlightbox",function(e){var d=e.target||e.srcElement;if(b._isOpen()&&!!c.closeOnOuterClick)d!==b.container.get(0)&&a(d).parents().index(b.container)<0&&b._close()});c.autoPlay&&this.play();b._refreshNavButtons();b._refreshDialogButtons();b._trigger("open")};this.container.data("moving.wijlightbox",true);this._show(f,true,e);return this},_getWinRect:function(){var b=a(window);return a.extend({width:b.width(),height:b.height()},b.offset()||{left:2,top:2})},_resizeHandler:function(){var b=this.options,a=this;a._removeText();a._size(a._getWinRect());a._createText()},_isFullSize:function(){return!!this.container.data("fullsize.wijlightbox")},_toggleFullSize:function(){var f=this.options,b=this;if(!b._isOpen())return;var d=a(window);if(this._isFullSize()){b.toolBox&&b.toolBox.css({top:"",right:""});this.container.data("fullsize.wijlightbox",false);d.unbind("resize.wijlightbox",a.proxy(this,"_resizeHandler"));b._resize()}else{this.container.data("fullsize.wijlightbox",true);d.bind("resize.wijlightbox",a.proxy(this,"_resizeHandler"));var c=b._getWinRect(),e=this.frame.borderSize();c.width-=e.width;c.height-=e.height;b._removeText();b._moveTo(c,{animated:"sync"},function(){b.toolBox&&b.toolBox.css({top:"2px",right:"4px"});b.frame.width(c.width);b.container.width(b.frame.outerWidth());b._createText()})}this._refreshDialogButtons()},_getExt:function(a){var b,e=/[0-9a-z]+$/i,d=a.indexOf("?");if(d>-1)a=a.substring(0,d);var c=a.match(e);if(c)b=c[0].toLowerCase();return b},_getPlayerName:function(c){if(c.indexOf("#")===0||c.indexOf("#")>0&&c.indexOf(document.location.href)===0)return"inline";var e=["bmp","gif","jpg","jpeg","png"],f=["swf"],d=["flv","m4v"],h=["dv","mov","moov","movie","mp4","avi","mpg","mpeg"],g=["asf","avi","mpg","mpeg","wm","wmv"],b=this._getExt(c);if(b){if(a.inArray(b,e)>=0)return"img";if(a.inArray(b,f)>=0)return"swf";if(a.inArray(b,d)>=0)return"flv";if(a.inArray(b,g)>=0)return"wmp";if(a.inArray(b,h)>=0)return"qt"}return"iframe"},_removePlayer:function(){var a=this.container.data("player.wijlightbox");if(a){a.remove();this.container.data("player.wijlightbox",null)}},_createPlayer:function(h,f,d){var b=h.player;if(!a.isFunction(a.wijmo.wijlightbox[b]))throw"unknown player "+b;var c=this,e=false,j=function(){e=true;this._hideWaiting();a.isFunction(f)&&window.setTimeout(function(){f.apply(c)},1)},i=function(){this._hideWaiting();a.isFunction(d)&&d.apply(c)},g=new a.wijmo.wijlightbox[b](this,h,j,i);this.container.data("player.wijlightbox",g);window.setTimeout(function(){e===false&&c._showWaiting()},200);return g}});a.extend(a.wijmo.wijlightbox,{img:function(c,b,e,d){this.name="img";this.lightbox=c;this.item=b;this.url=this.lightbox._getUrl(b);var f=this,g=a("<img></img>").css({width:"auto",height:"auto",display:"none"}).appendTo(document.body).bind({load:function(){var d=a(this);f.width=b.width?parseInt(b.width,10):d.width();f.height=b.height?parseInt(b.height,10):d.height();d.remove();e&&a.isFunction(e)&&e.apply(c)},error:function(){a(this).remove();d&&a.isFunction(d)&&d.apply(c)}}).attr("src",this.url)},swf:function(c,b,d){this.name="swf";var e=c.options;this.id="flashhost";this.lightbox=c;this.item=b;this.url=this.lightbox._getUrl(b);this.width=b.width?parseInt(b.width,10):e.width;this.height=b.height?parseInt(b.height,10):e.height;d&&a.isFunction(d)&&d.apply(c)},iframe:function(c,b,d){this.name="swf";var f=c.options;this.lightbox=c;this.item=b;this.url=this.lightbox._getUrl(b);if(b.width)this.width=parseInt(b.width,10);if(b.height)this.height=parseInt(b.height,10);this.$iframe=a("<iframe></iframe>").addClass("wijmo-wijlightbox-iframe").attr({frameborder:"0",marginwidth:"0",marginheight:"0",scrolling:"auto",allowtransparency:"true"}).hide().appendTo(c.content).bind("load",function(){d&&a.isFunction(d)&&d.apply(c)}).attr("src",this.url)},inline:function(c,b,d){this.name="inline";var f=c.options;this.lightbox=c;this.item=b;this.width=b.width?parseInt(b.width,10):f.width;if(b.height)this.height=parseInt(b.height,10);else{var e=a(this.item.href).clone().show().append('<br clear="all" />').wrap('<div class="wijmo-wijlightbox ui-widget"><div class="wijmo-wijlightbox-frame ui-widget-content ui-corner-all ui-helper-clearfix"><div class="wijmo-wijlightbox-frame ui-widget-content ui-corner-all ui-helper-clearfix"><div class="wijmo-wijlightbox-content"> </div></div></div></div>').appendTo(document.body).width(this.width);this.height=e.outerHeight(true)+10;e.unwrap();e.remove()}d&&a.isFunction(d)&&d.apply(c)},flv:function(c,b,d){this.name="flv";var e=c.options;this.id="flvhost";this.lightbox=c;this.item=b;this.url=this.lightbox._getUrl(b);var f=20;this.width=b.width?parseInt(b.width,10):e.width;this.height=b.height?parseInt(b.height,10):e.height;if(e.showMovieControls)this.height+=f;d&&a.isFunction(d)&&d.apply(c)},wmp:function(c,b,d){this.name="wmp";var e=c.options;this.id="wmphost";this.lightbox=c;this.item=b;this.url=this.lightbox._getUrl(b);var f=a.browser.msie?70:45;this.width=b.width?parseInt(b.width,10):e.width;this.height=b.height?parseInt(b.height,10):e.height;if(e.showMovieControls)this.height+=f;d&&a.isFunction(d)&&d.apply(c)},qt:function(c,b,d){this.name="qt";var e=c.options;this.id="qthost";this.lightbox=c;this.item=b;this.url=this.lightbox._getUrl(b);var f=16;this.width=b.width?parseInt(b.width,10):e.width;this.height=b.height?parseInt(b.height,10):e.height;if(e.showMovieControls)this.height+=f;d&&a.isFunction(d)&&d.apply(c)}});a.extend(a.wijmo.wijlightbox.img.prototype,{appendTo:function(b,c){this.$element=a("<img></img>").addClass("wijmo-wijlightbox-image").attr("src",this.url);c&&this.$element.hide();this.$element.appendTo(b)},remove:function(){this.$element&&this.$element.remove()},fadeOut:function(b,a){this.$element&&this.$element.fadeOut(b,a)},fadeIn:function(b,a){this.$element&&this.$element.fadeIn(b,a)},getElement:function(){return this.$element}});a.extend(a.wijmo.wijlightbox.swf.prototype,{appendTo:function(d){this.$container=a("<div/>").css({width:"100%",height:"100%",overflow:"hidden"}).attr("id",this.id).appendTo(d);var b=this.lightbox.options,e=b.flashInstall,f=b.flashVersion,c=b.flashVars,g=b.flashParams;S.flash.embedSWF(this.item.href,this.id,"100%","100%",f,e,c,g)},remove:function(){S.flash.expressInstallCallback();S.flash.removeSWF(this.id);this.$container.remove()},fadeOut:function(b,a){this.$container&&this.$container.fadeOut(b,a)},fadeIn:function(b,a){this.$container&&this.$container.fadeIn(b,a)},getElement:function(){return this.$container}});a.extend(a.wijmo.wijlightbox.iframe.prototype,{appendTo:function(b,a){!a&&this.$iframe.show()},remove:function(){this.$iframe&&this.$iframe.remove()},fadeOut:function(b,a){this.$iframe&&this.$iframe.fadeOut(b,a)},fadeIn:function(b,a){this.$iframe&&this.$iframe.fadeIn(b,a)},getElement:function(){return this.$iframe}});a.extend(a.wijmo.wijlightbox.inline.prototype,{appendTo:function(b,c){this.$element=a(this.item.href).clone().appendTo(b);!c&&this.$element.show()},remove:function(){this.$element&&this.$element.remove()},fadeOut:function(b,a){this.$element&&this.$element.fadeOut(b,a)},fadeIn:function(b,a){this.$element&&this.$element.fadeIn(b,a)},getElement:function(){return this.$element}});a.extend(a.wijmo.wijlightbox.flv.prototype,{appendTo:function(f){this.$container=a("<div/>").css({width:"100%",height:"100%",overflow:"hidden"}).attr("id",this.id).appendTo(f);var b=this.lightbox.options,d="100%",c="100%",j=b.flvPlayer,g=b.flashInstall,h=b.flashVersion,e=a.extend({file:this.url,width:d,height:c,autostart:b.autoPlayMovies?"true":"false",controlbar:b.showMovieControls?"bottom":"none",backcolor:"0x000000",frontcolor:"0xCCCCCC",lightcolor:"0x557722"},b.flashVars),i=a.extend({autostart:b.autoPlayMovies?"true":"false",allowscriptaccess:"always"},b.flashParams);S.flash.embedSWF(j,this.id,d,c,h,g,e,i)},remove:function(){S.flash.expressInstallCallback();S.flash.removeSWF(this.id);this.$container.remove()},fadeOut:function(b,a){this.$container&&this.$container.fadeOut(b,a)},fadeIn:function(b,a){this.$container&&this.$container.fadeIn(b,a)},getElement:function(){return this.$container}});a.extend(a.wijmo.wijlightbox.wmp.prototype,{appendTo:function(f){this.$container=a("<div/>").css({width:"100%",height:"100%",overflow:"hidden"}).appendTo(f);var d=this.lightbox.options,b='<object id="'+this.id+'" name="'+this.id+'" height="'+this.height+'" width="'+this.width+'"',c={autostart:d.autoPlayMovies?1:0},e;if(a.browser.msie){b+=' classid="clsid:6BF52A52-394A-11d3-B153-00C04F79FAA6"';c.url=this.url;c.uimode=d.showMovieControls?"full":"none"}else{b+=' type="video/x-ms-wmv"';b+=' data="'+this.url+'"';c.showcontrols=d.showMovieControls?1:0}b+=">";for(e in c)b+='<param name="'+e+'" value="'+c[e]+'">';b+="</object>";this.$container.html(b)},remove:function(){if(a.browser.msie)try{window[this.id].controls.stop();window[this.id].URL="movie"+now()+".wmv";window[this.id]=function(){}}catch(b){}this.$container.remove()},fadeOut:function(b,a){this.$container&&this.$container.fadeOut(b,a)},fadeIn:function(b,a){this.$container&&this.$container.fadeIn(b,a)},getElement:function(){return this.$container}});a.extend(a.wijmo.wijlightbox.qt.prototype,{appendTo:function(h){this.$container=a("<div/>").css({width:"100%",height:"100%",overflow:"hidden"}).appendTo(h);var g=this.lightbox.options,i=g.autoPlayMovies?"true":"false",j=g.showMovieControls?"true":"false",c="<object",b={id:this.id,name:this.id,width:this.width,height:this.height,kioskmode:"true"},d,e;if(a.browser.msie){b.classid="clsid:02BF25D5-8C17-4B23-BC80-D3488ABDDC6B";b.codebase="http://www.apple.com/qtactivex/qtplugin.cab#version=6,0,2,0"}else{b.type="video/quicktime";b.data=this.url}for(d in b)c+=" "+d+'="'+b[d]+'"';c+=">";var f={src:this.url,scale:"aspect",controller:j,autoplay:i};for(e in f)c+='<param name="'+e+'" value="'+f[e]+'">';c+="</object>";this.$container.html(c)},remove:function(){try{document[this.id].Stop()}catch(a){}this.$container.remove()},fadeOut:function(b,a){this.$container&&this.$container.fadeOut(b,a)},fadeIn:function(b,a){this.$container&&this.$container.fadeIn(b,a)},getElement:function(){return this.$container}});a.extend(a.wijmo.wijlightbox,{overlay:function(d,c){this.mask=a("<div></div>").addClass("ui-widget-overlay wijmo-wijlightbox-overlay"+(c?" wijmo-wijlightbox-waitingoverlay":"")).appendTo(document.body).css({width:this.width(),height:this.height()});a.fn.bgiframe&&this.mask.bgiframe();if(c){this.mask.css("z-index",this.zIndex);var b=a("<div></div>").addClass("wijmo-wijlightbox-waiting").css("z-index",this.zIndex+1).appendTo(this.mask);b.css({left:(this.mask.width()-b.width())/2,top:(this.mask.height()-b.height())/2})}a(window).bind("resize.wijlightbox-overlay",a.proxy(this,"resize"));window.setTimeout(function(){this.mask&&a(document).bind(a.wijmo.wijlightbox.overlay.events,function(b){if(a(b.target).zIndex()<a.wijmo.wijlightbox.overlay.zIndex)return false})},1)}});a.extend(a.wijmo.wijlightbox.overlay.prototype,{mask:null,zIndex:1e3,events:a.map("focus,mousedown,mouseup,keydown,keypress,click".split(","),function(a){return a+".wijlightbox-overlay"}).join(" "),close:function(){a([document,window]).unbind(".wijlightbox-overlay");this.mask.remove();this.mask=undefined},height:function(){var b,c;if(a.browser.msie&&a.browser.version<7){b=Math.max(document.documentElement.scrollHeight,document.body.scrollHeight);c=Math.max(document.documentElement.offsetHeight,document.body.offsetHeight);return b<c?a(window).height():b}else return a(document).height()},width:function(){var b,c;if(a.browser.msie&&a.browser.version<7){b=Math.max(document.documentElement.scrollWidth,document.body.scrollWidth);c=Math.max(document.documentElement.offsetWidth,document.body.offsetWidth);return b<c?a(window).width():b}else return a(document).width()},resize:function(){this.mask&&this.mask.css({width:this.width(),height:this.height()})}})})(jQuery);
(function(a){"use strict";a.widget("wijmo.wijcompositechart",a.wijmo.wijchartcore,{options:{stacked:false,clusterOverlap:0,clusterWidth:85,clusterRadius:0,clusterSpacing:0,seriesList:[],animation:{enabled:true,duration:400,easing:">"},seriesTransition:{enabled:true,duration:400,easing:">"},mouseDown:null,mouseUp:null,mouseOver:null,mouseOut:null,mouseMove:null,click:null},_create:function(){var b=this,c=b.options,d=b._getDefFill();a.each(c.seriesList,function(d,b){if(b.type==="bar"){a.extend(true,c.axis,{x:{compass:"west"},y:{compass:"south"}});return true}else if(b.type==="pie"&&b.pieSeriesList)b.data=b.pieSeriesList});a.extend(true,{compass:"east"},c.hint);a.each(c.seriesStyles,function(b,a){if(!a.fill)a.fill=d[b]});a.wijmo.wijchartcore.prototype._create.apply(b,arguments);b.chartElement.addClass("wijmo-wijcompositechart")},destroy:function(){var e=this,c=e.chartElement,d=c.data("fields"),b=d&&d.bars;c.removeClass("wijmo-wijcompositechart");a.wijmo.wijchartcore.prototype.destroy.apply(this,arguments);b&&b.length&&a.each(b,function(b,a){a=null});c.data("fields",null)},_isBarChart:function(){return true},getElement:function(f,b,c){var d=this.chartElement,e=d.data("fields"),a=e.chartElements;switch(f){case"bar":case"column":return a.bars[b];case"line":case"area":return a.paths[b];case"linemarkers":return a.markersSet[b];case"pie":return this._getPie(a,b,c)}return null},_getPie:function(b,e,d){if(d!==undefined)return b["sectors"+d]?b["sectors"+d][e]:null;else{var c=[];a.each(b,function(b,d){/sectors/.test(b)&&b!=="sectors"&&a.each(d,function(b,a){c.push(a)})});if(c.length===0)c=b.sectors;return c[e]}},_isSeriesDataEmpty:function(){var c=this,b=c.options.seriesList;if(!b||b.length===0)return true;a.each(b,function(b,a){return a.type==="pie"&&(!a.data||!a.label||a.label.length===0)?true:!a.data||(!a.data.x||!a.data.y)&&!a.data.xy?true:void 0});return false},_showSerieEles:function(d){var f=d.type,b=d.eles,e=this.options.showChartLabels,c;switch(f){case"pie":if(b.sector){b.sector.show();b.sector.shadow&&b.sector.shadow.show();b.sector.tracker&&b.sector.tracker.show()}b.label&&b.label.show();break;case"line":case"spline":case"bezier":case"area":b.markers&&a.each(b.markers,function(d,b){c=a(b.node).data("wijchartDataObj");if(c&&c.lineSeries&&c.lineSeries.markers)if(!c.lineSeries.markers.visible)return true;b.show()});b.dcl&&a.each(b.dcl,function(b,a){e&&a.show()});if(b.path){c=a(b.path.node).data("wijchartDataObj");if(c.visible||c.display==="show"){b.path.show();b.path.shadow&&b.path.shadow.show();b.path.area&&b.path.area.show();b.path.tracker&&b.path.tracker.show()}}break;case"bar":case"column":a.each(b,function(b,a){if(a.bar){a.bar.show();a.bar.shadow&&a.bar.shadow.show();a.bar.tracker&&a.bar.tracker.show()}a.dcl&&a.dcl.show();a.animatedBar&&a.animatedBar.show()});break;case"scatter":a.each(b,function(b,a){a.show()})}},_hideSerieEles:function(c){var d=c.type,b=c.eles;switch(d){case"pie":if(b.sector){b.sector.hide();b.sector.shadow&&b.sector.shadow.hide();b.sector.tracker&&b.sector.tracker.hide()}b.label&&b.label.hide();break;case"line":case"spline":case"bezier":case"area":b.markers&&a.each(b.markers,function(b,a){a.hide()});b.dcl&&a.each(b.dcl,function(b,a){a.hide()});if(b.path){b.path.hide();b.path.shadow&&b.path.shadow.hide();b.path.area&&b.path.area.hide();b.path.tracker&&b.path.tracker.hide()}break;case"bar":case"column":a.each(b,function(b,a){if(a.bar){a.bar.hide();a.bar.shadow&&a.bar.shadow.hide();a.bar.tracker&&a.bar.tracker.hide()}a.dcl&&a.dcl.hide();a.animatedBar&&a.animatedBar.hide()});break;case"scatter":a.each(b,function(b,a){a.hide()})}},_paintTooltip:function(){var b=this,d=b.chartElement,e=d.data("fields")||{},c=e.ctracers||[];a.wijmo.wijchartcore.prototype._paintTooltip.apply(this,arguments);b.tooltip&&a.each(c,function(c,a){if(a.trackers&&a.trackers.length)c===0&&b.tooltip.setOptions({relatedElement:a.trackers[0]})})},_paintPlotArea:function(){var b=this,c=b.options,g="seriesList",f="seriesStyles",e="seriesHoverStyles",o=c[f],m=c[e],i=b.canvasBounds,l={},h=0,p=a.isArray(c.axis.y),k={canvas:b.canvas,tooltip:b.tooltip,bounds:i,widgetName:b.widgetName,seriesTransition:c.seriesTransition,showChartLabels:c.showChartLabels,textStyle:c.textStyle,chartLabelStyle:c.chartLabelStyle,chartLabelFormatString:c.chartLabelFormatString,shadow:c.shadow,hint:c.hint,animation:c.animation,disabled:c.disabled,mouseDown:function(c,a){b._trigger("mouseDown",c,a)},mouseUp:function(c,a){b._trigger("mouseUp",c,a)},mouseOver:function(c,a){b._trigger("mouseOver",c,a)},mouseOut:function(c,a){b._trigger("mouseOut",c,a)},mouseMove:function(c,a){b._trigger("mouseMove",c,a)},click:function(c,a){b._trigger("click",c,a)}},n=b.chartElement.data("fields"),d,j;if(n)n.ctracers=[];a.each(c[g],function(s,d){var j=d.type,b={},k=j,i={},q=o[h],n=m[h],r=d.yAxis;if(!j||j.length===0)return true;if(k==="spline"||k==="bezier")k="line";b=l[k];if(!b){if(j==="pie")b=[];else b={};l[k]=b;if(d.hint){b.hint=d.hint;if(!c.hint.content)c.hint.content=d.hint.content;if(!c.hint.title)c.hint.title=d.hint.title}}if(j==="pie"){a.each(d.data,function(b,a){q=o[h];n=m[h];if(!i[g])i[g]=[];if(!i[f])i[f]=[];if(!i[e])i[e]=[];a.pieID=s+1;i[g].push(a);i[f].push(q);i[e].push(n);h++});i.radius=d.radius;i.center=d.center;i.label=d.label;b.push(i);return true}else if(j==="column")b.horizontal=false;else if(j==="bar")b.horizontal=true;else if(j==="spline")d.fitType="spline";else if(j==="bezier")d.fitType="bezier";if(p)b.yAxis=r||0;if(j==="line"||j==="spline"||j==="bezier"){delete q.fill;delete n.fill}if(!b[g])b[g]=[];if(!b[f])b[f]=[];if(!b[e])b[e]=[];b[g].push(d);b[f].push(q);b[e].push(n);h++});a.each(l,function(e,f){var g=f.yAxis;switch(e){case"pie":a.each(f,function(j,g){var f=g.center,c=g.radius||50,h=f?{startX:f.x-c,startY:f.y-c,endX:f.x+c,endY:f.y+c}:{startX:i.startX+10,startY:i.startY+10,endX:i.startX+10+2*c,endY:i.startY+10+2*c};d=a.extend(true,{},k,{bounds:h,radius:c},g);b.chartElement.wijpie(d);b.chartElement.data("fields").aniSectorAttrs=null;b.chartElement.data("fields").aniLabelAttrs=null;b._savechartData(e)});break;case"bar":case"column":d=a.extend(true,{},k,{stacked:c.stacked,axis:c.axis,clusterOverlap:c.clusterOverlap,clusterWidth:c.clusterWidth,clusterSpacing:c.clusterSpacing,is100Percent:c.is100Percent,clusterRadius:c.clusterRadius,isYTime:b.axisInfo.y[0].isTime,isXTime:b.axisInfo.x.isTime,yAxisInfo:b.axisInfo.y,yAxisIndex:g},f);b.chartElement.wijbar(d);b._savechartData(e);break;case"line":case"spline":case"bezier":case"area":j=b._getyAxisGroup(f);if(!b.aniPathsAttr)b.aniPathsAttr=[];a.each(j,function(g,f){d=a.extend(true,{},k,{axis:c.axis,isXTime:b.axisInfo.x.isTime,isYTime:b.axisInfo.y[0].isTime,aniPathsAttr:b.aniPathsAttr,chartLabelEles:b.chartLabelEles,type:e==="area"?"area":"line"},f);d.axis.y=c.axis.y[g]||c.axis.y;b.chartElement.wijline(d);b._savechartData(e,true)});break;case"scatter":j=b._getyAxisGroup(f);a.each(j,function(g,f){d=a.extend(true,{},k,{axis:c.axis,isXTime:b.axisInfo.x.isTime,isYTime:b.axisInfo.y[0].isTime,zoomOnHover:c.zoomOnHover},f);d.axis.y=c.axis.y[g]||c.axis.y;b.chartElement.wijscatter(d);b._savechartData(e)})}});b.chartElement.data("fields").seriesEles=null;b._bindtooltip()},_savechartData:function(e,f){var d=this,b=d.chartElement.data("fields"),g=b.seriesEles,c;a.each(g,function(b,a){d.seriesEles.push({eles:a,type:e})});if(f)b.ctracers=[];else{c=b.ctracers||[];c.push({trackers:b.trackers,type:e});b.ctracers=c}},_getyAxisGroup:function(c){var b={};a.each(c.seriesList,function(e,d){var a=d.yAxis||0;if(!b[a])b[a]={seriesList:[],seriesStyles:[],seriesHoverStyles:[]};b[a].seriesList.push(d);b[a].seriesStyles.push(c.seriesStyles[e]);b[a].seriesHoverStyles.push(c.seriesHoverStyles[e])});return b},_bindtooltip:function(){var b=this,c=b.widgetName,d=b.chartElement.data("fields");d&&a.each(d.ctracers,function(b,a){a.trackers&&a.trackers.toFront()});b.chartElement.delegate(".linetracker, .bartracker, .pietracker, .wijscatterchart","mouseover."+c,a.proxy(b._tooltipMouseOver,b));b.chartElement.delegate(".linetracker, .bartracker, .pietracker, .wijscatterchart","mouseout."+c,a.proxy(b._tooltipMouseOut,b));b.chartElement.delegate(".linetracker, .bartracker, .pietracker, .wijscatterchart","mousemove."+c,a.proxy(b._tooltipMouseMove,b))},_tooltipMouseOver:function(f){var d=f.target,b=this,n=b.tooltip,m=b.options.hint,e=null,l=m.title,k=m.content,j=a.isFunction(l),i=a.isFunction(k),c,g,h;h=a(b.canvas.canvas.parentNode).offset();if(a(d).data("owner"))d=a(d).data("owner");d=a(d);c=d.data("wijchartDataObj");if(b.tooltip){e=n.getOptions();if(j||i){if(j)e.title=a.proxy(l,c);if(i)e.content=a.proxy(k,c)}if(c.type==="line"){if(c.path.removed)return;if(b.hoverLine!==c){b.isNewLine=true;if(b.hoverLine)if(!b.hoverLine.path.removed){b.hoverLine.path.wijAttr(b.hoverLine.lineStyle);if(b.hoverPoint&&!b.hoverPoint.isSymbol){b.hoverPoint.marker.wijAttr(b.hoverPoint.markerStyle);b.hoverPoint.marker.transform("s1")}}c.lineHoverStyle&&c.path.wijAttr(c.lineHoverStyle);b.hoverLine=c;b.hoverPoint=null}}else if(c.type==="scatter"){b._clearHoverState();g=c.dot.getBBox();e.style.stroke=d.attr("stroke");b.tooltip.showAt({x:g.x+g.width/2,y:g.y},f)}else{b._clearHoverState();e.style.stroke=d.attr("stroke");b.tooltip.showAt({x:f.pageX-h.left,y:f.pageY-h.top},f)}}},_tooltipMouseMove:function(c){var e=this,b=c.target,d,f=a(e.canvas.canvas.parentNode).offset();if(a(b).data("owner"))b=a(b).data("owner");b=a(b);d=b.data("wijchartDataObj");if(e.tooltip)d.type!=="line"&&d.type!=="scatter"&&e.tooltip.showAt({x:c.pageX-f.left,y:c.pageY-f.top},c)},_tooltipMouseOut:function(e){var d=this,b=e.target,c;if(a(b).data("owner"))b=a(b).data("owner");b=a(b);c=b.data("wijchartDataObj");if(c.type!=="line")d.tooltip&&d.tooltip.hide()},_mouseMoveInsidePlotArea:function(t,s){var b=this,f=b.tooltip,h=b.options.hint,g,d=0,l,e,j,k,r=null,c=null,i=null,q=h.title,p=h.content,n=a.isFunction(q),m=a.isFunction(p),o=0;if(f)i=f.getOptions();if(b.hoverLine){if(b.isNewLine){h.enable&&f&&f.hide();b.isNewLine=false}g=b.hoverLine.lineMarkers;d=-1;l={x:0,y:0};a.each(g,function(f,b){if(b.removed)return true;var a=b.wijGetBBox(),e=a.x+a.width/2,c=Math.abs(e-s.left);if(f===0||c<o){o=c;d=f;l={x:e,y:a.y+a.height/2}}});if(b.hoverPoint&&b.hoverPoint.index===d)return;if(d>-1){if(g[d].removed)return;e=a(g[d].node).data("wijchartDataObj");if(e){if(b.hoverPoint&&!b.hoverPoint.isSymbol)if(!b.hoverPoint.removed){b.hoverPoint.marker.wijAttr(b.hoverPoint.markerStyle);b.hoverPoint.marker.transform("s1")}if(!e.isSymbol)!e.marker.removed&&e.marker.wijAttr(e.markerHoverStyle)}b.hoverPoint=e}if(f){c=b.hoverPoint;j=c.valX;k=c.valY;if(n||m){if(n)i.title=function(){var b={pointIndex:d,lineIndex:c.lineSeries.index,x:j,y:k,label:c.lineSeries.label,data:c,fmt:q},e=a.proxy(b.fmt,b),f=e();return f};if(m)i.content=function(){var b={pointIndex:d,lineIndex:c.lineSeries.index,x:j,y:k,label:c.lineSeries.label,data:c,fmt:p},f=a.proxy(b.fmt,b),e=f();return e}}r=a.extend({stroke:b.hoverLine.path.attr("stroke")},h.style);i.style.stroke=r.stroke;f.showAt(l)}}a.wijmo.wijchartcore.prototype._mouseMoveInsidePlotArea.apply(b,arguments)},_mouseMoveOutsidePlotArea:function(){var b=this;b._clearHoverState();a.wijmo.wijchartcore.prototype._mouseMoveOutsidePlotArea.apply(b,arguments)},_clearHoverState:function(){var a=this,b=a.tooltip,c=a.options.hint;c.enable&&b&&b.hide();if(a.hoverLine)if(!a.hoverLine.path.removed){a.hoverLine.path.wijAttr(a.hoverLine.lineStyle);if(a.hoverPoint&&!a.hoverPoint.isSymbol){a.hoverPoint.marker.wijAttr(a.hoverPoint.markerStyle);a.hoverPoint.marker.transform("s1")}}a.hoverLine=null;a.hoverPoint=null},_getTooltipText:function(){return""},_calculateParameters:function(d,g){var e=this,f=false,c,b;a.wijmo.wijchartcore.prototype._calculateParameters.apply(e,arguments);a.each(e.options.seriesList,function(b,a){if(a.type==="column"||a.type==="bar"){f=true;return false}});if(!f)return;if(d.id==="x"){c=g.unitMinor;b=e._getBarAdjustment(d);if(b===0)b=c;else if(c<b&&c!==0)b=Math.floor(b/c)*c;d.min-=b;d.max+=b;e._calculateMajorMinor(g,d)}},_getBarAdjustment:function(d){var b=0,g=this.options,f=d.max,c=d.min,e=0;a.each(g.seriesList,function(c,a){if(a.type==="pie")return true;e=a.data.x.length;if(b<e)b=e});if(b>1)return(f-c)/b*g.clusterWidth*.0125;else if(b===1){if(c===0&&f===1){c=-1;d.min=c}return(f-c)*.0125}else return 0}})})(jQuery);
(function(a){"use strict";a.widget("wijmo.wijdatepager",{options:{culture:"",firstDayOfWeek:0,selectedDate:new Date,viewType:"day"},_setOption:function(c,b){a.Widget.prototype._setOption.apply(this,arguments);switch(c){case"selectedDate":this.options.selectedDate=b;this._initBackground();break;case"disabled":if(b)this._disable();else this._enable();break;case"viewType":this.options.viewType=b;this._initBackground()}return this},_disable:function(){this.element.addClass("ui-state-disabled");this.element.find(".wijmo-wijdatepager-decrement").button("option","disabled",true);this.element.find(".wijmo-wijdatepager-increment").button("option","disabled",true)},_enable:function(){this.element.removeClass("ui-state-disabled");this.element.find(".wijmo-wijdatepager-decrement").button("option","disabled",false);this.element.find(".wijmo-wijdatepager-increment").button("option","disabled",false)},_create:function(){var b=this.options,c;if(!b.selectedDate)b.selectedDate=new Date;this._dtpagernamespacekey="dtpager"+ +new Date;this.element.addClass("wijmo-wijdatepager ui-widget ui-helper-clearfix");c=a.proxy(this.invalidate,this);a(window).bind("resize."+this._dtpagernamespacekey,c);this.element.disableSelection();this.element.append(a('<a class="wijmo-wijdatepager-decrement"><span>left</span></a>')).append('<div class="wijmo-wijdatepager-container ui-widget-content"><div class="wijmo-wijdatepager-pages"></div></div><a class="wijmo-wijdatepager-increment"><span>right</span></a>');a.Widget.prototype._create.apply(this,arguments);this.element.find(".wijmo-wijdatepager-decrement").button({icons:{primary:"ui-icon-triangle-1-w"},text:false}).click(a.proxy(this.goLeft,this));this.element.find(".wijmo-wijdatepager-increment").button({icons:{primary:"ui-icon-triangle-1-e"},text:false}).click(a.proxy(this.goRight,this));this._initBackground();b.disabled&&this._disable()},destroy:function(){this.element.removeClass("wijmo-wijdatepager");a(window).unbind("."+this._dtpagernamespacekey)},refresh:function(){this.invalidate()},invalidate:function(){var g=a(this.element.find(".wijmo-wijdatepager-pagelabel")[this._index]),c=this.element.find(".wijmo-wijdatepager-container"),e=this.element.find(".wijmo-wijdatepager-decrement"),f=this.element.find(".wijmo-wijdatepager-increment"),b=this.element.innerWidth(),d=e.is(":visible")?e.outerWidth(true):0,h=f.is(":visible")?f.outerWidth(true):0;this.element.find(".wijmo-wijdatepager-pagelabel.ui-state-active").removeClass("ui-state-active");g.addClass("ui-state-active");c.css("left",d);this.element.removeClass("wijmo-wijdatepager-width-smallest wijmo-wijdatepager-width-small wijmo-wijdatepager-width-medium wijmo-wijdatepager-width-normal");if(b<300)this.element.addClass("wijmo-wijdatepager-width-smallest");else if(b<475)this.element.addClass("wijmo-wijdatepager-width-small");else if(b<600)this.element.addClass("wijmo-wijdatepager-width-medium");else this.element.addClass("wijmo-wijdatepager-width-normal");c.outerWidth(b-d-h)},goLeft:function(){var a=this.options;if(a.disabled)return;this._setSelectedIndex(this._index-1,true)},goRight:function(){var a=this.options;if(a.disabled)return;this._setSelectedIndex(this._index+1)},_getCulture:function(a){return Globalize.findClosestCulture(a||this.options.culture)},_isRTL:function(){return!!this._getCulture().isRTL},_initBackground:function(j,i){var f,d,c,b,g,h,k=this.options,l=k.viewType.toLowerCase();if(this._isInAnimate)return;this._index=0;this._datesDef=this._getDatesDefinition();this._min=0;this._max=this._datesDef.length-1;f="";for(d=0;d<this._datesDef.length;d+=1)f+='<div class="wijmo-wijdatepager-pagelabel'+(d==0?" wijmo-wijdatepager-pagelabel-first":"")+(this._datesDef[d].range?" wijmo-wijdatepager-pagerange":"")+(this._datesDef[d].header?" wijmo-wijdatepager-pageheader ui-state-highlight":"")+(d==this._datesDef.length-1?" wijmo-wijdatepager-pagelabel-last":"")+'">'+this._datesDef[d].l+"</div>";b=this.element.find(".wijmo-wijdatepager-pages");if(j){this._isInAnimate=true;c=b.clone(true);b.html(f);g=b.find(".wijmo-wijdatepager-pagelabel");var e=this;if(!i){c.insertBefore(b);h=a(g[this._index]).offset().left;b.css("opacity",0).css("left",c.outerWidth(true)).stop().animate({left:"0px",opacity:100});c.stop().animate({left:"-"+c.outerWidth(true)+"px",opacity:0},function(){c.remove();e._isInAnimate=false;e.invalidate()})}else{c.insertAfter(b);h=a(g[this._index]).offset().left;b.css("opacity",0).css("left",-c.outerWidth(true)).stop().animate({left:"0px",opacity:100});c.css("left",0).stop().animate({left:c.outerWidth(true)+"px",opacity:0},function(){c.remove();e._isInAnimate=false;e.invalidate()})}}else{b.html(f);this.invalidate()}b.find(".wijmo-wijdatepager-pagelabel").hover(a.proxy(this._pagelabelHover,this),a.proxy(this._pagelabelHout,this));b.find(".wijmo-wijdatepager-pagelabel").bind("mousedown",a.proxy(this._pagelabelMouseDown,this));b.find(".wijmo-wijdatepager-pagelabel").click(a.proxy(function(d){var c=a(d.target),b;b=this.element.find(".wijmo-wijdatepager-pagelabel").index(c);this._setSelectedIndex(b)},this))},_addDays:function(a,b){return new Date(a.getFullYear(),a.getMonth(),a.getDate()+b)},_getDatesDefinition:function(){var g=this.options,i=g.viewType.toLowerCase(),d,c,a,f,h,e=[],b=g.selectedDate,j=g.firstDayOfWeek;switch(i){case"week":a=new Date(b.getFullYear(),b.getMonth(),-6);d=g.firstDayOfWeek-a.getDay();if(Math.abs(d)>6)d=a.getDay()-g.firstDayOfWeek;a=this._addDays(a,d);h=new Date(b.getFullYear(),b.getMonth()+1,7);d=0;while(a<h||a.getMonth()===b.getMonth()){f=this._addDays(a,7);e.push({l:Globalize.format(a,"MMM",this._getCulture())+" "+Globalize.format(a,"dd",this._getCulture())+"-"+Globalize.format(this._addDays(a,6),"dd",this._getCulture()),d:a,d2:this._addDays(a,6)});if(b>=a&&b<=f)this._index=d;a=f;d+=1}break;case"month":c=new Date(b.getFullYear()-2,0,1);e.push({l:c.getFullYear(),d:c,range:true});c=new Date(b.getFullYear()-1,0,1);e.push({l:c.getFullYear(),d:c,header:true});for(d=0;d<12;d+=1){c=new Date(b.getFullYear(),d,1);e.push({l:Globalize.format(c,"MMM",this._getCulture()),d:c});f=new Date(b.getFullYear(),d+1,1);if(b>=c&&b<=f)this._index=d+2}c=new Date(b.getFullYear()+1,0,1);e.push({l:c.getFullYear(),d:c,range:true});break;default:case"day":c=new Date(b.getFullYear(),b.getMonth(),0);e.push({l:Globalize.format(c,"MMM",this._getCulture()),d:c,range:true});c=new Date(b.getFullYear(),b.getMonth(),1);e.push({l:Globalize.format(c,"MMM",this._getCulture()),d:c,header:true});a=c;d=2;while(a.getMonth()===b.getMonth()){f=new Date(a.getFullYear(),a.getMonth(),a.getDate()+1);e.push({l:Globalize.format(a,"d ",this._getCulture()),d:a});if(b>=a&&b<=f)this._index=d;a=f;d+=1}c=new Date(b.getFullYear(),b.getMonth()+1,1);e.push({l:Globalize.format(c,"MMM",this._getCulture()),d:c,range:true})}return e},_setSelectedIndex:function(a,c){var b=this.options;if(b.disabled)return;if(a>=this._min&&a<=this._max){this._dragActivated&&this._showTooltip(a);if(this._index!==a){if(this._datesDef[a].header)if(c)a=a-1;else return;this._index=a;b.selectedDate=this._datesDef[a].d;if(this._index===this._max)if(b.viewType==="week")b.selectedDate=new Date(b.selectedDate.getFullYear(),b.selectedDate.getMonth(),b.selectedDate.getDate()+7);if(this._max>2&&this._index===0)this._initBackground(true,true);else if(this._index===this._max)this._initBackground(true,false);else this.invalidate();this._trigger("selectedDateChanged",null,{selectedDate:b.selectedDate})}}},_pagelabelHover:function(c){var b=a(c.target),d;if(b.hasClass("wijmo-wijdatepager-pageheader"))return;b.addClass("ui-state-hover")},_showTooltip:function(d){var g=this.options,b=this._datesDef[d],e=g.viewType,c,f=this.element.find(".wijmo-wijdatepager-pagelabel")[d];if(!this._tooltip){this._tooltip=a('<div class="wijmo-wijdatepager-tooltip"><div class="wijmo-wijdatepager-tooltip-inner"></div><div class="wijmo-wijdatepager-triangle"></div></div>');this.element.append(this._tooltip);this._tooltip.wijpopup()}c="";switch(e){case"day":c=Globalize.format(b.d,"dddd, MMMM d, yyyy",this._getCulture());break;case"week":c=Globalize.format(b.d,"MMMM d - ",this._getCulture())+Globalize.format(b.d2,b.d.getMonth()!==b.d2.getMonth()?"MMMM d, yyyy":"d, yyyy",this._getCulture());break;case"month":c=Globalize.format(b.d,"MMMM yyyy",this._getCulture())}this._tooltip.wijpopup("show",{of:f,my:"center bottom",at:"center top",offset:"-10 -10"});this._tooltip.find(".wijmo-wijdatepager-tooltip-inner").html(c)},_hideTooltip:function(){this._tooltip.wijpopup("hide")},_pagelabelHout:function(b){a(b.target).removeClass("ui-state-hover")},_pagelabelMouseDown:function(c){this._dragActivated=false;if(this.options.disabled)return;c.preventDefault();var d=a(c.target),b;if(d.hasClass("wijmo-wijdatepager-pageheader"))return;b=this.element.find(".wijmo-wijdatepager-pagelabel").index(d);this._dragActivated=true;this._setSelectedIndex(b);this._startClientX=c.pageX;this._startInd=b;a(document).bind("mousemove."+this._dtpagernamespacekey,a.proxy(this._pageindicatorMouseMove,this));a(document).bind("mouseup."+this._dtpagernamespacekey,a.proxy(this._pageindicatorMouseUp,this))},_pageindicatorMouseMove:function(c){c.preventDefault();if(this._isInAnimate)return;var b=this.element.find(".wijmo-wijdatepager-pagelabel")[this._startInd],d=b.offsetLeft+Math.round(b.offsetWidth/2)+(c.pageX-this._startClientX),a=this._findClosesPageIndexByPos(d);a!==-1&&a!==this._index&&this._setSelectedIndex(a)},_pageindicatorMouseUp:function(){this._dragActivated=false;a(document).unbind("."+this._dtpagernamespacekey);this._hideTooltip()},_findClosesPageIndexByPos:function(c){for(var b=this.element.find(".wijmo-wijdatepager-pages").find(".wijmo-wijdatepager-pagelabel"),d,a=0;a<b.length;a+=1)if(b[a].offsetLeft<c&&b[a].offsetLeft+b[a].offsetWidth>c)return a;return-1}})})(jQuery);
(function(a){"use strict";function c(a){return new Date(a.getFullYear(),a.getMonth(),a.getDate())}function h(){var b,c,a;b="";for(a=0;a<32;a+=1){if(a===8||a===12||a===16||a===20)b=b+"-";c=Math.floor(Math.random()*16).toString(16).toUpperCase();b=b+c}return b}var e,i="C1EventsCalendarDB",j="1.1",f=false,b;function g(c,d,a){if(f){b=amplify.store("wijevcal_tables1");if(!b)b={};if(!b[c]){b[c]={fields:d};amplify.store("wijevcal_tables1",b);amplify.store("wijevcal_tbl_"+c,{})}a&&a()}else e&&e.transaction(function(b){b.executeSql("SELECT COUNT(*) FROM "+c,[],function(){a&&a()},function(b){b.executeSql("CREATE TABLE "+c+" "+d,[],a,a)})})}function d(k,m,o,l){var n={rowsAffected:0,rows:[]},i,a,p,r,h,j,u,g,s,q,t,c,d;if(!m)m=[];if(!n.rows.item)n.rows.item=function(a){return this[a]};if(f)try{p=new RegExp("(SELECT) *(.*) *FROM (\\w+)");r=new RegExp("(INSERT OR REPLACE|INSERT) *(.*) *INTO *(\\w*) *\\(([\\w|,| ]*)\\)");if(k.match(r)){h=r.exec(k);if(h&&h.length>1){j=h[3];u=b[j];g=amplify.store("wijevcal_tbl_"+j);if(g){q=h[4].split(",");i={};for(a=0;a<q.length;a+=1)if(q[a]){if(a===0)g[m[a]]=i;t=q[a].replace(" ","");i[t]=m[a]}}amplify.store("wijevcal_tbl_"+j,g)}}else if(k.match(p)){h=p.exec(k);if(h&&h.length>1){j=h[3];u=b[j];g=amplify.store("wijevcal_tbl_"+j);if(g){c=k.replace(p,"");if(c.toUpperCase().indexOf(" WHERE ")===0){c=c.substr(7);d=c.split(" OR ");for(a=0;a<d.length;a+=1){d[a]=d[a].split("=");c=d[a][1];if(c.indexOf("'")===0){c=c.substring(1,c.length-1);d[a][1]=c}else d[a][1]=parseFloat(c)}}for(s in g)if(g.hasOwnProperty(s)){i=g[s];if(i)if(d)for(a=0;a<d.length;a+=1)i[d[a][0]]===d[a][1]&&n.rows.push(i);else n.rows.push(i)}}}}o&&o(n)}catch(v){l&&l(v)}else{if(!e){l("Local data storage not found.");return}e.transaction(function(a){a.executeSql(k,m,function(b,a){o&&o(a)},function(b,a){l&&l(a.message);return})})}}a.widget("wijmo.wijevcal",{options:{culture:"",webServiceUrl:"",colors:null,dataStorage:{addEvent:null,updateEvent:null,deleteEvent:null,loadEvents:null,addCalendar:null,updateCalendar:null,deleteCalendar:null,loadCalendars:null},appointments:[],calendars:[],disabled:false,editCalendarTemplate:"",enableLogs:false,eventTitleFormat:"{2}",titleFormat:{day:false,week:"_formatWeekTitle",month:"{0:MMMM yyyy}",list:false},firstDayOfWeek:0,headerBarVisible:true,navigationBarVisible:true,rightPaneVisible:false,selectedDate:null,selectedDates:null,statusBarVisible:false,timeInterval:30,timeIntervalHeight:15,timeRulerInterval:60,timeRulerFormat:"{0:h tt}",dayHeaderFormat:"{0:d }",firstRowDayHeaderFormat:"{0:ddd d}",dayViewHeaderFormat:{day:"all-day events",week:"{0:d dddd}",list:"{0:d dddd}"},viewType:"day",visibleCalendars:["Default"]},_setOption:function(e,b){var d=this.options;switch(e){case"appointments":d.appointments=b;this._onAppointmentsChanged();break;case"disabled":if(d.disabled!==b){d.disabled=b;this._ensureDisabled()}break;case"enableLogs":d.enableLogs=b;this._initLogPanel();break;case"selectedDate":if(b){b=c(b);if(d.selectedDates[0].getTime()!==b.getTime()){d.selectedDates[0]=b;this._onSelectedDatesChanged()}}return;case"selectedDates":if(b){d.selectedDates=b;this._onSelectedDatesChanged()}return;case"statusBarVisible":d.statusBarVisible=b;this._initStatusbar();this.invalidate();return;case"headerBarVisible":d.headerBarVisible=b;this._initHeaderbar();this.invalidate();return;case"navigationBarVisible":d.navigationBarVisible=b;this._initNavigationbar();this.invalidate();return;case"rightPaneVisible":d.rightPaneVisible=b;this._initRightPane();this.invalidate();return;case"timeInterval":if(d.timeInterval!==b){d.timeInterval=b;this._redrawActiveView()}break;case"timeIntervalHeight":if(d.timeIntervalHeight!==b){d.timeIntervalHeight=b;this._redrawActiveView()}break;case"timeRulerInterval":if(d.timeRulerInterval!==b){d.timeRulerInterval=b;this._redrawActiveView()}break;case"viewType":if(d.viewType!==b){d.viewType=b;this._onViewTypeChanged()}}a.Widget.prototype._setOption.apply(this,arguments)},_ensureDisabled:function(){var a=this.options;if(a.disabled){this.element.addClass("ui-state-disabled");this.element.find(".ui-button").button("option","disabled",true);this.element.find(".ui-buttonset").buttonset("option","disabled",true);this.element.find(".wijmo-wijcalendar").wijcalendar("option","disabled",true);this.element.find(".wijmo-wijsuperpanel").wijsuperpanel("option","disabled",true);this.element.find(".wijmo-wijdatepager").wijdatepager("option","disabled",true);this._unbindEvents()}else{this.element.removeClass("ui-state-disabled");this.element.find(".ui-button").button("option","disabled",false);this.element.find(".ui-buttonset").buttonset("option","disabled",false);this.element.find(".wijmo-wijcalendar").wijcalendar("option","disabled",false);this.element.find(".wijmo-wijsuperpanel").wijsuperpanel("option","disabled",false);this.element.find(".wijmo-wijdatepager").wijdatepager("option","disabled",false);this._bindEvents();this._updateTitleText()}},_onViewTypeChanged:function(){this._renderActiveView();this._updateTitleText();this._trigger("viewTypeChanged",null,this.options.viewType);this.element.find(".wijmo-wijev-datepager").wijdatepager("option","viewType",this.options.viewType)},_onSelectedDatesChanged:function(){var a=this.options;a.selectedDate=a.selectedDates[0];this.element.find(".wijmo-wijev-datepager").wijdatepager("option","selectedDate",a.selectedDate);this._trigger("selectedDatesChanged",null,{selectedDates:a.selectedDates});this._renderActiveView();this._updateTitleText()},_updateHeaderTitleText:function(){var a=this.options,b=a.titleFormat,c=a.selectedDates[0],d=a.selectedDates[a.selectedDates.length-1];if(b[a.viewType])b=b[a.viewType];else if(b[a.viewType]===false){this.element.find(".wijmo-wijev-view .wijmo-wijev-header-title").hide();return}else b=b.toString();if(a.viewType==="list")d=this._addDays(c,14);this.element.find(".wijmo-wijev-view .wijmo-wijev-header-title").show().html(this._formatString(b,c,d))},_updateTitleText:function(){var b=this.options,d=b.selectedDates[0],e=b.selectedDates[b.selectedDates.length-1],a=new Date,c=false;c=this._compareDayDates(d,a)===0||d<a&&e>a;this.element.find(".wijmo-wijev-navigationbar .wijmo-wijev-today").button("option","disabled",c);this._updateHeaderTitleText()},_create:function(){var d,b,c=this.options;if(!c.colors)c.colors=["red","darkorchid","green","blue","cornflowerblue","yellow","bronze"];if(!this.wijevcalnamespacekey)this.wijevcalnamespacekey="wijevcal"+ +new Date;if(!this.element[0].id)this.element[0].id="wijevcal_dynid_"+ +new Date;this._uidPref=this.element[0].id+"evcdynid";this.element.addClass("wijmo-wijevcal wijmo-wijev ui-widget ui-helper-reset ui-state-default");a('<div class="wijmo-wijev-headerbar ui-widget-header ui-corner-top"><span class="wijmo-wijev-tools"><input id="'+this._uidPref+'_daybtn" name="viewselection" type="radio" class="wijmo-wijev-day" /><label for="'+this._uidPref+'_daybtn">Day</label><input id="'+this._uidPref+'_weekbtn" name="viewselection" type="radio" class="wijmo-wijev-week" /><label for="'+this._uidPref+'_weekbtn">Week</label><input id="'+this._uidPref+'_monthbtn" name="viewselection" type="radio" class="wijmo-wijev-month" /><label for="'+this._uidPref+'_monthbtn">Month</label><input id="'+this._uidPref+'_listbtn" name="viewselection" type="radio" class="wijmo-wijev-list" /><label for="'+this._uidPref+'_listbtn">List</label></span></div>').appendTo(this.element);a('<div class="wijmo-wijev-view-container"><div class="wijmo-wijev-leftpane wijmo-wijev-viewdetails ui-widget-content wijmo-wijev-day-details"><div class="wijmo-wijev-leftpane-inner"><div class="wijmo-wijev-daycalendar"></div><div class="wijmo-wijev-monthday-container"><div class="wijmo-wijev-monthday-label">...</div><div class="wijmo-wijev-fulldate-label">Loading...</div><div class="wijmo-wijev-year-label">...</div></div><div class="wijmo-wijev-agenda-container ui-widget-content ui-corner-all ui-helper-clearfix"></div></div></div><div class="wijmo-wijev-leftpane wijmo-wijev-viewdetails ui-widget-content wijmo-wijev-list-details"><div class="wijmo-wijev-leftpane-inner"><div class="wijmo-wijev-agenda-container ui-widget-content ui-corner-all ui-helper-clearfix">&nbsp;</div></div></div><div class="wijmo-wijev-rightpane">&nbsp;</div></div>').appendTo(this.element);a('<div class="wijmo-wijev-loading-modal-frame"></div><div class="wijmo-wijev-loading"><div class="wijmo-wijev-loading-text">Loading...</div></div>').appendTo(this.element);a('<div class="wijmo-wijev-navigationbar ui-widget-header ui-corner-bottom ui-helper-clearfix"><a class="wijmo-wijev-today">today</a><div class="wijmo-wijev-datepager"></div></div>').appendTo(this.element);a('<div class="wijmo-wijev-statusbar ui-widget-header ui-corner-bottom"></div>').appendTo(this.element);d=this.element.find(".wijmo-wijev-navigationbar");b=this.element.find(".wijmo-wijev-headerbar .wijmo-wijev-tools");d.find(".wijmo-wijev-today").button({text:"today"}).click(a.proxy(this._onTodayClick,this));this.element.find(".wijmo-wijev-datepager").wijdatepager({selectedDate:c.selectedDate,culture:c.culture,viewType:c.viewType,firstDayOfWeek:c.firstDayOfWeek,selectedDateChanged:a.proxy(function(b,a){this.goToDate(a.selectedDate)},this)});b.find(".wijmo-wijev-day").button().click(a.proxy(this._onDayViewClick,this));b.find(".wijmo-wijev-week").button().click(a.proxy(this._onWeekViewClick,this));b.find(".wijmo-wijev-month").button().click(a.proxy(this._onMonthViewClick,this));b.find(".wijmo-wijev-list").button().click(a.proxy(this._onListViewClick,this));b.buttonset();this.showLoadingLabel()},showLoadingLabel:function(a,b){if(a===false)this.element.find(".wijmo-wijev-loading-text").hide();else{this.element.find(".wijmo-wijev-loading-text").show();if(!a)a="Loading..."}(b===undefined||b===true)&&this.element.find(".wijmo-wijev-loading-modal-frame").show();this.element.find(".wijmo-wijev-loading").show();this.element.find(".wijmo-wijev-loading-text").html(a)},hideLoadingLabel:function(){this.element.find(".wijmo-wijev-loading-modal-frame").hide();this.element.find(".wijmo-wijev-loading").hide()},_init:function(){var b=this.options;if(b.selectedDates&&b.selectedDates.length>0)b.selectedDate=b.selectedDates[0]=c(b.selectedDates[0]);else if(b.selectedDate){b.selectedDate=c(b.selectedDate);if(!b.selectedDates)b.selectedDates=[];b.selectedDates[0]=b.selectedDate}else{b.selectedDate=c(new Date);b.selectedDates=[b.selectedDate]}b.disabled&&this.element.addClass("ui-state-disabled");this._initHeaderbar();this._initNavigationbar();this._initStatusbar();this._initRightPane();b.fullScreen&&this._onFullScreenModeChanged(b.fullScreen);this._initLogPanel();this._initLocalDataStorage();this.element.ajaxError(jQuery.proxy(this._onAjaxError,this));a(window).resize(a.proxy(this._onWindowResize,this));this._renderActiveView();this._ensureDisabled()},_initLocalDataStorage:function(){try{if(window.amplify&&window.amplify.store)try{b=amplify.store("wijevcal_tables1");f=true;this.log("Using amplify.store for the local data storage")}catch(c){this.log("amplify.store exception:"+c);this._loadData();return}else if(window.openDatabase){try{e=window.openDatabase(i,j,"Wijmo Events Calendar Offline DB",2e5)}catch(h){this.log("web sql database error: "+h);this._loadData();return}if(!e){this.log("Failed to open the database on disk. This is probably because the version was bad or there is not enough space left in this domain's quota");this._loadData();return}this.log("Using Web SQL Database for the local data storage.")}else{this.log("Couldn't open built-in local data storage. Please, add amplify.store references.");this._loadData();return}g("calendars","(id TEXT PRIMARY KEY, name TEXT, location TEXT, description TEXT, color TEXT, tag TEXT)");g("events","(id TEXT PRIMARY KEY, calendar TEXT, subject TEXT, location TEXT, start TIMESTAMP, end TIMESTAMP, description TEXT, color TEXT, allday INTEGER, properties TEXT, tag TEXT)",a.proxy(this._loadData,this))}catch(d){this.log("local datastorage initialization error:"+d)}},_initStatusbar:function(){var a=this.element.find(".wijmo-wijev-statusbar");if(!this.options.statusBarVisible){a.hide();return}else a.show();if(this.statusbarEventsAdded)return true;this.statusbarEventsAdded=true},_initHeaderbar:function(){var a=this.element.find(".wijmo-wijev-headerbar");if(!this.options.headerBarVisible){a.hide();return}else a.show()},_initNavigationbar:function(){var a=this.element.find(".wijmo-wijev-navigationbar");if(!this.options.navigationBarVisible){a.hide();return}else a.show()},_initRightPane:function(){var a=this.element.find(".wijmo-wijev-rightpane");if(!this.options.rightPaneVisible){a.hide();return}else a.show()},_initLogPanel:function(){if(this.options.enableLogs){this._createLogPanel();this.log=this._log}else{this.logDialog&&this.logDialog.wijdialog("close");this.log=function(){}}},_handleServerError:function(a){if(a&&a.toString().indexOf("error:")===0){this.status(a.toString(),"error");return true}return false},_loadData:function(){var e=this.options,b=this,c,h,f,j,m,n,i,k,l,g;this.showLoadingLabel();g=function(){b.hideLoadingLabel()};e.calendars=[];m=this._calendarsById={};k=function(a){if(!a)return;if(typeof a==="string"){if(b._handleServerError(a)){g(a);return}try{a=b._jsonParse(a)}catch(d){b.status("Unable to parse received calendars data. "+d,"error");return}}if(a.calendars&&a.calendars.length)a=a.calendars;for(c=0;c<a.length;c+=1){f=b._cloneObj(a[c]);f.prevData=b._cloneObj(f);e.calendars.push(f);m[f.id]=f}b._onCalendarsChanged()};if(e.dataStorage.loadCalendars)e.dataStorage.loadCalendars(k,g);else if(e.webServiceUrl)a.getJSON(e.webServiceUrl+"?clientId="+this.element[0].id+"&command=loadCalendars&calendars="+e.calendars,k);else d("SELECT * FROM calendars",[],function(a){for(c=0,h=a.rows.length;c<h;c+=1){f=b._cloneObj(a.rows.item(c));f.prevData=b._cloneObj(f);e.calendars.push(f);m[f.id]=f}b._onCalendarsChanged()},g);e.appointments=[];n=this._appointmentsById={};l=function(a){if(!a)return;if(typeof a==="string"){if(b._handleServerError(a)){g(a);return}try{a=b._jsonParse(a)}catch(d){b.log("Unable to parse received calendars data. "+d);return}}if(a.events&&a.events.length)a=a.events;for(c=0;c<a.length;c+=1){j=b._readEventData(a[c]);b._storeEventWithSort(j)}b._onAppointmentsChanged();b._trigger("initialized");b.hideLoadingLabel()};if(e.dataStorage.loadEvents)e.dataStorage.loadEvents(e.visibleCalendars,l,g);else if(e.webServiceUrl)a.ajax({url:e.webServiceUrl+"?clientId="+this.element[0].id+"&command=loadEvents",dataType:"text",contentType:"application/json; charset=utf-8",data:{visibleCalendars:e.visibleCalendars},success:l});else{i="SELECT * FROM events where ";for(c=0;c<e.visibleCalendars.length;c+=1){if(c>0)i+=" OR ";i+="calendar='"+e.visibleCalendars[c]+"'"}d(i,[],function(a){for(c=0,h=a.rows.length;c<h;c+=1){j=b._readEventData(a.rows.item(c));b._storeEventWithSort(j)}b._onAppointmentsChanged();b._trigger("initialized");b.hideLoadingLabel()},g)}},_readEventData:function(b){var a=this._cloneObj(b);a.start=new Date(a.start);a.end=new Date(a.end);if(typeof a.allday==="string"){if(a.allday==="false")a.allday=false;if(a.allday==="true")a.allday=true}if(a.start.getTime()>=a.end.getTime())a.end=this._addMinutes(a.start,this.options.timeInterval);this._deSerializeProperties(a.properties,a);a.prevData=this._cloneObj(a);return a},_prepareEventsForView:function(){this._eventsView=this.getOccurrences()},_cloneObj:function(b){var c={},a;for(a in b)if(b.hasOwnProperty(a))c[a]=b[a];return c},_onDayViewClick:function(){var a=this.options;if(a.viewType!=="day"){a.viewType="day";this._onViewTypeChanged()}a.selectedDates=[a.selectedDate];this._onSelectedDatesChanged()},_onWeekViewClick:function(){var b=this.options,c,d,a;if(b.viewType!=="week"){b.viewType="week";this._onViewTypeChanged()}c=b.selectedDate;a=b.firstDayOfWeek-c.getDay();if(Math.abs(a)>6)a=c.getDay()-b.firstDayOfWeek;c=this._addDays(c,a);b.selectedDates=[];for(a=0;a<7;a+=1){d=this._addDays(c,a);b.selectedDates.push(d)}this._onSelectedDatesChanged()},_onMonthViewClick:function(){var a=this.options;if(a.viewType!=="month"){a.viewType="month";this._onViewTypeChanged()}},_onListViewClick:function(){var a=this.options;if(a.viewType!=="list"){a.viewType="list";this._onViewTypeChanged()}a.selectedDates=[a.selectedDate];this._onSelectedDatesChanged()},_ensureEditCalendarDialogCreated:function(){var c=this.options,b;if(!this._editCalendarDialog){b=c.editCalendarTemplate;if(!b)b='<p><label>Calendar name</label><input type="text" class="wijmo-wijev-name" value=""></p><p><label>Location</label><input type="text" class="wijmo-wijev-location" value=""></p><p><label>Description</label><textarea class="wijmo-wijev-description" /></p><p><label>Color</label><select class="wijmo-wijev-color"></p>';this._editCalendarDialog=a('<div class="wijmo-wijev-editcalendar-dialog">'+b+"</div>");this.element.append(this._editCalendarDialog);this._editCalendarDialog.wijdialog({autoOpen:true,height:600,width:700,modal:true,title:"Edit calendar",buttons:{Save:a.proxy(function(){var b=this._editCalendarDialog,a=b.cal||{};a.name=b.find(".wijmo-wijev-name").val();a.location=b.find(".wijmo-wijev-location").val();a.description=b.find(".wijmo-wijev-description").val();a.color=b.find(".wijmo-wijev-color").val();if(a.prevData)this.updateCalendar(a);else this.addCalendar(a);b.wijdialog("close")},this)},captionButtons:{pin:{visible:false},refresh:{visible:false},toggle:{visible:false},minimize:{visible:false},maximize:{visible:false}}})}},_ensureEditEventDialogCreated:function(){if(!this._editEventDialog){var b=this.options.editEventDialogTemplate;if(!b)b='<div class="wijmo-wijev-event-dialog ui-widget-content ui-corner-all"><ul class="wijmo-wijev-brief-content"><li><label>Name</label><input type="text" name="subject" class="wijmo-wijev-subject" value=""><div class="wijmo-wijev-color-button"><div class="wijmo-wijev-color ui-wijmo-wijev-event-color-default">&nbsp;</div></div></li><li><label for="'+this._uidPref+'_alldaybtn">all-day</label><input type="checkbox" class="wijmo-wijev-allday" id="'+this._uidPref+'_alldaybtn" /></li><li><label>Starts</label><input type="text" class="wijmo-wijev-start" value=""><input type="text" class="wijmo-wijev-start-time" value=""></li><li><label>Ends</label><input type="text" class="wijmo-wijev-end" value=""><input type="text" class="wijmo-wijev-end-time" value=""></li></ul><ul class="wijmo-wijev-detailed-content ui-corner-all"><li><label>Location</label><input type="text" class="wijmo-wijev-location" value=""></li><li><label>Repeat</label><select class="wijmo-wijev-repeat"><option value="none">None</option><option value="daily">Every Day</option><option value="workdays">Work days</option><option value="weekly">Every Week</option><option value="monthly">Every Month</option><option value="yearly">Every Year</option></select></li><li><label>Calendar</label><select class="wijmo-wijev-calendar"></select></li><li class="wijmo-wijev-description-item"><label>Description</label><textarea class="wijmo-wijev-description" /></li></ul><div class="footer"><a href="#" class="wijmo-wijev-delete">Delete</a><a href="#" class="wijmo-wijev-save">OK</a><a href="#" class="wijmo-wijev-cancel">Cancel</a></div><div class="wijmo-wijev-angle"></div></div>';this._editEventDialog=a(b);this.element.append(this._editEventDialog);this._editEventDialog.find(".wijmo-wijev-color-button").button({icons:{primary:"ui-icon-triangle-1-s"}}).click(a.proxy(this._onColorButtonClick,this));this._editEventDialog.find(".wijmo-wijev-delete").button().click(a.proxy(function(){this.deleteEvent(this._editEventDialog.appt);this._editEventDialog.wijpopup("hide")},this));this._editEventDialog.find(".wijmo-wijev-cancel").button().click(a.proxy(function(){this._editEventDialog.wijpopup("hide")},this));this._editEventDialog.find(".wijmo-wijev-start").width(114).wijinputdate({culture:this.options.culture,showTrigger:true,dateFormat:"d",dateChanged:a.proxy(function(c,a){var b=this._editEventDialog.find(".wijmo-wijev-end").wijinputdate("option","date");a.date>b&&this._editEventDialog.find(".wijmo-wijev-end").wijinputdate("option","date",a.date)},this)});this._editEventDialog.find(".wijmo-wijev-start-time").width(80).wijinputdate({culture:this.options.culture,dateFormat:"t",dateChanged:a.proxy(function(d,a){var c=this._editEventDialog.find(".wijmo-wijev-end-time").wijinputdate("option","date"),b=this._editEventDialog.find(".wijmo-wijev-start").wijinputdate("option","date");if(a.date.getDate()!==b.getDate()){a.date.setDate(b.getDate());this._editEventDialog.find(".wijmo-wijev-start-time").wijinputdate("option","date",a.date)}a.date>c&&this._editEventDialog.find(".wijmo-wijev-end-time").wijinputdate("option","date",a.date)},this)});this._editEventDialog.find(".wijmo-wijev-end").width(114).wijinputdate({culture:this.options.culture,showTrigger:true,dateFormat:"d",dateChanged:a.proxy(function(c,a){var b=this._editEventDialog.find(".wijmo-wijev-start").wijinputdate("option","date");a.date<b&&this._editEventDialog.find(".wijmo-wijev-start").wijinputdate("option","date",a.date)},this)});this._editEventDialog.find(".wijmo-wijev-end-time").width(80).wijinputdate({culture:this.options.culture,dateFormat:"t",dateChanged:a.proxy(function(d,a){var c=this._editEventDialog.find(".wijmo-wijev-start-time").wijinputdate("option","date"),b=this._editEventDialog.find(".wijmo-wijev-end").wijinputdate("option","date");if(a.date.getDate()!==b.getDate()){a.date.setDate(b.getDate());this._editEventDialog.find(".wijmo-wijev-end-time").wijinputdate("option","date",a.date)}a.date<c&&this._editEventDialog.find(".wijmo-wijev-start-time").wijinputdate("option","date",a.date)},this)});this._editEventDialog.find(".wijmo-wijev-allday").wijcheckbox().change(a.proxy(this._eventDialogEnsureTimePartState,this));this._editEventDialog.find(".wijmo-wijev-subject,.wijmo-wijev-location,.wijmo-wijev-description").wijtextbox();this._editEventDialog.find(".wijmo-wijev-save").button().click(a.proxy(function(){var a=this._editEventDialog.appt;this._readApptDialogFields(this._editEventDialog,a);if(a.prevData)this.updateEvent(a);else this.addEvent(a);this._editEventDialog.wijpopup("hide")},this));this._editEventDialog.wijpopup({autoHide:true,hiding:a.proxy(function(){this._colorMenu&&this._colorMenu.wijpopup("hide");this.element.find(".wijmo-wijev-dayview .ui-selected").removeClass("ui-selected")},this),shown:a.proxy(function(){var a=this;if(!this._dropDownInitialized){this._editEventDialog.find(".wijmo-wijev-calendar").wijdropdown().bind("change",function(){var b=a._calendarsById[this.value];if(b&&b.color)a._addColorClass(a._editEventDialog.find(".wijmo-wijev-color"),b.color);else a._editEventDialog.appt&&a._editEventDialog.appt.color&&a._addColorClass(a._editEventDialog.find(".wijmo-wijev-color"),a._editEventDialog.appt.color)});this._editEventDialog.find(".wijmo-wijev-repeat").wijdropdown().bind("change",function(){var c=this.value,b=a._editEventDialog.appt;switch(c){case"none":b.recurrenceState=null;b.recurrencePattern=null;break;case"daily":b.recurrenceState="master";b.recurrencePattern={parentRecurrenceId:b.id,recurrenceType:"daily",startTime:b.start,endTime:b.end,patternStartDate:b.start};break;case"workdays":b.recurrenceState="master";b.recurrencePattern={parentRecurrenceId:b.id,recurrenceType:"workdays",startTime:b.start,endTime:b.end,patternStartDate:b.start};break;case"weekly":b.recurrenceState="master";b.recurrencePattern={parentRecurrenceId:b.id,recurrenceType:"weekly",startTime:b.start,endTime:b.end,patternStartDate:b.start};break;case"monthly":b.recurrenceState="master";b.recurrencePattern={parentRecurrenceId:b.id,recurrenceType:"monthly",startTime:b.start,endTime:b.end,patternStartDate:b.start};break;case"yearly":b.recurrenceState="master";b.recurrencePattern={parentRecurrenceId:b.id,recurrenceType:"yearly",startTime:b.start,endTime:b.end,patternStartDate:b.start};break;case"custom":alert("show custom recurrence pattern.")}});this._dropDownInitialized=true}else{this._editEventDialog.find(".wijmo-wijev-calendar").wijdropdown("refresh");this._editEventDialog.find(".wijmo-wijev-repeat").wijdropdown("refresh")}this._editEventDialog.find(".wijmo-wijev-subject").focus();this._updateEditEventPopupCallout()},this)})}},_updateEditEventPopupCallout:function(){if(this._editEventDialog&&this._editEventDialog._arrowTarget){var b=this._editEventDialog,f=a(b._arrowTarget),c=f.offset(),e=b.offset(),d;if(c.left<e.left)b.removeClass("wijmo-wijev-rightangle").addClass("wijmo-wijev-leftangle");else b.removeClass("wijmo-wijev-leftangle").addClass("wijmo-wijev-rightangle");d=Math.round(c.top-e.top+f.outerHeight(true)/2);this._editEventDialog.find(".wijmo-wijev-angle").css("top",d)}},_onColorButtonClick:function(){var c,e=this.options,b=e.colors,d="";if(b&&b.length>0)for(c=0;c<b.length;c+=1)d+='<span class="wijmo-wijev-listcolor wijmo-wijev-event-color-'+b[c]+'">&nbsp;</span>';if(!this._colorMenu){this._colorMenu=a('<div class="wijmo-wijev-color-menu ui-widget-content ui-corner-all"></div>');this._editEventDialog.append(this._colorMenu);this._colorMenu.wijpopup({autoHide:true})}this._colorMenu.html(d);this._colorMenu.find(".wijmo-wijev-listcolor").click(a.proxy(function(b){this._addColorClass(this._editEventDialog.find(".wijmo-wijev-color"),this._readColorFromClass(a(b.target),"default"));this._colorMenu.wijpopup("hide")},this));this._colorMenu.wijpopup("show",{of:this._editEventDialog.find(".wijmo-wijev-color-button"),my:"left top",at:"left bottom"})},_readApptDialogFields:function(b,a){var c,d;a.subject=b.find(".wijmo-wijev-subject").val();a.location=b.find(".wijmo-wijev-location").val();a.start=b.find(".wijmo-wijev-start").wijinputdate("option","date");a.end=b.find(".wijmo-wijev-end").wijinputdate("option","date");if(b.find(".wijmo-wijev-allday").length>0)a.allday=b.find(".wijmo-wijev-allday")[0].checked;if(!a.allday){c=b.find(".wijmo-wijev-start-time").wijinputdate("option","date");a.start=new Date(a.start.getFullYear(),a.start.getMonth(),a.start.getDate(),c.getHours(),c.getMinutes(),c.getSeconds());d=b.find(".wijmo-wijev-end-time").wijinputdate("option","date");a.end=new Date(a.end.getFullYear(),a.end.getMonth(),a.end.getDate(),d.getHours(),d.getMinutes(),d.getSeconds())}a.calendar=b.find(".wijmo-wijev-calendar").val();a.description=b.find(".wijmo-wijev-description").val();a.color=this._readColorFromClass(b.find(".wijmo-wijev-color"),a.color)},_bindApptToDialog:function(b){if(!b)return;var a=this._editEventDialog,d,c;a.appt=b;a.find(".wijmo-wijev-subject").val(b.subject||"");a.find(".wijmo-wijev-location").val(b.location||"");try{a.find(".wijmo-wijev-start").wijinputdate("option","date",b.start);a.find(".wijmo-wijev-start-time").wijinputdate("option","date",b.start);a.find(".wijmo-wijev-end").wijinputdate("option","date",b.end);a.find(".wijmo-wijev-end-time").wijinputdate("option","date",b.end)}catch(e){alert("[e0001a] wijinputdate/wijtextselection firefox error\n"+e)}if(a.find(".wijmo-wijev-allday").length>0)a.find(".wijmo-wijev-allday")[0].checked=b.allday;a.find(".wijmo-wijev-allday").wijcheckbox("refresh");this._fillCalendarsSelect(a.find(".wijmo-wijev-calendar"),b.calendar);this._loadRepeatValue(b,a.find(".wijmo-wijev-repeat"));a.find(".wijmo-wijev-description").val(b.description||"");if(!b.prevData)a.find(".wijmo-wijev-delete").hide();else a.find(".wijmo-wijev-delete").show();if(a.find(".wijmo-wijev-calendar").length>0)d=this._calendarsById[a.find(".wijmo-wijev-calendar")[0].value];c=b.color;if(!c&&d&&d.color)c=d.color;this._addColorClass(a.find(".wijmo-wijev-color"),c);this._eventDialogEnsureTimePartState()},_eventDialogEnsureTimePartState:function(){var a=this._editEventDialog;if(a.find(".wijmo-wijev-allday").length>0)if(a.find(".wijmo-wijev-allday")[0].checked){a.find(".wijmo-wijev-start-time").wijinputdate("option","disabled",true);a.find(".wijmo-wijev-end-time").wijinputdate("option","disabled",true)}else{a.find(".wijmo-wijev-start-time").wijinputdate("option","disabled",false);a.find(".wijmo-wijev-end-time").wijinputdate("option","disabled",false)}},_loadRepeatValue:function(b,c){var a="none";if(b.recurrenceState==="master"&&b.recurrencePattern)switch(b.recurrencePattern.recurrenceType){case"daily":a="daily";break;case"workdays":a="workdays";break;case"weekly":a="weekly";break;case"monthly":a="monthly";break;case"yearly":a="yearly";break;default:a="custom"}c.val(a)},_addColorClass:function(a,d){var b,c=new RegExp("wijmo-wijev-event-color-(\\w+)\\s*");if(a.length>0){b=a[0].className;a[0].className=b.replace(c,"");a.addClass("wijmo-wijev-event-color-"+(d||"default"))}},_readColorFromClass:function(b,c){var d=new RegExp("wijmo-wijev-event-color-(\\w+)\\s*"),a;if(b.length>0){a=d.exec(b[0].className);if(a&&a.length>1)return a[1]}return c},_fillCalendarsSelect:function(f,i){var h="",g=this.options,a,d,e,b=g.calendars.slice(0),c=g.visibleCalendars;if(c&&c.length>0)for(a=0;a<c.length;a+=1){e=false;for(d=0;d<b.length;d+=1)if(b[d].name===c[a])e=true;!e&&b.push({id:c[a],name:c[a]})}if(b.length===0){f.html("");return}for(a=0;a<b.length;a+=1)h+='<option value="'+b[a].id+'">'+b[a].name+"</option>";f.html(h).val(i)},_fillColorSelect:function(e,d){var c="",f=this.options,b=f.colors,a;if(b)for(a=0;a<b.length;a+=1)c+="<option"+(d===b[a]?' selected="selected"':"")+' value="'+b[a]+'">'+b[a]+"</option>";e.html(c)},_bindCalendarToDialog:function(a){if(!a)return;this._editCalendarDialog.cal=a;this._editCalendarDialog.find(".wijmo-wijev-name").val(a.name||"");this._editCalendarDialog.find(".wijmo-wijev-location").val(a.location||"");this._editCalendarDialog.find(".wijmo-wijev-description").val(a.description||"");this._fillColorSelect(this._editCalendarDialog.find(".wijmo-wijev-color"),a.color)},_onTodayClick:function(){this.goToday();return false},_bindEvents:function(){if(!this._eventsAttached){this.element.find(".wijmo-wijev-appointment").live("click."+this.wijevcalnamespacekey,a.proxy(this._onAppointmentClick,this));this.element.find(".wijmo-wijev-dayview .wijmo-wijev-appointment").live("mousedown."+this.wijevcalnamespacekey,a.proxy(this._onDayViewAppointmentMouseDown,this));this.element.find(".wijmo-wijev-monthview .wijmo-wijev-appointment").live("mousedown."+this.wijevcalnamespacekey,a.proxy(this._onMonthViewAppointmentMouseDown,this));this.element.find(".wijmo-wijev-dayview .wijmo-wijev-timeinterval").live("click."+this.wijevcalnamespacekey,a.proxy(this._onDayViewTimeIntervalClick,this));this.element.find(".wijmo-wijev-dayview .wijmo-wijev-allday-cell").live("click."+this.wijevcalnamespacekey,a.proxy(this._onDayViewAllDayCellClick,this));this.element.find(".wijmo-wijev-monthview .wijmo-wijev-monthcellheader").live("click."+this.wijevcalnamespacekey,a.proxy(this._onMonthViewDayLabelClick,this));this.element.find(".wijmo-wijev-monthview .wijmo-wijev-monthcell-showmore").live("click."+this.wijevcalnamespacekey,a.proxy(this._onMonthViewDayLabelClick,this));this.element.find(".wijmo-wijev-weekview .wijmo-wijev-daylabel").live("click."+this.wijevcalnamespacekey,a.proxy(this._onMonthViewDayLabelClick,this));this.element.find(".wijmo-wijev-monthview .wijmo-wijev-monthcell").live("click."+this.wijevcalnamespacekey,a.proxy(this._onMonthViewCellClick,this));this._eventsAttached=true}},_unbindEvents:function(){if(this._eventsAttached){this.element.find(".wijmo-wijev-appointment").die("click."+this.wijevcalnamespacekey);this.element.find(".wijmo-wijev-dayview .wijmo-wijev-daycolumn .wijmo-wijev-appointment").die("mousedown."+this.wijevcalnamespacekey);this.element.find(".wijmo-wijev-dayview .wijmo-wijev-dayheadercolumn .wijmo-wijev-daylabel").die("click."+this.wijevcalnamespacekey);this.element.find(".wijmo-wijev-dayview .wijmo-wijev-timeinterval").die("click."+this.wijevcalnamespacekey);this.element.find(".wijmo-wijev-dayview .wijmo-wijev-allday-cell").die("click."+this.wijevcalnamespacekey);this.element.find(".wijmo-wijev-monthview .wijmo-wijev-monthcellheader").die("click."+this.wijevcalnamespacekey);this.element.find(".wijmo-wijev-monthview .wijmo-wijev-monthcell-showmore").die("click."+this.wijevcalnamespacekey);this.element.find(".wijmo-wijev-weekview .wijmo-wijev-daylabel").die("click."+this.wijevcalnamespacekey);this.element.find(".wijmo-wijev-monthview .wijmo-wijev-monthcell").die("click."+this.wijevcalnamespacekey);this._eventsAttached=false}},destroy:function(){this.element.removeClass("wijmo-wijev wijmo-wijevcal ui-widget ui-helper-reset");this._unbindEvents();a.Widget.prototype.destroy.apply(this,arguments)},deleteCalendar:function(b,j,k){for(var h=this.options.calendars,i=b.name||b,l=false,g,f,m,c=this,e=0;e<h.length;e+=1)if(h[e].name===i){l=true;b=h[e];if(!this._trigger("beforeDeleteCalendar",null,{data:b}))return false;delete this._calendarsById[b.id];h.splice(e,1);break}if(!l){this.status("Calendar with name '"+i+"' not found.");return false}this.showLoadingLabel("Deleting calendar...");g=function(a){c.status("Calendar '"+b.name+"' deleted.");c._onCalendarsChanged();c.hideLoadingLabel();j&&j(a)};f=function(a){c.status("Unable to delete calendar '"+b.name+"': "+a);c.hideLoadingLabel();k&&k(a)};if(this.options.dataStorage.deleteCalendar)this.options.dataStorage.deleteCalendar(b,g,f);else if(this.options.webServiceUrl){try{m=this._jsonStringify(b)}catch(n){this.status("Unable to prepare calendar data for server. "+n,"error");f("Unable to prepare calendar data for server. "+n);return}a.ajax({url:this.options.webServiceUrl+"?clientId="+this.element[0].id+"&command=deleteCalendar",dataType:"text",contentType:"application/json; charset=utf-8",data:{calendar:m},success:g})}else d("DELETE FROM calendars WHERE name='"+i+"'",[],g,f)},addCalendar:function(b,h,i){var g,e,f,c=this;if(!this._trigger("beforeAddCalendar",null,{data:b,prevData:b.prevData||{}})){if(b.prevData)for(e in b.prevData)if(b.prevData.hasOwnProperty(e))b[e]=b.prevData[e];return false}if(!b.id){if(!this._dynIdCounter)this._dynIdCounter=0;this._dynIdCounter+=1;b.id="dynid"+this._dynIdCounter+"ts"+ +new Date}this.showLoadingLabel("Creating calendar...");g=function(a){if(c._handleServerError(a)){f(a);return}c._readUpdatedServerDataIfAny(a,b);if(!c._calendarsById[b.id]){c.options.calendars.push(b);c._calendarsById[b.id]=b;c.status("Calendar '"+b.name+"' added.")}else c.status("Calendar '"+b.name+"' added.");b.prevData=c._cloneObj(b);c._onCalendarsChanged();c.hideLoadingLabel();h&&h(a)};f=function(a){c.status("Unable to add calendar '"+b.name+"': "+a);c.hideLoadingLabel();i&&i(a)};if(this.options.dataStorage.addCalendar)this.options.dataStorage.addCalendar(b,g,f);else if(this.options.webServiceUrl){try{e=this._jsonStringify(b)}catch(j){this.status("Unable prepare calendar data for server."+j,"error");f("Unable to prepare calendar data for server."+j);return}a.ajax({url:this.options.webServiceUrl+"?clientId="+this.element[0].id+"&command=addCalendar",dataType:"text",contentType:"application/json; charset=utf-8",data:{calendar:e},success:g})}else d("INSERT OR REPLACE INTO calendars (id, name, location, description, color, tag) VALUES(?,?,?,?,?,?);",[b.id,b.name,b.location,b.description,b.color,b.tag],g,f)},updateCalendar:function(b,h,i){var g,e,f,c=this;if(!this._trigger("beforeUpdateCalendar",null,{data:b,prevData:b.prevData||{}})){if(b.prevData)for(e in b.prevData)if(b.prevData.hasOwnProperty(e))b[e]=b.prevData[e];return false}if(!b.id){if(!this._dynIdCounter)this._dynIdCounter=0;this._dynIdCounter+=1;b.id="dynid"+this._dynIdCounter+"ts"+ +new Date}this.showLoadingLabel("Updating calendar...");g=function(a){if(c._handleServerError(a)){f(a);return}c._readUpdatedServerDataIfAny(a,b);if(!c._calendarsById[b.id]){c.options.calendars.push(b);c._calendarsById[b.id]=b;c.status("Calendar '"+b.name+"' added.")}else c.status("Calendar '"+b.name+"' updated.");b.prevData=c._cloneObj(b);c._onCalendarsChanged();c.hideLoadingLabel();h&&h(a)};f=function(a){c.status("Unable to update calendar '"+b.name+"': "+a);c.hideLoadingLabel();i&&i(a)};if(this.options.dataStorage.updateCalendar)this.options.dataStorage.updateCalendar(b,g,f);else if(this.options.webServiceUrl){try{e=this._jsonStringify(b)}catch(j){this.status("Unable prepare calendar data for server. "+j,"error");f("Unable to prepare calendar data for server. "+j);return}a.ajax({url:this.options.webServiceUrl+"?clientId="+this.element[0].id+"&command=updateCalendar",dataType:"text",contentType:"application/json; charset=utf-8",data:{calendar:e},success:g})}else d("INSERT OR REPLACE INTO calendars (id, name, location, description, color, tag) VALUES(?,?,?,?,?,?);",[b.id,b.name,b.location,b.description,b.color,b.tag],g,f)},addEvent:function(b,i,j){var g,f,e,c=this;if(!this._trigger("beforeAddEvent",null,{data:b,prevData:b.prevData||{}})){if(b.prevData)for(e in b.prevData)if(b.prevData.hasOwnProperty(e))b[e]=b.prevData[e];return false}if(!b.id){if(!this._dynIdCounter)this._dynIdCounter=0;this._dynIdCounter+=1;b.id=h()}if(!b.calendar)b.calendar="Default";this.showLoadingLabel("Creating event...");f=function(a){c.hideLoadingLabel();c.status("Unable to add event '"+b.subject+"': "+a,"error");if(b.prevData)for(e in b.prevData)if(b.prevData.hasOwnProperty(e))b[e]=b.prevData[e];j&&j(a)};g=function(a){if(c._handleServerError(a)){f(a);return}c._readUpdatedServerDataIfAny(a,b);if(!c._appointmentsById[b.id]){c._storeEventWithSort(b);c.status("Event '"+b.subject+"' added.")}else c.status("Event '"+b.subject+"' added.");b.prevData=c._cloneObj(b);c._onAppointmentsChanged();c.hideLoadingLabel();i&&i(a)};if(this.options.dataStorage.addEvent)this.options.dataStorage.addEvent(b,g,f);else if(this.options.webServiceUrl){try{e=this._jsonStringify(b)}catch(k){this.status("Unable prepare event data for server. "+k,"error");f("Unable to prepare event data for server. "+k);return}a.ajax({url:this.options.webServiceUrl+"?clientId="+this.element[0].id+"&command=addEvent",dataType:"text",contentType:"application/json; charset=utf-8",data:{event:e},success:g})}else d("INSERT OR REPLACE INTO events (id, calendar, subject, location, start, end, description, color, allday, properties, tag) VALUES(?,?,?,?,?,?,?,?,?,?,?);",[b.id,b.calendar,b.subject,b.location,b.start.getTime(),b.end.getTime(),b.description,b.color,b.allday,this._serializeProperties(b),b.tag],g,f)},_storeEventWithSort:function(b){var c=this.options.appointments,a,d;this._appointmentsById[b.id]=b;for(a=0,d=c.length;a<d;a+=1)if(c[a].start>b.start){c.splice(a,0,b);return}else if(c[a].start.getTime()===b.start.getTime())if(c[a].subject>b.subject){c.splice(a,0,b);return}c.push(b)},_readUpdatedServerDataIfAny:function(a,d){var b=null,c;if(typeof a==="string"&&a.indexOf("update:")===0){a=a.toString().substr("update:".length);try{b=this._jsonParse(a)}catch(e){this.status("Unable to read updated server data. "+e,"warning")}if(b)for(c in b)if(b[c])d[c]=b[c]}},updateEvent:function(b,h,i){var g,f,e,c=this;if(!this._trigger("beforeUpdateEvent",null,{data:b,prevData:b.prevData||{}})){if(b.prevData)for(e in b.prevData)if(b.prevData.hasOwnProperty(e))b[e]=b.prevData[e];this._updateAppointmentVisual(b);return false}if(!b.calendar)b.calendar="Default";this.showLoadingLabel("Updating event...");f=function(a){c.hideLoadingLabel();c.status("Unable to update event '"+b.subject+"': "+a,"error");if(b.prevData)for(e in b.prevData)if(b.prevData.hasOwnProperty(e))b[e]=b.prevData[e];c._updateAppointmentVisual(b);i&&i(a)};if(!b.id){f("id is empty");return}g=function(a){if(c._handleServerError(a)){f(a);return}c._readUpdatedServerDataIfAny(a,b);if(!c._appointmentsById[b.id]){c._storeEventWithSort(b);c.status("Event '"+b.subject+"' added.")}else c.status("Event '"+b.subject+"' updated.");b.prevData=c._cloneObj(b);c._onAppointmentsChanged();c.hideLoadingLabel();h&&h(a)};if(this.options.dataStorage.updateEvent)this.options.dataStorage.updateEvent(b,g,f);else if(this.options.webServiceUrl){try{e=this._jsonStringify(b)}catch(j){this.status("Unable prepare event data for server. "+j,"error");f("Unable to prepare event data for server. "+j);return}a.ajax({url:this.options.webServiceUrl+"?clientId="+this.element[0].id+"&command=updateEvent",dataType:"text",contentType:"application/json; charset=utf-8",data:{event:e},success:g})}else d("INSERT OR REPLACE INTO events (id, calendar, subject, location, start, end, description, color, allday, properties, tag) VALUES(?,?,?,?,?,?,?,?,?,?,?);",[b.id,b.calendar,b.subject,b.location,b.start.getTime(),b.end.getTime(),b.description,b.color,b.allday,this._serializeProperties(b),b.tag],g,f)},_serializeProperties:function(b){var c="",a={};a.parentRecurrenceId=b.parentRecurrenceId;a.recurrenceState=b.recurrenceState;a.recurrencePattern=b.recurrencePattern;a.color=b.color;a.allday=b.allday;try{c=this._jsonStringify(a)}catch(d){this.status("Unable save additional event properties. "+d,"error")}return c},_deSerializeProperties:function(d,c){var b={},a;if(d){if(typeof d==="string")try{b=this._jsonParse(d)}catch(e){this.status("Unable to load additional event properties. "+e,"error");return}else b=d;if(b.parentRecurrenceId)c.parentRecurrenceId=b.parentRecurrenceId;if(b.recurrenceState)c.recurrenceState=b.recurrenceState;if(b.recurrencePattern)c.recurrencePattern=b.recurrencePattern;if(b.color)c.color=b.color;if(b.allday)c.allday=b.allday}if(c&&c.recurrencePattern){a=c.recurrencePattern;a.patternStartDate=a.patternStartDate?new Date(a.patternStartDate):a.patternStartDate;a.startTime=a.startTime?new Date(a.startTime):a.startTime;a.endTime=a.endTime?new Date(a.endTime):a.endTime;if(a.startTime.getTime()>=a.endTime.getTime())a.endTime=this._addMinutes(a.startTime,this.options.timeInterval)}},_jsonStringify:function(b){var a;if(window.__JSONC1)a=window.__JSONC1.stringify(b);else if(window.JSON)a=JSON.stringify(b);else throw"JSON not found.";return a},_jsonParse:function(d){var a,c,b;if(window.__JSONC1)a=window.__JSONC1.parse(d);else if(window.JSON){c=/^(\d{4})-(\d{2})-(\d{2})T(\d{2}):(\d{2}):(\d{2}(?:\.\d*)?)Z$/;b=/^\/Date\((d|-|.*)\)\/$/;a=window.JSON.parse(d,function(f,d){if(typeof d==="string"){var a=c.exec(d),e;if(a)return new Date(Date.UTC(+a[1],+a[2]-1,+a[3],+a[4],+a[5],+a[6]));a=b.exec(d);if(a){e=a[1].split(/[-,.]/);return new Date(+e[0])}}return d})}else throw"JSON variable not found.";return a},getOccurrences:function(i,k){var p=this.options,m=p.appointments,c,a,h,l,b,n,j,o=100,g,d,f,e=[];for(l=0,n=m.length;l<n;l+=1){c=m[l];if(c.recurrenceState==="master"){h=c.recurrencePattern;j=h.occurrences||o;g=h.patternStartDate||c.start;d=h.startTime||c.start;f=h.endTime||c.end;switch(h.recurrenceType){case"daily":for(b=0;b<j;b+=1){a=this._cloneObj(c);a.parentRecurrenceId=c.id;a.recurrenceState="occurrence";a.start=this._setTime(this._addDays(g,b),d);a.end=this._setTime(a.start,f,d);a.recurrencePattern=null;this._testIsEventInTimeInterval(a,i,k)&&e.push(a)}break;case"workdays":for(b=0;b<j;b+=1){a=this._cloneObj(c);a.parentRecurrenceId=c.id;a.recurrenceState="occurrence";a.start=this._setTime(this._addDays(g,b),d);if(a.start.getDay()===0||a.start.getDay()===6)continue;a.end=this._setTime(a.start,f,d);a.recurrencePattern=null;this._testIsEventInTimeInterval(a,i,k)&&e.push(a)}break;case"weekly":for(b=0;b<j;b+=1){a=this._cloneObj(c);a.parentRecurrenceId=c.id;a.recurrenceState="occurrence";a.start=this._setTime(this._addDays(g,b*7),d);a.end=this._setTime(a.start,f,d);a.recurrencePattern=null;this._testIsEventInTimeInterval(a,i,k)&&e.push(a)}break;case"monthly":for(b=0;b<j;b+=1){a=this._cloneObj(c);a.parentRecurrenceId=c.id;a.recurrenceState="occurrence";a.start=this._setTime(new Date(g),d);a.start.setMonth(a.start.getMonth()+b);a.end=this._setTime(a.start,f,d);a.recurrencePattern=null;this._testIsEventInTimeInterval(a,i,k)&&e.push(a)}break;case"yearly":for(b=0;b<j;b+=1){a=this._cloneObj(c);a.parentRecurrenceId=c.id;a.recurrenceState="occurrence";a.start=this._setTime(new Date(g),d);a.start.setYear(a.start.getFullYear()+b);a.end=this._setTime(a.start,f,d);a.recurrencePattern=null;this._testIsEventInTimeInterval(a,i,k)&&e.push(a)}}}else this._testIsEventInTimeInterval(c,i,k)&&e.push(c)}return e},_testIsEventInTimeInterval:function(b,a,c){return!a||!c?true:b.start<c&&b.end>a?true:false},deleteEvent:function(e,j,k){if(e.id)e=e.id;var c=this._appointmentsById[e],f,i,h,g,b=this,l;if(!this._trigger("beforeDeleteEvent",null,{data:c}))return false;this.showLoadingLabel("Deleting event...");g=function(a){b.status("Unable to delete event '"+(c?c.subject:"undefined")+"': "+a);b.hideLoadingLabel();k&&k(a)};h=function(a){if(b._handleServerError(a)){g(a);return}if(b._appointmentsById[c.id]){i=b.options.appointments;for(f=0;f<i.length;f=f+1)i[f].id===e&&i.splice(f,1);delete b._appointmentsById[c.id];b.status("Event '"+c.subject+"' deleted.")}else b.status("Event '"+c.subject+"' deleted.");c.prevData=b._cloneObj(c);b._onAppointmentsChanged();b.hideLoadingLabel();j&&j(a)};if(this.options.dataStorage.deleteEvent)this.options.dataStorage.deleteEvent(c,h,g);else if(this.options.webServiceUrl){try{l=this._jsonStringify(c)}catch(m){this.status("Unable prepare event data for server. "+m,"error");g("Unable prepare event data for server. "+m);return}a.ajax({url:this.options.webServiceUrl+"?clientId="+this.element[0].id+"&command=deleteEvent",dataType:"text",contentType:"application/json; charset=utf-8",data:{event:l},success:h})}else d("DELETE FROM events WHERE id='"+e+"'",[],h,g)},beginUpdate:function(){this._isUpdating=true;this.showLoadingLabel("Updating...")},endUpdate:function(){this._isUpdating=false;this._pendingRedrawActiveView&&this._redrawActiveView();this.hideLoadingLabel()},goToEvent:function(a){if(a.id)a=a.id;var d=this.options,b,c=this.findEventById(a);switch(d.viewType){case"day":case"week":case"list":b=this.element.find(".wijmo-wijev-dayview .wijmo-wijev-daycolumn ."+this._eventIdToCssClass(a));if(b.length>0)this.element.find(".wijmo-wijev-scrollpanel").wijsuperpanel("scrollChildIntoView",b);else{this._dayViewScrollToEvent=c;this.goToDate(c.start)}break;case"month":this.goToDate(c.start)}},isAllDayEvent:function(b){var a=b;if(!b.id)a=this.findEventById(b);return a.allday?(a.end.getTime()-a.start.getTime())/864e5>=1?true:true:false},goToDate:function(d){d=c(d);var f=this.options,g=d.getDay(),a,e,b=f.selectedDates;if(b&&b.length>0)if(this._isContainsDayDate(b,d))return;else{e=(d-b[0].getTime())/864e5;if(f.viewType==="week")for(a=0;a<b.length;a+=1)if(b[a].getDay()===g){e=e-a;break}for(a=0;a<b.length;a+=1)b[a]=this._addDays(b[a],e);this._onSelectedDatesChanged()}else{f.selectedDates=[d];this._onSelectedDatesChanged()}},goToday:function(){this.goToDate(new Date)},goLeft:function(){var b,c=this.options,d=c.viewType,a=c.selectedDates;if(d==="month")this.goToDate(this._addMonths(a[0],-1));else{b=-7;if(a.length===1)b=-1;this.goToDate(this._addDays(a[0],b))}},goRight:function(){var b,c=this.options,d=c.viewType,a=c.selectedDates;if(d==="month")this.goToDate(this._addMonths(a[0],1));else{b=7;if(a.length===1)b=1;this.goToDate(this._addDays(a[0],b))}},update:function(){this.invalidate()},invalidate:function(){var a=this.options;switch(a.viewType.toLowerCase()){case"list":case"day":case"week":this._invalidateDayView();break;case"month":this._invalidateMonthView()}},showEditCalendarDialog:function(a){var d=this.options,c=d.calendars,b;if(!a)a={name:"",description:"",location:"",color:""};else if(!a.name)for(b=0;b<c.length;b+=1)if(c[b].name===a){a=c[b];break}this._ensureEditCalendarDialogCreated();this._bindCalendarToDialog(a);this._editCalendarDialog.wijdialog("open")},showEditEventDialog:function(c,g,e){var f=this.options,d,h,b=g?a(g):e?a(e.target):null;this._ensureEditEventDialogCreated();this.element.find(".wijmo-wijev-dayview .ui-selected").removeClass("ui-selected");if(b&&b.hasClass("wijmo-wijev-daylabel"))b=b.parent(".wijmo-wijev-allday-cell");if(!c){c={subject:"New Event"};if(b&&b.length>0){this._editEventDialog._arrowTarget=b;b.addClass("ui-selected");d=b.parent(".wijmo-wijev-daycolumn");if(d.length<1)d=b.parent(".wijmo-wijev-dayheadercolumn");d=d[0];if(b.hasClass("wijmo-wijev-allday-cell"))c.allday=true;else if(b.hasClass("wijmo-wijev-monthcellcontainer")){d=b[0];c.allday=true}else c.allday=false;if(d){h=this._parseDateFromClass(d.className,c.allday?null:b[0].className);c.start=h;if(c.allday)c.end=this._addMinutes(c.start,1440);else c.end=this._addMinutes(c.start,f.timeInterval)}}else{c.start=new Date(f.selectedDates[0]);c.end=this._addMinutes(c.start,f.timeInterval)}}else this._editEventDialog._arrowTarget=b;this._bindApptToDialog(c);this._editEventDialog.wijpopup("show",{of:b,my:"left center",at:"right center",offset:(b&&e?Math.round(e.offsetX-b.width()):10)+" 0",collision:"fit"})},_renderActiveView:function(){var a=this.options,b=this.element.find(".wijmo-wijev-headerbar .wijmo-wijev-tools");this.element.find(".wijmo-wijev-view").hide();this.element.find(".wijmo-wijev-viewdetails").hide();this.element.find(".wijmo-wijev-"+a.viewType.toLowerCase()+"-details").show();switch(a.viewType.toLowerCase()){case"day":case"week":case"list":this.element.find(".wijmo-wijev-view.wijmo-wijev-dayview").show();this._renderDayView();break;case"month":this.element.find(".wijmo-wijev-view.wijmo-wijev-monthview").show();this._renderMonthView()}b.find(".wijmo-wijev-"+a.viewType.toLowerCase())[0].checked=true;b.buttonset("refresh")},_redrawActiveView:function(){if(this._isUpdating){this._pendingRedrawActiveView=true;return}switch(this.options.viewType.toLowerCase()){case"day":case"week":this._clearViewsCache();this._templateDayColumn=null}this._renderActiveView()},_renderDayView:function(){var d=this.options,h=0,u=1440,o,l,p,k=d.selectedDates,f,b,c,e,m=new Date,s,r=false,i=this.element.find(".wijmo-wijev-dayview"),q,j,t,g=0,n;if(!k)k=[new Date];if(i.length===0){i=a('<div class="wijmo-wijev-view wijmo-wijev-dayview ui-widget-content"><h3 class="wijmo-wijev-header-title">title</h3><div class="wijmo-wijev-dayview-inner"><div class="wijmo-wijev-headercontainer"><div class="wijmo-wijev-sizer"><div class="wijmo-wijev-gmtlabel">all-day</div></div></div><div class="wijmo-wijev-scrollpanel"><div class="wijmo-wijev-scrollcontent"><div class="wijmo-wijev-timeruler"><div class="wijmo-wijev-currenttime-indicator"><div class="wijmo-wijev-currenttime-indicator-arrow ui-state-error"></div><div class="wijmo-wijev-currenttime-indicator-line ui-state-error"></div></div></div></div></div></div></div>');i.appendTo(this.element.find(".wijmo-wijev-view-container"));this.element.find(".wijmo-wijev-scrollpanel").wijsuperpanel({hScroller:{scrollBarVisibility:"hidden"}})}i.removeClass("wijmo-wijev-weekview wijmo-wijev-listview");i.addClass("wijmo-wijev-"+d.viewType.toLowerCase()+"view");q=this.element.find(".wijmo-wijev-headercontainer");j=this.element.find(".wijmo-wijev-scrollcontent");t=j.find(".wijmo-wijev-timeruler");if(!this._templateDayColumn){t.find(".wijmo-wijev-timerulerinterval").remove();o='<div class="wijmo-wijev-daycolumn">';n=true;while(h<u){l="wijmo-wijev-timeinterval ui-widget-content wijmo-wijev-minute-"+h;if(n)l+=" wijmo-wijev-oddrow";n=!n;p="wijmo-wijev-timerulerinterval ui-widget-content wijmo-wijev-minute-"+h;o+='<div class="'+l+'" style="height: '+d.timeIntervalHeight+'px"></div>';h+=d.timeInterval;g+=d.timeInterval;if(g>=d.timeRulerInterval){l+=" wijmo-wijev-timeinterval-hourstart";p+=" wijmo-wijev-timerulerinterval-hourstart";t.append(a('<div class="'+p+'" style="height:'+g/d.timeInterval*d.timeIntervalHeight+'px">'+this._formatString(d.timeRulerFormat,new Date(m.getFullYear(),m.getMonth(),m.getDate(),0,h-g))+"</div>"));g=0}}o+="</div>";this._templateDayColumn=a(o);this._templateDayHeader=a('<div class="wijmo-wijev-dayheadercolumn ui-widget-content"><div class="wijmo-wijev-allday-cell ui-widget-content"><div class="wijmo-wijev-daylabel">3 Monday</div></div></div>')}q.find(".wijmo-wijev-dayheadercolumn").remove();j.find(".wijmo-wijev-daycolumn").remove();for(f=0,s=k.length;f<s;f=f+1){e=k[f];b=this._getCachedDayHeader(e);c=this._getCachedDayColumn(e);if(!b){b=this._templateDayHeader.clone(true);c=this._templateDayColumn.clone(true);b.addClass(this._dayDateToCssClass(e));b.find(".wijmo-wijev-daylabel").html(this._formatDayHeaderDate(e));c.addClass(this._dayDateToCssClass(e));if(r)r=false;else{c.addClass("wijmo-wijev-leftborder");b.addClass("wijmo-wijev-leftborder")}if(this._compareDayDates(e,m)===0){c.addClass("wijmo-wijev-today ui-state-highlight");c.addClass("wijmo-wijev-leftborder");c.addClass("wijmo-wijev-rightborder");b.addClass("wijmo-wijev-today").find(".wijmo-wijev-allday-cell").addClass("ui-state-highlight");b.addClass("wijmo-wijev-leftborder");b.addClass("wijmo-wijev-rightborder");r=true}if(f===s-1){c.addClass("wijmo-wijev-rightborder");b.addClass("wijmo-wijev-rightborder")}}else{b=a(b);b.find(".wijmo-wijev-daylabel").html(this._formatDayHeaderDate(e))}q.append(b);j.append(c)}this._invalidateDayView();this._renderDayViewAppointments()},_getCachedDayHeader:function(a){var b=null;if(this._dayViewCache)if(this._dayViewCache[a])b=this._dayViewCache[a].h;return b},_getCachedDayColumn:function(a){var b=null;if(this._dayViewCache)if(this._dayViewCache[a])b=this._dayViewCache[a].c;return b},_storeDayCache:function(a,c,b){if(!this._dayViewCache)this._dayViewCache={};this._dayViewCache[a]={h:c,c:b}},_clearViewsCache:function(){this._dayViewCache={}},_invalidateDayView:function(){var b=this.element.find(".wijmo-wijev-headercontainer"),k=this.element.find(".wijmo-wijev-scrollcontent"),s=k.find(".wijmo-wijev-timeruler"),j=b.find(".wijmo-wijev-dayheadercolumn"),p=k.find(".wijmo-wijev-daycolumn"),q=this.element.find(".wijmo-wijev-view .wijmo-wijev-header-title"),o,d,l,c,n,f,h,r=s.outerWidth(),g,e,m,i;this._updateHeaderTitleText();o=q.is(":visible")?q.outerHeight(true):0;this._invalidateView();if(!this._maxAllDayEventCount)this._maxAllDayEventCount=0;c=b.find(".wijmo-wijev-dayheadercolumn .wijmo-wijev-appointment").outerHeight(true);if(!c)c=17;n=b.find(".wijmo-wijev-daylabel").outerHeight(true);f=0;for(g=0;g<j.length;g+=1){h=a(j[g]).find(".wijmo-wijev-allday-cell .wijmo-wijev-appointment").length;if(h>f)f=h}l=c*f+n+c;b.outerHeight(l+Math.round(c/2));b.find(".wijmo-wijev-allday-cell").outerHeight(l);d=this.element.find(".wijmo-wijev-view").innerWidth();e=d-r;e=e-18;m=this.element.find(".wijmo-wijev-view").innerHeight()-b.outerHeight(true)-o;i=Math.floor(e/p.length);b.outerWidth(d);k.outerWidth(d);j.outerWidth(i);p.outerWidth(i);this._invalidateCurrentTimeIndicator();this.element.find(".wijmo-wijev-scrollpanel").outerWidth(d).outerHeight(m).wijsuperpanel("refresh");switch(this.options.viewType.toLowerCase()){case"day":this._updateDayViewDetails();break;case"list":this._updateListViewDetails()}},_updateDayViewDetails:function(){var c=this.options,b=c.selectedDate;if(!this._dayViewDetailsInit){this._dayViewDetailsInit=true;this.element.find(".wijmo-wijev-day-details .wijmo-wijev-daycalendar").wijcalendar({culture:c.culture,showTitle:false,showOtherMonthDays:false,showWeekNumbers:false,selectionMode:{day:true,days:false},selectedDatesChanged:a.proxy(function(b,a){a.dates&&!c.disabled&&this.goToDate(a.dates[0])},this)});this.element.find(".wijmo-wijev-day-details .wijmo-wijev-agenda-container").wijsuperpanel()}this.element.find(".wijmo-wijev-day-details .wijmo-wijev-daycalendar").wijcalendar("option","displayDate",b).wijcalendar("unSelectAll").wijcalendar("selectDate",b);this.element.find(".wijmo-wijev-day-details .wijmo-wijev-daycalendar").wijcalendar("refresh");this.element.find(".wijmo-wijev-day-details .wijmo-wijev-monthday-label").html(b.getDate());this.element.find(".wijmo-wijev-day-details .wijmo-wijev-fulldate-label").html(this._formatString("{0:dddd, MMMM d}",b));this.element.find(".wijmo-wijev-day-details .wijmo-wijev-year-label").html(b.getFullYear());this._loadAgendaList(this.element.find(".wijmo-wijev-day-details  .wijmo-wijev-agenda-container"),b,b,false)},_updateListViewDetails:function(){if(!this._listViewDetailsInit){this._listViewDetailsInit=true;this.element.find(".wijmo-wijev-list-details .wijmo-wijev-agenda-container").wijsuperpanel()}this._loadAgendaList(this.element.find(".wijmo-wijev-list-details  .wijmo-wijev-agenda-container"),null,null,true)},_loadAgendaList:function(h,s,t,p){var k=this._eventsView,f,d,j,r,n=0,l,e="",g="",i=null,m=null,b,q,o=false;if(h.find(".wijmo-wijsuperpanel-templateouterwrapper").length>0){h=h.find(".wijmo-wijsuperpanel-templateouterwrapper");o=true}h.html("");if(s){i=c(s);m=this._addDays(c(t),1);r=(m.getTime()-i.getTime())/864e5}if(k){j=k.length;if(!i){g="";for(d=0;d<j;d+=1){f=k[d];if(d===0||b.getDate()!==f.start.getDate()){b=f.start;if(d!==0){e+='<ul class="wijmo-wijev-agenda-list">'+g+"</ul>";e+="</div>"}e+='<div class="wijmo-wijev-agenda-day-container '+this._dayDateToCssClass(b)+'">';if(p)e+=this._renderAgendaDayHeader(b);g=""}g+=this._renderAgendaAppointmentVisual(f);l+=1;if(d===j-1){e+='<ul class="wijmo-wijev-agenda-list">'+g+"</ul>";e+="</div>"}}}else while(n<r){b=this._addDays(i,n);b=new Date(b.getFullYear(),b.getMonth(),b.getDate());q=new Date(b.getFullYear(),b.getMonth(),b.getDate(),23,59,59);l=0;g="";for(d=0;d<j;d+=1){f=k[d];if(f.start<m&&f.end>i&&f.start<q&&f.start>=b){g+=this._renderAgendaAppointmentVisual(f);l+=1}}if(g!==""){e+='<div class="wijmo-wijev-agenda-day-container '+this._dayDateToCssClass(b)+'">';if(p)e+=this._renderAgendaDayHeader(b);e+='<ul class="wijmo-wijev-agenda-list">'+g+"</ul>";e+="</div>"}n+=1}a(e).appendTo(h)}h.find(".wijmo-wijev-agenda-event").click(a.proxy(this._onAgendaEventClick,this)).hover(function(){a(this).addClass("ui-state-hover")},function(){a(this).removeClass("ui-state-hover").removeClass("ui-state-active")}).mousedown(function(){a(this).addClass("ui-state-active")}).mouseup(function(){a(this).removeClass("ui-state-active")});o&&h.parents(".wijmo-wijsuperpanel").wijsuperpanel("refresh")},_renderAgendaDayHeader:function(a){return'<div class="wijmo-wijev-agenda-header ui-widget-header"><div class="wijmo-wijev-weekday">'+this._formatString("{0:dddd}",a)+'</div><div class="wijmo-wijev-date">'+this._formatString("{0:MMMM d, yyyy}",a)+"</div></div>"},_onAgendaEventClick:function(c){var b=a(c.target);if(!b.hasClass("wijmo-wijev-agenda-event"))b=b.parent(".wijmo-wijev-agenda-event");b.length>0&&this.goToEvent(this._parseEventIdFromClass(b[0].className))},_renderAgendaAppointmentVisual:function(a){return'<li class="wijmo-wijev-agenda-event '+this._dayDateToCssClass(a.start)+" "+this._eventIdToCssClass(a.id)+' ui-state-default ui-helper-clearfix"><div class="wijmo-wijev-agenda-event-color wijmo-wijev-event-color-'+(a.color||"default")+'"><div></div></div><div class="wijmo-wijev-agenda-event-title">'+a.subject+'</div><div class="wijmo-wijev-agenda-event-time">'+(this.isAllDayEvent(a)?"all-day":this._formatString("{0:hh:mm tt} to {1:hh:mm tt}",a.start,a.end))+"</div></li>"},_invalidateCurrentTimeIndicator:function(){var c=this.element.find(".wijmo-wijev-timeruler .wijmo-wijev-currenttime-indicator"),a=new Date,b=this.options;a=a.getMinutes()+a.getHours()*60;c.css("top",a/b.timeInterval*b.timeIntervalHeight)},_onAppointmentsChanged:function(){this._clearViewsCache();this._prepareEventsForView();this._renderActiveView()},_onCalendarsChanged:function(){this._trigger("calendarsChanged",null,{calendars:this.options.calendars})},_renderDayViewAppointments:function(){var o=this._eventsView,d,m,c,v,w,x=this.element.find(".wijmo-wijev-headercontainer"),y=this.element.find(".wijmo-wijev-scrollcontent"),q=x.find(".wijmo-wijev-dayheadercolumn"),h=y.find(".wijmo-wijev-daycolumn"),b,l,i=this.options,f=i.selectedDates,z=f[0],g,p,e,j,k,s,t,n,u,r=[];g=f[f.length-1];g=new Date(g.getFullYear(),g.getMonth(),g.getDate(),23,59,59);if(o)for(c=0,w=f.length;c<w;c+=1)if(!h[c]._cached){b=f[c];b=new Date(b.getFullYear(),b.getMonth(),b.getDate());l=new Date(b.getFullYear(),b.getMonth(),b.getDate(),23,59,59);for(m=0,v=o.length;m<v;m+=1){d=o[m];if(d.start<g&&d.end>z&&d.start<l&&d.end>b)if(this.isAllDayEvent(d)){p=true;e=a(this._getAllDayEventMarkup(d));a(q[c]).find(".wijmo-wijev-allday-cell").append(e)}else{j=d.start;k=d.end;if(j<b)j=b;if(k>l)k=l;s=(j-b)/6e4;t=(k-b)/6e4;n=Math.round(s*i.timeIntervalHeight/i.timeInterval);u=Math.round(t*i.timeIntervalHeight/i.timeInterval);e=a(this._getEventMarkup(d));e.css("top",n);e.outerHeight(u-n);a(h[c]).append(e)}}this._storeDayCache(f[c],q[c],h[c]);h[c]._cached=true;r.push(h[c])}this._dayColumnsToResolve=r;this._dayColumnResolveIdx=0;if(!this._resolveDayApptConflictsTimeout){clearTimeout(this._resolveDayApptConflictsTimeout);this._resolveDayApptConflictsTimeout=null}this._resolveDayApptConflictsTimeout=setTimeout(a.proxy(this._resolveDayViewAppointmentConflictsCb1,this),1);p&&this._invalidateDayView(true);if(this._dayViewScrollToEvent){e=this.element.find(".wijmo-wijev-dayview .wijmo-wijev-daycolumn ."+this._eventIdToCssClass(this._dayViewScrollToEvent.id));e.length>0&&this.element.find(".wijmo-wijev-scrollpanel").wijsuperpanel("scrollChildIntoView",e)}},_getAllDayEventMarkup:function(a){return'<div class="wijmo-wijev-appointment '+this._eventIdToCssClass(a.id)+'"><div class=" wijmo-wijev-colordot wijmo-wijev-event-color-'+(a.color||"default")+'"></div><div class="wijmo-wijev-event-title">'+a.subject+"</div></div>"},_getEventMarkup:function(a){return'<div class="wijmo-wijev-appointment wijmo-wijev-event-color-'+(a.color||"default")+" "+this._eventIdToCssClass(a.id)+'"><div class="wijmo-wijev-content"><div class="wijmo-wijev-title">'+this._formatString(this.options.eventTitleFormat,a.start,a.end,a.subject,a.location,"")+'</div></div><div class="wijmo-wijev-resizer"><div class="ui-icon ui-icon-grip-solid-horizontal">&nbsp;</div></div></div>'},_resolveDayViewAppointmentConflictsCb1:function(){this._resolveDayApptConflictsTimeout=null;if(!this._dayColumnsToResolve||this._dayColumnResolveIdx>=this._dayColumnsToResolve.length)return;this._resolveDayViewAppointmentConflicts(this._dayColumnsToResolve[this._dayColumnResolveIdx]);this._dayColumnResolveIdx=this._dayColumnResolveIdx+1;setTimeout(a.proxy(this._resolveDayViewAppointmentConflictsCb1,this),1)},_resolveDayViewAppointmentConflicts:function(l){var j=a(l).find(".wijmo-wijev-appointment"),f=[],e,b,d,c,h,g,i,k;for(b=0,g=j.length;b<g;b+=1){c=j[b];for(d=0;d<g;d+=1)if(d!==b){h=j[d];if(c.offsetTop<h.offsetTop+h.offsetHeight&&c.offsetTop+c.offsetHeight>h.offsetTop){if(!f[b])f[b]=[c];f[b].push(h)}}}for(b=0,g=f.length;b<g;b+=1){e=f[b];if(e){c=e[0];i=e.length;c.style.width=Math.ceil(100/i)+"%";e.sort(this._sortOffsetTop);for(d=0;d<i;d+=1){c=e[d];k=Math.floor(100*d/i);c.style.marginLeft=k+"%";c.style.zIndex=k}}}},_sortOffsetTop:function(a,b){return a.offsetTop<b.offsetTop?-1:a.offsetTop>b.offsetTop?1:0},_onDayViewTimeIntervalClick:function(a){this.showEditEventDialog(null,a.target,a)},_onDayViewAllDayCellClick:function(c){var b=a(c.target);if(b.hasClass("wijmo-wijev-appointment")||b.parents(".wijmo-wijev-appointment").length>0)return;if(b.hasClass("wijmo-wijev-daylabel")||b.parents(".wijmo-wijev-daylabel").length>0)return;this.showEditEventDialog(null,c.target,c)},_onMonthViewDayLabelClick:function(e){var b=a(e.target).parents(".wijmo-wijev-monthcellcontainer"),c=this.options,d;if(b.length<1)b=a(e.target).parents(".wijmo-wijev-dayheadercolumn");if(b[0]){d=this._parseDateFromClass(b[0].className);if(c.viewType!=="day"){c.viewType="day";this._onViewTypeChanged()}c.selectedDates=[new Date(d)];this._onSelectedDatesChanged()}},_onMonthViewCellClick:function(c){var b=a(c.target).parent(".wijmo-wijev-monthcellcontainer");if(b.length<1)return;this.showEditEventDialog(null,b,c)},_onAppointmentClick:function(d){var b=a(d.target),c;if(this._apptDragResizeFlag)return;if(!b.hasClass("wijmo-wijev-appointment"))b=b.parents(".wijmo-wijev-appointment");if(b.length>0){c=this.findEventById(b[0].className);this.showEditEventDialog(c,b,d)}},findEventById:function(a){var b;if(a){b=a.indexOf("apptid_");if(b!==-1)a=this._parseEventIdFromClass(a);if(this._appointmentsById)return this._appointmentsById[a]}return null},_onMonthViewAppointmentMouseDown:function(c){var b=a(c.target),d=b.hasClass("wijmo-wijev-appointment")?b:b.parents(".wijmo-wijev-appointment");c.preventDefault();this.__targetAppt=d;a(document).bind("mouseup.tmp_wijevcal",a.proxy(this._onMonthViewAppointmentMouseUp,this));this.element.find(".wijmo-wijev-monthview .wijmo-wijev-monthcellcontainer").bind("mouseover.tmp_wijevcal",a.proxy(this._onMonthViewCellMouseOver,this))},_onDayViewAppointmentMouseDown:function(d){var b=a(d.target),c=b.hasClass("wijmo-wijev-appointment")?b:b.parents(".wijmo-wijev-appointment"),e=b.hasClass("wijmo-wijev-resizer")||b.parents(".wijmo-wijev-resizer").length>0;this._isApptResize=e;d.preventDefault();if(this._isApptResize){this.__startApptH=c[0].offsetHeight;this.__startApptY=c[0].offsetTop}else this.__startApptY=c[0].offsetTop;this.__startClientY=d.clientY;this.__targetAppt=c;a(document).bind("mousemove.tmp_wijevcal",a.proxy(this._onDayViewAppointmentMouseMove,this));a(document).bind("mouseup.tmp_wijevcal",a.proxy(this._onDayViewAppointmentMouseUp,this));this.element.find(".wijmo-wijev-dayview .wijmo-wijev-daycolumn").bind("mouseover.tmp_wijevcal",a.proxy(this._onDayViewColumnMouseOver,this));this.element.find(".wijmo-wijev-dayview .wijmo-wijev-allday-cell").bind("mouseover.tmp_wijevcal",a.proxy(this._onDayViewAllDayMouseOver,this))},_onDayViewAppointmentMouseMove:function(d){d.preventDefault();var c=d.clientY-this.__startClientY,b,e=this.options,a;if(!d.ctrlKey)c=Math.round(c/e.timeIntervalHeight)*e.timeIntervalHeight;if(c!==0&&!this._apptDragResizeFlag){this._apptDragResizeFlag=true;this.__targetAppt.addClass("wijmo-wijev-dragging");this.__targetAppt.css("width","100%").css("margin-left","0").css("z-index","1000")}if(this._apptDragResizeFlag){if(this._isApptResize){a=this.__startApptH+c;if(a<0){a=Math.abs(a);b=this.__startApptY-a;if(b>=0){this.__targetAppt.css("height",a);this.__targetAppt.css("top",b)}}else this.__targetAppt.css("height",a)}else{b=this.__startApptY+c;if(b<0)b=0;this.__targetAppt.css("top",b)}this._onApptVisualDargOrResize(this.__targetAppt,this.findEventById(this.__targetAppt[0].className))}},_onDayViewAppointmentMouseUp:function(){this.__targetAppt&&this.__targetAppt.removeClass("wijmo-wijev-dragging");a(document).unbind(".tmp_wijevcal");this.element.find(".wijmo-wijev-dayview .wijmo-wijev-daycolumn").unbind(".tmp_wijevcal");this.element.find(".wijmo-wijev-dayview .wijmo-wijev-allday-cell").unbind(".tmp_wijevcal");this._resolveDayViewAppointmentConflicts(this.__targetAppt.parents(".wijmo-wijev-daycolumn"));if(this._apptDragResizeFlag||this._apptMovedFlag){var b=this.findEventById(this.__targetAppt[0].className);this._onApptVisualDargOrResize(this.__targetAppt,b);this._apptMovedFlag=false;this.updateEvent(b);window.setTimeout(a.proxy(function(){if(this.__targetAppt&&!this.__targetAppt.hasClass("wijmo-wijev-dragging"))this._apptDragResizeFlag=false},this),1)}},_updateAppointmentVisual:function(b){var a=this.element.find(".wijmo-wijev-dayview ."+this._eventIdToCssClass(b.id)),d=this.options,h,i,g,j,e,f,k,l;if(a.length===1){this._addColorClass(a,b.color);a.find(".wijmo-wijev-title").html(this._formatString(d.eventTitleFormat,b.start,b.end,b.subject,b.location,""));e=c(b.start);h=(b.start-e)/6e4;i=(b.end-e)/6e4;g=Math.round(h*d.timeIntervalHeight/d.timeInterval);j=Math.round(i*d.timeIntervalHeight/d.timeInterval);a.css("top",g);a.css("height",j-g);f=this._dayDateToCssClass(e);if(a.parents(".wijmo-wijev-daycolumn."+f).length!==1){k=a[0].parentNode;l=this.element.find(".wijmo-wijev-daycolumn."+f);k.removeChild(a[0]);a.appendTo(l)}}},_onApptVisualDargOrResize:function(b,a){var c=this.options,h=b[0].offsetTop,k=h+b[0].offsetHeight,f,i,g,j,d,e;if(b.parents(".wijmo-wijev-dayheadercolumn").length>0)e=b.parents(".wijmo-wijev-dayheadercolumn")[0];else e=b.parents(".wijmo-wijev-daycolumn")[0];d=this._parseDateFromClass(e.className,null);f=Math.round(h*c.timeInterval/c.timeIntervalHeight);i=Math.round(k*c.timeInterval/c.timeIntervalHeight);g=new Date(f*6e4+d.getTime());j=new Date(i*6e4+d.getTime());if(a){a.allday=b.parents(".wijmo-wijev-dayheadercolumn").length>0;a.start=g;a.end=j;b.find(".wijmo-wijev-title").html(this._formatString(c.eventTitleFormat,a.start,a.end,a.subject,a.location,""))}},_onDayViewColumnMouseOver:function(d){var c=a(d.target).parents(".wijmo-wijev-daycolumn"),b=this.__targetAppt.parents(".wijmo-wijev-daycolumn");if(c.length<1)return;if(b.length<1){b=this.__targetAppt.parents(".wijmo-wijev-dayheadercolumn");if(b.length<1)return;else this.__targetAppt.html(this._getEventMarkup(this.findEventById(this.__targetAppt[0].className),true))}if(c[0].className!==b[0].className){this.__targetAppt[0].parentNode.removeChild(this.__targetAppt[0]);this._resolveDayViewAppointmentConflicts(b);this.__targetAppt.appendTo(c);this._apptMovedFlag=true}},_onMonthViewCellMouseOver:function(e){var c=a(e.target),b=c.hasClass("wijmo-wijev-monthcellcontainer")?c:c.parents(".wijmo-wijev-monthcellcontainer"),d=this.__targetAppt.parents(".wijmo-wijev-monthcellcontainer");if(b.length<1||d.length<1)return;if(b[0].className!==d[0].className){this.__targetAppt[0].parentNode.removeChild(this.__targetAppt[0]);this.__targetAppt.appendTo(b.find(".wijmo-wijev-monthcell"))}},_onMonthViewAppointmentMouseUp:function(){var b,f=this.__targetAppt.parents(".wijmo-wijev-monthcellcontainer")[0],e=this._parseDateFromClass(f.className,null),d;a(document).unbind(".tmp_wijevcal");this.element.find(".wijmo-wijev-monthview .wijmo-wijev-monthcellcontainer").unbind(".tmp_wijevcal");b=this.findEventById(this.__targetAppt[0].className);d=(e.getTime()-c(b.start).getTime())/864e5;b.start=this._addDays(b.start,d);b.end=this._addDays(b.end,d);this.updateEvent(b)},_onDayViewAllDayMouseOver:function(e){var d=a(e.target).parents(".wijmo-wijev-dayheadercolumn"),b=this.__targetAppt.parents(".wijmo-wijev-daycolumn"),c;if(d.length<1)return;if(b.length>0){c=a(this._getAllDayEventMarkup(this.findEventById(this.__targetAppt[0].className)));this.__targetAppt.replaceWith(c);this.__targetAppt=c}else b=this.__targetAppt.parents(".wijmo-wijev-dayheadercolumn");if(b.length<1)return;if(d[0].className!==b[0].className){this.__targetAppt[0].parentNode.removeChild(this.__targetAppt[0]);this._resolveDayViewAppointmentConflicts(b);this.__targetAppt.appendTo(a(d).find(".wijmo-wijev-allday-cell"));this._apptMovedFlag=true}},_renderMonthView:function(){var m=this.options,d=m.selectedDate,t=m.firstDayOfWeek,i=false,j=false,c,g,h,u=new Date,e,p,o=false,f,q=["","","","","","",""],b,l,k=this.element.find(".wijmo-wijev-view.wijmo-wijev-monthview"),n,s=m.dayHeaderFormat,r=m.firstRowDayHeaderFormat;if(!d)d=new Date;g=new Date(d.getFullYear(),d.getMonth(),1);while(g.getDay()!==t)g=this._addDays(g,-1);h=new Date(d.getFullYear(),d.getMonth(),this._daysInMonth(d.getMonth(),d.getFullYear()));c=g;e=0;p=0;while(c<h||e<7){if(c>h)h=c;b="";f="wijmo-wijev-monthcellcontainer ui-widget-content "+this._dayDateToCssClass(c);j=c.getMonth()!==d.getMonth();if(j)f+=" wijmo-wijev-othermonth";if(o)o=false;else{f+=" wijmo-wijev-leftborder";if(e===6)f+=" wijmo-wijev-rightborder"}i=this._compareDayDates(c,u)===0;if(i){f+=" wijmo-wijev-today";f+=" wijmo-wijev-rightborder";o=true}b+='<div class="'+f+'">';b+='<div class="wijmo-wijev-monthcellheader';if(j)b+=" ui-priority-secondary";if(i)b+=" ui-state-highlight";b+='">';if(i)b+='<span class="wijmo-wijev-todaylabel">Today</span>';if(p===0)b+=this._formatString(r,c);else b+=this._formatString(s,c);b+="</div>";b+='<div class="wijmo-wijev-monthcell';if(j)b+=" ui-priority-secondary";if(i)b+=" ui-state-highlight";b+='"></div>';b+="</div>";q[e]=q[e]+b;e+=1;c=this._addDays(c,1);if(e>6){if(c>h)break;e=0;p+=1}}if(k.length===0){k=a('<div class="wijmo-wijev-view wijmo-wijev-monthview ui-widget-content"><h3 class="wijmo-wijev-header-title">title</h3><div class="wijmo-wijev-monthview-inner"></div></div>');k.appendTo(this.element.find(".wijmo-wijev-view-container"))}n=k.find(".wijmo-wijev-monthview-inner");n.find(".wijmo-wijev-monthcolumn").remove();c=g;for(l=0;l<7;l+=1){n.append('<div class="wijmo-wijev-monthcolumn">'+q[l]+"</div>");c=this._addDays(c,1)}this._invalidateMonthView();this._renderMonthViewAppointments()},_invalidateMonthView:function(){var f=this.element.find(".wijmo-wijev-monthview"),c=f.find(".wijmo-wijev-monthview-inner"),b=f.find(".wijmo-wijev-monthcolumn"),i=f.find(".wijmo-wijev-monthcellcontainer"),n=this.element.find(".wijmo-wijev-monthview .wijmo-wijev-header-title"),d,e,g,h,k,m,l,j;this._invalidateView();if(b.length<1)return;d=f.innerWidth();e=f.innerHeight()-n.outerHeight(true);c.outerWidth(d);c.outerHeight(e);d=d-(c.outerWidth(true)-c.innerWidth());e=e-(c.outerHeight(true)-c.innerHeight());g=Math.floor(d/b.length);b.outerWidth(g);j=d-g*b.length;j>0&&a(b[b.length-1]).outerWidth(g+j);l=a(b[0]).find(".wijmo-wijev-weekdayname").outerHeight(true);h=Math.floor((e-l)/a(b[0]).find(".wijmo-wijev-monthcellcontainer").length);i.height(h);k=a(i[0]).find(".wijmo-wijev-monthcellheader").outerHeight(true);m=h-k;i.find(".wijmo-wijev-monthcell").outerHeight(m)},_renderMonthViewAppointments:function(){var h=this._eventsView,b,d,e,i,l,f=this.element.find(".wijmo-wijev-monthcellcontainer"),g,c,k,j;if(h)for(e=0,l=f.length;e<l;e+=1){g=f[e];c=this._parseDateFromClass(g.className);k=new Date(c.getFullYear(),c.getMonth(),c.getDate(),23,59,59);for(d=0,i=h.length;d<i;d+=1){b=h[d];if(b.start<k&&b.end>c){j=a('<div class="wijmo-wijev-appointment '+this._eventIdToCssClass(b.id)+'"><div class=" wijmo-wijev-colordot wijmo-wijev-event-color-'+(b.color||"default")+'"></div><div class="wijmo-wijev-event-title">'+b.subject+"</div></div>");a(g).find(".wijmo-wijev-monthcell").append(j)}}}f.find(".wijmo-wijev-monthcell").each(a.proxy(function(i,h){var b=a(h),e=b.find(".wijmo-wijev-appointment"),f=b.outerHeight(),d=e.outerHeight(),g=e.length*d,c=0;if(g>f){e.each(function(b,a){if(b*d+d>f){a.style.display="none";c+=1}});if(c>0)b.find(".wijmo-wijev-monthcell-showmore").length<1&&b.append(a('<div class="wijmo-wijev-monthcell-showmore">'+c+" more...</div>"))}},this))},log:function(){},_log:function(d,c){var b;if(this.logPanel){b=new Date;this.logPanel.prepend(a('<span class="'+(c?c:"wijmo-wijev-information")+'">['+b.getHours()+":"+b.getMinutes()+":"+b.getSeconds()+"] "+d+"</span><br/>"))}},_createLogPanel:function(){if(!this.logPanel){this.logDialog=a('<div title="Log"><div class="wijmo-wijev-log"></div></div>');this.logDialog.appendTo(this.element);this.logPanel=this.logDialog.wijdialog({captionButtons:{},buttons:{"Clear All":function(){a(this).find(".wijmo-wijev-log").html("")},Close:function(){a(this).wijdialog("close")}},width:600,height:420,position:["right","top"]}).find(".wijmo-wijev-log")}this.logDialog.wijdialog("open")},status:function(b,a){this.element.find(".wijmo-wijev-statusbar").html("<span class='"+(a?a:"wijmo-wijev-status")+"'>"+b+"</span>");this.log(b,a?a:"wijmo-wijev-status")},_invalidateView:function(){var n=this.element.find(".wijmo-wijev-rightpane"),c=this.element.find(".wijmo-wijev-leftpane"),q=c.find(".wijmo-wijev-agenda-container"),p=this.element.find(".wijmo-wijev-headerbar"),k=this.element.find(".wijmo-wijev-navigationbar"),o=this.element.find(".wijmo-wijev-statusbar"),b=this.element.find(".wijmo-wijev-view-container"),s=this.element.find(".wijmo-wijev-view"),l,d,j,g,i,r,h,e,m,f;l=this.element.innerWidth()-(b.outerWidth(true)-b.innerWidth());d=this.element.innerHeight()-(b.outerHeight(true)-b.innerHeight());j=p.is(":visible")?p.outerHeight(true):0;g=k.is(":visible")?k.outerHeight(true):0;i=o.is(":visible")?o.outerHeight(true):0;b.outerWidth(l);b.outerHeight(d-j-g-i);e=0;for(f=0;f<c.length;f+=1)if(a(c[f]).is(":visible"))e+=a(c[f]).outerWidth();m=n.is(":visible")?n.outerWidth():0;r=d-j-g-i;h=l-m-e;s.outerHeight(r);s.outerWidth(h);p.outerWidth(h+e);k.outerWidth(this.element.innerWidth());o.outerWidth(h+e+m);c.outerHeight(d-j-g-i);q.outerHeight(c.innerHeight()-q[0].offsetTop);n.outerHeight(d+100);this.element.find(".wijmo-wijev-datepager").wijdatepager("refresh")},_daysInMonth:function(a,b){var c=new Date(b,a+1,0);return c.getDate()},_addMinutes:function(a,b){return new Date(a.getFullYear(),a.getMonth(),a.getDate(),a.getHours(),a.getMinutes()+b)},_addDays:function(a,b){return new Date(a.getFullYear(),a.getMonth(),a.getDate()+b)},_setTime:function(a,b){a=new Date(a);a.setHours(b.getHours());a.setMinutes(b.getMinutes());a.setSeconds(b.getSeconds());a.setMilliseconds(b.getMilliseconds());return a},_addMonths:function(a,b){return new Date(a.getFullYear(),a.getMonth()+b,a.getDate())},_compareDayDates:function(a,b){a=new Date(a.getFullYear(),a.getMonth(),a.getDate());b=new Date(b.getFullYear(),b.getMonth(),b.getDate());return a<b?-1:a>b?1:0},_dayDateToCssClass:function(a){return"wijmo-wijev-date_"+a.getFullYear()+"_"+a.getMonth()+"_"+a.getDate()},_parseDateFromClass:function(e,d,g){var c,a,b,h=new RegExp("wijmo-wijev-minute-(\\d+)\\s"),f=new RegExp("wijmo-wijev-date_(\\d+_\\d+_\\d+)\\s");if(e){b=f.exec(e+" ")[1].split("_");c=new Date(parseInt(b[0],10),parseInt(b[1],10),parseInt(b[2],10));if(d){a=h.exec(d+" ");if(a){a=parseInt(a[1],10);c.setMinutes(a)}}return c}else return g||null},_eventIdToCssClass:function(a){return"apptid_"+a},_parseEventIdFromClass:function(d){var c="",b,a;b=new RegExp("apptid_(\\S+)");a=b.exec(d);if(a&&a.length>1)c=a[1];return c},_isContainsDayDate:function(b,c){var a;if(b){for(a=0;a<b.length;a+=1)if(this._compareDayDates(b[a],c)===0)return true}else return false},_formatString:function(a){var e,b=arguments,c,d,f=this;if(b.length<=1)return Globalize.format(b);if(typeof a==="string")if(a==="_formatWeekTitle")a=this._formatWeekTitle;else if(typeof window[a]==="function")a=window[a];if(typeof a==="function"){d=[];for(c=1;c<b.length;c+=1)d[c-1]=b[c];return a.apply(this,d)}e=new RegExp("\\{(\\d+)(?:,([-+]?\\d+))?(?:\\:([^(^}]+)(?:\\(((?:\\\\\\)|[^)])+)\\)){0,1}){0,1}\\}","g");return a.replace(e,function(a,d,g,c){a=b[Number(d)+1];return c?Globalize.format(a,c,f._getCulture()):a})},_formatWeekTitle:function(a,b){return a.getMonth()!==b.getMonth()?this._formatString("{0:MMMM} - {1:MMMM yyyy}",a,b):this._formatString("{0:MMMM yyyy}",a)},_formatDayHeaderDate:function(c){var d=this.options,b=d.viewType.toLowerCase(),a=this.options.dayViewHeaderFormat;if(a[b])a=a[b];else if(!a[b])return"";return this._formatString(a,c)},_getCulture:function(a){return Globalize.findClosestCulture(a||this.options.culture)},_isRTL:function(){return!!this._getCulture().isRTL},_onAjaxError:function(d,a,b){if(a){this.status("Ajax error "+a.status+" ("+a.statusText+")","error");this.log("Error, requested url: "+b.url,"error")}else{this.status("Ajax error detected.","error");this.log("Error, requested url: "+b.url,"error")}},_onWindowResize:function(){this.invalidate()}})})(jQuery);
